@@ -30,11 +30,19 @@
  ****************************************************************************/
 /***********************************************************************
  * The rest of it is all my fault -- MLM
+ *
+ * Copyright (C) 1995-2000 LessTif Development Team
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
+/* $Id: mwm.c,v 1.22 2000/12/21 09:53:15 amai Exp $ */
+
 #include "mwm.h"
 
+#include <stdlib.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <string.h>
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -56,17 +64,66 @@
 #ifdef __EMX__
 #include <netdb.h>
 #endif
-
-#include <stdlib.h>
-
-#include <X11/Shell.h>
-#include <Xm/DisplayP.h>
-#include <Xm/ScreenP.h>
-
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
+#include <signal.h>
 #ifdef HAVE_GETRLIMIT
 #include <sys/resource.h>
 #endif
 
+#include <X11/Shell.h>
+#include <X11/Xproto.h>
+
+#include <Xm/XmosP.h>
+#include <Xm/DisplayP.h>
+#include <Xm/ScreenP.h>
+
+#if XmVERSION >= 2
+#include <XmI/XmI.h>
+#endif
+
+#ifndef HAVE_GETHOSTNAME
+/* our fallback implementation (gethostname.c) */
+extern int gethostname (char *name, size_t len);
+#endif
+
+
+static int SetEnvironment(const char *key, const char *value);
+
+#ifdef HAVE_PUTENV
+static int
+SetEnvironment(const char *key, const char *value)
+{
+ char *str;
+ int len, rc;
+ 
+ len=strlen(key)+strlen(value)+2;
+ str=(char *)malloc(len);
+ strcpy(str, key);
+ strcat(str, "=");
+ strcat(str, value);
+ rc=putenv(str);
+ /* do not free 'str' here! */
+ return rc;
+}
+#else
+#ifdef HAVE_SETENV
+static int
+SetEnvironment(const char *key, const char *value)
+{
+ int rc;
+ int overwrite=1;
+
+ rc=setenv(key, value, overwrite);
+ return rc;
+}
+#else
+#error You lose (neither putenv ()  nor setenv() available!)
+#endif /* #ifdef HAVE_SETENV */
+#endif /* #ifdef HAVE_PUTENV */
+
+
 /*
  * application globals
  */
@@ -111,39 +168,29 @@ usage(void)
 /*
  * restart on a signal
  */
-static RETSIGTYPE
+static void
 sig_restart(int sig)
 {
     MWM_Done(1, *g_argv);
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 /*
  * exit on a signal
  */
-static RETSIGTYPE
+static void
 sig_done(int nonsense)
 {
     MWM_Done(0, NULL);
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 /*
  * For auto-raising windows, this routine is called
  */
-static RETSIGTYPE
+static void
 sig_alarm(int nonsense)
 {
     alarmed = True;
     signal(SIGALRM, sig_alarm);
-
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 
@@ -270,7 +317,7 @@ MWM_SetErrorHandler(int which)
  * cleanup and exit mwm
  */
 void
-MWM_Done(int restart, char *command)
+MWM_Done(int restart, const char *command)
 {
     ScreenInfo *scr;
     int i, done, j;
@@ -345,23 +392,23 @@ main(int argc, char **argv)
 
     for (i = 1; i < argc; i++)
     {
-	if (strncasecmp(argv[i], "-debug", 6) == 0)
+	if (strncmp(argv[i], "-debug", 6) == 0)
 	    debugging = True;
-	else if (strncasecmp(argv[i], "-multiscreen", 12) == 0)
+	else if (strncmp(argv[i], "-multiscreen", 12) == 0)
 	{
 	    multiscreen = True;
 	}
-	else if (strncasecmp(argv[i], "-name", 5) == 0)
+	else if (strncmp(argv[i], "-name", 5) == 0)
 	{
 	    if (++i >= argc)
 		usage();
 	    mwm_name = argv[i];
 	}
-	else if (strncasecmp(argv[i], "-version", 8) == 0)
+	else if (strncmp(argv[i], "-version", 8) == 0)
 	{
 	    fprintf(stderr, "Mwm Version %s\n", VERSION);
 	}
-	else if (strncasecmp(argv[i], "-V", 2) == 0)
+	else if (strncmp(argv[i], "-V", 2) == 0)
 	{
 	    verbose = 1;
 	}
@@ -424,7 +471,7 @@ main(int argc, char **argv)
     len = strlen(XDisplayString(dpy));
     display_string = XtMalloc(len + 10);
     sprintf(display_string, "DISPLAY=%s", XDisplayString(dpy));
-    putenv(display_string);
+    SetEnvironment("DISPLAY", XDisplayString(dpy));
 
     /*
      * Add a HOSTDISPLAY environment variable, which is the same as
@@ -437,8 +484,9 @@ main(int argc, char **argv)
 
 	gethostname(client, MAXHOSTNAME);
 	rdisplay_string = XtMalloc(len + 14 + strlen(client));
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client, &display_string[9]);
-	putenv(rdisplay_string);
+	sprintf(rdisplay_string, "%s:%s", client, &display_string[9]);
+
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
     else if (strncmp(display_string, "DISPLAY=unix:", 13) == 0)
     {
@@ -446,17 +494,17 @@ main(int argc, char **argv)
 
 	gethostname(client, MAXHOSTNAME);
 	rdisplay_string = XtMalloc(len + 14 + strlen(client));
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client,
+	sprintf(rdisplay_string, "%s:%s", client,
 		&display_string[13]);
-	putenv(rdisplay_string);
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
     else
     {
 	char *rdisplay_string;
 
 	rdisplay_string = XtMalloc(len + 14);
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s", XDisplayString(dpy));
-	putenv(rdisplay_string);
+	sprintf(rdisplay_string, "%s", XDisplayString(dpy));
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
 
     initialize_mwm();
