@@ -35,6 +35,8 @@
 
 #include "mwm.h"
 
+#include <stdio.h>
+
 static int dragx;		/* all these variables are used */
 static int dragy;		/* in resize operations */
 static int dragWidth;
@@ -78,7 +80,7 @@ display_size(ScreenInfo *scr, MwmWindow *tmp_win, int width, int height,
     dwidth /= tmp_win->hints.width_inc;
     dheight /= tmp_win->hints.height_inc;
 
-    (void)sprintf(str, " %4d x %-4d ", dwidth, dheight);
+    sprintf(str, " %4d x %-4d ", dwidth, dheight);
     offset = (ssw + SIZE_HINDENT * 2 -
 	      XTextWidth(scr->components[MWM_FEEDBACK].font,
 			 str, strlen(str))) / 2;
@@ -433,6 +435,4 @@ RESIZE_EventLoop(ScreenInfo *scr, Window w, MwmWindow *tmp_win,
     XUngrabServer(dpy);
     MISC_Ungrab(scr);
     PAGER_Clear(scr);
-
-    return;
 }
