@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Attribute.h,v 1.2 1997/08/28 02:39:16 miers Exp $
+ * $Id: Attribute.h,v 1.4 2000/12/06 14:18:00 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -36,7 +37,7 @@ typedef struct _AttributeList
 }
 AttributeList;
 
-AttributeList *AttributeListNew();
+AttributeList *AttributeListNew(void);
 ExpressionElement *AttributeListErase(AttributeList *, ExpressionElement *);
 void AttributeListAppend(AttributeList *this, ExpressionElement *expr);
 void AttributeListAppendLists(AttributeList *this, AttributeList *list);
