@@ -13,11 +13,7 @@
 
 #include "mwm.h"
 
-#if XmVERSION >= 2
-#include <Xm/Xpm.h>
-#else
-#include <XmI/XmXpm.h>
-#endif
+#include <stdio.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -27,6 +23,15 @@
 #include <fcntl.h>
 #endif
 
+#include <X11/extensions/shape.h>
+
+#if XmVERSION >= 2
+#include <Xm/XpmP.h>
+#else
+#include <XmI/XmXpm.h>
+#endif
+
+
 #define def_bitmap_width 50
 #define def_bitmap_height 50
 static unsigned char def_bitmap_bits[] =
@@ -138,7 +143,7 @@ find_icon_file(char *icon, char *pathlist, int type)
 	    pathlist = dir_end + 1;
     }
     /* Hmm, couldn't find the file.  Return NULL */
-    free(path);
+    XtFree(path);
     return NULL;
 }
 
@@ -220,7 +225,7 @@ get_bitmap_file(ScreenInfo *scr, MwmWindow *tmp_win)
 	tmp_win->icon_p_height = 0;
     }
 
-    free(path);
+    XtFree(path);
 }
 
 /*
@@ -297,7 +302,7 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     }
 #endif
 
-    free(path);
+    XtFree(path);
 }
 
 /*
