@@ -25,7 +25,7 @@
 /**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
 /*****************************************************************************/
 /****************************************************************************
- * This module is based on Twm, but has been siginificantly modified 
+ * This module is based on Twm, but has been significantly modified 
  * by Rob Nation 
  ****************************************************************************/
 /***********************************************************************
@@ -35,6 +35,8 @@
 
 #include "mwm.h"
 
+#include <stdio.h>
+#include <ctype.h>
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -44,7 +46,9 @@
 #include <time.h>
 #endif
 #endif
-#include <X11/Xfuncs.h>
+
+#include <X11/keysym.h>
+
 
 static int menu_on = 0;
 static MenuRoot *ActiveMenu = NULL;	/* the active menu */
@@ -729,7 +733,7 @@ MENU_Remove(ScreenInfo *scr, MenuRoot * menu)
 	if (menu == scr->popups[i])
 	{
 	    if (scr->num_popups != (i + 1))
-		bcopy(&scr->popups[i + 1], &scr->popups[i],
+		memmove(&scr->popups[i], &scr->popups[i + 1], 
 		      (scr->num_popups - i - 1) * sizeof(MenuRoot *));
 	    scr->num_popups--;
 	}
@@ -786,7 +790,12 @@ MENU_AddItem(ScreenInfo *scr, MenuRoot * menu, char *item, char *item2,
 	if (action != (char *)0)
 	{
 	    for (i = 0; i < scr->num_popups; i++)
+#if 0
+  /* amai: it seems we don't ever use this catch!?! */
 		if (strcasecmp(scr->popups[i]->name, action) == 0)
+#else
+		if (strcmp(scr->popups[i]->name, action) == 0)
+#endif
 		{
 		    tmp->menu = scr->popups[i];
 		    break;
@@ -1273,14 +1282,14 @@ MENU_BuildWindowMenu(ScreenInfo *scr, MwmWindow *win)
     else
     {
 	mr = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
-	bcopy(def, mr, sizeof(MenuRoot));
+	memcpy(mr, def, sizeof(MenuRoot));
 	mr->first = mr->last = NULL;
     }
 
     for (mi = def->last; mi != NULL; mi = mi->prev)
     {
 	tmp = (MenuItem *)XtMalloc(sizeof(MenuItem));
-	bcopy(mi, tmp, sizeof(MenuItem));
+	memcpy(tmp, mi, sizeof(MenuItem));
 	if (mr->first == NULL)
 	{
 	    mr->first = tmp;
