@@ -35,6 +35,7 @@
 
 #include "mwm.h"
 
+#include <stdio.h>
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -47,6 +48,17 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
+
+#include <X11/keysym.h>
+
+#include <Xm/XmosP.h>
+#if XmVERSION >= 2
+#include <XmI/XmI.h>
+#endif
+
 
 static Time lastTimestamp = CurrentTime;
 
@@ -215,27 +227,10 @@ window_in_subtree(MwmWindow *win, MwmWindow *sub)
     return False;
 }
 
-/*
- * Sleep for n microseconds
- */
-void
-MISC_usleep(int n)
-{
-    struct timeval value;
-
-    if (n <= 0)
-	return;
-
-    value.tv_usec = n % 1000000;
-    value.tv_sec = n / 1000000;
-
-    (void)select(1, 0, 0, 0, &value);
-}
-
 /*
  * Removes expose events for a specific window from the queue 
  */
-int
+extern int
 MISC_FlushExpose(Window w)
 {
     XEvent dummy;
@@ -249,7 +244,7 @@ MISC_FlushExpose(Window w)
 /*
  * Start/Stops the auto-raise timer
  */
-void
+extern void
 MISC_SetTimer(int delay)
 {
 #ifdef HAVE_SETITIMER
@@ -266,7 +261,7 @@ MISC_SetTimer(int delay)
 /*
  * Records the time of the last processed event. Used in XSetInputFocus
  */
-Boolean
+extern Boolean
 MISC_StashEventTime(XEvent *ev)
 {
     Time NewTimestamp = CurrentTime;
@@ -311,7 +306,7 @@ MISC_StashEventTime(XEvent *ev)
 /*
  * fetch the last saved time
  */
-Time
+extern Time
 MISC_FetchEventTime()
 {
     return lastTimestamp;
@@ -322,7 +317,7 @@ MISC_FetchEventTime()
  * Cleare the CIRCULATED field of the window flags.
  * 
  *****************************************************************************/
-void
+extern void
 MISC_SetFocusSequence(ScreenInfo *scr)
 {
     MwmWindow *temp;
@@ -341,7 +336,7 @@ MISC_SetFocusSequence(ScreenInfo *scr)
  * Grab the pointer and keyboard
  *
  ****************************************************************************/
-Boolean
+extern Boolean
 MISC_Grab(ScreenInfo *scr, int cursor)
 {
     int i = 0, val = 0;
@@ -366,7 +361,7 @@ MISC_Grab(ScreenInfo *scr, int cursor)
 
 	/* If you go too fast, other windows may not get a change to release
 	 * any grab that they have. */
-	MISC_usleep(1000);
+	_XmMicroSleep(1000);
     }
 
     /* If we fall out of the loop without grabbing the pointer, its
@@ -385,7 +380,7 @@ MISC_Grab(ScreenInfo *scr, int cursor)
  * UnGrab the pointer and keyboard
  *
  ****************************************************************************/
-void
+extern void
 MISC_Ungrab(ScreenInfo *scr)
 {
     Window w;
@@ -414,7 +409,7 @@ MISC_Ungrab(ScreenInfo *scr)
  * 
  * Discard superflous button events during this wait period.
  */
-void
+extern void
 MISC_WaitForButtonsUp(ScreenInfo *scr)
 {
     Bool AllUp = False;
@@ -446,7 +441,7 @@ MISC_WaitForButtonsUp(ScreenInfo *scr)
  * For menus, move, and resize operations, we can effect keyboard 
  * shortcuts by warping the pointer.
  */
-void
+extern void
 MISC_KeyboardShortcut(ScreenInfo *scr, XEvent *event, int ReturnEvent)
 {
     int x, y, x_root, y_root;
@@ -515,7 +510,7 @@ MISC_KeyboardShortcut(ScreenInfo *scr, XEvent *event, int ReturnEvent)
 /*
  * find the root of a window tree
  */
-MwmWindow *
+extern MwmWindow *
 MISC_RootOfTree(MwmWindow *win)
 {
     MwmWindow *anc;
@@ -533,7 +528,7 @@ MISC_RootOfTree(MwmWindow *win)
 /*
  * print the window tree
  */
-void
+extern void
 MISC_PrintTree(ScreenInfo *scr)
 {
     print_window_tree(scr->mwm_root.next, 0);
@@ -542,7 +537,7 @@ MISC_PrintTree(ScreenInfo *scr)
 /*
  * add a window to the window tree
  */
-void
+extern void
 MISC_AddToTree(ScreenInfo *scr, MwmWindow *win)
 {
     MwmWindow *tmp;
@@ -577,7 +572,7 @@ MISC_AddToTree(ScreenInfo *scr, MwmWindow *win)
 /*
  * remove a window from the window tree
  */
-void
+extern void
 MISC_RemoveFromTree(ScreenInfo *scr, MwmWindow *win)
 {
     if (win->ancestor != NULL)
@@ -597,7 +592,7 @@ MISC_RemoveFromTree(ScreenInfo *scr, MwmWindow *win)
  * after starting, fix up the transients whose parent windows weren't
  * captured yet
  */
-void
+extern void
 MISC_FixupTransients(ScreenInfo *scr)
 {
     MwmWindow *tmp, *ptr;
@@ -627,7 +622,7 @@ MISC_FixupTransients(ScreenInfo *scr)
     }
 }
 
-void
+extern void
 MISC_DestroyChildren(ScreenInfo *scr, MwmWindow *win)
 {
     MwmWindow *child, *tmp;
@@ -639,142 +634,8 @@ MISC_DestroyChildren(ScreenInfo *scr, MwmWindow *win)
     }
 }
 
-#if BUILD_FOR_MOTIF
-struct _XmFontListRec {
-    char *tag;
-    XmFontType type;
-    XtPointer font;
-};
-
-XmFontList
-_XmFontListCreateDefault(Display *d)
-{
-    struct _XmFontListRec defaultEntry;
-    XmFontList defaultList;
-    XFontStruct *fs = XLoadQueryFont(d, XmDEFAULT_FONT);
- 
-    defaultEntry.tag = XmFONTLIST_DEFAULT_TAG;
-    defaultEntry.type = XmFONT_IS_FONT;
-    defaultEntry.font = (XtPointer)fs;
- 
-    defaultList = XmFontListAppendEntry(NULL, &defaultEntry);
- 
-    return defaultList;
-}
-
-#define FLOOR(x) ((int)((x) - 0.5) > (x) ? (x) : (x)-1)
- 
-/* Convert between RGB and HSV */
-void
-__XmRGB2HSV(unsigned short r,
-            unsigned short g,
-            unsigned short b,
-            double *hr,
-            double *sr,
-            double *vr)
-{
-    double rd, gd, bd, max, min, del;
-    double rc, gc, bc;
-    double v, h, s;
- 
-    /* convert RGB to HSV */
-    rd = r / 65535.0;           /* rd,gd,bd range 0-1 instead of 0-65535 */
-    gd = g / 65535.0;
-    bd = b / 65535.0;
- 
-    /* compute maximum of rd,gd,bd */
-    if (rd >= gd)
-    {
-        if (rd >= bd)
-        {
-            max = rd;
-        }
-        else
-        {
-            max = bd;
-        }
-    }
-    else
-    {
-        if (gd >= bd)
-        {
-            max = gd;
-        }
-        else
-        {
-            max = bd;
-        }
-    }
- 
-    /* compute minimum of rd,gd,bd */
-    if (rd <= gd)
-    {
-        if (rd <= bd)
-        {
-            min = rd;
-        }
-        else
-        {
-            min = bd;
-        }
-    }
-    else
-    {
-        if (gd <= bd)
-        {
-            min = gd;
-        }
-        else
-        {
-            min = bd;
-        }
-    }
- 
- 
-    del = max - min;
-    v = max;
-    if (max != 0.0)
-    {
-        s = (del) / max;
-    }
-    else
-    {
-        s = 0.0;
-    }
- 
-    h = -1;
-    if (s != 0.0)
-    {
-        rc = (max - rd) / del;
-        gc = (max - gd) / del;
-        bc = (max - bd) / del;
- 
-        if (rd == max)
-        {
-            h = bc - gc;
-        }
-        else if (gd == max)
-        {
-            h = 2 + rc - bc;
-        }
-        else if (bd == max)
-        {
-            h = 4 + gc - rc;
-        }
- 
-        h = h * 60;
-        if (h < 0)
-            h += 360;
-    }
- 
-    *hr = h;
-    *sr = s;
-    *vr = v;
-}
-#endif
-
 /* Debugging purposes only */
-char *
+extern const char *
 _MwmPrintF(int x)
 {
 	switch(x) {
@@ -827,10 +688,10 @@ _MwmPrintF(int x)
 	}
 }
 
-char *
+extern const char *
 _MwmPrintC(int x)
 {
-	static char	res[256];
+	static char res[256];
 
 	res[0] = 0;
 	if (x == C_NO_CONTEXT)
