@@ -100,7 +100,7 @@
 
 /**
  *
- * $Id: mwmparse.y,v 1.23 2000/04/29 17:13:52 amai Exp $
+ * $Id: mwmparse.y,v 1.24 2000/09/21 16:04:37 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -123,7 +123,6 @@
  **/
 #include "mwm.h"
 
-#include <ctype.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #ifdef HAVE_FCNTL_H
@@ -139,11 +138,6 @@
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 #include <X11/Xfuncs.h>
 #ifdef __EMX__
 #include <X11/Xlibint.h>    /* for __XOS2RedirRoot() */
@@ -173,7 +167,7 @@ extern int	verbose;
 static int lineno;
 
 
-#line 232 "mwmparse.y"
+#line 226 "mwmparse.y"
 typedef union {
     char	*string;
     int		number;
@@ -308,20 +302,20 @@ static const short yyrhs[] = {   102,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   258,   259,   262,   263,   264,   267,   286,   289,   290,   296,
-   299,   405,   424,   427,   428,   434,   437,   489,   494,   500,
-   501,   507,   510,   612,   614,   618,   620,   624,   626,   628,
-   630,   632,   634,   636,   638,   640,   642,   644,   648,   653,
-   660,   665,   672,   674,   678,   680,   682,   684,   686,   688,
-   690,   692,   694,   698,   704,   710,   716,   722,   728,   734,
-   740,   746,   752,   758,   764,   770,   776,   782,   788,   794,
-   800,   806,   812,   818,   827,   829,   831,   839,   843,   853,
-   857,   862,   867,   872,   877,   882,   887,   892,   897,   902,
-   907,   912,   917,   922,   927,   932,   937,   942,   947,   952,
-   957,   962,   967,   972,   977,   982,   987,   992,   997,  1002,
-  1007,  1012,  1017,  1022,  1027,  1032,  1037,  1042,  1047,  1055,
-  1057,  1061,  1063,  1065,  1067,  1069,  1071,  1073,  1075,  1077,
-  1079,  1082
+   252,   253,   256,   257,   258,   261,   280,   283,   284,   290,
+   293,   399,   418,   421,   422,   428,   431,   483,   488,   494,
+   495,   501,   504,   606,   608,   612,   614,   618,   620,   622,
+   624,   626,   628,   630,   632,   634,   636,   638,   642,   647,
+   654,   659,   666,   668,   672,   674,   676,   678,   680,   682,
+   684,   686,   688,   692,   698,   704,   710,   716,   722,   728,
+   734,   740,   746,   752,   758,   764,   770,   776,   782,   788,
+   794,   800,   806,   812,   821,   823,   825,   833,   837,   847,
+   851,   856,   861,   866,   871,   876,   881,   886,   891,   896,
+   901,   906,   911,   916,   921,   926,   931,   936,   941,   946,
+   951,   956,   961,   966,   971,   976,   981,   986,   991,   996,
+  1001,  1006,  1011,  1016,  1021,  1026,  1031,  1036,  1041,  1049,
+  1051,  1055,  1057,  1059,  1061,  1063,  1065,  1067,  1069,  1071,
+  1073,  1076
 };
 #endif
 
@@ -530,7 +524,7 @@ static const short yycheck[] = {     3,
     22,    23,    24,    25,    26
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/share/misc/bison.simple"
+#line 3 "/usr/share/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -679,9 +673,13 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #define YYMAXDEPTH 10000
 #endif
 
+#ifndef YYPARSE_RETURN_TYPE
+#define YYPARSE_RETURN_TYPE int
+#endif
+
 /* Prevent warning if -Wstrict-prototypes.  */
 #ifdef __GNUC__
-int yyparse (void);
+YYPARSE_RETURN_TYPE yyparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
@@ -723,7 +721,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/share/misc/bison.simple"
+#line 196 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -744,7 +742,7 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
-int
+YYPARSE_RETURN_TYPE
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
@@ -1028,7 +1026,7 @@ yyreduce:
   switch (yyn) {
 
 case 6:
-#line 268 "mwmparse.y"
+#line 262 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (button_bind_found == False) {
@@ -1049,7 +1047,7 @@ case 6:
 			;
     break;}
 case 9:
-#line 291 "mwmparse.y"
+#line 285 "mwmparse.y"
 {
 			    yyerror("Invalid button binding");
 			    yyerrok;
@@ -1057,7 +1055,7 @@ case 9:
 			;
     break;}
 case 11:
-#line 300 "mwmparse.y"
+#line 294 "mwmparse.y"
 {
 			    int contexts = yyvsp[-1].number;
 			    int mods, func;
@@ -1163,7 +1161,7 @@ case 11:
 			;
     break;}
 case 12:
-#line 406 "mwmparse.y"
+#line 400 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (key_bind_found == False) {
@@ -1184,7 +1182,7 @@ case 12:
 			;
     break;}
 case 15:
-#line 429 "mwmparse.y"
+#line 423 "mwmparse.y"
 {
 			    yyerror("Invalid key binding");
 			    yyerrok;
@@ -1192,7 +1190,7 @@ case 15:
 			;
     break;}
 case 17:
-#line 438 "mwmparse.y"
+#line 432 "mwmparse.y"
 {
 			    FuncKey        *tmp = NULL;
 			    KeySym          keysym;
@@ -1244,20 +1242,20 @@ case 17:
 			;
     break;}
 case 18:
-#line 490 "mwmparse.y"
+#line 484 "mwmparse.y"
 {
 			    num_items = 0;
 			    cur_menu = MENU_Create(yyvsp[0].string);
 			;
     break;}
 case 19:
-#line 495 "mwmparse.y"
+#line 489 "mwmparse.y"
 {
 			    MENU_Add(pscr, cur_menu);
 			;
     break;}
 case 21:
-#line 502 "mwmparse.y"
+#line 496 "mwmparse.y"
 {
 			    yyerror("Invalid menu item");
 			    yyerrok;
@@ -1265,7 +1263,7 @@ case 21:
 			;
     break;}
 case 23:
-#line 511 "mwmparse.y"
+#line 505 "mwmparse.y"
 {
 			    MenuItem *tmp;
 			    int width, width2;
@@ -1367,139 +1365,139 @@ case 23:
 			;
     break;}
 case 24:
-#line 613 "mwmparse.y"
+#line 607 "mwmparse.y"
 { yyval.hotkey = yyvsp[0].hotkey; ;
     break;}
 case 25:
-#line 615 "mwmparse.y"
+#line 609 "mwmparse.y"
 { yyval.hotkey.modifiers = 0; yyval.hotkey.key = 0; ;
     break;}
 case 26:
-#line 619 "mwmparse.y"
+#line 613 "mwmparse.y"
 { yyval.number = yyvsp[-2].number | yyvsp[0].number; ;
     break;}
 case 27:
-#line 621 "mwmparse.y"
+#line 615 "mwmparse.y"
 { yyval.number = yyvsp[0].number; ;
     break;}
 case 28:
-#line 625 "mwmparse.y"
+#line 619 "mwmparse.y"
 { yyval.number = C_ROOT; ;
     break;}
 case 29:
-#line 627 "mwmparse.y"
+#line 621 "mwmparse.y"
 { yyval.number = C_ICON; ;
     break;}
 case 30:
-#line 629 "mwmparse.y"
+#line 623 "mwmparse.y"
 { yyval.number = C_MENUB; ;
     break;}
 case 31:
-#line 631 "mwmparse.y"
+#line 625 "mwmparse.y"
 { yyval.number = C_MINIMIZEB; ;
     break;}
 case 32:
-#line 633 "mwmparse.y"
+#line 627 "mwmparse.y"
 { yyval.number = C_MAXIMIZEB; ;
     break;}
 case 33:
-#line 635 "mwmparse.y"
+#line 629 "mwmparse.y"
 { yyval.number = C_WINDOW|C_FRAME|C_TITLE|C_LALL|C_RALL|C_ICON; ;
     break;}
 case 34:
-#line 637 "mwmparse.y"
+#line 631 "mwmparse.y"
 { yyval.number = C_TITLE; ;
     break;}
 case 35:
-#line 639 "mwmparse.y"
+#line 633 "mwmparse.y"
 { yyval.number = C_FRAME|C_TITLE|C_LALL|C_RALL; ;
     break;}
 case 36:
-#line 641 "mwmparse.y"
+#line 635 "mwmparse.y"
 { yyval.number = C_FRAME; ;
     break;}
 case 37:
-#line 643 "mwmparse.y"
+#line 637 "mwmparse.y"
 { yyval.number = C_WINDOW; ;
     break;}
 case 38:
-#line 645 "mwmparse.y"
+#line 639 "mwmparse.y"
 { yyerror("Invalid context"); yyval.number = 0; ;
     break;}
 case 39:
-#line 649 "mwmparse.y"
+#line 643 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = yyvsp[-3].modifiers;
 			;
     break;}
 case 40:
-#line 654 "mwmparse.y"
+#line 648 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = 0;
 			;
     break;}
 case 41:
-#line 661 "mwmparse.y"
+#line 655 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = yyvsp[-4].modifiers;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 42:
-#line 666 "mwmparse.y"
+#line 660 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = 0;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 43:
-#line 673 "mwmparse.y"
+#line 667 "mwmparse.y"
 { yyval.modifiers = yyvsp[-1].modifiers | yyvsp[0].modifiers; ;
     break;}
 case 44:
-#line 675 "mwmparse.y"
+#line 669 "mwmparse.y"
 { yyval.modifiers = yyvsp[0].modifiers; ;
     break;}
 case 45:
-#line 679 "mwmparse.y"
+#line 673 "mwmparse.y"
 { yyval.modifiers = ControlMask; ;
     break;}
 case 46:
-#line 681 "mwmparse.y"
+#line 675 "mwmparse.y"
 { yyval.modifiers = ShiftMask; ;
     break;}
 case 47:
-#line 683 "mwmparse.y"
+#line 677 "mwmparse.y"
 { yyval.modifiers = pscr->alt_mask; ;
     break;}
 case 48:
-#line 685 "mwmparse.y"
+#line 679 "mwmparse.y"
 { yyval.modifiers = LockMask; ;
     break;}
 case 49:
-#line 687 "mwmparse.y"
+#line 681 "mwmparse.y"
 { yyval.modifiers = Mod1Mask; ;
     break;}
 case 50:
-#line 689 "mwmparse.y"
+#line 683 "mwmparse.y"
 { yyval.modifiers = Mod2Mask; ;
     break;}
 case 51:
-#line 691 "mwmparse.y"
+#line 685 "mwmparse.y"
 { yyval.modifiers = Mod3Mask; ;
     break;}
 case 52:
-#line 693 "mwmparse.y"
+#line 687 "mwmparse.y"
 { yyval.modifiers = Mod4Mask; ;
     break;}
 case 53:
-#line 695 "mwmparse.y"
+#line 689 "mwmparse.y"
 { yyval.modifiers = Mod5Mask; ;
     break;}
 case 54:
-#line 699 "mwmparse.y"
+#line 693 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1507,7 +1505,7 @@ case 54:
 			;
     break;}
 case 55:
-#line 705 "mwmparse.y"
+#line 699 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1515,7 +1513,7 @@ case 55:
 			;
     break;}
 case 56:
-#line 711 "mwmparse.y"
+#line 705 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1523,7 +1521,7 @@ case 56:
 			;
     break;}
 case 57:
-#line 717 "mwmparse.y"
+#line 711 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1531,7 +1529,7 @@ case 57:
 			;
     break;}
 case 58:
-#line 723 "mwmparse.y"
+#line 717 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1539,7 +1537,7 @@ case 58:
 			;
     break;}
 case 59:
-#line 729 "mwmparse.y"
+#line 723 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1547,7 +1545,7 @@ case 59:
 			;
     break;}
 case 60:
-#line 735 "mwmparse.y"
+#line 729 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1555,7 +1553,7 @@ case 60:
 			;
     break;}
 case 61:
-#line 741 "mwmparse.y"
+#line 735 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1563,7 +1561,7 @@ case 61:
 			;
     break;}
 case 62:
-#line 747 "mwmparse.y"
+#line 741 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1571,7 +1569,7 @@ case 62:
 			;
     break;}
 case 63:
-#line 753 "mwmparse.y"
+#line 747 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1579,7 +1577,7 @@ case 63:
 			;
     break;}
 case 64:
-#line 759 "mwmparse.y"
+#line 753 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1587,7 +1585,7 @@ case 64:
 			;
     break;}
 case 65:
-#line 765 "mwmparse.y"
+#line 759 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1595,7 +1593,7 @@ case 65:
 			;
     break;}
 case 66:
-#line 771 "mwmparse.y"
+#line 765 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1603,7 +1601,7 @@ case 66:
 			;
     break;}
 case 67:
-#line 777 "mwmparse.y"
+#line 771 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1611,7 +1609,7 @@ case 67:
 			;
     break;}
 case 68:
-#line 783 "mwmparse.y"
+#line 777 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1619,7 +1617,7 @@ case 68:
 			;
     break;}
 case 69:
-#line 789 "mwmparse.y"
+#line 783 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1627,7 +1625,7 @@ case 69:
 			;
     break;}
 case 70:
-#line 795 "mwmparse.y"
+#line 789 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1635,7 +1633,7 @@ case 70:
 			;
     break;}
 case 71:
-#line 801 "mwmparse.y"
+#line 795 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1643,7 +1641,7 @@ case 71:
 			;
     break;}
 case 72:
-#line 807 "mwmparse.y"
+#line 801 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1651,7 +1649,7 @@ case 72:
 			;
     break;}
 case 73:
-#line 813 "mwmparse.y"
+#line 807 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1659,7 +1657,7 @@ case 73:
 			;
     break;}
 case 74:
-#line 819 "mwmparse.y"
+#line 813 "mwmparse.y"
 {
 			    yyerror("Invalid button event name");
 			    yyval.button.button = 0;
@@ -1668,15 +1666,15 @@ case 74:
 			;
     break;}
 case 75:
-#line 828 "mwmparse.y"
+#line 822 "mwmparse.y"
 { yyval.label.type = IS_STRING; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 76:
-#line 830 "mwmparse.y"
+#line 824 "mwmparse.y"
 { yyval.label.type = IS_BITMAP; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 77:
-#line 832 "mwmparse.y"
+#line 826 "mwmparse.y"
 {
 			    yyerror("Invalid label");
 			    yyval.label.type = IS_STRING;
@@ -1684,11 +1682,11 @@ case 77:
 			;
     break;}
 case 78:
-#line 840 "mwmparse.y"
+#line 834 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 79:
-#line 844 "mwmparse.y"
+#line 838 "mwmparse.y"
 {
 			    if (strlen(yyvsp[0].string) != 1) {
 				yyerror("Invalid mnemonic specification");
@@ -1700,277 +1698,277 @@ case 79:
 			;
     break;}
 case 80:
-#line 854 "mwmparse.y"
+#line 848 "mwmparse.y"
 { yyval.key = 0; ;
     break;}
 case 81:
-#line 858 "mwmparse.y"
+#line 852 "mwmparse.y"
 {
 			    yyval.function.func = F_BEEP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 82:
-#line 863 "mwmparse.y"
+#line 857 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_DOWN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 83:
-#line 868 "mwmparse.y"
+#line 862 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_UP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 84:
-#line 873 "mwmparse.y"
+#line 867 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 85:
-#line 878 "mwmparse.y"
+#line 872 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 86:
-#line 883 "mwmparse.y"
+#line 877 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_COLOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 87:
-#line 888 "mwmparse.y"
+#line 882 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_KEY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 88:
-#line 893 "mwmparse.y"
+#line 887 "mwmparse.y"
 {
 			    yyval.function.func = F_CLOSE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 89:
-#line 898 "mwmparse.y"
+#line 892 "mwmparse.y"
 {
 			    yyval.function.func = F_LOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 90:
-#line 903 "mwmparse.y"
+#line 897 "mwmparse.y"
 {
 			    yyval.function.func = F_MAXIMIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 91:
-#line 908 "mwmparse.y"
+#line 902 "mwmparse.y"
 {
 			    yyval.function.func = F_POPUP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 92:
-#line 913 "mwmparse.y"
+#line 907 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 93:
-#line 918 "mwmparse.y"
+#line 912 "mwmparse.y"
 {
 			    yyval.function.func = F_MOVE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 94:
-#line 923 "mwmparse.y"
+#line 917 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 95:
-#line 928 "mwmparse.y"
+#line 922 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 96:
-#line 933 "mwmparse.y"
+#line 927 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 97:
-#line 938 "mwmparse.y"
+#line 932 "mwmparse.y"
 {
 			    yyval.function.func = F_NORMALIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 98:
-#line 943 "mwmparse.y"
+#line 937 "mwmparse.y"
 {
 			    yyval.function.func = F_NORM_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 99:
-#line 948 "mwmparse.y"
+#line 942 "mwmparse.y"
 {
 			    yyval.function.func = F_PACK_ICONS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 100:
-#line 953 "mwmparse.y"
+#line 947 "mwmparse.y"
 {
 			    yyval.function.func = F_PASS_KEYS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 101:
-#line 958 "mwmparse.y"
+#line 952 "mwmparse.y"
 {
 			    yyval.function.func = F_W_POPUP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 102:
-#line 963 "mwmparse.y"
+#line 957 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 103:
-#line 968 "mwmparse.y"
+#line 962 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 104:
-#line 973 "mwmparse.y"
+#line 967 "mwmparse.y"
 {
 			    yyval.function.func = F_QUIT;
 			    yyval.function.arg = "";
 			;
     break;}
 case 105:
-#line 978 "mwmparse.y"
+#line 972 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISE;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 106:
-#line 983 "mwmparse.y"
+#line 977 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISELOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 107:
-#line 988 "mwmparse.y"
+#line 982 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH;
 			    yyval.function.arg = "";
 			;
     break;}
 case 108:
-#line 993 "mwmparse.y"
+#line 987 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH_WIN;
 			    yyval.function.arg = "";
 			;
     break;}
 case 109:
-#line 998 "mwmparse.y"
+#line 992 "mwmparse.y"
 {
 			    yyval.function.func = F_RESIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 110:
-#line 1003 "mwmparse.y"
+#line 997 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 111:
-#line 1008 "mwmparse.y"
+#line 1002 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTORE_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 112:
-#line 1013 "mwmparse.y"
+#line 1007 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTART;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 113:
-#line 1018 "mwmparse.y"
+#line 1012 "mwmparse.y"
 {
 			    yyval.function.func = F_SCREEN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 114:
-#line 1023 "mwmparse.y"
+#line 1017 "mwmparse.y"
 {
 			    yyval.function.func = F_SEND_MSG;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 115:
-#line 1028 "mwmparse.y"
+#line 1022 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 116:
-#line 1033 "mwmparse.y"
+#line 1027 "mwmparse.y"
 {
 			    yyval.function.func = F_SET_BEHAVIOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 117:
-#line 1038 "mwmparse.y"
+#line 1032 "mwmparse.y"
 {
 			    yyval.function.func = F_TITLE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 118:
-#line 1043 "mwmparse.y"
+#line 1037 "mwmparse.y"
 {
 			    yyval.function.func = F_WINDOWLIST;
 			    yyval.function.arg = "";
 			;
     break;}
 case 119:
-#line 1048 "mwmparse.y"
+#line 1042 "mwmparse.y"
 {
 			    yyerror("Invalid mnemonic, accelerator, or function");
 			    yyval.function.func = F_NOP;
@@ -1978,60 +1976,60 @@ case 119:
 			;
     break;}
 case 120:
-#line 1056 "mwmparse.y"
+#line 1050 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 121:
-#line 1058 "mwmparse.y"
+#line 1052 "mwmparse.y"
 { yyval.string = ""; ;
     break;}
 case 122:
-#line 1062 "mwmparse.y"
+#line 1056 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 123:
-#line 1064 "mwmparse.y"
+#line 1058 "mwmparse.y"
 { yyval.string = "ROOT"; ;
     break;}
 case 124:
-#line 1066 "mwmparse.y"
+#line 1060 "mwmparse.y"
 { yyval.string = "WINDOW"; ;
     break;}
 case 125:
-#line 1068 "mwmparse.y"
+#line 1062 "mwmparse.y"
 { yyval.string = "TRANSIENT"; ;
     break;}
 case 126:
-#line 1070 "mwmparse.y"
+#line 1064 "mwmparse.y"
 { yyval.string = "ICON"; ;
     break;}
 case 127:
-#line 1072 "mwmparse.y"
+#line 1066 "mwmparse.y"
 { yyval.string = "WITHIN"; ;
     break;}
 case 128:
-#line 1074 "mwmparse.y"
+#line 1068 "mwmparse.y"
 { yyval.string = "FREE_FAMILY"; ;
     break;}
 case 129:
-#line 1076 "mwmparse.y"
+#line 1070 "mwmparse.y"
 { yyval.string = "NEXT"; ;
     break;}
 case 130:
-#line 1078 "mwmparse.y"
+#line 1072 "mwmparse.y"
 { yyval.string = "PREV"; ;
     break;}
 case 131:
-#line 1080 "mwmparse.y"
+#line 1074 "mwmparse.y"
 { yyval.string = "BACK"; ;
     break;}
 case 132:
-#line 1083 "mwmparse.y"
+#line 1077 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/share/misc/bison.simple"
+#line 498 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2227,7 +2225,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 1085 "mwmparse.y"
+#line 1079 "mwmparse.y"
 
 
 /*
