@@ -35,6 +35,26 @@
 
 #include "mwm.h"
 
+#include <stdio.h>
+
+#if 0
+/* Unfortunately X11 forgot about non-case-sensitive filesystems which
+   may have problems to store both "X11/bitmaps/Stipple" and
+   "X11/bitmaps/stipple".
+   So we inline the few lines here instead. */
+#include <X11/bitmaps/stipple>
+#else
+#define stipple_width 16
+#define stipple_height 4
+static char stipple_bits[] = {
+   0x55, 0x55, 0xee, 0xee, 0x55, 0x55, 0xba, 0xbb};
+#endif /* #if 0 */
+
+#include <X11/keysym.h>
+
+#include <Xm/XmP.h>
+
+
 extern Boolean debugging;
 
 extern XmFontList _XmFontListCreateDefault(Display *);
@@ -78,6 +98,21 @@ create_menu_gcs(ScreenInfo *scr)
     scr->components[MWM_MENU].normal_GC =
 	XCreateGC(dpy, scr->root_win, gcm, &gcv);
 
+    /* FIXME - not a very good grayed out color */
+    scr->components[MWM_MENU].grayed_GC =
+	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+
+    {
+        Pixmap stipple = XCreateBitmapFromData(dpy, scr->root_win, stipple_bits,
+                                     stipple_width, stipple_height);
+        if (stipple) {
+            XSetFillStyle(dpy, scr->components[MWM_MENU].grayed_GC,
+                          FillOpaqueStippled);
+            XSetStipple(dpy, scr->components[MWM_MENU].grayed_GC,
+                        stipple);
+        }
+    }
+
     if (scr->components[MWM_MENU].top_shadow_pixmap != None &&
 	scr->components[MWM_MENU].top_shadow_pixmap != XmUNSPECIFIED_PIXMAP)
     {
@@ -168,6 +203,10 @@ create_feedback_gcs(ScreenInfo *scr)
     scr->components[MWM_FEEDBACK].normal_GC =
 	XCreateGC(dpy, scr->root_win, gcm, &gcv);
 
+    scr->components[MWM_FEEDBACK].grayed_GC =
+	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    XSetFillStyle(dpy, scr->components[MWM_FEEDBACK].grayed_GC, FillOpaqueStippled);
+
     if (scr->components[MWM_FEEDBACK].top_shadow_pixmap != None &&
 	scr->components[MWM_FEEDBACK].top_shadow_pixmap != XmUNSPECIFIED_PIXMAP)
     {
@@ -253,6 +292,9 @@ create_pager_gcs(ScreenInfo *scr)
     gcv.background = scr->components[MWM_PAGER].background;
     scr->components[MWM_PAGER].normal_GC =
 	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    scr->components[MWM_PAGER].grayed_GC =
+	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    XSetFillStyle(dpy, scr->components[MWM_PAGER].grayed_GC, FillOpaqueStippled);
 }
 
 /*
@@ -295,6 +337,9 @@ create_icon_gcs(ScreenInfo *scr)
 
     scr->components[MWM_ICON].normal_GC =
 	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    scr->components[MWM_ICON].grayed_GC =
+	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    XSetFillStyle(dpy, scr->components[MWM_ICON].grayed_GC, FillStippled);
 
     if (scr->components[MWM_ICON].top_shadow_pixmap != None &&
 	scr->components[MWM_ICON].top_shadow_pixmap != XmUNSPECIFIED_PIXMAP)
@@ -453,6 +498,9 @@ create_title_gcs(ScreenInfo *scr)
 
     scr->components[MWM_TITLE_A].normal_GC =
 	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    scr->components[MWM_TITLE_A].grayed_GC =
+	XCreateGC(dpy, scr->root_win, gcm, &gcv);
+    XSetFillStyle(dpy, scr->components[MWM_TITLE_A].grayed_GC, FillOpaqueStippled);
 
     if (scr->components[MWM_TITLE_A].top_shadow_pixmap != None &&
 	scr->components[MWM_TITLE_A].top_shadow_pixmap != XmUNSPECIFIED_PIXMAP)
@@ -1346,10 +1394,6 @@ SCREEN_Initialize(ScreenInfo *scr)
 
     XMapRaised(dpy, scr->shield_win);
 
-#if 0
-    XSetInputFocus(dpy, scr->shield_win, RevertToParent, CurrentTime);
-#endif
-
     /* create a window which will accept the keyboard focus when no other 
        windows have it */
     attributes.event_mask = KeyPressMask | FocusChangeMask;
@@ -1358,6 +1402,7 @@ SCREEN_Initialize(ScreenInfo *scr)
 				      InputOnly, CopyFromParent,
 				      CWEventMask | CWOverrideRedirect,
 				      &attributes);
+    XStoreName(dpy, scr->no_focus_win, "NoFocusWin");
     XMapWindow(dpy, scr->no_focus_win);
 
     XSetInputFocus(dpy, scr->no_focus_win, RevertToParent, CurrentTime);
