@@ -61,9 +61,10 @@
 
 /**
  *
- * $Id: yacc.y,v 1.9 1999/05/28 20:43:09 danny Exp $
+ * $Id: yacc.y,v 1.12 2000/12/06 14:18:00 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -89,6 +90,7 @@
 
 #include <LTconfig.h>
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include "uil.h"	
@@ -104,15 +106,17 @@ extern char *yytext;
 #else
 extern unsigned char yytext[];	/* Unsigned needed on HP/UX */
 #endif
-extern int yylex();
+extern int yylex(void);
+
+/* For the prototype police */ 
+void yyerror(const char *s);
+void yyExit(int line, char *file, const char *fmt, ...);
 
-/* For the protocol police */ 
-extern void yyExit(int line, char *file, char *fmt, ...);
 
 #define YYDEBUG	1
 int yydebug = 1;
 
-#line 187 "yacc.y"
+#line 191 "yacc.y"
 typedef union {
     char	*string;
 } YYSTYPE;
@@ -256,20 +260,20 @@ static const short yyrhs[] = {     7,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   193,   196,   202,   207,   212,   216,   220,   227,   231,   236,
-   240,   244,   251,   255,   259,   265,   269,   273,   277,   281,
-   285,   289,   293,   297,   303,   307,   313,   317,   323,   327,
-   331,   337,   341,   345,   349,   353,   357,   361,   365,   371,
-   375,   379,   383,   389,   393,   398,   403,   407,   412,   419,
-   423,   429,   433,   437,   441,   445,   449,   453,   457,   463,
-   468,   473,   478,   484,   488,   494,   498,   503,   507,   513,
-   517,   523,   528,   533,   538,   544,   548,   555,   559,   563,
-   568,   572,   576,   580,   584,   588,   594,   600,   604,   608,
-   612,   618,   622,   626,   630,   636,   640,   644,   650,   654,
-   659,   663,   668,   672,   676,   680,   684,   688,   693,   697,
-   701,   705,   709,   713,   717,   721,   727,   732,   736,   740,
-   746,   750,   756,   763,   767,   773,   777,   782,   786,   790,
-   794,   798,   802,   806,   810
+   197,   200,   206,   211,   216,   220,   224,   231,   235,   240,
+   244,   248,   255,   259,   263,   269,   273,   277,   281,   285,
+   289,   293,   297,   301,   307,   311,   317,   321,   327,   331,
+   335,   341,   345,   349,   353,   357,   361,   365,   369,   375,
+   379,   383,   387,   393,   397,   402,   407,   411,   416,   423,
+   427,   433,   437,   441,   445,   449,   453,   457,   461,   467,
+   472,   477,   482,   488,   492,   498,   502,   507,   511,   517,
+   521,   527,   532,   537,   542,   548,   552,   559,   563,   567,
+   572,   576,   580,   584,   588,   592,   598,   604,   608,   612,
+   616,   622,   626,   630,   634,   640,   644,   648,   654,   658,
+   663,   667,   672,   676,   680,   684,   688,   692,   697,   701,
+   705,   709,   713,   717,   721,   725,   731,   736,   740,   744,
+   750,   754,   760,   767,   771,   777,   781,   786,   790,   794,
+   798,   802,   806,   810,   814
 };
 #endif
 
@@ -527,7 +531,7 @@ static const short yycheck[] = {    50,
     -1,    -1,    65
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/share/misc/bison.simple"
+#line 3 "/usr/share/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -676,9 +680,13 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #define YYMAXDEPTH 10000
 #endif
 
+#ifndef YYPARSE_RETURN_TYPE
+#define YYPARSE_RETURN_TYPE int
+#endif
+
 /* Prevent warning if -Wstrict-prototypes.  */
 #ifdef __GNUC__
-int yyparse (void);
+YYPARSE_RETURN_TYPE yyparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
@@ -720,7 +728,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/share/misc/bison.simple"
+#line 196 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -741,7 +749,7 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
-int
+YYPARSE_RETURN_TYPE
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
@@ -1025,755 +1033,755 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 194 "yacc.y"
+#line 198 "yacc.y"
 {
 		;
     break;}
 case 2:
-#line 197 "yacc.y"
+#line 201 "yacc.y"
 {
-		    Warn(LOC,"Empty input file\n");
+		    __MrmWarn(LOC,"Empty input file\n");
 		;
     break;}
 case 3:
-#line 203 "yacc.y"
+#line 207 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 4:
-#line 208 "yacc.y"
+#line 212 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 5:
-#line 213 "yacc.y"
+#line 217 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 6:
-#line 217 "yacc.y"
+#line 221 "yacc.y"
 {
 		    yyval.string = body_OBJECT_object(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 7:
-#line 221 "yacc.y"
+#line 225 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 8:
-#line 228 "yacc.y"
+#line 232 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 9:
-#line 232 "yacc.y"
+#line 236 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-3].string;
 		;
     break;}
 case 10:
-#line 237 "yacc.y"
+#line 241 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 11:
-#line 241 "yacc.y"
+#line 245 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 12:
-#line 245 "yacc.y"
+#line 249 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 13:
-#line 252 "yacc.y"
+#line 256 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 14:
-#line 256 "yacc.y"
+#line 260 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 15:
-#line 260 "yacc.y"
+#line 264 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 16:
-#line 266 "yacc.y"
+#line 270 "yacc.y"
 {
 		    MakeTable(yyvsp[-4].string,yyvsp[-2].string, 0);
 		;
     break;}
 case 17:
-#line 270 "yacc.y"
+#line 274 "yacc.y"
 {
 		    MakeTable(yyvsp[-6].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 18:
-#line 274 "yacc.y"
+#line 278 "yacc.y"
 {
 		    MakeTable(yyvsp[-7].string,yyvsp[-3].string,0);
 		;
     break;}
 case 19:
-#line 278 "yacc.y"
+#line 282 "yacc.y"
 {
 		    MakeTable(yyvsp[-7].string, yyvsp[-3].string, 0);
 		;
     break;}
 case 20:
-#line 282 "yacc.y"
+#line 286 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 21:
-#line 286 "yacc.y"
+#line 290 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 22:
-#line 290 "yacc.y"
+#line 294 "yacc.y"
 {
 		    MakeTable(yyvsp[-5].string, yyvsp[-2].string, 1);
 		;
     break;}
 case 24:
-#line 298 "yacc.y"
+#line 302 "yacc.y"
 {
 			yyval.string = NULL;
 	       	;
     break;}
 case 25:
-#line 304 "yacc.y"
+#line 308 "yacc.y"
 {
 		    yyval.string = AddFont(yyvsp[-4].string, yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 26:
-#line 308 "yacc.y"
+#line 312 "yacc.y"
 {
 		    yyval.string = AddFont(yyvsp[-2].string, yyvsp[0].string, NULL);
 		;
     break;}
 case 27:
-#line 314 "yacc.y"
+#line 318 "yacc.y"
 {
 		    yyval.string = CharSetName(NULL, yyvsp[0].string);
 		;
     break;}
 case 28:
-#line 318 "yacc.y"
+#line 322 "yacc.y"
 {
 		    yyval.string = CharSetName(yyvsp[-1].string, yyvsp[-2].string);
 		;
     break;}
 case 29:
-#line 324 "yacc.y"
+#line 328 "yacc.y"
 {
 		    yyval.string = CharSetRToL(yyvsp[0].string, (int)(long)yyvsp[-1].string);
 		;
     break;}
 case 30:
-#line 328 "yacc.y"
+#line 332 "yacc.y"
 {
 		    yyval.string = CharSet16Bit(yyvsp[0].string, (int)(long)yyvsp[-1].string);
 		;
     break;}
 case 31:
-#line 332 "yacc.y"
+#line 336 "yacc.y"
 {
 		    yyval.string = MakeNewCharSet();
 		;
     break;}
 case 32:
-#line 338 "yacc.y"
+#line 342 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-4].string,yyvsp[-2].string, yyvsp[0].string, 1);
 		;
     break;}
 case 33:
-#line 342 "yacc.y"
+#line 346 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-2].string,yyvsp[0].string, NULL, 1);
 		;
     break;}
 case 34:
-#line 346 "yacc.y"
+#line 350 "yacc.y"
 {
-		    yyval.string = AddColor(Store("\"_bg\""),yyvsp[0].string, NULL, 0);
+		    yyval.string = AddColor(__MrmStore("\"_bg\""),yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 35:
-#line 350 "yacc.y"
+#line 354 "yacc.y"
 {
-		    yyval.string = AddColor(Store("\"_bg\""), yyvsp[-2].string, yyvsp[0].string, 0);
+		    yyval.string = AddColor(__MrmStore("\"_bg\""), yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 36:
-#line 354 "yacc.y"
+#line 358 "yacc.y"
 {
-		    yyval.string = AddColor(Store("\"_fg\""), yyvsp[0].string, NULL, 0);
+		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 37:
-#line 358 "yacc.y"
+#line 362 "yacc.y"
 {
-		    yyval.string = AddColor(Store("\"_fg\""), yyvsp[-2].string, yyvsp[0].string, 0);
+		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 38:
-#line 362 "yacc.y"
+#line 366 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-5].string, yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 39:
-#line 366 "yacc.y"
+#line 370 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-3].string, yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 40:
-#line 372 "yacc.y"
-{
-		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
-		;
-    break;}
-case 41:
 #line 376 "yacc.y"
 {
 		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
-case 42:
+case 41:
 #line 380 "yacc.y"
+{
+		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
+		;
+    break;}
+case 42:
+#line 384 "yacc.y"
 {
 		    yyval.string = InsertString(NULL,yyvsp[0].string);
 		;
     break;}
 case 43:
-#line 384 "yacc.y"
+#line 388 "yacc.y"
 {
 		    yyval.string = InsertString(NULL, yyvsp[0].string);
 		;
     break;}
 case 44:
-#line 390 "yacc.y"
+#line 394 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 45:
-#line 394 "yacc.y"
+#line 398 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 46:
-#line 399 "yacc.y"
+#line 403 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-4].string;
 		;
     break;}
 case 47:
-#line 404 "yacc.y"
+#line 408 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 48:
-#line 408 "yacc.y"
+#line 412 "yacc.y"
 {
-		    Warn(LOC, "NO OP\n");
+		    __MrmWarn(LOC, "NO OP\n");
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 49:
-#line 413 "yacc.y"
+#line 417 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-3].string;
 		;
     break;}
 case 50:
-#line 420 "yacc.y"
+#line 424 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 51:
-#line 424 "yacc.y"
+#line 428 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 52:
-#line 430 "yacc.y"
+#line 434 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 53:
-#line 434 "yacc.y"
+#line 438 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 54:
-#line 438 "yacc.y"
+#line 442 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 55:
-#line 442 "yacc.y"
+#line 446 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 56:
-#line 446 "yacc.y"
+#line 450 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 57:
-#line 450 "yacc.y"
+#line 454 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 58:
-#line 454 "yacc.y"
+#line 458 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 59:
-#line 458 "yacc.y"
+#line 462 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 60:
-#line 464 "yacc.y"
+#line 468 "yacc.y"
 {
 		    AddAttributeList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 61:
-#line 469 "yacc.y"
+#line 473 "yacc.y"
 {
 		    AddControlList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 62:
-#line 474 "yacc.y"
+#line 478 "yacc.y"
 {
 		    AddCallbackList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 63:
-#line 479 "yacc.y"
+#line 483 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 64:
-#line 485 "yacc.y"
+#line 489 "yacc.y"
 {
 		    yyval.string = (char *)arglist_arglist_ID_addexpr(yyvsp[-4].string, yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 65:
-#line 489 "yacc.y"
+#line 493 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 66:
-#line 495 "yacc.y"
+#line 499 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 67:
-#line 499 "yacc.y"
+#line 503 "yacc.y"
 {
 		    ID_ID_features(yyvsp[-6].string,yyvsp[-4].string,yyvsp[-2].string);
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 68:
-#line 504 "yacc.y"
+#line 508 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 69:
-#line 508 "yacc.y"
+#line 512 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    ID_ID_features(yyvsp[-7].string, yyvsp[-4].string, yyvsp[-2].string);
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 70:
-#line 514 "yacc.y"
+#line 518 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 71:
-#line 518 "yacc.y"
+#line 522 "yacc.y"
 {
-		    /* Warn(LOC,"Empty object\n"); */
+		    /* __MrmWarn(LOC,"Empty object\n"); */
 		;
     break;}
 case 72:
-#line 524 "yacc.y"
+#line 528 "yacc.y"
 {
 		    features_controls(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 73:
-#line 529 "yacc.y"
+#line 533 "yacc.y"
 {
 		    features_arguments(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 74:
-#line 534 "yacc.y"
+#line 538 "yacc.y"
 {
 		    features_callbacks(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 75:
-#line 539 "yacc.y"
+#line 543 "yacc.y"
 {
 		    yyval.string = (char *)Features_NULL();
 		;
     break;}
 case 76:
-#line 545 "yacc.y"
+#line 549 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 77:
-#line 549 "yacc.y"
+#line 553 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 78:
-#line 556 "yacc.y"
+#line 560 "yacc.y"
 {
 		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string,1);
 		;
     break;}
 case 79:
-#line 560 "yacc.y"
+#line 564 "yacc.y"
 {
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-2].string, 1);
 		;
     break;}
 case 80:
-#line 564 "yacc.y"
+#line 568 "yacc.y"
 {   /* $2 may be wrong for this type of call */
 		    /* I confused this rule for the next one */
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string, yyvsp[-5].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 81:
-#line 569 "yacc.y"
+#line 573 "yacc.y"
 {
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string,yyvsp[-4].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 82:
-#line 573 "yacc.y"
+#line 577 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 83:
-#line 577 "yacc.y"
+#line 581 "yacc.y"
 {
 		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-4].string,yyvsp[-2].string,yyvsp[-1].string,0);
 		;
     break;}
 case 84:
-#line 581 "yacc.y"
+#line 585 "yacc.y"
 {
 		    yyval.string = InheritControls(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 85:
-#line 585 "yacc.y"
+#line 589 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 86:
-#line 589 "yacc.y"
+#line 593 "yacc.y"
 {
 			yyval.string = NULL;
 		;
     break;}
 case 87:
-#line 595 "yacc.y"
+#line 599 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 88:
-#line 601 "yacc.y"
+#line 605 "yacc.y"
 {
 		    yyval.string = arglist_arglist_ID_addexpr(yyvsp[-4].string,yyvsp[-3].string,yyvsp[-1].string);
 		;
     break;}
 case 89:
-#line 605 "yacc.y"
+#line 609 "yacc.y"
 {
 		    yyval.string = WidgetArgument(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-1].string);
 	     	;
     break;}
 case 90:
-#line 609 "yacc.y"
+#line 613 "yacc.y"
 {
 		    yyval.string = InheritArgument(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 91:
-#line 613 "yacc.y"
+#line 617 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 92:
-#line 619 "yacc.y"
+#line 623 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 93:
-#line 623 "yacc.y"
+#line 627 "yacc.y"
 {
 		    yyval.string = Subtract(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 94:
-#line 627 "yacc.y"
+#line 631 "yacc.y"
 {
 		    yyval.string = Add(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 95:
-#line 631 "yacc.y"
+#line 635 "yacc.y"
 {
 		    yyval.string = AppendStrings(yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 96:
-#line 637 "yacc.y"
+#line 641 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 97:
-#line 641 "yacc.y"
+#line 645 "yacc.y"
 {
 		    yyval.string = Multiply(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 98:
-#line 645 "yacc.y"
+#line 649 "yacc.y"
 {
 		    yyval.string = Divide(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 99:
-#line 651 "yacc.y"
+#line 655 "yacc.y"
 {
 		    yyval.string = (char *) expr_ID(yyvsp[0].string);
 		;
     break;}
 case 100:
-#line 655 "yacc.y"
+#line 659 "yacc.y"
 {
-		    Warn(LOC, "Font Unit not implemented yet\n");
+		    __MrmWarn(LOC, "Font Unit not implemented yet\n");
 		    yyval.string = (char *) prim_exp(yyvsp[-1].string);
 		;
     break;}
 case 101:
-#line 660 "yacc.y"
+#line 664 "yacc.y"
 {
 		    yyval.string = (char *)prim_exp(yyvsp[0].string);
 		;
     break;}
 case 102:
-#line 664 "yacc.y"
+#line 668 "yacc.y"
 {
 		    fprintf(stderr,"BLAB BLAB ID = %s\n", yyvsp[0].string);
 		    yyval.string = (char *) expr_STRING(yyvsp[0].string, yyvsp[-1].string,/*Compound?*/ False);
 		;
     break;}
 case 103:
-#line 669 "yacc.y"
+#line 673 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING(yyvsp[0].string, NULL, /*Compound?*/ False);
 		;
     break;}
 case 104:
-#line 673 "yacc.y"
+#line 677 "yacc.y"
 {
 		    yyval.string = (char *) expr_BOOL(yyvsp[0].string);
 		;
     break;}
 case 105:
-#line 677 "yacc.y"
+#line 681 "yacc.y"
 {
 		    yyval.string = (char *) keysym(yyvsp[-1].string);
 		;
     break;}
 case 106:
-#line 681 "yacc.y"
+#line 685 "yacc.y"
 {
 		    yyval.string = (char *) font(yyvsp[-1].string);
 		;
     break;}
 case 107:
-#line 685 "yacc.y"
+#line 689 "yacc.y"
 {
 		    yyval.string = (char *) keysym(yyvsp[-1].string);
 		;
     break;}
 case 108:
-#line 689 "yacc.y"
+#line 693 "yacc.y"
 {
-		    Warn(LOC,"NO OP\n");
+		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 109:
-#line 694 "yacc.y"
+#line 698 "yacc.y"
 {	
 		    yyval.string = (char *) bitmap(yyvsp[-1].string);
 		;
     break;}
 case 110:
-#line 698 "yacc.y"
+#line 702 "yacc.y"
 {
 		    yyval.string = (char *) pixmap(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 111:
-#line 702 "yacc.y"
+#line 706 "yacc.y"
 {
 		    yyval.string = pixmap(NULL,yyvsp[-1].string);
 		;
     break;}
 case 112:
-#line 706 "yacc.y"
+#line 710 "yacc.y"
 {
 		    yyval.string = color(NULL, yyvsp[-5].string, yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 113:
-#line 710 "yacc.y"
+#line 714 "yacc.y"
 {
 		    yyval.string = color(yyvsp[-1].string, 0, 0, 0);
 		;
     break;}
 case 114:
-#line 714 "yacc.y"
+#line 718 "yacc.y"
 {
 		    yyval.string = color(yyvsp[-3].string, 0, 0, 0); /* For Now  FIX ME */
 		;
     break;}
 case 115:
-#line 718 "yacc.y"
+#line 722 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 116:
-#line 722 "yacc.y"
+#line 726 "yacc.y"
 {	
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 117:
-#line 728 "yacc.y"
+#line 732 "yacc.y"
 {
 		    /* string, separate, IsAddress */
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,False);
 		;
     break;}
 case 118:
-#line 733 "yacc.y"
+#line 737 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,True);
 		;
     break;}
 case 119:
-#line 737 "yacc.y"
+#line 741 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, True);
 		;
     break;}
 case 120:
-#line 741 "yacc.y"
+#line 745 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, False);
 		;
     break;}
 case 121:
-#line 747 "yacc.y"
+#line 751 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 122:
-#line 751 "yacc.y"
+#line 755 "yacc.y"
 {
 		    yyval.string = InheritCallback(yyvsp[-1].string);
 		;
     break;}
 case 123:
-#line 757 "yacc.y"
+#line 761 "yacc.y"
 {
 		    yyval.string = (char *)callbacklist_callbacklist_PROCID_arglist(yyvsp[-8].string,
 									  yyvsp[-7].string,
@@ -1782,79 +1790,79 @@ case 123:
 		;
     break;}
 case 124:
-#line 764 "yacc.y"
+#line 768 "yacc.y"
 {
-		    Warn(LOC,"NO OP************\n");
+		    __MrmWarn(LOC,"NO OP************\n");
 		;
     break;}
 case 125:
-#line 768 "yacc.y"
+#line 772 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 126:
-#line 774 "yacc.y"
+#line 778 "yacc.y"
 {
-		    Warn(LOC, "NO OP\n");
+		    __MrmWarn(LOC, "NO OP\n");
 		;
     break;}
 case 127:
-#line 778 "yacc.y"
+#line 782 "yacc.y"
 {
 		;
     break;}
 case 128:
-#line 783 "yacc.y"
+#line 787 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, prim_exp(yyvsp[0].string));
 		;
     break;}
 case 129:
-#line 787 "yacc.y"
+#line 791 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, expr_ID(yyvsp[0].string));
 		;
     break;}
 case 130:
-#line 791 "yacc.y"
+#line 795 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, expr_STRING(yyvsp[0].string, NULL, 0));
 		;
     break;}
 case 131:
-#line 795 "yacc.y"
+#line 799 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, prim_exp(yyvsp[0].string));
 		;
     break;}
 case 132:
-#line 799 "yacc.y"
+#line 803 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_ID(yyvsp[0].string));
 		;
     break;}
 case 133:
-#line 803 "yacc.y"
+#line 807 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 0));
 		;
     break;}
 case 134:
-#line 807 "yacc.y"
+#line 811 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 1));
 		;
     break;}
 case 135:
-#line 811 "yacc.y"
+#line 815 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, NULL);
 		;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/share/misc/bison.simple"
+#line 498 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2050,23 +2058,20 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 817 "yacc.y"
+#line 821 "yacc.y"
 
 
 
-extern int optind;
-extern char *optarg;
-
 void
-yyerror(s)
-char *s;
+yyerror(const char *s)
 {
     fprintf(stderr,"%s:%d: %s\n", FileName, LineNumber, s);
     fprintf(stderr," current token \'%s\'\n", yytext);
 }
 
+
 void
-yyExit(int line, char *file, char *fmt, ...)
+yyExit(int line, char *file, const char *fmt, ...)
 {
     va_list ap;
 
@@ -2074,8 +2079,8 @@ yyExit(int line, char *file, char *fmt, ...)
 
     va_start (ap, fmt);
 
-    fprintf(stderr,"%s:%d:",file,line);
-    vfprintf(stderr,fmt,ap);
+    fprintf(stderr,"%s:%d:", file, line);
+    vfprintf(stderr, fmt, ap);
 
     va_end(ap);
 
