@@ -1,5 +1,5 @@
 /*
- * $Id: events.c,v 1.9 2000/01/10 22:59:03 amai Exp $
+ * $Id: events.c,v 1.12 2000/12/18 19:41:48 amai Exp $
  */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
@@ -51,7 +51,9 @@
 #include <time.h>
 #endif
 #endif
-
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -59,6 +61,13 @@
 #include <sys/select.h>
 #endif
 
+#include <X11/extensions/shape.h>
+
+#include <Xm/XmosP.h>
+#if XmVERSION >= 2
+#include <XmI/XmI.h>
+#endif
+
 /*
  * shorthand defines
  */
@@ -1513,11 +1522,11 @@ EVENT_Next(XEvent *event)
 	return 0;
     }
 
-#ifndef HAVE_GETITIMER
+#ifdef HAVE_GETITIMER
+    getitimer(ITIMER_REAL, &value);
+#else
     value.it_value.tv_usec = 10000;
     value.it_value.tv_sec = 0;
-#else
-    getitimer(ITIMER_REAL, &value);
 #endif
 
     FD_ZERO(&in_fdset);
