@@ -42,19 +42,20 @@
 
 #include "mwm.h"
 
+#include <stdlib.h>
+#include <stdio.h>
 #include <ctype.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include <stdio.h>
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
 #endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
@@ -876,14 +877,14 @@ win_list(ScreenInfo *scr, int val1, int val2)
 	if (mi->func != F_TITLE)
 	{
 	    if (mi->item != NULL)
-		free(mi->item);
+		XtFree(mi->item);
 	    if (mi->item2 != NULL)
-		free(mi->item2);
+		XtFree(mi->item2);
 	}
-	free(mi);
+	XtFree((char *)mi);
 	mi = tmp;
     }
-    free(mr);
+    XtFree((char *)mr);
 }
 
 /*
