@@ -33,38 +33,21 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#ifndef MWM_H
-#define MWM_H
+/* $Id: mwm.h,v 1.17 2000/12/18 19:41:48 amai Exp $ */
+
+#ifndef _MWM_H
+#define _MWM_H
 
 #include <LTconfig.h>
 
-#include <ctype.h>
-#include <stdio.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#define ANSI_STRING
-#include <strings.h>
-#endif
-#include <stdlib.h>
-#include <signal.h>
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
-#include <X11/Xutil.h>
 #include <X11/Xresource.h>
-#include <X11/Xproto.h>
-#include <X11/Intrinsic.h>
-#include <X11/IntrinsicP.h>
-#include <X11/keysym.h>
-#include <X11/cursorfont.h>
-#include <X11/extensions/shape.h>
-#include <Xm/XmP.h>
-#include <Xm/XmosP.h>
+
+#include <Xm/Xm.h>
 #include <Xm/MwmUtil.h>
 
+
 /*
  * path components
  */
@@ -75,12 +58,17 @@
 #define DEFAULT_DISPLAY		"DISPLAY=%s:%s.%d"
 #define DEFAULT_DISPLAY_STRING	"DISPLAY=%s"
 #define HOME_MWMRC		".mwmrc"	/* precede with $HOME */
-#define SYSTEM_MWMRC		"system.mwmrc"	/* precede with XLIB_PATH */
+#define SYSTEM_MWMRC		"system.mwmrc"	/* precede with MWM_DDIR */
 #define HOME_BINDINGS_FILE	".motifbind"
 #define MWM_VERSION		"Lesstif mwm Release"
 #define OPT_MULTISCREEN		"-multiscreen"
 #define OPT_SCREENS		"-screens"
-#define MWM_ICONDIR		XINCL_PATH"/bitmaps:"XINCL_PATH"/pixmaps"
+#ifndef __EMX__
+#define MWM_ICONDIR		XINCL_PATH"/X11/bitmaps:"XINCL_PATH"/X11/pixmaps"
+#else
+#define MWM_ICONDIR		"/XFree86/include/X11/bitmaps;/XFree86/include/X11/pixmaps"
+/* char mwm_icondir[255]; */
+#endif
 #define USAGE \
 "Mwm Ver %s\n\nusage: mwm [-display dpy] [-debug] [-xrm resourcestring] [-multiscreen] [-name name] [-screens name [name [...]]]\n"
 
@@ -204,6 +192,7 @@ typedef struct ComponentInfo {
     Pixmap          top_shadow_pixmap;
 
     GC              normal_GC;
+    GC              grayed_GC;
     GC              top_GC;
     GC              bot_GC;
     XFontStruct    *font;
@@ -465,7 +454,11 @@ typedef struct FuncKey {
 #ifdef HAVE_WAITPID
 #define ReapChildren()  while ((waitpid(-1, NULL, WNOHANG)) > 0);
 #else
+#ifdef HAVE_WAIT3
 #define ReapChildren()  while ((wait3(NULL, WNOHANG, NULL)) > 0);
+#else
+# Error You lose
+#endif
 #endif
 
 #define SIZE_HINDENT 5
@@ -907,7 +900,6 @@ extern void	RES_GetComponentDefaults(ScreenInfo *scr);
 extern Boolean	MISC_Grab(ScreenInfo *scr, int);
 extern void     MISC_Ungrab(ScreenInfo *scr);
 extern void	MISC_WaitForButtonsUp(ScreenInfo *scr);
-extern void     MISC_usleep(int);
 extern int      MISC_FlushExpose(Window w);
 extern void     MISC_SetTimer(int);
 extern Boolean  MISC_StashEventTime(XEvent * ev);
@@ -1043,9 +1035,54 @@ extern void	RESIZE_EventLoop(ScreenInfo *scr, Window w, MwmWindow *tmp_win,
 
 /* exit functions */
 extern void	MWM_SetErrorHandler(int which);
-extern void     MWM_Done(int, char *);
+extern void MWM_Done(int, const char *);
 
-/* functions that don't fit */
+/* Debugging functions */
+extern const char	 *_MwmPrintC(int x);
+extern const char	 *_MwmPrintF(int x);
+
+/* Resource default functions */
+extern void	_WmMultiClickTimeDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmFocusAutoRaiseDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmDefaultBorderWidth(Widget w, int offset, XrmValue *val);
+extern void	_WmDefaultResizeBorderWidth(Widget widget, int offset,
+					    XrmValue *val);
+extern void	_WmIconImageBDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmIconImageBSCDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmIconImageBSPDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmIconImageFDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmIconImageTSCDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmIconImageTSPDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteBDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteBSCDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteBSPDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteFDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteTSCDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmMatteTSPDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmBackgroundDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmBackgroundPixmapDefault(Widget w, int offset,
+					   XrmValue *val);
+extern void	_WmBottomShadowColorDefault(Widget w, int offset,
+					    XrmValue *val);
+extern void	_WmBottomShadowPixmapDefault(Widget w, int offset,
+					     XrmValue *val);
+extern void	_WmForegroundDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmTopShadowColorDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmTopShadowPixmapDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmABackgroundDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmAForegroundDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmABottomShadowColorDefault(Widget w, int offset,
+					     XrmValue *val);
+extern void	_WmATopShadowColorDefault(Widget w, int offset, XrmValue *val);
+extern void	_WmABackgroundPixmapDefault(Widget w, int offset,
+					    XrmValue *val);
+extern void	_WmATopShadowPixmapDefault(Widget w, int offset,
+					   XrmValue *val);
+
+/* Parsing functions */
+extern char	mwm_getc(void);
+extern void	mwm_putc(char c);
+extern void	mwm_unputc(char c);
 extern void	yyerror(char *fmt, ...);
 
 /*
@@ -1080,4 +1117,4 @@ extern Atom     XA_MWM_MESSAGES;
 extern Atom     XA_MWM_MENU;
 extern Atom     XA_MWM_INFO;
 
-#endif /* _MWM_ */
+#endif /* _MWM_H */
