@@ -1,6 +1,6 @@
 /**
  *
- * $Id: resources.c,v 1.9 2000/04/29 17:13:53 amai Exp $
+ * $Id: resources.c,v 1.10 2000/09/21 16:04:37 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -24,7 +24,10 @@
 
 #include "mwm.h"
 #include "mwmstrings.h"
+#include <stdio.h>
+
 #include <Xm/Xm.h>
+#include <Xm/XmP.h>
 #include <Xm/XmStrDefs.h>
 
 /*
