@@ -49,6 +49,7 @@
 #endif
 
 #include <X11/Intrinsic.h>
+#include <X11/extensions/shape.h>
 
 /*
  * some macros used by the constraint code
@@ -608,7 +609,7 @@ place_window(ScreenInfo *scr, MwmWindow *tmp_win)
 				 (unsigned int *)&DragHeight,
 				 &JunkBW, &JunkDepth) == 0)
 		{
-		    free((char *)tmp_win);
+		    XtFree((char *)tmp_win);
 		    XUngrabServer(dpy);
 		    return False;
 		}
@@ -712,7 +713,7 @@ add_window(ScreenInfo *scr, Window w)
     if (XGetGeometry(dpy, tmp_win->w, &JunkRoot, &JunkX, &JunkY,
 		     &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0)
     {
-	free((char *)tmp_win);
+	XtFree((char *)tmp_win);
 	return (NULL);
     }
 
@@ -793,7 +794,7 @@ add_window(ScreenInfo *scr, Window w)
 		     &JunkWidth, &JunkHeight,
 		     &JunkBW, &JunkDepth) == 0)
     {
-	free((char *)tmp_win);
+	XtFree((char *)tmp_win);
 	XUngrabServer(dpy);
 	return (NULL);
     }
@@ -1452,7 +1453,7 @@ WIN_Raise(ScreenInfo *scr, MwmWindow *t)
 	XRaiseWindow(dpy, wins[0]);
 
     XRestackWindows(dpy, wins, i);
-    free(wins);
+    XtFree((char *)wins);
 
     PAGER_Clear(scr);
 
@@ -1933,7 +1934,7 @@ WIN_DestroyWindow(ScreenInfo *scr, MwmWindow *tmp)
     if (tmp->cmap_windows != (Window *)NULL)
 	XFree((void *)tmp->cmap_windows);
 
-    free((char *)tmp);
+    XtFree((char *)tmp);
 
     PAGER_Clear(scr);
     XSync(dpy, 0);
