@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DragDropI.h,v 1.9 1998/06/29 21:10:14 danny Exp $
+ * $Id: DragDropI.h,v 1.13 2000/10/05 20:58:48 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -35,8 +36,8 @@ about the suitability of this software for any purpose.  It is
 provided "as is" without express or implied warranty.
 ************************************************************/
 
-#ifndef DRAGDROP_I_H
-#define DRAGDROP_I_H
+#ifndef _XMI_DRAGDROPI_H
+#define _XMI_DRAGDROPI_H
 
 #include <X11/Xmd.h>
 
@@ -344,7 +345,7 @@ typedef struct _XmDropSiteInfo {
  * store per-widget info
  */
 typedef struct {
-    int num_buckets;
+    long num_buckets;
     XmDropSiteInfo *buckets;
 } DSInfoTable;
 
@@ -429,5 +430,20 @@ typedef struct {
 #define _XA_MOTIF_WM_QUERY_N		"_MOTIF_WM_QUERY_%d"
 #define _XA_MOTIF_DRAG_AND_DROP_MESSAGE	"_MOTIF_DRAG_AND_DROP_MESSAGE"
 
-#endif /* DRAGDROP_I_H */
+/* functions */
 
+extern Boolean _XmGetDragReceiverInfo(Display *display, Window win,
+				      XmDragReceiverInfo ri);
+extern void _XmSetDragReceiverInfo(Widget w, Widget widget);
+extern void _XmClearDragReceiverInfo(Widget shell);
+extern void _XmFreeDragReceiverInfo(XmShellDropSiteInfo di);
+extern unsigned char _XmByteOrder(void);
+
+/*
+ * resources from DropSMgrI.c
+ */
+extern XtResource _XmDSResources[];
+extern int _XmNumDSResources;
+
+
+#endif /* _XMI_DRAGDROPI_H */
