@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Mrm.c,v 1.21 2000/05/16 14:41:24 amai Exp $
+ * $Id: Mrm.c,v 1.26 2000/10/16 09:02:59 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -28,27 +29,15 @@
 
 #include <LTconfig.h>
 
-#include <stdarg.h>
 #include <stdlib.h>
-#include <Mrm/MrmPublic.h>
-#include <Xm/XmP.h>
-#include <Xm/Text.h>
-#include <Xm/RowColumn.h>
-#include <Xm/MainW.h>
-#include <Xm/PushB.h>
-#include <Xm/BulletinB.h>
-#include <Xm/Label.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Separator.h>
-#include <Xm/PanedW.h>
-#include <Xm/FileSB.h>
-#include <Xm/ToggleB.h>
-#include <Xm/Form.h>
-#include <Xm/Frame.h>
-#include <Xm/MessageB.h>
-#include <XmI/XmXpm.h>
-#include <X11/Xlibint.h>
+#include <string.h>
+#include <stdio.h>
+
 #include <X11/Xlib.h>
+#include <Xm/XmP.h>
+#include <XmI/XmXpm.h>
+
+#include <Mrm/MrmPublic.h>
 
 #include "uil.h"
 #include "lookup.h"
@@ -70,14 +59,6 @@ enum
 };
 #define ANOTHER_WIDGET -1
 
-typedef Widget (*CreateFunction) (Widget, String, ArgList, Cardinal);
-
-typedef struct _CreateFunctionsType
-{
-    char *Name;
-    CreateFunction function;
-}
-CreateFunctionsType;
 
 typedef struct _MyHierStruct
 {
@@ -86,10 +67,7 @@ typedef struct _MyHierStruct
     Arg *args;
     int argCount;
     int SizeArgs;
-}
-MyHierStruct;
-
-extern CreateFunctionsType CreateFunctions[];
+} MyHierStruct;
 
 typedef struct _SymbolTable
 {
@@ -99,8 +77,7 @@ typedef struct _SymbolTable
     char *Name;
     char *value;
     char Access;
-}
-SymbolTableType;
+} SymbolTableType;
 
 typedef struct _callbackType
 {
@@ -195,67 +172,75 @@ static String *FileList;
 static int MaxAttributes;
 static int MaxHier;
 static UilModuleType UilModule[MAX_HIER];
+static int FetchCount = 0;
+static SymbolTableType *InstantationSymbolTable = NULL;
 
-int NumberRegisteredFunctions;
-extern MrmRegisterArg *RegisteredFunctions;
+
+
+/* exported stuff */
+int NumberRegisteredFunctions = 0;
+MrmRegisterArg *RegisteredFunctions = NULL;
 
 /*
  * Forward declarations of functions
  */
-int GetSymbolTableValue(XtArgVal *, SymbolTableType *, int, SymbolTableType *);
-SymbolTableType *GetSymbolTable(SymbolTableType *);
-SymbolTableType *LookupValue(SymbolTableType *SymbolTable, char *name);
-FILE *UILOpen(char *FileName, char *mode, FILE * old);
-char *Substitute(char *buffer);
-void ReadWidgetTree(UilModuleType *Module);
-void PrintWidgetTree(UilModuleType *Module);
-void PrintWidgets(UilModuleType *Module);
-void MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg, Pixel bg);
-void FreeSymbolTable(SymbolTableType *t);
-void GetCallbacks(int filenr, int wid_id, DummyWidget *DW);
-void AddGeometryAttributes(GeoType **GeometryList, int module_id, int this_id,
+static int GetSymbolTableValue(XtArgVal *, SymbolTableType *, int, SymbolTableType *);
+static SymbolTableType *GetSymbolTable(SymbolTableType *);
+static SymbolTableType *LookupValue(SymbolTableType *SymbolTable, char *name);
+static FILE *UILOpen(char *FileName, char *mode, FILE * old);
+static char *Substitute(char *buffer);
+static void ReadWidgetTree(UilModuleType *Module);
+static void PrintWidgetTree(UilModuleType *Module);
+static void PrintWidgets(UilModuleType *Module);
+static void MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg, Pixel bg);
+static void FreeSymbolTable(SymbolTableType *t);
+static void GetCallbacks(int filenr, int wid_id, DummyWidget *DW);
+static void AddGeometryAttributes(GeoType **GeometryList, int module_id, int this_id,
 			   DummyWidget *DW);
-void SetGeometryAttributes(GeoType **GeometryList);
-void ReadList(UilModuleType *Module);
-void ReadWidgets(UilModuleType *Module);
-void PrintArgs(SymbolTableType *Next);
-void PrintControls(int count, int *ids, DummyWidget *Array);
-void PrintCallbacks(callbackType *Next);
-void PrintSymbolTable(SymbolTableType *SymbolTable);
-SymbolTableType *LookUpAddr(char *temp, int module_id);
-char *CreateFontListFromFontName(char *FontName);
+static void SetGeometryAttributes(GeoType **GeometryList);
+static void ReadList(UilModuleType *Module);
+static void ReadWidgets(UilModuleType *Module);
+static void PrintArgs(SymbolTableType *Next);
+static void PrintControls(int count, int *ids, DummyWidget *Array);
+static void PrintCallbacks(callbackType *Next);
+static void PrintSymbolTable(SymbolTableType *SymbolTable);
+static SymbolTableType *LookUpAddr(char *temp, int module_id);
+/* static char *CreateFontListFromFontName(char *FontName); */
 
-SymbolTableType *ReadAttributes(void);
-void ReadCallbacks(callbackType **last);
-char *ReadType(int type);
+static SymbolTableType *ReadAttributes(void);
+static void ReadCallbacks(callbackType **last);
+static char *ReadType(int type);
 
-XmString DecodeComplexString(StringType * value, int module_id, char *ascii);
-void Xm_List(Widget parent_widget, DummyWidget *DW, int module_id);
+static XmString DecodeComplexString(StringType * value, int module_id, char *ascii);
+static void Xm_List(Widget parent_widget, DummyWidget *DW, int module_id);
 
-void GetAttributes(Display *d, Window w, int module_id,
+static void GetAttributes(Display *d, Window w, int module_id,
 		   int *n, Arg *args,
 		   DummyWidget *DW, SymbolTableType
 		   *FormSymbolTable, int OnGeometry);
 
-void 
+
+
+extern void 
 MrmInitialize(void)
 {
+ /* ? */
 }
 
-Cardinal 
+extern Cardinal 
 MrmCloseHierarchy(MrmHierarchy hierarchy_id)
 {
     return MrmSUCCESS;
 }
 
-Cardinal 
+extern Cardinal 
 MrmOpenHierarchy(MrmCount num_files, String *name_list, MrmOsOpenParamPtr *os_ext_list, MrmHierarchy *hierarchy_id_return)
 {
-    Exit(LOC, "Must replace MrmOpenHierarchy with MrmOpenHierarchyPerDisplay\nBecause I can't figure out how to get the display if you don't\n");
+    __MrmExit(LOC, "Must replace MrmOpenHierarchy with MrmOpenHierarchyPerDisplay\nBecause I can't figure out how to get the display if you don't\n");
     return MrmFAILURE;
 }
 
-Cardinal 
+extern Cardinal 
 MrmOpenHierarchyPerDisplay(Display *theDisplay, MrmCount num_files, String *name_list, MrmOsOpenParamPtr *os_ext_list, MrmHierarchy *hierarchy_id_return)
 {
     int fileIndex;
@@ -282,7 +267,7 @@ MrmOpenHierarchyPerDisplay(Display *theDisplay, MrmCount num_files, String *name
     {
 	if (NULL == UILOpen(FileList[fileIndex], "r", stdin))
 	{
-	    Exit(LOC, "Can't open %s\n", FileList[fileIndex]);
+	    __MrmExit(LOC, "Can't open %s\n", FileList[fileIndex]);
 	}
 	ReadWidgetTree(&UilModule[fileIndex]);
 	if (1)
@@ -298,7 +283,7 @@ MrmOpenHierarchyPerDisplay(Display *theDisplay, MrmCount num_files, String *name
     return MrmSUCCESS;
 }
 
-Cardinal 
+extern Cardinal 
 MrmRegisterNames(MrmRegisterArglist reglist, MrmCount num_reg)
 {
 /*
@@ -311,14 +296,14 @@ MrmRegisterNames(MrmRegisterArglist reglist, MrmCount num_reg)
     return MrmSUCCESS;
 }
 
-Cardinal
+extern Cardinal
 MrmRegisterClass(MrmType class_code, String class_name, String create_name,
-		 Widget (*creator) (), WidgetClass class_record)
+		 Widget (*creator) (void), WidgetClass class_record)
 {
     return MrmFAILURE;
 }
 
-Cardinal 
+extern Cardinal 
 MrmFetchIconLiteral(MrmHierarchy hierarchy_id, String index,
 		    Screen *scrn, Display *d, Pixel fg, Pixel bg,
 		    Pixmap *pixmap)
@@ -344,161 +329,8 @@ MrmFetchIconLiteral(MrmHierarchy hierarchy_id, String index,
     return MrmNOT_FOUND;
 }
 
-void 
-MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg,
-	   Pixel bg)
-{
-    char *temp, *value;
-    char buffer[256];
-    int filenr;
-    ColorTableHeaderType *ColorTableHeader;
-    ColorTableType *ColorTable;
-    _LtXpmAttributes attributes;
-    char Header[256];
-    char **andrew = NULL;
-    int NumColors;
-    int i, j, k, Index;
-    SymbolTableType *symbol;
-    GC *GCTable;
-    XColor exact, def;
-    char *Image;
-    ColorDefType *Color;
 
-    attributes.valuemask = 0;
-    temp = data->ColorTable;
-    if (NULL == (symbol = LookupValue(GlobalSymbolTable, temp)))
-    {
-	for (filenr = 0; filenr < NumberFiles; filenr++)
-	{
-	    if (NULL !=
-		(symbol = LookupValue(UilModule[filenr].SymbolTable, temp)))
-		break;
-	}
-	if (NULL == symbol)
-	    Exit(LOC, "Couldn't find %s in symbol tables\n", temp);
-    }
-    ColorTableHeader = (ColorTableHeaderType *)symbol->value;
-    ColorTable = ColorTableHeader->ColorTable;
-    NumColors = ColorTableHeader->NumColors;
-    GCTable = (GC *)malloc(sizeof(GC) * NumColors);
-    if (NULL == ColorTable[0].StringXPM)
-    {
-	for (i = 0; i < NumColors; i++)
-	{
-	    long theColor = 0;
-
-	    value = ColorTable[i].Color;
-	    if (ColorTable[i].IsAddress)
-	    {
-		if (NULL == (symbol = LookupValue(GlobalSymbolTable, value)))
-		{
-		    for (filenr = 0; filenr < MaxHier; filenr++)
-		    {
-			if (NULL !=
-			    (symbol = LookupValue(UilModule[filenr].SymbolTable, value)))
-			    break;
-		    }
-		    if (NULL == symbol)
-			Exit(LOC, "Couldn't find %s in symbol tables\n", value);
-		}
-		value = symbol->value;
-	    }
-	    Color = (ColorDefType *) value;
-	    sprintf(buffer, "%s     c %s", ColorTable[i].Reference, Color->name);
-	    GCTable[i] = XCreateGC(d, window, 0, NULL);
-	    if (Color->name)
-	    {
-		if (strcmp(Color->name, "_fg") == 0)
-		      theColor = fg;
-		    else if (strcmp(Color->name, "_bg") == 0)
-			  theColor = bg;
-		    else
-		    {
-			XAllocNamedColor(d, colormap, Color->name, &def, &exact);
-			theColor = def.pixel;
-		    }
-	    }
-	    else
-	    {
-		def.red = Color->r;
-		def.green = Color->g;
-		def.blue = Color->b;
-		if (XAllocColor(display, colormap, &def))
-		    theColor = def.pixel;
-		else
-		    Exit(LOC, "Couldn't resolve color: %s\n",
-			 Color->r, Color->g, Color->b);
-	    }
-
-	    XSetForeground(d, GCTable[i], theColor);
-/*      ColorTable[i].StringXPM = Store(buffer); */
-	}
-    }
-    andrew = (char **)malloc(sizeof(char *) * (1 + NumColors + data->width));
-    sprintf(Header, "%d %d %d 1 -1 -1", data->width, data->height, NumColors);
-    andrew[0] = Header;
-    for (i = 0; i < NumColors; i++)
-	andrew[i + 1] = ColorTable[i].StringXPM;
-    for (i = 0; i < data->width; i++)
-	andrew[i + NumColors + 1] = &data->data[i * data->width];
-    Image = data->data;
-
-    /* the following is a total hack because I want to go to bed.  The Pixel
-     * value in XmGetPixmapByDepth are totally made up. */
-    *pixmap = XCreatePixmap(display, window, data->width, data->height,
-			    DefaultDepth(display, 0));
-    for (i = 0; i < data->height; i++)
-    {
-	for (j = 0; j < data->width; j++)
-	{
-	    Index = -1;
-	    for (k = 0; k < NumColors; k++)
-	    {
-		/* FIX ME  -- the following may need to compare more than one
-		   byte in case each pixel of the image is wider
-		 */
-		if (strncmp(ColorTable[k].Reference, Image, 1) == 0)
-		{
-		    Index = k;
-		    break;
-		}
-	    }
-	    if (Index == -1)
-		Exit(LOC, "Color Error\n");
-	    XDrawPoint(display, *pixmap, GCTable[Index], j, i);
-	    Image += 1;
-	}
-    }
-#if 0
-    if (_LtXmXpmCreateImageFromData(d, andrew, &im, &imshape, &attributes) ==
-	_LtXpmSuccess)
-    {
-	GC gc;
-
-	*pixmap = XCreatePixmap(d, window, im->width, im->height, im->depth);
-
-	gc = XCreateGC(d, window, 0, NULL);
-
-	XPutImage(d, *pixmap, gc, im, 0, 0, 0, 0, im->width, im->height);
-
-	XFreeGC(d, gc);
-
-	/* this should probably be enabled */
-#if 0
-	XDestroyImage(im);
-	if (imshape)
-	    XDestroyImage(imshape);
-#endif
-
-	_LtXmXpmFreeAttributes(&attributes);
-    }
-#endif
-
-    free(andrew);
-    free(GCTable);
-}
-
-Cardinal 
+extern Cardinal 
 MrmFetchColorLiteral(MrmHierarchy hierarchy_id, String index,
 		     Display *display, Colormap cmap,
 		     Pixel *pixel_return)
@@ -517,7 +349,7 @@ MrmFetchColorLiteral(MrmHierarchy hierarchy_id, String index,
     return MrmFAILURE;
 }
 
-Cardinal 
+extern Cardinal 
 MrmFetchLiteral(MrmHierarchy hierarchy_id, String index, Display *d, XtPointer *value, MrmCode *type)
 {
     SymbolTableType *symbol;
@@ -543,7 +375,7 @@ MrmFetchLiteral(MrmHierarchy hierarchy_id, String index, Display *d, XtPointer *
     return MrmNOT_FOUND;
 }
 
-Cardinal 
+extern Cardinal 
 MrmFetchWidgetOverride(MrmHierarchy hierarchy_id, String index, Widget parent_widget, String override_name, ArgList override_args, Cardinal override_num_args, Widget *widget, MrmType *class)
 {
     Cardinal returnValue =
@@ -552,7 +384,7 @@ MrmFetchWidgetOverride(MrmHierarchy hierarchy_id, String index, Widget parent_wi
     return returnValue;
 }
 
-Cardinal
+extern Cardinal
 MrmFetchSetValues(MrmHierarchy hierarchy_id,
 				  Widget w,
 				  ArgList args,
@@ -563,7 +395,7 @@ MrmFetchSetValues(MrmHierarchy hierarchy_id,
 	return MrmFAILURE;
 }
 
-Cardinal
+extern Cardinal
 MrmFetchBitmapLiteral(MrmHierarchy hierarchy_id,
 				      String index,
 				      Screen *screen,
@@ -577,11 +409,7 @@ MrmFetchBitmapLiteral(MrmHierarchy hierarchy_id,
 	return MrmFAILURE;
 }
 	
-
-static int FetchCount = 0;
-SymbolTableType *InstantationSymbolTable = NULL;
-
-Cardinal 
+extern Cardinal 
 MrmFetchWidget(MrmHierarchy hierarchy_id, String index, Widget parent_widget, Widget *widget, MrmType *class)
 {
     DummyWidget *DW = NULL;
@@ -622,7 +450,7 @@ MrmFetchWidget(MrmHierarchy hierarchy_id, String index, Widget parent_widget, Wi
 	}
     }
     if (NULL == DW)
-	Exit(LOC, "Looks like a corrupt uid file\n");
+	__MrmExit(LOC, "Looks like a corrupt uid file\n");
 
     if ((FetchCount != 1) && (NULL != hierarchy_id))
     {
@@ -701,7 +529,7 @@ MrmFetchWidget(MrmHierarchy hierarchy_id, String index, Widget parent_widget, Wi
 	    *widget = CreateFunctions[CreateClass].function(parent_widget,
 							  CreateName, args, n);
 	    new->value = (char *)*widget;
-	    new->Name = Store(CreateName);
+	    new->Name = __MrmStore(CreateName);
 	    new->Next = InstantationSymbolTable;
 	    InstantationSymbolTable = new;
 	    new->type = ANOTHER_WIDGET;
@@ -709,7 +537,7 @@ MrmFetchWidget(MrmHierarchy hierarchy_id, String index, Widget parent_widget, Wi
     }
     if (NULL == *widget)
     {
-	Exit(LOC, "Couldn't create widget %s", DW->Name);
+	__MrmExit(LOC, "Couldn't create widget %s", DW->Name);
     }
     UilModule[module_id].WidgetArray[this_id] = *widget;
     for (i = 0; i < DW->NumberOfChildren; i++)
@@ -762,7 +590,7 @@ MrmFetchWidget(MrmHierarchy hierarchy_id, String index, Widget parent_widget, Wi
 }
 
 
-Cardinal
+extern Cardinal
 MrmFetchInterfaceModule(MrmHierarchy hierarchy_id ,
 					char *module_name,
 					Widget parent,
@@ -772,7 +600,164 @@ MrmFetchInterfaceModule(MrmHierarchy hierarchy_id ,
 	_XmWarning(NULL, "MrmFetchInterfaceModule() is not yet implemented!");
 	return MrmFAILURE;
 }
-void 
+
+
+static void 
+MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg,
+	   Pixel bg)
+{
+    char *temp, *value;
+    char buffer[256];
+    int filenr;
+    ColorTableHeaderType *ColorTableHeader;
+    ColorTableType *ColorTable;
+    _LtXpmAttributes attributes;
+    char Header[256];
+    char **andrew = NULL;
+    int NumColors;
+    int i, j, k, Index;
+    SymbolTableType *symbol;
+    GC *GCTable;
+    XColor exact, def;
+    char *Image;
+    ColorDefType *Color;
+
+    attributes.valuemask = 0;
+    temp = data->ColorTable;
+    if (NULL == (symbol = LookupValue(GlobalSymbolTable, temp)))
+    {
+	for (filenr = 0; filenr < NumberFiles; filenr++)
+	{
+	    if (NULL !=
+		(symbol = LookupValue(UilModule[filenr].SymbolTable, temp)))
+		break;
+	}
+	if (NULL == symbol)
+	    __MrmExit(LOC, "Couldn't find %s in symbol tables\n", temp);
+    }
+    ColorTableHeader = (ColorTableHeaderType *)symbol->value;
+    ColorTable = ColorTableHeader->ColorTable;
+    NumColors = ColorTableHeader->NumColors;
+    GCTable = (GC *)malloc(sizeof(GC) * NumColors);
+    if (NULL == ColorTable[0].StringXPM)
+    {
+	for (i = 0; i < NumColors; i++)
+	{
+	    long theColor = 0;
+
+	    value = ColorTable[i].Color;
+	    if (ColorTable[i].IsAddress)
+	    {
+		if (NULL == (symbol = LookupValue(GlobalSymbolTable, value)))
+		{
+		    for (filenr = 0; filenr < MaxHier; filenr++)
+		    {
+			if (NULL !=
+			    (symbol = LookupValue(UilModule[filenr].SymbolTable, value)))
+			    break;
+		    }
+		    if (NULL == symbol)
+			__MrmExit(LOC, "Couldn't find %s in symbol tables\n", value);
+		}
+		value = symbol->value;
+	    }
+	    Color = (ColorDefType *) value;
+	    sprintf(buffer, "%s     c %s", ColorTable[i].Reference, Color->name);
+	    GCTable[i] = XCreateGC(d, window, 0, NULL);
+	    if (Color->name)
+	    {
+		if (strcmp(Color->name, "_fg") == 0)
+		      theColor = fg;
+		    else if (strcmp(Color->name, "_bg") == 0)
+			  theColor = bg;
+		    else
+		    {
+			XAllocNamedColor(d, colormap, Color->name, &def, &exact);
+			theColor = def.pixel;
+		    }
+	    }
+	    else
+	    {
+		def.red = Color->r;
+		def.green = Color->g;
+		def.blue = Color->b;
+		if (XAllocColor(display, colormap, &def))
+		    theColor = def.pixel;
+		else
+		    __MrmExit(LOC, "Couldn't resolve color: %s\n",
+			 Color->r, Color->g, Color->b);
+	    }
+
+	    XSetForeground(d, GCTable[i], theColor);
+/*      ColorTable[i].StringXPM = __MrmStore(buffer); */
+	}
+    }
+    andrew = (char **)malloc(sizeof(char *) * (1 + NumColors + data->width));
+    sprintf(Header, "%d %d %d 1 -1 -1", data->width, data->height, NumColors);
+    andrew[0] = Header;
+    for (i = 0; i < NumColors; i++)
+	andrew[i + 1] = ColorTable[i].StringXPM;
+    for (i = 0; i < data->width; i++)
+	andrew[i + NumColors + 1] = &data->data[i * data->width];
+    Image = data->data;
+
+    /* the following is a total hack because I want to go to bed.  The Pixel
+     * value in XmGetPixmapByDepth are totally made up. */
+    *pixmap = XCreatePixmap(display, window, data->width, data->height,
+			    DefaultDepth(display, 0));
+    for (i = 0; i < data->height; i++)
+    {
+	for (j = 0; j < data->width; j++)
+	{
+	    Index = -1;
+	    for (k = 0; k < NumColors; k++)
+	    {
+		/* FIX ME  -- the following may need to compare more than one
+		   byte in case each pixel of the image is wider
+		 */
+		if (strncmp(ColorTable[k].Reference, Image, 1) == 0)
+		{
+		    Index = k;
+		    break;
+		}
+	    }
+	    if (Index == -1)
+		__MrmExit(LOC, "Color Error\n");
+	    XDrawPoint(display, *pixmap, GCTable[Index], j, i);
+	    Image += 1;
+	}
+    }
+#if 0
+    if (_LtXmXpmCreateImageFromData(d, andrew, &im, &imshape, &attributes) ==
+	_LtXpmSuccess)
+    {
+	GC gc;
+
+	*pixmap = XCreatePixmap(d, window, im->width, im->height, im->depth);
+
+	gc = XCreateGC(d, window, 0, NULL);
+
+	XPutImage(d, *pixmap, gc, im, 0, 0, 0, 0, im->width, im->height);
+
+	XFreeGC(d, gc);
+
+	/* this should probably be enabled */
+#if 0
+	XDestroyImage(im);
+	if (imshape)
+	    XDestroyImage(imshape);
+#endif
+
+	_LtXmXpmFreeAttributes(&attributes);
+    }
+#endif
+
+    free(andrew);
+    free(GCTable);
+}
+
+
+static void 
 AddGeometryAttributes(GeoType **GeometryList, int module_id, int this_id,
 		      DummyWidget *DW)
 {
@@ -784,7 +769,7 @@ AddGeometryAttributes(GeoType **GeometryList, int module_id, int this_id,
     node->DW = DW;
 }
 
-void 
+static void 
 SetGeometryAttributes(GeoType **GeometryList)
 {
     GeoType *node = *GeometryList;
@@ -808,7 +793,7 @@ SetGeometryAttributes(GeoType **GeometryList)
     *GeometryList = NULL;
 }
 
-void 
+static void
 GetCallbacks(int filenr, int wid_id, DummyWidget *DW)
 {
     callbackType *Next = DW->callbacks;
@@ -825,13 +810,13 @@ GetCallbacks(int filenr, int wid_id, DummyWidget *DW)
 		char *temp;
 
 		temp = Next->Parameters->value;
-		if (1 != LookUpPredefines(temp, (long *)&ParameterValue))
+		if (1 != __MrmLookUpPredefines(temp, (long *)&ParameterValue))
 		    if (NULL ==
 			(SymbolTable = LookupValue(UilModule[filenr].SymbolTable, temp)))
 		    {
 			if (NULL == (SymbolTable = LookupValue(GlobalSymbolTable, temp)))
 			{
-			    Exit(LOC, "Couldn't find %s in symbol tables\n", temp);
+			    __MrmExit(LOC, "Couldn't find %s in symbol tables\n", temp);
 			}
 		    }
 	    }
@@ -849,17 +834,17 @@ GetCallbacks(int filenr, int wid_id, DummyWidget *DW)
 	}
 	if (strcmp("createCallback", Next->argName) != 0)
 	    XtAddCallback(w, Next->argName,
-			  (XtCallbackProc)LookUpFunction(Next->functionName),
+			  (XtCallbackProc)__MrmLookUpFunction(Next->functionName),
 			  ParameterValue);
 	else
 	    ((XtCallbackProc)
-	     LookUpFunction(Next->functionName)) (w, ParameterValue, NULL);
+	     __MrmLookUpFunction(Next->functionName)) (w, ParameterValue, NULL);
 	Next = Next->next;
     }
     return;
 }
 
-void 
+static void
 GetAttributes(Display *d, Window w, int module_id,
 	      int *n, Arg *args,
 	      DummyWidget *DW, SymbolTableType
@@ -893,7 +878,7 @@ GetAttributes(Display *d, Window w, int module_id,
 	    XtSetArg(args[*n], Next->Name, value);
 	    (*n)++;
 	    if (*n >= MAX_ARGS)
-		Exit(LOC, "Too many args\n");
+		__MrmExit(LOC, "Too many args\n");
 	    if (count > 0)
 	    {			/* Certain attributes have a count associated */
 		char buff[256];	/* with them.  This is a temporary(?) way to  */
@@ -909,18 +894,18 @@ GetAttributes(Display *d, Window w, int module_id,
 		    strcpy(buff, XmNnumValues);
 #endif
 		else
-		    Warn(LOC, "Can't find %s\n", Next->Name);
+		    __MrmWarn(LOC, "Can't find %s\n", Next->Name);
 		XtSetArg(args[*n], buff, count);
 		(*n)++;
 		if (*n >= MAX_ARGS)
-		    Exit(LOC, "You guessed it - Too many args\n");
+		    __MrmExit(LOC, "You guessed it - Too many args\n");
 	    }
 	}
 	Next = Next->Next;
     }
 }
 
-int 
+static int 
 GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 		    int module_id, SymbolTableType *FormSymbolTable)
 {
@@ -965,7 +950,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 		    {
 			if (NULL == (SymbolTable = LookupValue(FormSymbolTable, temp)))
 			{
-			    Exit(LOC, "Could not find %s\n", temp);
+			    __MrmExit(LOC, "Could not find %s\n", temp);
 			}
 		    }
 		}
@@ -985,7 +970,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 	    XmFontListEntry theEntry;
 
 	    if (NULL == theFont)
-		Exit(LOC, "Can't load font %s\n", Next->value);
+		__MrmExit(LOC, "Can't load font %s\n", Next->value);
 	    theEntry = XmFontListEntryCreate(XmFONTLIST_DEFAULT_TAG,
 					     XmFONT_IS_FONT, theFont);
 	    *value = (long)XmFontListAppendEntry(NULL, theEntry);
@@ -1010,7 +995,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 		symbolTable = LookUpAddr(FontName, module_id);
 		fprintf(stderr, "LOOKUP FONT %s\n", FontName);
 		if (NULL == symbolTable)
-		    Exit(LOC, "Can't find %s in the symbol tables\n", FontName);
+		    __MrmExit(LOC, "Can't find %s in the symbol tables\n", FontName);
 		FontName = (char *)symbolTable->value;
 
 /* RtoL = theHeader->FontTable[i].Tag.DirectionRtoL; */
@@ -1036,7 +1021,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 		    *value = (XtArgVal)def.pixel;
 		}
 		else
-		    Exit(LOC, "Couldn't resolve color: %s\n", Next->value);
+		    __MrmExit(LOC, "Couldn't resolve color: %s\n", Next->value);
 	    }
 	    else
 	    {
@@ -1046,13 +1031,13 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 		if (XAllocColor(display, colormap, &def))
 		    *value = (XtArgVal)def.pixel;
 		else
-		    Exit(LOC, "Couldn't resolve color: %s\n", Next->value);
+		    __MrmExit(LOC, "Couldn't resolve color: %s\n", Next->value);
 	    }
 	    break;
 	}
     case MrmRtypeAddrName:
 	temp = Next->value;
-	if (1 == LookUpPredefines(temp, value))
+	if (1 == __MrmLookUpPredefines(temp, value))
 	    break;
 	if (NULL ==
 	    (SymbolTable = LookupValue(UilModule[module_id].SymbolTable, temp)))
@@ -1061,7 +1046,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 	    {
 		if (NULL == (SymbolTable = LookupValue(FormSymbolTable, temp)))
 		{
-		    Exit(LOC, "Could not find %s\n", temp);
+		    __MrmExit(LOC, "Could not find %s\n", temp);
 		}
 	    }
 	}
@@ -1092,7 +1077,7 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 			{
 			    if (NULL == (SymbolTable = LookupValue(FormSymbolTable, temp)))
 			    {
-				Exit(LOC, "Could not find %s\n", temp);
+				__MrmExit(LOC, "Could not find %s\n", temp);
 			    }
 			}
 		    }
@@ -1116,12 +1101,12 @@ GetSymbolTableValue(XtArgVal *value, SymbolTableType *Next,
 	*value = (XtArgVal)(Next->value);
 	break;
     default:
-	Exit(LOC, "UNKNOWN ATTRIBUTE: %d\n", Next->type);
+	__MrmExit(LOC, "UNKNOWN ATTRIBUTE: %d\n", Next->type);
     }
     return status;
 }
 
-XmString 
+static XmString 
 DecodeComplexString(StringType * stringC, int module_id, char *ascii)
 {
     SymbolTableType *st;
@@ -1137,7 +1122,7 @@ DecodeComplexString(StringType * stringC, int module_id, char *ascii)
 	    tempC = stringC;
 	    st = LookUpAddr(stringC->theString, module_id);
 	    if (NULL == st)
-		Exit(LOC, "Could not find %s\n", stringC->theString);
+		__MrmExit(LOC, "Could not find %s\n", stringC->theString);
 	    tempC = (StringType *) st->value;
 	    s = XmStringConcat(s, DecodeComplexString(tempC, module_id, NULL));
 	}
@@ -1158,7 +1143,7 @@ DecodeComplexString(StringType * stringC, int module_id, char *ascii)
     return s;
 }
 
-SymbolTableType *
+static SymbolTableType *
 GetSymbolTable(SymbolTableType *Table)
 {
     char name[256], ch;
@@ -1183,7 +1168,7 @@ GetSymbolTable(SymbolTableType *Table)
 	else if (NULL == Table)
 	    Table = NewTable;
 	LastTable = NewTable;
-	NewTable->Name = Store(name);
+	NewTable->Name = __MrmStore(name);
 	NewTable->type = getchar();
 	NewTable->value = ReadType(NewTable->type);
     }
@@ -1194,7 +1179,7 @@ GetSymbolTable(SymbolTableType *Table)
 	return Table;
 }
 
-SymbolTableType *
+static SymbolTableType *
 LookupValue(SymbolTableType *SymbolTable, char *name)
 {
     while (SymbolTable)
@@ -1207,13 +1192,14 @@ LookupValue(SymbolTableType *SymbolTable, char *name)
     return NULL;
 }
 
-void 
+static void 
 PrintWidgetTree(UilModuleType *Module)
 {
     PrintWidgets(Module);
 }
+
 /* LIST SYMBOL_TABLE(Global) SYMBOL_TABLE(local) WIDGETS */
-void 
+static void 
 ReadWidgetTree(UilModuleType *Module)
 {
     ReadList(Module);
@@ -1225,7 +1211,7 @@ ReadWidgetTree(UilModuleType *Module)
 }
 
 /* LIST = INT(count) NAMES  CHAR(0) */
-void 
+static void 
 ReadList(UilModuleType *Module)
 {
     int NumberOfWidgets;
@@ -1249,17 +1235,17 @@ ReadList(UilModuleType *Module)
 	{			/* NAMES = NAME "  */
 	    string[j] = (char)c;	/* NAME = [^"]*    */
 	    if (j >= MAX_STR)
-		Exit(LOC, "String def too long\n");
+		__MrmExit(LOC, "String def too long\n");
 	    c = getc(stdin);
 	}
 	string[j] = 0;
-	Module->DummyWidgetArray[i].Name = Store(string);
+	Module->DummyWidgetArray[i].Name = __MrmStore(string);
     }
     if (c)
-	Exit(LOC, "ERROR in header\n");
+	__MrmExit(LOC, "ERROR in header\n");
 }
 
-void 
+static void 
 PrintWidgets(UilModuleType *Module)
 {
     DummyWidget *DW;
@@ -1277,7 +1263,7 @@ PrintWidgets(UilModuleType *Module)
     }
 }
 
-void 
+static void 
 PrintArgs(SymbolTableType *Next)
 {
     fprintf(stderr, "\targuments {\n");
@@ -1310,7 +1296,7 @@ PrintArgs(SymbolTableType *Next)
     fprintf(stderr, "\t};\n");
 }
 
-void 
+static void 
 PrintControls(int count, int *ids, DummyWidget *Array)
 {
     int i;
@@ -1325,7 +1311,7 @@ PrintControls(int count, int *ids, DummyWidget *Array)
     fprintf(stderr, "\t}\n");
 }
 
-void 
+static void 
 PrintCallbacks(callbackType *Next)
 {
     SymbolTableType *NextParam;
@@ -1362,11 +1348,12 @@ PrintCallbacks(callbackType *Next)
     };
     fprintf(stderr, "\t};\n");
 }
+
 /*
    // WIDGETS = WIDGET WIDGETS
    //         | NULL
  */
-void 
+static void 
 ReadWidgets(UilModuleType *Module)
 {
     char c;
@@ -1403,12 +1390,12 @@ ReadWidgets(UilModuleType *Module)
 	}
 	temp[i] = 0;
 	DW = &Module->DummyWidgetArray[WidgetIndex];
-	DW->Name = Store(temp);
+	DW->Name = __MrmStore(temp);
 	if (strcmp(DW->Name, "templatePick") == 0)
 	    fprintf(stderr, "STOP\n");
 	fread(&this_id, sizeof(this_id), 1, stdin);	/*INT(id)    */
 	if (this_id != (WidgetIndex + 1))
-	    Exit(LOC, "INDEX ERROR:widgets should be stored in file by id number\n");
+	    __MrmExit(LOC, "INDEX ERROR:widgets should be stored in file by id number\n");
 	fread(&DW->class, sizeof(DW->class), 1, stdin);		/*INT(class) */
 	fread(&DW->managed, sizeof(DW->managed), 1, stdin);	/*CHAR(managed) */
 	fread(&DW->parent, sizeof(DW->parent), 1, stdin);	/*INT(parent) */
@@ -1458,7 +1445,7 @@ ReadWidgets(UilModuleType *Module)
    // PARAMS = CHAR(type) INT(value) PARAMS      integer,bool
    //        | CHAR(type) STRING CHAR(0) PARAMS   AddrName,CString,String,keysym
  */
-void 
+static void 
 ReadCallbacks(callbackType **first)
 {
     char c, temp[MAX_BUFFER];
@@ -1484,11 +1471,11 @@ ReadCallbacks(callbackType **first)
 	for (i = 0, c = getchar(); c != '"'; c = getchar())	/* NAME(argname) */
 	    temp[i++] = c;
 	temp[i] = 0;
-	new->argName = Store(temp);
+	new->argName = __MrmStore(temp);
 	for (i = 0, c = getchar(); c != '"'; c = getchar())	/* NAME(function name) */
 	    temp[i++] = c;
 	temp[i] = 0;
-	new->functionName = Store(temp);
+	new->functionName = __MrmStore(temp);
 /* PARAMS = CHAR(type) INT(value) PARAMS      integer,bool       */
 /*        | CHAR(type) STRING CHAR(0) PARAMS   AddrName,CString,String,keysym */
 	NumberOfParams = getchar();
@@ -1509,7 +1496,7 @@ ReadCallbacks(callbackType **first)
 /*  TABLE(attributes) = EXPRESSION TABLE(attributes)
    //                    | NULL
  */
-SymbolTableType *
+static SymbolTableType *
 ReadAttributes(void)
 {
     char c;
@@ -1532,7 +1519,7 @@ ReadAttributes(void)
 	else
 	    Last->Next = Next;
 	fread(&(Next->Index), sizeof(Next->Index), 1, stdin);
-	GetArgValues(Next->Index, &Next->Name, &Next->Access);
+	__MrmGetArgValues(Next->Index, &Next->Name, &Next->Access);
 	Next->type = getchar();	/* CHAR(type) */
 	Next->value = ReadType(Next->type);
 	Last = Next;
@@ -1541,7 +1528,7 @@ ReadAttributes(void)
     return Return;
 }
 
-char *
+static char *
 ReadType(int type)
 {
     int i, j;
@@ -1585,7 +1572,7 @@ ReadType(int type)
 			size += 10;
 			array = (char **)realloc(array, size * sizeof(char *));
 		    }
-		    array[index] = Store(last);
+		    array[index] = __MrmStore(last);
 		    index++;
 		    last = temp + 1;
 		}
@@ -1599,7 +1586,7 @@ ReadType(int type)
     case MrmRtypeAddrName:
 	temp = &buffer[0];
 	while ((*temp++ = getchar()));
-	ReturnValue = (char *)Store(buffer);
+	ReturnValue = (char *)__MrmStore(buffer);
 	break;
     case MrmRtypeChar8:
 	{
@@ -1607,10 +1594,10 @@ ReadType(int type)
 	    temp = &buffer[0];
 	    while ((*temp++ = getchar()));
 	    fprintf(stderr, "name = %s  ", buffer);
-	    theString->theString = (char *)Store(buffer);
+	    theString->theString = (char *)__MrmStore(buffer);
 	    temp = &buffer[0];
 	    while ((*temp++ = getchar()));
-	    theString->theFontSet = Store(buffer);
+	    theString->theFontSet = __MrmStore(buffer);
 	    ReturnValue = (char *)theString;
 	    break;
 	}
@@ -1629,14 +1616,14 @@ ReadType(int type)
 		    break;
 		}
 		if (MAX_BUFFER == i)
-		    Exit(LOC, "Static storage area exhausted\n");
+		    __MrmExit(LOC, "Static storage area exhausted\n");
 		(*handle) = (StringType *) malloc(sizeof(StringType));
-		(*handle)->theString = Store(buffer);
+		(*handle)->theString = __MrmStore(buffer);
 
 		for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 		if (MAX_BUFFER == i)
-		    Exit(LOC, "Static storage area exhausted: %s\n", buffer);
-		(*handle)->theFontSet = Store(buffer);
+		    __MrmExit(LOC, "Static storage area exhausted: %s\n", buffer);
+		(*handle)->theFontSet = __MrmStore(buffer);
 		(*handle)->IsAddr = getchar();
 		(*handle)->IsSeparator = getchar();
 		(*handle)->Next = NULL;
@@ -1664,23 +1651,23 @@ ReadType(int type)
 
 		fread(&tempType, sizeof(char), 1, stdin);
 		if (tempType != MrmRtypeFontSet)
-		    Exit(LOC, "There may be an internal bug with font table decoding. "
+		    __MrmExit(LOC, "There may be an internal bug with font table decoding. "
 		    "%d read != %d from header.\n", tempType, MrmRtypeFontSet);
 		for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 		if (MAX_BUFFER == i)
-		    Exit(LOC, "Static storage area exhausted\n");
-		FontTable[j].Tag.name = Store(buffer);
+		    __MrmExit(LOC, "Static storage area exhausted\n");
+		FontTable[j].Tag.name = __MrmStore(buffer);
 		fread(&FontTable[j].Tag.DirectionRtoL, sizeof(int), 1, stdin);
 		fread(&FontTable[j].Tag.WideChar, sizeof(int), 1, stdin);
 
 		/*                   FONT = CHAR(MrmTypeFont) NAME   */
 		fread(&tempType, sizeof(char), 1, stdin);
 		if (tempType != MrmRtypeFont)
-		    Exit(LOC, "There may be an internal bug with font table decoding\n");
+		    __MrmExit(LOC, "There may be an internal bug with font table decoding\n");
 		for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 		if (MAX_BUFFER == i)
-		    Exit(LOC, "Static storage area exhausted\n");
-		FontTable[j].FontName = Store(buffer);
+		    __MrmExit(LOC, "Static storage area exhausted\n");
+		FontTable[j].FontName = __MrmStore(buffer);
 	    }
 	    ReturnValue = (char *)FontTableHeader;
 	    break;
@@ -1701,8 +1688,8 @@ ReadType(int type)
 	    {
 		for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 		if (MAX_BUFFER == i)
-		    Exit(LOC, "Static storage area exhausted\n");
-		ColorTable[j].Reference = Store(buffer);
+		    __MrmExit(LOC, "Static storage area exhausted\n");
+		ColorTable[j].Reference = __MrmStore(buffer);
 		fread(&type, sizeof(type), 1, stdin);
 		ColorTable[j].IsAddress = (MrmRtypeAddrName == type);
 		ColorTable[j].StringXPM = NULL;
@@ -1716,7 +1703,7 @@ ReadType(int type)
 	    ColorDefType *Color = (ColorDefType *) malloc(sizeof(ColorDefType));
 	    for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 	    if (MAX_BUFFER == i)
-		Exit(LOC, "Static storage area exhausted\n");
+		__MrmExit(LOC, "Static storage area exhausted\n");
 	    if (0 == i)
 	    {
 		Color->name = NULL;
@@ -1726,7 +1713,7 @@ ReadType(int type)
 	    }
 	    else
 	    {
-		Color->name = Store(buffer);
+		Color->name = __MrmStore(buffer);
 	    }
 	    ReturnValue = (char *)Color;
 	    break;
@@ -1734,8 +1721,8 @@ ReadType(int type)
     case MrmRtypeFont:
 	for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 	if (MAX_BUFFER == i)
-	    Exit(LOC, "Static storage area exhausted\n");
-	ReturnValue = Store(buffer);
+	    __MrmExit(LOC, "Static storage area exhausted\n");
+	ReturnValue = __MrmStore(buffer);
 	break;
     case MrmRtypePixmapImage:
 	{
@@ -1749,15 +1736,15 @@ ReadType(int type)
 	    SizeOfData = pixmap->width * pixmap->height;
 	    for (i = 0; (i < MAX_BUFFER) && (buffer[i] = getchar()); i++);
 	    if (MAX_BUFFER == i)
-		Exit(LOC, "Static storage area exhausted\n");
-	    pixmap->ColorTable = Store(buffer);
+		__MrmExit(LOC, "Static storage area exhausted\n");
+	    pixmap->ColorTable = __MrmStore(buffer);
 	    pixmap->data = (char *)malloc(SizeOfData);
 	    fread(pixmap->data, sizeof(char), SizeOfData, stdin);
 	    ReturnValue = (char *)pixmap;
 	    break;
 	}
     default:
-	Exit(LOC, "UNKNOWN ATTRIBUTE: code = %d\n", type);
+	__MrmExit(LOC, "UNKNOWN ATTRIBUTE: code = %d\n", type);
     }
 
     return ReturnValue;
@@ -1779,8 +1766,8 @@ ReadType(int type)
 	    fread(pixmap, sizeof(PixmapType) - sizeof(long), 1, stdin);		/*NAME(pixmap) */
 	    for (i = 0; (i < MAX_BUFFER) && (temp[i] = getchar()); i++);	/*NAME(colortab */
 	    if (2048 == i)
-		Exit(LOC, "Static storage area exhausted\n");
-	    pixmap->ColorTable = Store(temp);
+		__MrmExit(LOC, "Static storage area exhausted\n");
+	    pixmap->ColorTable = __MrmStore(temp);
 	    SizeOfData = pixmap->width * pixmap->height;
 	    pixmap->data = (char *)malloc(SizeOfData);
 	    fread(pixmap->data, sizeof(char), SizeOfData, stdin);	/* image data */
@@ -1812,16 +1799,16 @@ ReadType(int type)
 	if (MAX_BUFFER == i)
 	{
 	    temp[256] = 0;
-	    Exit(LOC, "String too complex: %s", temp);
+	    __MrmExit(LOC, "String too complex: %s", temp);
 	}
 	temp[i] = 0;
-	ReturnValue = Store(temp);
+	ReturnValue = __MrmStore(temp);
 	i = 0;			/* NAME(tag) CHAR(0) */
 	while ((i < MAX_BUFFER) && (temp[i++] = getchar()));
 	if (MAX_BUFFER == i)
 	{
 	    temp[256] = 0;
-	    Exit(LOC, "String too complex: %s", temp);
+	    __MrmExit(LOC, "String too complex: %s", temp);
 	}
 	temp[i] = 0;
 	fprintf(stderr, "TAG = %s\n", temp);
@@ -1835,19 +1822,19 @@ ReadType(int type)
 	if (MAX_BUFFER == i)
 	{
 	    temp[256] = 0;
-	    Exit(LOC, "String too complex: %s", temp);
+	    __MrmExit(LOC, "String too complex: %s", temp);
 	}
 	temp[i] = 0;
-	return (Store(temp));
+	return (__MrmStore(temp));
 	break;
     default:
-	Exit(LOC, "Unknown Attribute type: %d\n", c);
+	__MrmExit(LOC, "Unknown Attribute type: %d\n", c);
     }
 #endif
 
 }
 
-void 
+static void 
 Xm_List(Widget parent_widget, DummyWidget *DW, int module_id)
 {
     Arg args[10];
@@ -1872,7 +1859,7 @@ Xm_List(Widget parent_widget, DummyWidget *DW, int module_id)
 	    temp = Next->value;
 	    if (NULL == (SymbolTable = LookUpAddr(temp, module_id)))
 	    {
-		LookUpPredefines(temp, &value);
+		__MrmLookUpPredefines(temp, &value);
 		break;
 	    }
 	    if (0 == strcmp(Next->Name, "items"))
@@ -1897,7 +1884,7 @@ Xm_List(Widget parent_widget, DummyWidget *DW, int module_id)
 			{
 			    if (NULL == (SymbolTable = LookupValue(GlobalSymbolTable, temp)))
 			    {
-				Exit(LOC, "Could not find %s\n", temp);
+				__MrmExit(LOC, "Could not find %s\n", temp);
 			    }
 			}
 			strcpy(s, SymbolTable->value);
@@ -1912,7 +1899,7 @@ Xm_List(Widget parent_widget, DummyWidget *DW, int module_id)
 		value = (XtArgVal)SymbolTable->value;
 	    break;
 	default:
-	    Exit(LOC, "UNKNOWN ATTRIBUTE\n");
+	    __MrmExit(LOC, "UNKNOWN ATTRIBUTE\n");
 	}
 	XtSetArg(args[n], Next->Name, value);
 	n++;
@@ -1923,7 +1910,7 @@ Xm_List(Widget parent_widget, DummyWidget *DW, int module_id)
 }
 
 
-FILE *
+static FILE *
 UILOpen(char *tFileName, char *mode, FILE * old)
 {
     FILE *Return = NULL;
@@ -1987,7 +1974,7 @@ UILOpen(char *tFileName, char *mode, FILE * old)
 		j = -1;
 		if (NULL != (Return = freopen(Substitute(buffer), mode, old)))
 		{
-		    Warn(LOC, "Opening %s\n", buffer);
+		    __MrmWarn(LOC, "Opening %s\n", buffer);
 		    return Return;
 		}
 		if (0 == UILPath[i])
@@ -2006,11 +1993,11 @@ UILOpen(char *tFileName, char *mode, FILE * old)
 	    {
 	    };
     if (NULL != Return)
-	Warn(LOC, "Opening %s\n", buffer);
+	__MrmWarn(LOC, "Opening %s\n", buffer);
     return Return;
 }
 
-char *
+static char *
 Substitute(char *buffer)
 {
     static char buffer2[256];
@@ -2048,7 +2035,7 @@ Substitute(char *buffer)
 		string += 4;
 		break;
 	    default:
-		Exit(LOC, "Unknown format\n");
+		__MrmExit(LOC, "Unknown format\n");
 	    }
 	}
 	else
@@ -2060,7 +2047,7 @@ Substitute(char *buffer)
     return buffer2;
 }
 
-void 
+static void 
 PrintSymbolTable(SymbolTableType *SymbolTable)
 {
     for (; SymbolTable; SymbolTable = SymbolTable->Next)
@@ -2068,7 +2055,7 @@ PrintSymbolTable(SymbolTableType *SymbolTable)
 }
 
 
-void 
+static void 
 FreeSymbolTable(SymbolTableType *t)
 {
     SymbolTableType *n;
@@ -2081,7 +2068,7 @@ FreeSymbolTable(SymbolTableType *t)
     }
 }
 
-SymbolTableType *
+static SymbolTableType *
 LookUpAddr(char *temp, int module_id)
 {
     SymbolTableType *SymbolTable;
@@ -2094,7 +2081,7 @@ LookUpAddr(char *temp, int module_id)
     return SymbolTable;
 }
 
-Cardinal
+extern Cardinal
 MrmRegisterNamesInHierarchy(MrmHierarchy hierarchy_id,
 			    MrmRegisterArglist reglist,
 			    MrmCount num_reg)
