@@ -1,8 +1,8 @@
-
 /* 
- * $Id: lookup.c,v 1.4 2000/01/26 12:43:39 amai Exp $
+ * $Id: lookup.c,v 1.8 2000/11/14 15:40:52 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -27,7 +27,14 @@
 
 #include <LTconfig.h>
 
-#include "Mrm/MrmPublic.h"
+#include <stdio.h>
+
+#if XtSpecificationRelease < 6
+#include <ctype.h>
+#include <X11/Xos.h>
+#endif
+
+#include <Mrm/MrmPublic.h>
 
 #include <Xm/Xm.h>
 #include <Xm/ArrowB.h>
@@ -73,57 +80,27 @@
 #if XmVERSION > 1
 #include <Xm/ComboBox.h>
 #include <Xm/Container.h>
-#include <Xm/CSText.h>
 #include <Xm/IconG.h>
 #include <Xm/Notebook.h>
 #include <Xm/SpinB.h>
 #endif
 
+/* CSText disappeared in Motif 2.1 */
+#if (XmVERSION == 2) && (XmREVISION == 0)
+#include <Xm/CSText.h>
+#endif
+
 #include "misc.h"
 #include "lookup.h"
 
-typedef Widget (*CreateFunction) (Widget, String, ArgList, Cardinal);
-
-typedef struct _CreateFunctionsType
-{
-    char *Name;
-    CreateFunction function;
-}
-CreateFunctionsType;
-
-typedef struct _ArgNamesType
-{
-    char *Name;
-    String theString;
-    char Access;
-}
-ArgNamesType;
-
-typedef struct _PredefinedType
-{
-    char *Name;
-    XtPointer value;
-}
-PredefinedType;
-
-extern ArgNamesType ArgNames[];
-extern PredefinedType Predefines[];
-extern int ArgSize;
-extern int PreSize;
-
-extern CreateFunctionsType CreateFunctions[];
-extern int ClassSize;
 
 enum
 {
     false, true
 };
 
-int NumberRegisteredFunctions;
-MrmRegisterArg *RegisteredFunctions;
-
-int NumberRegisteredFunctions;
-MrmRegisterArg *RegisteredFunctions;
+extern int NumberRegisteredFunctions;
+extern MrmRegisterArg *RegisteredFunctions;
 
 CreateFunctionsType CreateFunctions[] =
 {
@@ -145,6 +122,8 @@ CreateFunctionsType CreateFunctions[] =
     {"XmCommandDialog", XmCreateCommandDialog},
 #if XmVERSION > 1
     {"XmContainer", XmCreateContainer},
+#endif
+#if (XmVERSION == 2) && (XmREVISION == 0)
     {"XmCSText", XmCreateCSText},
 #endif
     {"XmDialogShell", XmCreateDialogShell},
@@ -185,7 +164,7 @@ CreateFunctionsType CreateFunctions[] =
     {"XmScale", XmCreateScale},
     {"XmScrollBar", XmCreateScrollBar},
     {"XmScrolledList", XmCreateScrolledList},
-#if XmVERSION > 1
+#if (XmVERSION == 2) && (XmREVISION == 0)
     {"XmScrolledCSText", XmCreateScrolledCSText},
 #endif
     {"XmScrolledText", XmCreateScrolledText},
@@ -274,7 +253,7 @@ ArgNamesType ArgNames[] =
     {"XmNbottomPosition", XmNbottomPosition, CSG},
     {"XmNbottomShadowColor", XmNbottomShadowColor, CSG},
     {"XmNbottomShadowPixmap", XmNbottomShadowPixmap, CSG},
-    {"XmNbottomWidget", XmNbottomWidget, /* 0 */ CSG},
+    {"XmNbottomWidget", XmNbottomWidget, 0 /* CSG */},
     {"XmNbrowseSelectionCallback", XmNbrowseSelectionCallback, C},
     {"XmNbuttonAcceleratorText", XmNbuttonAcceleratorText, C},
     {"XmNbuttonAccelerators", XmNbuttonAccelerators, C},
@@ -551,7 +530,7 @@ ArgNamesType ArgNames[] =
     {"XmNleftAttachment", XmNleftAttachment, CSG},
     {"XmNleftOffset", XmNleftOffset, CSG},
     {"XmNleftPosition", XmNleftPosition, CSG},
-    {"XmNleftWidget", XmNleftWidget, /* 0 */ CSG},
+    {"XmNleftWidget", XmNleftWidget, 0 /* CSG */},
     {"XmNlightThreshold", XmNlightThreshold, C},
     {"XmNlistItemCount", XmNlistItemCount, CSG},
     {"XmNlistItems", XmNlistItems, CSG},
@@ -727,7 +706,7 @@ ArgNamesType ArgNames[] =
     {"XmNrightAttachment", XmNrightAttachment, CSG},
     {"XmNrightOffset", XmNrightOffset, CSG},
     {"XmNrightPosition", XmNrightPosition, CSG},
-    {"XmNrightWidget", XmNrightWidget, /* 0 */ CSG},
+    {"XmNrightWidget", XmNrightWidget, 0 /* CSG */},
     {"XmNrowColumnType", XmNrowColumnType, CG},
     {"XmNrows", XmNrows, CSG},
     {"XmNrubberPositioning", XmNrubberPositioning, CSG},
@@ -864,7 +843,7 @@ ArgNamesType ArgNames[] =
     {"XmNtopPosition", XmNtopPosition, CSG},
     {"XmNtopShadowColor", XmNtopShadowColor, CSG},
     {"XmNtopShadowPixmap", XmNtopShadowPixmap, CSG},
-    {"XmNtopWidget", XmNtopWidget, /* 0 */ CSG},
+    {"XmNtopWidget", XmNtopWidget, 0 /* CSG */},
     {"XmNtransferProc", XmNtransferProc, CSG},
     {"XmNtransferStatus", XmNtransferStatus, CSG},
     {"XmNtransient", XmNtransient, CSG},
@@ -1258,8 +1237,8 @@ int ClassSize = sizeof(CreateFunctions) / sizeof(CreateFunctions[0]);
 int ArgSize = sizeof(ArgNames) / sizeof(ArgNames[0]);
 int PreSize = sizeof(Predefines) / sizeof(Predefines[0]);
 
-int 
-LookUpClassIndex(char *ClassName)
+extern int 
+__MrmLookUpClassIndex(char *ClassName)
 {
     int i = 0;
 
@@ -1269,19 +1248,19 @@ LookUpClassIndex(char *ClassName)
 	    fprintf(stderr, "lookup %s = index of %d\n", ClassName, i);
 	    return i;
 	}
-    Warn(LOC, "ZZ Undefined Class Name: %s\n", ClassName);
+    __MrmWarn(LOC, "ZZ Undefined Class Name: %s\n", ClassName);
     return -1;
 }
 
 void 
-GetArgValues(int index, char **theString, char *Access)
+__MrmGetArgValues(int index, char **theString, char *Access)
 {
     *theString = ArgNames[index].theString;
     *Access = ArgNames[index].Access;
 }
 
-int 
-LookUpArgIndex(char *ArgName)
+extern int 
+__MrmLookUpArgIndex(char *ArgName)
 {
     int i = 0;
 
@@ -1290,13 +1269,13 @@ LookUpArgIndex(char *ArgName)
 	{
 	    return i;
 	}
-    Warn(LOC, "Undefined Arg Name: %s\n", ArgName);
+    __MrmWarn(LOC, "Undefined Arg Name: %s\n", ArgName);
     return -1;
 }
 
 /* XtPointer         String     */
 char *
-LookUpFunction(char *FunctionName)
+__MrmLookUpFunction(char *FunctionName)
 {
     int i = 0;
 
@@ -1305,13 +1284,13 @@ LookUpFunction(char *FunctionName)
 	{
 	    return RegisteredFunctions[i].value;
 	}
-    Warn(LOC, "Could not find %s\n", FunctionName);
+    __MrmWarn(LOC, "Could not find %s\n", FunctionName);
     return NULL;
 }
 
 /* XtPointer           String */
-int 
-LookUpPredefines(char *Name, long *value)
+extern int
+__MrmLookUpPredefines(char *Name, long *value)
 {
     int i = 0;
 
@@ -1325,9 +1304,9 @@ LookUpPredefines(char *Name, long *value)
 }
 
 char *
-ArgNamesString(char *ArgName)
+__MrmArgNamesString(char *ArgName)
 {
-    return ArgNames[LookUpArgIndex(ArgName)].theString;
+    return ArgNames[__MrmLookUpArgIndex(ArgName)].theString;
 }
 
 #if XtSpecificationRelease < 6
@@ -1382,9 +1361,11 @@ ArgNamesString(char *ArgName)
  * without the other).
  */
 
+/*
 #include <X11/Xos.h>
 #include <stdio.h>
 #include <ctype.h>
+*/
 
 
 #define MAX_SIZE 255
@@ -1613,18 +1594,20 @@ XReadBitmapFileData(_Xconst char *filename,
 
     return (BitmapSuccess);
 }
-#endif
+#endif /* XtSpecificationRelease < 6 */
 
-int
-ReadBitmapFileData(char *Name, unsigned int *width, unsigned int *height,
-		   char **data, int *x_hot, int *y_hot)
+
+extern int
+__MrmReadBitmapFileData(char *Name, unsigned int *width, unsigned int *height,
+                        char **data, int *x_hot, int *y_hot)
 {
     int stat;
 
-    stat = XReadBitmapFileData(Name, width, height, (unsigned char **)data, x_hot, y_hot);
+    stat = XReadBitmapFileData(Name, width, height,
+                (unsigned char **)data, x_hot, y_hot);
     if (BitmapOpenFailed == stat)
-	Exit(LOC, "%s can't be opened\n", Name);
+	__MrmExit(LOC, "%s can't be opened\n", Name);
     if (BitmapFileInvalid == stat)
-	Exit(LOC, "%s is an invalid bitmap file\n", Name);
+	__MrmExit(LOC, "%s is an invalid bitmap file\n", Name);
     return 1;
 }
