@@ -1,8 +1,9 @@
 /**
  *
- * $Id: uillex.c,v 1.8 2000/01/16 17:12:02 amai Exp $
+ * $Id: uillex.c,v 1.13 2000/10/25 11:38:59 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,23 +23,31 @@
  *
  */ 
 
-static char *rcsid = "$Id: uillex.c,v 1.8 2000/01/16 17:12:02 amai Exp $";
+static const char rcsid[] = "$Id: uillex.c,v 1.13 2000/10/25 11:38:59 amai Exp $";
+
+#include <LTconfig.h>
 
 /* Enable this for verbose lexing */
 /* #define DEBUG */
 
 #include <stdarg.h>
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <errno.h>
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
 
 #include <XmI/UilI.h>
 #include <uil/UilSymGl.h>
 
-void parse_destroy(Uil_parse_data *pd);
 
-void
-uilmsg(Uil_parse_data *pd, int severity, char *fmt,...)
+
+extern void
+_uilmsg(Uil_parse_data *pd, int severity, const char *fmt, ...)
 {
     va_list arg_list;
  
@@ -47,6 +56,7 @@ uilmsg(Uil_parse_data *pd, int severity, char *fmt,...)
     va_end(arg_list);
 }
 
+
 static unsigned char
 hashval(char *data, int len)
 {
@@ -63,7 +73,8 @@ hashval(char *data, int len)
     return hash;
 }
 
-sym_entry *
+
+static sym_entry *
 add_symbol(Uil_parse_data *pd, char *data, int len, int type)
 {
     int hash = hashval(data, len);
@@ -86,7 +97,8 @@ add_symbol(Uil_parse_data *pd, char *data, int len, int type)
     return e;
 }
 
-sym_entry *
+
+static sym_entry *
 find_symbol(Uil_parse_data *pd, char *data, int len)
 {
     int hash = hashval(data, len);
@@ -94,7 +106,7 @@ find_symbol(Uil_parse_data *pd, char *data, int len)
 
     for (lst = pd->hash[hash]; lst != NULL; lst = lst->next)
     {
-	if (lst->len == len && bcmp(lst->text, data, len) == 0)
+	if (lst->len == len && memcmp(lst->text, data, len) == 0)
 	{
 	    return lst;
 	}
@@ -103,6 +115,7 @@ find_symbol(Uil_parse_data *pd, char *data, int len)
     return NULL;
 }
 
+
 static void
 add_file(Uil_parse_data *pd, char *fn)
 {
@@ -151,7 +164,8 @@ remove_file(Uil_parse_data *pd)
     }
 }
 
-int
+
+static int
 get_file(Uil_parse_data *pd, char *fn)
 {
     int ret, i;
@@ -210,8 +224,9 @@ get_file(Uil_parse_data *pd, char *fn)
     return -ENOENT;
 }
 
-Uil_parse_data *
-parse_init(Uil_command_type *cmd, Uil_compile_desc_type *desc)
+
+extern Uil_parse_data *
+_uil_parse_init(Uil_command_type *cmd, Uil_compile_desc_type *desc)
 {
     Uil_parse_data *pd;
     int fd, i;
@@ -227,10 +242,10 @@ parse_init(Uil_command_type *cmd, Uil_compile_desc_type *desc)
     pd->cur_file = -1;
     if ((fd = get_file(pd, cmd->source_file)) < 0)
     {
-	uilmsg(pd, Uil_k_severe_status,
+	_uilmsg(pd, Uil_k_severe_status,
 	       "Can't open source file: %s\n", cmd->source_file);
 
-	parse_destroy(pd);
+	_uil_parse_destroy(pd);
 
 	return NULL;
     }
@@ -256,8 +271,9 @@ parse_init(Uil_command_type *cmd, Uil_compile_desc_type *desc)
     return pd;
 }
 
-void
-parse_destroy(Uil_parse_data *pd)
+
+extern void
+_uil_parse_destroy(Uil_parse_data *pd)
 {
     int i;
 
@@ -288,7 +304,8 @@ parse_destroy(Uil_parse_data *pd)
     XtFree((char *)pd);
 }
 
-char
+
+static char
 input(Uil_parse_data *pd)
 {
     int ret;
@@ -303,7 +320,7 @@ input(Uil_parse_data *pd)
 	    if ((ret = read(cf->fd, cf->pbuf,
 			    PARSE_BUF_SIZE / 2 - 1)) < 0)
 	    {
-		uilmsg(pd, Uil_k_severe_status,
+		_uilmsg(pd, Uil_k_severe_status,
 		       "Error reading source file: %s fd %d ret %d errno %d\n",
 		       pd->files[pd->cur_file_name_idx],
 		       pd->file_data[pd->cur_file].fd, ret, errno);
@@ -341,7 +358,7 @@ input(Uil_parse_data *pd)
 	    if ((ret = read(cf->fd, cf->pbuf + PARSE_BUF_SIZE / 2,
 			    PARSE_BUF_SIZE / 2 - 1)) < 0)
 	    {
-		uilmsg(pd, Uil_k_severe_status,
+		_uilmsg(pd, Uil_k_severe_status,
 		       "Error reading source file: %s fd %d ret %d errno %d\n",
 		       pd->files[pd->cur_file_name_idx],
 		       pd->file_data[pd->cur_file].fd, ret, errno);
@@ -389,7 +406,8 @@ input(Uil_parse_data *pd)
     return *cf->forward;
 }
 
-void
+
+static void
 unput(Uil_parse_data *pd)
 {
     struct _file_data *cf = &pd->file_data[pd->cur_file];
@@ -413,8 +431,9 @@ unput(Uil_parse_data *pd)
     }
 }
 
-int
-next_lexeme(Uil_parse_data *pd)
+
+extern int
+_uil_next_lexeme(Uil_parse_data *pd)
 {
     char ch, ch2, *ptr;
     int have_point;
@@ -638,7 +657,7 @@ next_lexeme(Uil_parse_data *pd)
 	    }
 	    else
 	    {
-		uilmsg(pd, Uil_k_severe_status,
+		_uilmsg(pd, Uil_k_severe_status,
 		       "Invalid lexical component: '%c' : %02x %s %d\n",
 		       ch, (unsigned char)ch,
 		       pd->files[pd->cur_file_name_idx],
