@@ -1,8 +1,9 @@
 /**
  *
- * $Id: uilsym.c,v 1.1 1997/09/05 01:32:46 miers Exp $
+ * $Id: uilsym.c,v 1.5 2000/10/28 13:31:34 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,11 +22,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-static char *rcsid = "$Id: uilsym.c,v 1.1 1997/09/05 01:32:46 miers Exp $";
+static const char rcsid[] = "$Id: uilsym.c,v 1.5 2000/10/28 13:31:34 amai Exp $";
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
+#include <LTconfig.h>
 
 #include <uil/UilDef.h>
 #include <uil/UilSymDef.h>
@@ -82,7 +81,8 @@ static char *rcsid = "$Id: uilsym.c,v 1.1 1997/09/05 01:32:46 miers Exp $";
  * 	information specific to each different entry type.
  * } sym_entry_type;
  */
-void
+
+static void
 sym_dump_header(sym_entry_type *h)
 {
     switch (h->header.b_tag)
@@ -328,7 +328,9 @@ sym_dump_header(sym_entry_type *h)
  *
  * } sym_obj_entry_type;
  */
-void
+ 
+ 
+static void
 sym_dump_obj_header(sym_obj_entry_type *o)
 {
 }
@@ -362,8 +364,9 @@ sym_dump_obj_header(sym_obj_entry_type *o)
  * 
  * } sym_color_element;
  */
-void
-dump_color_element(sym_color_element *c)
+
+static void
+_uil_dump_color_element(sym_color_element *c)
 {
 }
 
@@ -383,8 +386,8 @@ dump_color_element(sym_color_element *c)
  * 
  * } sym_icon_element;
  */ 
-void
-dump_icon(sym_icon_element *i)
+static void
+_uil_dump_icon(sym_icon_element *i)
 {
 }
 
@@ -405,8 +408,8 @@ dump_icon(sym_icon_element *i)
 /*
  * dump a Uil generated symbol table
  */
-void
-dump_node(sym_entry_type *node_entry)
+extern void
+_uil_dump_node(sym_entry_type *node_entry)
 {
     switch (node_entry->header.b_tag)
     {
