@@ -3,7 +3,7 @@
  *
  * Simple example of the draw cell, write cell routines
  *
- * $Id: draw.c,v 1.4 2000/04/27 07:48:45 amai Exp $
+ * $Id: draw.c,v 1.5 2000/07/25 11:40:08 amai Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -15,13 +15,17 @@
 #include <Xbae/Matrix.h>
 #include <Xm/Text.h>
 #include <Xm/Form.h>
-#if defined(HAVE_XPM_H)
-#include <xpm.h>
-#else  /* !HAVE_XPM_H */
-#ifdef HAVE_X11_XPM_H
-#include <X11/xpm.h>
-#endif /* HAVE_X11_XPM_H */
-#endif /* HAVE_XPM_H */
+
+#if XmVERSION >= 2
+# define HAVE_XPM
+# include <Xm/XpmP.h>
+#elif defined(HAVE_XPM_H)
+# define HAVE_XPM
+# include <xpm.h>
+#elif defined(HAVE_X11_XPM_H)
+# define HAVE_XPM
+# include <X11/xpm.h>
+#endif
 
 #define ROWS 10000
 #define COLUMNS 20
@@ -38,7 +42,7 @@ static void EnterCB(Widget w, XtPointer cd, XbaeMatrixEnterCellCallbackStruct *c
 static void LeaveCB(Widget w, XtPointer cd, XbaeMatrixLeaveCellCallbackStruct *cbs);
 static void LoadMatrix(void);
 
-#if defined(HAVE_XPM_H) || defined(HAVE_X11_XPM_H)
+#ifdef HAVE_XPM
 /* XPM */
 static char * xbae_xpm[] =
 {
@@ -97,7 +101,7 @@ DrawCB(Widget w, XtPointer cd, XbaeMatrixDrawCellCallbackStruct *cbs)
     {
     if( !pixmap )
     {
-#if defined(HAVE_XPM_H) || defined(HAVE_X11_XPM_H)
+#ifdef HAVE_XPM
 	XpmAttributes attributes;
 
 	attributes.valuemask = 0;
@@ -134,7 +138,7 @@ DrawCB(Widget w, XtPointer cd, XbaeMatrixDrawCellCallbackStruct *cbs)
 	   However, providing the values improves efficiency */
  	cbs->height = xbae_height;
  	cbs->width = xbae_width;
-#if defined(HAVE_XPM_H) || defined(HAVE_X11_XPM_H)
+#ifdef HAVE_XPM
 	cbs->depth = 8;
 #else
 	cbs->depth = 1;
