@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Macros.h,v 1.16 2000/06/11 17:58:39 danny Exp $
+ * $Id: Macros.h,v 1.17 2000/11/01 01:10:18 dannybackx Exp $
  */
 
 /*
@@ -498,6 +498,14 @@ extern "C" {
 					       column_button_labels); \
 					}
 
+#define xbaeFreeColumnFontBold(mw)	{ \
+						if (mw->matrix. \
+						column_font_bold) \
+						XtFree((XtPointer) \
+						mw->matrix. \
+						column_font_bold); \
+					}
+
 #define xbaeFreeRowButtonLabels(mw)	{ \
 					       if (mw->matrix. \
 					       row_button_labels) \
