@@ -24,7 +24,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Matrix.h,v 1.4 2000/06/11 17:58:40 danny Exp $
+ * $Id: Matrix.h,v 1.6 2000/11/01 01:10:18 dannybackx Exp $
  */
 
 #ifndef _Xbae_Matrix_h
@@ -49,24 +49,6 @@ extern int XbaeGetVersionNum(void);
 extern const char *XbaeGetXmVersionTxt(void);
 extern int XbaeGetXmVersionNum(void);
 
-/*
- * A few definitions we like to use, but those with R4 won't have.
- * From Xfuncproto.h in R5.
- */
-
-#ifndef XlibSpecificationRelease
-# ifndef _XFUNCPROTOBEGIN
-#   ifdef __cplusplus                      /* for C++ V2.0 */
-#     define _XFUNCPROTOBEGIN extern "C" {
-#     define _XFUNCPROTOEND }
-#   else
-#     define _XFUNCPROTOBEGIN
-#     define _XFUNCPROTOEND
-#   endif
-# endif /* _XFUNCPROTOBEGIN */
-#else
-#include <X11/Xfuncproto.h>
-#endif
 
 /* Resources:
  * Name			Class			RepType		Default Value
@@ -91,6 +73,7 @@ extern int XbaeGetXmVersionNum(void);
  * colors		Colors			PixelTable	NULL
  * columnAlignments	Alignments		AlignmentArray	dynamic
  * columnButtonLabels	ButtonLabels		BooleanArray	NULL
+ * columnFontBold	ButtonLabels		BooleanArray	NULL
  * columnLabelAlignments Alignments		AlignmentArray	dynamic
  * columnLabelColor	Color			Pixel		dynamic
  * columnLabels		Labels			StringArray	NULL
@@ -227,6 +210,9 @@ extern int XbaeGetXmVersionNum(void);
 #ifndef XmNcolumnButtonLabels
 #define XmNcolumnButtonLabels		"columnButtonLabels"
 #endif
+#ifndef XmNcolumnFontBold
+#define XmNcolumnFontBold		"columnFontBold"
+#endif
 #ifndef XmNcolumnLabelAlignments
 #define XmNcolumnLabelAlignments	"columnLabelAlignments"
 #endif
@@ -596,7 +582,6 @@ typedef struct _XbaeMatrixRec *XbaeMatrixWidget;
 /*
  * External interfaces to class methods
  */
-_XFUNCPROTOBEGIN
 
 extern void XbaeMatrixAddColumns(Widget, int, String *, String *, short *,
 				     int *, unsigned char *, unsigned char *,
@@ -678,7 +663,6 @@ extern int XbaeMatrixGetColumnWidth(Widget w, int column);
 extern void XbaeMatrixSetRowHeight(Widget w, int row, int height);
 extern int XbaeMatrixGetRowHeight(Widget w, int row);
 
-_XFUNCPROTOEND
 
 typedef unsigned char	Alignment;
 typedef Alignment *	AlignmentArray;
@@ -1017,13 +1001,6 @@ typedef struct _XbaeMatrixLabelActivateCallbackStruct
 XbaeMatrixLabelActivateCallbackStruct;
 
 
-/* provide clean-up for those with R4 */
-#ifndef XlibSpecificationRelease
-# undef _Xconst
-# undef _XFUNCPROTOBEGIN
-# undef _XFUNCPROTOEND
-#endif
-
 #ifdef __cplusplus
 }
 #endif
