@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Actions.c,v 1.13 2000/06/11 17:58:48 danny Exp $
+ * $Id: Actions.c,v 1.14 2000/09/01 20:04:33 amai Exp $
  */
 
 #undef	VERBOSE_SLIDE
@@ -48,6 +48,9 @@
 #include <Xbae/ScrollMgr.h>
 #include <Xbae/ClipP.h>
 #include <X11/cursorfont.h>
+#ifdef XBAE_VERBOSE
+#include <stdio.h>
+#endif
 
 #ifndef XlibSpecificationRelease
 #define XrmPermStringToQuark XrmStringToQuark
