@@ -24,7 +24,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Create.c,v 1.9 2000/06/11 17:58:54 danny Exp $
+ * $Id: Create.c,v 1.11 2000/11/01 01:10:23 dannybackx Exp $
  */
 
 /*
@@ -39,6 +39,8 @@
 #include <dmalloc.h>
 #endif
 
+#include <stdlib.h>
+
 #include <Xm/Xm.h>
 #include <Xbae/MatrixP.h>
 #include <Xbae/Macros.h>
@@ -49,10 +51,6 @@
 
 static Pixmap createInsensitivePixmap(XbaeMatrixWidget mw);
 
-#ifndef MAXSCREENS
-#define MAXSCREENS 1
-#endif
-
 void
 xbaeCopyBackground(Widget widget, int offset, XrmValue *value)
 {
@@ -588,6 +586,29 @@ xbaeCopyColumnButtonLabels(XbaeMatrixWidget mw)
     xbaeObjectUnlock((Widget)mw);
 }
 
+void
+xbaeCopyColumnFontBold(XbaeMatrixWidget mw)
+{
+    Boolean *copy = NULL;
+    int i;
+
+    xbaeObjectLock((Widget)mw);
+
+    if (mw->matrix.columns)
+    {
+      copy = (Boolean *) XtMalloc(mw->matrix.columns *
+                                  sizeof(Boolean));
+
+      for (i = 0; i < mw->matrix.columns; i++)
+      {
+          copy[i] = mw->matrix.column_font_bold[i];
+      }
+    }
+    mw->matrix.column_font_bold = copy;
+
+    xbaeObjectUnlock((Widget)mw);
+}
+
 void
 xbaeCopyRowButtonLabels(XbaeMatrixWidget mw)
 {
@@ -923,7 +944,7 @@ static Pixmap
 createInsensitivePixmap(XbaeMatrixWidget mw)
 {
     static char stippleBits[] = { 0x01, 0x02 };
-    static Pixmap stipple[MAXSCREENS] = {(Pixmap)NULL};
+    static Pixmap *stipple = NULL;
     Display *dpy = XtDisplay(mw);
     Screen *scr  = XtScreen (mw);
     int i;
@@ -931,11 +952,12 @@ createInsensitivePixmap(XbaeMatrixWidget mw)
     
     xbaeObjectLock((Widget)mw);
 
-    if (maxScreens > MAXSCREENS)
-	maxScreens = MAXSCREENS;
-    
-    if (!stipple[0])
+    if (!stipple)
     {
+	stipple = malloc(maxScreens*sizeof(Pixmap));
+	if (!stipple) {
+            return (Pixmap) NULL;
+	}
 	for (i = 0 ; i < maxScreens ; i++)
 	    stipple[i] = XCreatePixmapFromBitmapData(
 		dpy, RootWindow(dpy,i), stippleBits, 2, 2, 0, 1, 1);
