@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Draw.c,v 1.16 2000/08/21 15:01:51 danny Exp $
+ * $Id: Draw.c,v 1.20 2000/12/09 12:40:46 dannybackx Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +39,9 @@
 #include <Xbae/Shadow.h>
 #include <Xbae/Draw.h>
 #include <stdlib.h>
+#ifdef XBAE_VERBOSE
+#include <stdio.h>
+#endif
 
 static void xbaeDrawCellString(XbaeMatrixWidget, int, int, int, int,
 				  String, Pixel, Pixel);
@@ -47,6 +50,13 @@ static void xbaeDrawCellWidget(XbaeMatrixWidget, int, int, int, int,
 static void xbaeDrawCellPixmap(XbaeMatrixWidget, int, int, int, int,
 				  Pixmap, Pixmap, int, int, Pixel,
 				  Pixel, int);
+static void xbaeDrawString(XbaeMatrixWidget mw, Window win, GC gc,
+			String string, int length,
+			int x, int y,
+			int maxlen, int maxht,
+			unsigned char alignment, Boolean highlight,
+			Boolean bold, Boolean rowLabel,
+			Boolean colLabel, Pixel color);
 
 /*
  * Draw a fixed or non-fixed cell. The coordinates are calculated relative
@@ -341,7 +351,8 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
 		mw->matrix.column_alignments ?
 		mw->matrix.column_alignments[column] :
 		XmALIGNMENT_BEGINNING, selected,
-		False, False, False, fg);
+		mw->matrix.column_font_bold ? mw->matrix.column_font_bold[column] : 0,
+		False, False, fg);
 
 #if XmVersion >= 1002
     if (mw->matrix.highlighted_cells &&
@@ -449,7 +460,8 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
 	mw->matrix.column_alignments ?
 	mw->matrix.column_alignments[column] :
 	XmALIGNMENT_BEGINNING, selected,
-	False, False, False, fg);
+	mw->matrix.column_font_bold ? mw->matrix.column_font_bold[column] : 0,
+	False, False, fg);
 
 #if XmVersion >= 1002
     if (mw->matrix.highlighted_cells &&
@@ -836,8 +848,10 @@ xbaeDrawString(XbaeMatrixWidget mw,
     clipht.y = 0;
 
     if (doclip) {
+#ifdef XBAE_VERBOSE
 	fprintf(stderr, "XSetClipRectangles - x %d y %d w %d h %d\n",
 		x, y, clipht.width, clipht.height);
+#endif
 	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
     }
 #endif
@@ -1373,10 +1387,10 @@ xbaeDrawColumnLabel(XbaeMatrixWidget mw, int column, Boolean pressed)
 	    xbaeDrawString(mw, XtWindow(mw), gc, label,
 			   mw->matrix.column_label_lines[column].lengths[i],
 			   labelX, labelY, mw->matrix.column_widths[column],
+                         -1,
 			   mw->matrix.column_label_alignments ?
 			   mw->matrix.column_label_alignments[column] :
-			   XmALIGNMENT_BEGINNING,
-			False, -1,
+                         XmALIGNMENT_BEGINNING, False,
 			   mw->matrix.bold_labels, False, True,
 			   mw->matrix.column_label_color);
 	
