@@ -24,7 +24,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Public.c,v 1.13 2000/06/11 17:58:50 danny Exp $
+ * $Id: Public.c,v 1.15 2000/11/02 16:53:59 dannybackx Exp $
  */
 
 /*
@@ -35,6 +35,7 @@
 #include <XbaeConfig.h>
 #endif
 
+#include <stdio.h>
 #include <Xm/Xm.h>
 #include <Xm/ScrollBar.h>
 #include <Xbae/MatrixP.h>
@@ -2306,7 +2307,6 @@ XbaeCreateMatrix(Widget parent, String name, ArgList args, Cardinal ac)
 void
 XbaeMatrixSetColumnWidth(Widget w, int column, int width)
 {
-#ifdef	HAVE_ROW_HEIGHTS
 	XbaeMatrixWidget	mw = (XbaeMatrixWidget) w;
 
 	if (mw && mw->matrix.column_widths && column >= 0 && column <= mw->matrix.columns) {
@@ -2314,6 +2314,8 @@ XbaeMatrixSetColumnWidth(Widget w, int column, int width)
 			mw->matrix.column_widths[column] = 5;	/* The default */
 		else
 			mw->matrix.column_widths[column] = width;
+
+		xbaeGetColumnPositions(mw);
 		XbaeMatrixRefresh(w);
 	} else {
 		XtAppWarningMsg(XtDisplayToApplicationContext(XtDisplay(w)),
@@ -2321,21 +2323,16 @@ XbaeMatrixSetColumnWidth(Widget w, int column, int width)
 			"XbaeMatrix doesn't have this column",
 			(String *)NULL, (Cardinal *)NULL);
 	}
-#endif
 }
 
 int
 XbaeMatrixGetColumnWidth(Widget w, int column)
 {
-#ifdef	HAVE_ROW_HEIGHTS
 	XbaeMatrixWidget	mw = (XbaeMatrixWidget) w;
 
 	if (mw && mw->matrix.column_widths && column >= 0 && column <= mw->matrix.columns)
 		return mw->matrix.column_widths[column];
 	return 0;
-#else
-        return 0;
-#endif
 }
 
 void
@@ -2349,6 +2346,8 @@ XbaeMatrixSetRowHeight(Widget w, int row, int height)
 			mw->matrix.row_heights[row] = ROW_HEIGHT(mw);
 		else
 			mw->matrix.row_heights[row] = height;
+
+		xbaeGetRowPositions(mw);
 		XbaeMatrixRefresh(w);
 	} else {
 		XtAppWarningMsg(XtDisplayToApplicationContext(XtDisplay(w)),
@@ -2362,13 +2361,13 @@ XbaeMatrixSetRowHeight(Widget w, int row, int height)
 int
 XbaeMatrixGetRowHeight(Widget w, int row)
 {
-#ifdef	HAVE_ROW_HEIGHTS
 	XbaeMatrixWidget	mw = (XbaeMatrixWidget) w;
 
+#ifdef	HAVE_ROW_HEIGHTS
 	if (mw && mw->matrix.row_heights && row >= 0 && row <= mw->matrix.rows)
 		return mw->matrix.row_heights[row];
 	return 0;
 #else
-        return 0;
+        return ROW_HEIGHT(mw);
 #endif
 }
