@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: ScrollMgr.c,v 1.14 2000/06/11 17:58:50 danny Exp $
+ * $Id: ScrollMgr.c,v 1.16 2000/11/22 20:43:47 dannybackx Exp $
  */
 
 /*
@@ -41,6 +41,9 @@
 #include <Xbae/ScrollMgr.h>
 #include <Xbae/Utils.h>
 #include <Xm/ScrollBar.h>
+#ifdef XBAE_VERBOSE
+#include <stdio.h>
+#endif
 
 /*
  * ScrollMgr implementation.
@@ -1260,6 +1263,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
     if (mw->matrix.column_labels && mw->matrix.columns)
     {
 	Rectangle rect;
+	Rectangle corrected_expose;
 
 	/*
 	 * Get the Rectangle enclosing the non-fixed column labels
@@ -1269,10 +1273,18 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 		fixed_column_label_offset + VISIBLE_WIDTH(mw) - 1,
 		horiz_sb_offset + column_label_height - 1);
 
+	/*
+	 * Get the Rectangle enclosing the non-fixed column labels
+	 */
+	SETRECT(corrected_expose,
+		expose->x1, expose->y1 - mw->matrix.matrix_scroll_mgr->offset_y,
+		expose->x2, expose->y2 - mw->matrix.matrix_scroll_mgr->offset_y);
+
+
 	/*
 	 * If the expose Rectangle overlaps, then some labels must be redrawn
 	 */
-	if (OVERLAP(*expose, rect))
+	if (OVERLAP(corrected_expose, rect))
 	{
 	    Rectangle intersect;
 	    int endCol, i;
@@ -1282,7 +1294,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	     * Rectangle along the X axis.  The resulting Rectangle will
 	     * be in 'rect's coordinate system.
 	     */
-	    X_INTERSECT(rect, *expose, intersect);
+	    X_INTERSECT(rect, corrected_expose, intersect);
 
 	    /*
 	     * Translate 'intersect' to take into account any fixed columns.
