@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Shadow.c,v 1.7 2000/06/11 17:58:49 danny Exp $
+ * $Id: Shadow.c,v 1.8 2000/09/01 20:04:33 amai Exp $
  */
 
 
@@ -44,6 +44,9 @@
 #include <Xbae/Shadow.h>
 #include <Xbae/Draw.h>
 #include <Xbae/Utils.h>
+#ifdef XBAE_VERBOSE
+#include <stdio.h>
+#endif
 
 static void DrawRowShadow(XbaeMatrixWidget, Window, int, int, int,
 			     int, int, int, GC, GC);
