@@ -24,7 +24,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Utils.c,v 1.19 2000/06/21 21:27:31 danny Exp $
+ * $Id: Utils.c,v 1.20 2000/09/01 20:04:33 amai Exp $
  */
 
 /*
@@ -41,6 +41,9 @@
 #include <Xbae/Utils.h>
 #include <Xbae/Actions.h>
 #include <Xm/ScrollBar.h>
+#ifdef XBAE_VERBOSE
+#include <stdio.h>
+#endif
 
 /*
  * Return the top and bottom-most visible non-fixed row
