@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DisplayOptions.c,v 1.1 1998/06/03 21:54:59 rwscott Exp $
+ * $Id: DisplayOptions.c,v 1.3 2000/01/25 11:54:20 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -22,13 +22,14 @@
  *
  **/
 
+#include "../config.h"
 #include <stdio.h>
 #include <X11/Intrinsic.h>
 
-static const char rcsid[] = "$Id: DisplayOptions.c,v 1.1 1998/06/03 21:54:59 rwscott Exp $";
+static const char rcsid[] = "$Id: DisplayOptions.c,v 1.3 2000/01/25 11:54:20 amai Exp $";
 
 void 
-XltDisplayOptions(XrmOptionDescRec *opTable, int num_options)
+XltDisplayOptions(XrmOptionDescRec *opTable, Cardinal num_options)
 {
 	int i;
 
