@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Host.c,v 1.5 1998/09/12 14:30:27 rwscott Exp $
+ * $Id: Host.c,v 1.14 2000/12/18 19:41:48 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -22,24 +22,37 @@
  *
  **/
 
+#include "../config.h"
+
 #include <unistd.h>
-#include <fcntl.h>
+/* #include <fcntl.h> */
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 #include <sys/socket.h>
+#include <sys/time.h>
+#ifdef HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
 #include <netinet/in.h>
 #include <netdb.h>
+
 #include <X11/StringDefs.h>
+
 #include <Xm/MessageB.h>
 #include <Xm/Form.h>
 #include <Xm/TextF.h>
 #include <Xm/Label.h>
-#include <HostP.h>
+#include <Xm/RepType.h>
+
+#include "HostP.h"
 
 #undef DEBUG
 
-static const char rcsid[] = "$Id: Host.c,v 1.5 1998/09/12 14:30:27 rwscott Exp $";
+static const char rcsid[] = "$Id: Host.c,v 1.14 2000/12/18 19:41:48 amai Exp $";
 
 typedef struct
 {
@@ -62,7 +75,7 @@ static char DefaultHelp[] = "\n"
    Widget methods, forward declarations
  */
 
-static void class_initialize();
+static void class_initialize(void);
 static void class_part_initialize(WidgetClass widget_class);
 static void initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
 static void destroy(Widget w);
@@ -76,6 +89,7 @@ static void get_values_hook(Widget w, ArgList args, Cardinal *num_args);
 static Boolean SendByte(Widget w);
 static Boolean Connect(Widget W);
 static int SockOpen(char *HostName, char *Service);
+static void InputHandler(Widget W, int *Fd, XtInputId *Id);
 
 /*
    Widget default resources
@@ -134,6 +148,11 @@ static XtResource resources[] =
 	sizeof(XtCallbackList), Offset(OutputCallback),
 	XtRCallback, NULL
     },
+    {
+	XltNhostType, XltCHostType, XltRHostType,
+	sizeof(unsigned char), Offset(type),
+	XtRImmediate, (XtPointer)XltHOST_CLIENT
+    },
 };
 #undef Offset
 
@@ -187,6 +206,7 @@ XltHostClassRec xrwsHostClassRec = {
 
 
 
+
 WidgetClass xrwsHostWidgetClass = (WidgetClass)&xrwsHostClassRec;
 
 /*
@@ -196,9 +216,21 @@ WidgetClass xrwsHostWidgetClass = (WidgetClass)&xrwsHostClassRec;
 static void
 Disconnect(Widget w)
 {
+int i;
+
 #ifdef DEBUG
     printf("Disconnect()\n");
 #endif
+    for (i = 0; i < Host_NumClients(w); i++)
+    {
+	close(Host_ClientList(w)[i].fd);
+    }
+    if (Host_ClientList(w))
+    {
+    	XtFree((char *)Host_ClientList(w));
+    	Host_ClientList(w) = NULL;
+    }
+    Host_NumClients(w) = 0;
     if (Host_InputId(w))
     {
 	XtRemoveInput(Host_InputId(w));
@@ -214,6 +246,11 @@ Disconnect(Widget w)
 	XtRemoveTimeOut(Host_OutputId(w));
 	Host_OutputId(w) = 0;
     }
+    if (Host_BinaryTimeOutId(w))
+    {
+	XtRemoveTimeOut(Host_BinaryTimeOutId(w));
+	Host_BinaryTimeOutId(w) = 0;
+    }
     Host_OutputSize(w) = 0;
     Host_InputSize(w) = 0;
     Host_OutputData(w)[0] = '\0';
@@ -263,11 +300,9 @@ TimeOut(Widget W)
 static void
 BinaryByte(Widget W, char byte)
 {
-    static XtIntervalId Id = (XtIntervalId)NULL;
-
-    if (Id != (XtIntervalId)NULL)
+    if (Host_BinaryTimeOutId(W) != (XtIntervalId)NULL)
     {
-	XtRemoveTimeOut(Id);
+	XtRemoveTimeOut(Host_BinaryTimeOutId(W));
     }
     Host_InputData(W)[Host_InputSize(W)] = byte;
     Host_InputSize(W)++;
@@ -325,8 +360,8 @@ BinaryByte(Widget W, char byte)
     }
     if (Host_Mode(W) == MODE_BINARY)
     {
-	Id = XtAppAddTimeOut(XtWidgetToApplicationContext(W),
-			     10000, (void *)TimeOut, W);
+	Host_BinaryTimeOutId(W) = XtAppAddTimeOut(XtWidgetToApplicationContext(W),
+			     10000, (XtTimerCallbackProc)TimeOut, W);
     }
 }
 
@@ -350,11 +385,67 @@ Throttle(Widget W, Boolean state)
 	{
 	    Host_OutputId(W) = XtAppAddTimeOut(XtWidgetToApplicationContext(W),
 					       Host_Delay(W),
-					       (void *)SendByte, W);
+					       (XtTimerCallbackProc)SendByte, W);
 	}
     }
 }
 
+static int
+Listen(char *Service)
+{
+int optval = 1;
+int ListenFd;
+struct sockaddr_in my_addr_in;
+struct servent *sp;
+
+    memset((char *)&my_addr_in, 0, sizeof(struct sockaddr_in));
+    my_addr_in.sin_family = AF_INET;
+    my_addr_in.sin_addr.s_addr = INADDR_ANY;
+    if (atoi(Service) != 0)
+    {
+    	my_addr_in.sin_port = htons(atoi(Service));
+    }
+    else
+    {
+#ifdef HAVE_GETSERVBYNAME
+    	sp = getservbyname(Service, "tcp");
+    	if (sp == NULL)
+#endif
+    	{
+	    fprintf(stderr, "Service >%s< not found\n", Service);
+	    ListenFd = -1;
+	    return(ListenFd);
+    	}
+	my_addr_in.sin_port = sp->s_port;
+    }
+    ListenFd = socket(AF_INET, SOCK_STREAM, 0);
+    if (ListenFd == -1)
+    {
+	fprintf(stderr, "socket error\n");
+	ListenFd = -1;
+	return(ListenFd);
+    }
+    if (setsockopt(ListenFd, SOL_SOCKET, SO_REUSEADDR, (void *)&optval, sizeof(optval)) == -1)
+    {
+	fprintf(stderr, "setsockopt error\n");
+	ListenFd = -1;
+	return(ListenFd);
+    }
+    if (bind(ListenFd, (void *)&my_addr_in, sizeof(struct sockaddr_in)) == -1)
+    {
+	fprintf(stderr, "bind error\n");
+	ListenFd = -1;
+	return(ListenFd);
+    }
+    if (listen(ListenFd, 5) == -1)
+    {
+	fprintf(stderr, "listen error\n");
+	ListenFd = -1;
+	return(ListenFd);
+    }
+    return(ListenFd);
+}
+
 static int
 SockOpen(char *HostName, char *Service)
 {
@@ -414,6 +505,8 @@ SockOpen(char *HostName, char *Service)
 static Boolean
 SendByte(Widget w)
 {
+int i;
+
     while ((XtAppPending(XtWidgetToApplicationContext(w)) & XtIMAlternateInput) == XtIMAlternateInput)
     {
 	XtAppProcessEvent(XtWidgetToApplicationContext(w), XtIMAlternateInput);
@@ -421,7 +514,20 @@ SendByte(Widget w)
     Host_OutputId(w) = (XtIntervalId)NULL;
     if (!Host_Throttle(w))
     {
-	write(Host_Fd(w), &(Host_OutputData(w)[0]), 1);
+	switch (Host_Type(w))
+	{
+	case XltHOST_CLIENT:
+	    write(Host_Fd(w), &(Host_OutputData(w)[0]), 1);
+	    break;
+	case XltHOST_SERVER:
+	    for (i = 0; i < Host_NumClients(w); i++)
+	    {
+	    	write(Host_ClientList(w)[i].fd, &(Host_OutputData(w)[0]), 1);
+	    }
+	    break;
+	default:
+	    break;
+	}
 	memmove(&(Host_OutputData(w)[0]), &(Host_OutputData(w)[1]), Host_OutputSize(w));
 	Host_OutputSize(w)--;
 	if (Host_OutputCallback(w))
@@ -529,6 +635,48 @@ ProcessByte(Widget W, char byte)
 
 /* ******************** */
 
+static void
+ConnectionRequest(Widget W, int *Fd, XtInputId *Id)
+{
+int addrlen;
+
+    Host_NumClients(W)++;
+    Host_ClientList(W) = (XltClientInfo *)XtRealloc((char *)Host_ClientList(W), Host_NumClients(W) * sizeof(XltClientInfo));
+    addrlen = sizeof(struct sockaddr_in);
+    Host_ClientList(W)[Host_NumClients(W) - 1].fd = accept(Host_Fd(W), (void *)&(Host_ClientList(W)[Host_NumClients(W) - 1].addr), &addrlen);
+    Host_ClientList(W)[Host_NumClients(W) -1].id = XtAppAddInput(XtWidgetToApplicationContext(W),
+						Host_ClientList(W)[Host_NumClients(W) - 1].fd,
+						(XtPointer)XtInputReadMask,
+						(XtInputCallbackProc)InputHandler,
+						W);
+}
+
+/* ******************** */
+
+static void
+ReleaseClient(Widget w, int fd)
+{
+int i, j;
+
+    for (i = 0; i < Host_NumClients(w); i++)
+    {
+    	if (Host_ClientList(w)[i].fd == fd)
+    	{
+	    XtRemoveInput(Host_ClientList(w)[i].id);
+	    close(Host_ClientList(w)[i].fd);
+	    for (j = i + 1; j < Host_NumClients(w); j++)
+	    {
+	    	Host_ClientList(w)[j - 1] = Host_ClientList(w)[j];
+	    }
+	    Host_NumClients(w)--;
+	    Host_ClientList(w) = (XltClientInfo *)XtRealloc((char *)Host_ClientList(w), Host_NumClients(w) * sizeof(XltClientInfo));
+	    break;
+    	}
+    }
+}
+
+/* ******************** */
+
 static void
 InputHandler(Widget W, int *Fd, XtInputId *Id)
 {
@@ -549,47 +697,67 @@ InputHandler(Widget W, int *Fd, XtInputId *Id)
     }
     if (XtAppPending(XtWidgetToApplicationContext(W)) & XtIMAlternateInput)
     {
-	BytesRead = read(*Fd, ReadBuffer, BufferSize);
-	if (BytesRead == BufferSize)
-	{
-	    BufferSize++;
-	    ReadBuffer = XtRealloc(ReadBuffer, BufferSize);
-	}
-	switch (BytesRead)
-	{
-	case 0:
-	    fprintf(stderr, "InputHandler(%s) - EOF while reading device\n", XtName(W));
-	    DoCallback = True;
-	    Disconnect(W);
-	    break;
-	case -1:
-	    perror("InputHandler");
-	    DoCallback = True;
-	    Disconnect(W);
-	    break;
-	default:
-	    if (Host_InputCallback(W))
-	    {
-		_XltHostCallbackStruct tmp;
+	fd_set rfds;
+	struct timeval tv;
 
-		tmp.reason = XltCR_INPUT;
-		tmp.len = BytesRead;
-		tmp.data = ReadBuffer;
-		tmp.input_size = Host_InputSize(W);
-		tmp.input_need = Host_InputNeed(W);
-		XtCallCallbackList(W, Host_InputCallback(W), &tmp);
-		BytesRead = tmp.len;
-	    }
-	    for (i = 0; i < BytesRead; i++)
-	    {
-		ProcessByte(W, ReadBuffer[i]);
-	    }
-	    break;
-	}
-	if (DoCallback)
+	FD_ZERO(&rfds);
+	FD_SET(*Fd, &rfds);
+	tv.tv_sec = 0;
+	tv.tv_usec = 0;
+	if (select(*Fd + 1, SELECT_TYPE_ARG234(&rfds), NULL, NULL, &tv))
 	{
-	    tmp.reason = XltCR_DISCONNECT;
-	    XtCallCallbackList(W, Host_DisconnectCallback(W), &tmp);
+	    BytesRead = read(*Fd, ReadBuffer, BufferSize);
+	    if (BytesRead == BufferSize)
+	    {
+		BufferSize++;
+		ReadBuffer = XtRealloc(ReadBuffer, BufferSize);
+	    }
+	    switch (BytesRead)
+	    {
+	    case 0:
+		fprintf(stderr, "InputHandler(%s) - EOF while reading device\n", XtName(W));
+		DoCallback = True;
+		switch (Host_Type(W))
+		{
+		case XltHOST_CLIENT:
+		    Disconnect(W);
+		    break;
+		case XltHOST_SERVER:
+		    ReleaseClient(W, *Fd);
+		    break;
+		default:
+		    break;
+		}
+		break;
+	    case -1:
+		perror("InputHandler");
+		DoCallback = True;
+		Disconnect(W);
+		break;
+	    default:
+		if (Host_InputCallback(W))
+		{
+		    _XltHostCallbackStruct tmp;
+
+		    tmp.reason = XltCR_INPUT;
+		    tmp.len = BytesRead;
+		    tmp.data = ReadBuffer;
+		    tmp.input_size = Host_InputSize(W);
+		    tmp.input_need = Host_InputNeed(W);
+		    XtCallCallbackList(W, Host_InputCallback(W), &tmp);
+		    BytesRead = tmp.len;
+		}
+		for (i = 0; i < BytesRead; i++)
+		{
+		    ProcessByte(W, ReadBuffer[i]);
+		}
+		break;
+	    }
+	    if (DoCallback)
+	    {
+		tmp.reason = XltCR_DISCONNECT;
+		XtCallCallbackList(W, Host_DisconnectCallback(W), &tmp);
+	    }
 	}
     }
 }
@@ -622,38 +790,57 @@ Connect(Widget W)
 	{
 	    XtAppProcessEvent(XtWidgetToApplicationContext(XtParent(W)), XtIMAll);
 	}
-	Host_Fd(W) = SockOpen(Host_Name(W), Host_Port(W));
-	if (Host_Fd(W) > 0)
+	switch (Host_Type(W))
 	{
-	    _XltHostCallbackStruct tmp;
-	    String Name;
-	    String Class;
-	    FILE *xrdb;
-	    String xrdb_command;
-	    String base = "xrdb -merge -nocpp -display";
-
-	    Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
-					    Host_Fd(W),
-					    (XtPointer)XtInputReadMask,
-					    (XtInputCallbackProc)InputHandler,
-					    W);
-	    xrdb_command = XtMalloc(strlen(base) + strlen(DisplayString(XtDisplay(XtParent(W)))) + 2);
-	    sprintf(xrdb_command, "%s %s", base, DisplayString(XtDisplay(XtParent(W))));
-	    xrdb = popen(xrdb_command, "w");
-	    if (xrdb != NULL)
+	case XltHOST_CLIENT:
+	    Host_Fd(W) = SockOpen(Host_Name(W), Host_Port(W));
+	    if (Host_Fd(W) > 0)
 	    {
-		XtGetApplicationNameAndClass(XtDisplay(XtParent(W)), &Name, &Class);
-		fprintf(xrdb, "%s.Host: %s\n%s.Service: %s\n",
-			Class,
-			Host_Name(W),
-			Class,
-			Host_Port(W));
-		pclose(xrdb);
+		_XltHostCallbackStruct tmp;
+		String Name;
+		String Class;
+		FILE *xrdb;
+		String xrdb_command;
+		String base = "xrdb -merge -nocpp -display";
+
+		Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
+						Host_Fd(W),
+						(XtPointer)XtInputReadMask,
+						(XtInputCallbackProc)InputHandler,
+						W);
+		xrdb_command = XtMalloc(strlen(base) + strlen(DisplayString(XtDisplay(XtParent(W)))) + 2);
+		sprintf(xrdb_command, "%s %s", base, DisplayString(XtDisplay(XtParent(W))));
+		xrdb = popen(xrdb_command, "w");
+		if (xrdb != NULL)
+		{
+		    XtGetApplicationNameAndClass(XtDisplay(XtParent(W)), &Name, &Class);
+		    fprintf(xrdb, "%s.Host: %s\n%s.Service: %s\n",
+			    Class,
+			    Host_Name(W),
+			    Class,
+			    Host_Port(W));
+		    pclose(xrdb);
+		}
+		XtFree(xrdb_command);
+		Host_Throttle(W) = False;
+		tmp.reason = XltCR_CONNECT;
+		XtCallCallbackList(W, Host_ConnectCallback(W), &tmp);
 	    }
-	    XtFree(xrdb_command);
-	    Host_Throttle(W) = False;
-	    tmp.reason = XltCR_CONNECT;
-	    XtCallCallbackList(W, Host_ConnectCallback(W), &tmp);
+	    break;
+	case XltHOST_SERVER:
+	    Host_Fd(W) = Listen(Host_Port(W));
+	    if (Host_Fd(W) > 0)
+	    {
+		Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
+						Host_Fd(W),
+						(XtPointer)XtInputReadMask,
+						(XtInputCallbackProc)ConnectionRequest,
+						W);
+	    }
+	    break;
+	default:
+	    fprintf(stderr, "%s: Unknown host type\n", XtName(W));
+	    break;
 	}
     }
     return (True);
@@ -686,7 +873,7 @@ OpenHost(Widget W, Widget w)
        Connect(w);
      */
     XtAppAddTimeOut(XtWidgetToApplicationContext(w),
-		    1000, (void *)Connect, w);
+		    1000, (XtTimerCallbackProc)Connect, w);
 }
 
 /*
@@ -694,11 +881,23 @@ OpenHost(Widget W, Widget w)
  */
 
 static void
-class_initialize()
+class_initialize(void)
 {
+static char *value_names[] =
+{
+    "client",
+    "server"
+};
+
+static unsigned char values[] =
+{
+    XltHOST_CLIENT,
+    XltHOST_SERVER
+};
     /*
        printf("class_initialize()\n");
      */
+     XmRepTypeRegister(XltRHostType, value_names, values, XtNumber(values));
 }
 
 static void
@@ -734,6 +933,9 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     Host_InputData(new_w) = XtMalloc(Host_InputMaxSize(new_w));
     Host_Dialog(new_w) = NULL;
     Host_InputNeed(new_w) = 0;
+    Host_BinaryTimeOutId(new_w) = (XtIntervalId)NULL;
+    Host_NumClients(new_w) = 0;
+    Host_ClientList(new_w) = NULL;
     if (Host_Terminator(new_w) == NULL)
     {
 	Host_Terminator(new_w) = XtNewString("\r\n");
@@ -800,6 +1002,10 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
     {
 	ReConnect = True;
     }
+    if (Host_Type(old) != Host_Type(new_w))
+    {
+	ReConnect = True;
+    }
     if (ReConnect)
     {
 	Disconnect(new_w);
