@@ -1,6 +1,6 @@
 /**
  *
- * $Id: NumEntry.c,v 1.10 2000/01/25 11:54:23 amai Exp $
+ * $Id: NumEntry.c,v 1.11 2000/10/15 17:20:13 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -39,7 +39,7 @@
 #include <stdio.h>
 #endif
 
-static const char rcsid[] = "$Id: NumEntry.c,v 1.10 2000/01/25 11:54:23 amai Exp $";
+static const char rcsid[] = "$Id: NumEntry.c,v 1.11 2000/10/15 17:20:13 amai Exp $";
 
 /*
    Widget methods, forward declarations
@@ -299,7 +299,7 @@ DoMath(Widget W)
 #endif
     value = XmTextFieldGetString(NumEntry_TextField(W));
     Place = XmTextFieldGetInsertionPosition(NumEntry_TextField(W));
-    result = Calc(value);
+    result = XltCalc(value);
     if (result != NumEntry_Result(W))
     {
 	char buf[1024];
