@@ -1,4 +1,4 @@
-/* $Id: test4.c,v 1.4 2000/04/26 09:08:52 amai Exp $ */
+/* $Id: test4.c,v 1.5 2000/06/29 10:05:24 amai Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,7 +35,7 @@
 #include "eye24.xpm"
 
 void
-debug()
+debug(void)
 {
 }
 
