@@ -1,3 +1,5 @@
+/* $Id: test3.c,v 1.6 2000/06/29 10:05:32 amai Exp $ */
+
 #include <stdlib.h>
 #include <Xm/PushB.h>
 #include <Xm/Label.h>
@@ -19,18 +21,18 @@ static char *FallBack[] =
 };
 
 void
-debug()
+debug(void)
 {
 }
 
 static void
-LosingFocus()
+LosingFocus(void)
 {
 	printf("LosingFocus()\n");
 }
 
 static void
-Activate()
+Activate(void)
 {
 	printf("Activate()\n");
 }
@@ -47,6 +49,7 @@ char buf[1024];
 }
 
 char *Program = "";
+
 int
 main(int argc, char **argv)
 {
@@ -60,9 +63,9 @@ main(int argc, char **argv)
   one = XltCreateNumEntry(toplevel, "NumEntry1", NULL, 0);
   StrokeInitialize(toplevel);
   XltSoundInitialize(toplevel);
-  XtAddCallback(one, XmNlosingFocusCallback, (void *)LosingFocus, (XtPointer)NULL);
-  XtAddCallback(one, XmNactivateCallback, (void *)Activate, (XtPointer)NULL);
-  XtAddCallback(one, XmNvalueChangedCallback, (void *)ValueChange, (XtPointer)NULL);
+  XtAddCallback(one, XmNlosingFocusCallback, (XtCallbackProc)LosingFocus, (XtPointer)NULL);
+  XtAddCallback(one, XmNactivateCallback, (XtCallbackProc)Activate, (XtPointer)NULL);
+  XtAddCallback(one, XmNvalueChangedCallback, (XtCallbackProc)ValueChange, (XtPointer)NULL);
   XtManageChild(one);
 
   XtRealizeWidget(toplevel);
