@@ -1,5 +1,5 @@
 /*
-    $Id: test1.c,v 1.1 1998/06/03 21:55:44 rwscott Exp $
+    $Id: test1.c,v 1.4 2000/06/29 10:05:34 amai Exp $
 
     stroke.c is a test program for the Stroke library.
     Copyright (C) 1997  Richard Scott
@@ -19,10 +19,11 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 #include <stdlib.h>
+#include <stdarg.h>
+#include <string.h>
 #include <unistd.h>
 #include <signal.h>
 #include <stdio.h>
-#include <varargs.h>
 #include <values.h>
 
 #include <Xm/RowColumn.h>
@@ -51,12 +52,12 @@
 #endif
 #include <Xlt.h>
 
-int getopt();
 
 char *Program;
+
 Widget AppShell;
 XtAppContext    Context;
-static char rcsid[]="$Id: test1.c,v 1.1 1998/06/03 21:55:44 rwscott Exp $";
+static char rcsid[]="$Id: test1.c,v 1.4 2000/06/29 10:05:34 amai Exp $";
 typedef struct {
 	Boolean Sounds;
 	String StartupSound;
@@ -88,19 +89,18 @@ static XrmOptionDescRec opTable[] = {
 	{"-debug",".debug",XrmoptionSepArg, NULL},
 };
 
-static void ClearDA();
+static void ClearDA(void);
 
-static void DisplayVersion();
-static void DisplayCopyright();
-static void DisplayLicense();
+static void DisplayVersion(void);
+static void DisplayCopyright(void);
+static void DisplayLicense(void);
 
 static XtActionsRec GlobalActions[] = {
-	{"DisplayVersion", DisplayVersion},
-	{"DisplayCopyright", DisplayCopyright},
-	{"DisplayLicense", DisplayLicense},
+	{"DisplayVersion", (XtActionProc)DisplayVersion},
+	{"DisplayCopyright", (XtActionProc)DisplayCopyright},
+	{"DisplayLicense", (XtActionProc)DisplayLicense},
 	{"Exit", (XtActionProc)exit},
-
-	{"ClearDA", ClearDA},
+	{"ClearDA", (XtActionProc)ClearDA},
 };
 
 static char *FallBack[] = {
@@ -139,14 +139,13 @@ static char *FallBack[] = {
 
 /* ******************** */
 
-void debug(va_alist)
-va_dcl
+void debug(int no, ...)
 {
 va_list args;
 char    *fmt;
 int     level;
 
-        va_start(args);
+        va_start(args, no);
         level = va_arg(args,int);
         if (level <= AppResources.debug)
         {
@@ -200,7 +199,7 @@ FILE *xrdb;
 
 /* ******************** */
 
-static void DoNothing()
+static void DoNothing(void)
 {
 	/*
 		This is necessary to ensure not more than 250 mS delay from
@@ -208,7 +207,7 @@ static void DoNothing()
 		be re-started and the WorkProc will not be noticed until
 		another Xevent is processed!
 	*/
-	XtAppAddTimeOut(Context,250,DoNothing,NULL);
+	XtAppAddTimeOut(Context,250,(XtTimerCallbackProc)DoNothing,NULL);
 }
 
 /* ******************** */
@@ -244,6 +243,7 @@ XmString        string;
 
 /* ******************** */
 
+#if 0
 static void ToggleBoolean(Widget W, Boolean *state)
 {
 String ResourceString;
@@ -258,6 +258,7 @@ String Class;
         UpdateResources(ResourceString);
         XtFree(ResourceString);
 }
+#endif
 
 /* ******************** */
 
@@ -268,10 +269,7 @@ static void ToggleStrokeDebug(Widget W, Boolean *state)
 
 /* ******************** */
 
-static Widget CreateOptionPulldown(parent,args_in,n_in)
-Widget  parent;
-Arg     *args_in;
-int     n_in;
+static Widget CreateOptionPulldown(Widget parent, Arg *args_in, int n_in)
 {
 Widget  PulldownMenu,
         Button;
@@ -315,7 +313,7 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static void DisplayLicense()
+static void DisplayLicense(void)
 {
 static Widget Dialog;
 String msg = "\n\
@@ -563,9 +561,9 @@ POSSIBILITY OF SUCH DAMAGES.\n\
 
 /* ******************** */
 
-static void DisplayCopyright()
+static void DisplayCopyright(void)
 {
-String msg = "stroke $Revision: 1.1 $\n\
+String msg = "stroke $Revision: 1.4 $\n\
 \n\
 Copyright (C) 1997 Richard Scott\n\
 \n\
@@ -582,14 +580,14 @@ click `Help->License' for details.\n\
 
 /* ******************** */
 
-static void DisplayVersion()
+static void DisplayVersion(void)
 {
 String msg = "stroke\n\
 A stroke test program for the X11\n\
 window system and Motif\n\
 \n\
 by Rick Scott <rwscott@magi.com>\n\
-$Revision: 1.1 $";
+$Revision: 1.4 $";
 
 	debug(5,"DisplayVersion(%s)\n",rcsid);
         Info(msg);
@@ -597,10 +595,7 @@ $Revision: 1.1 $";
 
 /* ******************** */
 
-static Widget CreateFilePulldown(parent,args_in,n_in)
-Widget  parent;
-Arg     *args_in;
-int     n_in;
+static Widget CreateFilePulldown(Widget  parent, Arg *args_in, int n_in)
 {
 Widget  PulldownMenu,
         Button;
@@ -623,7 +618,7 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static void ClearDA()
+static void ClearDA(void)
 {
 Widget mainDA = XtNameToWidget(AppShell, "*mainDA");
 
@@ -634,10 +629,7 @@ Widget mainDA = XtNameToWidget(AppShell, "*mainDA");
 
 /* ******************** */
 
-static Widget CreateEditPulldown(parent,args_in,n_in)
-Widget  parent;
-Arg     *args_in;
-int     n_in;
+static Widget CreateEditPulldown(Widget  parent, Arg *args_in, int n_in)
 {
 Widget  PulldownMenu,
         Button;
@@ -658,10 +650,7 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static Widget CreateHelpPulldown(parent,args_in,n_in)
-Widget  parent;
-Arg     *args_in;
-int     n_in;
+static Widget CreateHelpPulldown(Widget  parent, Arg *args_in, int n_in)
 {
 Widget  HelpMenu,
         Button;
@@ -693,10 +682,7 @@ Widget  HelpMenu,
 
 /* ******************** */
 
-static Widget CreateMenus(parent,args_in,n_in)
-Widget  parent;
-Arg     *args_in;
-int     n_in;
+static Widget CreateMenus(Widget parent, Arg *args_in, int n_in)
 {
 Widget  MenuBar;
 
@@ -721,27 +707,25 @@ static void GetApplicationResources(Widget W)
 
 /* ******************** */
 
-static void ExposeDA()
+static void ExposeDA(void)
 {
 }
 
 /* ******************** */
 
-static void ResizeDA()
+static void ResizeDA(void)
 {
 }
 
 /* ******************** */
 
-static void InputDA()
+static void InputDA(void)
 {
 }
 
 /* ******************** */
 
-int main(argc,argv)
-int	argc;
-char	*argv[];
+int main(int	argc, char *argv[])
 {
 Widget		Form,
 		Menus;
