@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/ComboBox.c,v 1.46 2000/01/25 23:56:25 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.48 2000/12/20 19:48:31 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/ComboBox.c,v 1.46 2000/01/25 23:56:25 amai Exp $";
-
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.48 2000/12/20 19:48:31 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ListP.h>
 #include <Xm/TextFP.h>
@@ -3099,8 +3099,9 @@ The text field widget is called "Text".
   END:
 */
 
-void
-XmComboBoxAddItem(Widget w, XmString xms, int a, int b)
+
+extern void
+XmComboBoxAddItem(Widget w, XmString xms, int a, Boolean unique)
 {
 	char    *s = NULL;
 	XmStringGetLtoR(xms, XmFONTLIST_DEFAULT_TAG, &s);
@@ -3108,7 +3109,7 @@ XmComboBoxAddItem(Widget w, XmString xms, int a, int b)
 	fprintf(stderr, "XmComboBoxAddItem(%s,%d,%d)\n", s, a, b);
 #endif
 	XtFree(s);
-
+      /* FIXME: what about 'unique' ?? */
 	XmListAddItemUnselected(CB_List(w), xms, a);
 }
 
