@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Container.c,v 1.10 2000/07/04 23:08:52 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Container.c,v 1.12 2000/11/02 21:32:08 amai Exp $
  *
  * Copyright (C) 1997-1999 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +24,8 @@
  **/
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/BaseClassP.h>
 #include <Xm/Container.h>
@@ -33,16 +34,14 @@
 
 #include <XmI/DebugUtil.h>
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Container.c,v 1.10 2000/07/04 23:08:52 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Container.c,v 1.12 2000/11/02 21:32:08 amai Exp $";
 
 /* 
   MODULE:	Container.c
   DESCRIPTION:	Implement the XmContainer widget class.
   STATUS:	Not too well yet.
   
-  online references:
-    http://www.software.hp.com/STK/man/11.00/XmContainer_3.html
-  END:
+
 */
 
 /*
