@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Draw.c,v 1.10 2000/02/15 23:32:52 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Draw.c,v 1.12 2000/10/24 21:00:19 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Draw.c,v 1.10 2000/02/15 23:32:52 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Draw.c,v 1.12 2000/10/24 21:00:19 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/DebugUtil.h>
 #include <Xm/DrawP.h>
 
+
 #define INDICATOR_GLYPH_MASK	0xf0
 
 void
@@ -41,6 +44,7 @@ XmeClearBorder(Display *display,
 }
 
 void
+
 XmeDrawShadows(Display *display,
 	       Drawable d,
 	       GC top_gc,
@@ -54,6 +58,7 @@ XmeDrawShadows(Display *display,
 		   shadow_thick, shadow_type);
 }
 
+
 void
 XmeDrawDiamond(Display *display,
 	       Drawable d,
@@ -69,6 +74,7 @@ XmeDrawDiamond(Display *display,
 		   x, y, width, height, shadow_thick, fill);
 }
 
+
 void
 XmeDrawSeparator(Display *display,
 		 Drawable d,
@@ -87,6 +93,7 @@ XmeDrawSeparator(Display *display,
 		     orientation, separator_type);
 }
 
+
 void
 XmeDrawHighlight(Display *display,
 		 Drawable d,
@@ -99,6 +106,7 @@ XmeDrawHighlight(Display *display,
 			   highlight_thick);
 }
 
+
 void
 XmeDrawArrow(Display *display,
 	     Drawable d,
@@ -114,6 +122,7 @@ XmeDrawArrow(Display *display,
 		 shadow_thick, direction);
 }
 
+
 void
 XmeDrawCircle(Display *display,
 	      Drawable d,
@@ -186,6 +195,7 @@ XmeDrawCircle(Display *display,
     }
 }
 
+
 void
 XmeDrawIndicator(Display *display, 
 		 Drawable d, 
@@ -244,3 +254,18 @@ XmeDrawIndicator(Display *display,
 	XFillPolygon(display, d, gc, xp, 6, Convex, CoordModePrevious);
   }
 }
+
+
+void 
+XmeDrawPolygonShadow(Display *display,
+                     Drawable drawable,
+                     GC top_gc,
+                     GC bottom_gc,
+                     XPoint *points,
+                     int point_count,
+                     Dimension shadow_thickness,
+                     unsigned char shadow_type)
+{
+
+  _XmWarning(NULL, "XmeDrawPolygonShadow(): not yet implemented!");
+}
