@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/IconG.c,v 1.7 2000/02/15 23:32:52 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.10 2000/09/22 20:35:14 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/IconG.c,v 1.7 2000/02/15 23:32:52 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.10 2000/09/22 20:35:14 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
+#include <XmI/PixConvI.h>
 #include <Xm/XmP.h>
 #include <Xm/CacheP.h>
 #include <Xm/CascadeB.h>
@@ -37,11 +41,10 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/IconG.c
 #include <Xm/IconGP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/XmosP.h>
-#include <X11/Xfuncs.h>
 #include <X11/ShellP.h>
 
 #include <XmI/DebugUtil.h>
-#include <XmI/PixConvI.h>
+
 
 #ifndef XmUNSPECIFIED
 #define XmUNSPECIFIED (~0)
@@ -456,7 +459,7 @@ secondary_object_create(Widget request, Widget new_w,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -473,7 +476,7 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmIconCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmIconGCacheObjPart *)A),
+    return !memcmp(((XmIconGCacheObjPart *)A),
 		 ((XmIconGCacheObjPart *)B),
 		 sizeof(XmIconGCacheObjPart));
 }
@@ -514,10 +517,10 @@ class_initialize(void)
 			     &labels, &nlabels);
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
-    bcopy(labels, combined, nlabels * sizeof(XtResource));
-    bcopy(cache_resources,
-	  &combined[nlabels],
-	  XtNumber(cache_resources) * sizeof(XtResource));
+    memcpy(combined, labels, nlabels * sizeof(XtResource));
+    memcpy(&combined[nlabels],
+           cache_resources,
+	   XtNumber(cache_resources) * sizeof(XtResource));
     XtFree((char *)labels);
 
     xmIconGCacheObjClassRec.object_class.resources = combined;
@@ -897,13 +900,13 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
 #if 0
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 #endif
-    bcopy(IG_Cache(new_w),
-	  &((XmIconGCacheObject)nsec)->icon_cache,
-	  sizeof(XmIconGCacheObjPart));
+    memcpy(&((XmIconGCacheObject)nsec)->icon_cache,
+           IG_Cache(new_w),
+	   sizeof(XmIconGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -918,7 +921,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
 #if 0
     LabG_Cache(new_w) = &(((XmIconGCacheObject)nsec)->label_cache);
@@ -1175,13 +1178,13 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     nsec = _XmExtObjAlloc(size);
 
 #if 0
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 #endif
-    bcopy(IG_Cache(new_w),
-	  &((XmIconGCacheObject)nsec)->icon_cache,
-	  sizeof(XmIconGCacheObjPart));
+    memcpy(&((XmIconGCacheObject)nsec)->icon_cache,
+           IG_Cache(new_w),
+	   sizeof(XmIconGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
