@@ -1,9 +1,9 @@
-#define	LARGE_PAGE
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.28 2000/08/08 22:21:13 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.31 2000/11/06 09:40:18 amai Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.28 2000/08/08 22:21:13 danny Exp $";
-
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.31 2000/11/06 09:40:18 amai Exp $";
 
 /*
  * This is a widget whose main purpose is to do geometry management for its
@@ -50,15 +49,19 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Noteboo
  * XmPushButton, XmPushButtonGadget, XmArrowButton, XmArrowButtonGadget,
  * XmText, XmTextField, XmScrollBar, XmDrawnButton; and all their subclasses.
  */
+
+/* definitions used below */
+#define	LARGE_PAGE
 #define	TRAIT_WORKAROUND
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <XmI/DebugUtil.h>
 
 #include <Xm/NotebookP.h>
-#include <Xm/Xpm.h>
+#include <Xm/XpmP.h>
 
 /*
  * Traits used by Notebook
@@ -85,6 +88,7 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Noteboo
 #include <Xm/ScrollBar.h>
 #endif
 
+
 /* Forward Declarations */
 
 static void ClassInitialize(void);
@@ -980,7 +984,7 @@ resize(Widget w)
 static void
 _XmNBTabCallback(Widget w, XtPointer client, XtPointer call)
 {
-	int			r = (int)client;
+	int			r = (int)(long)client;
 	XmAnyCallbackStruct	*cbp = (XmAnyCallbackStruct *)call;
 
 	DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBTabCallback\n"));
@@ -1139,7 +1143,7 @@ ConstraintInitialize(Widget request, Widget nw,
 	t = XmeTraitGet(XtClass(nw), XmQTactivatable);
 	if (t)
 		((XmActivatableTrait)t)->changeCB(nw,
-			_XmNBTabCallback, (XtPointer)rc,
+			_XmNBTabCallback, (XtPointer)(long)rc,
 			True);	/* Add it */
 	else
 		_XmWarning(nw, "has no XmQTactivatable trait\n");
