@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/PanedW.c,v 1.13 2000/04/24 06:04:07 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PanedW.c,v 1.15 2000/09/22 20:35:14 amai Exp $
  *
  * Copyright (C) 1995-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/PanedW.c,v 1.13 2000/04/24 06:04:07 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PanedW.c,v 1.15 2000/09/22 20:35:14 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -32,9 +38,6 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/PanedW.
 #include <Xm/PanedWP.h>
 #include <Xm/SashP.h>
 #include <Xm/SeparatorP.h>
-#include <X11/Xfuncs.h>
-#include <stdlib.h>
-#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -1313,7 +1316,7 @@ change_managed(Widget w)
 
 	    if ((PW_NumManagedChildren(w) - i) > 0)
 	    {
-		bcopy(&PW_ManagedChildren(w)[i + 1], &PW_ManagedChildren(w)[i],
+		memcpy(&PW_ManagedChildren(w)[i], &PW_ManagedChildren(w)[i + 1], 
 		      sizeof(Widget) * (PW_NumManagedChildren(w) - i));
 	    }
 	}
