@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/PixConv.c,v 1.6 1998/09/24 15:37:39 pgw Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PixConv.c,v 1.8 2000/09/23 15:05:27 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/PixConv.c,v 1.6 1998/09/24 15:37:39 pgw Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PixConv.c,v 1.8 2000/09/23 15:05:27 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <XmI/PixConvI.h>  /* <--- just to see if we get any warnings */
 
@@ -55,11 +56,30 @@ _XmTopShadowPixmapDefault(Widget w, int offset, XrmValue *val)
    val->addr = (XtPointer) &pmap;
 }
 
+/*
+  FUNCTION: _XmHighlightPixmapDefault 
+  SYNOPSIS: void _XmHighlightPixmapDefault(Widget w, int offset, XrmValue *val)
+  DESCRIPTION:
+  This function is an internal Motif 2.0 function.  It sets the default 
+  highlight shadow pixmap.  This routine is not implemented yet.  
+  It just returns XmUNSPECIFIED_PIXMAP for the time being. 
+  END:
+*/
+void
+_XmHighlightPixmapDefault(Widget w, int offset, XrmValue *val)
+{
+   static Pixmap pmap;
+
+   /* FIXTHIS: This is not implemented yet. */
+   pmap = XmUNSPECIFIED_PIXMAP;
+   val->addr = (XtPointer) &pmap;
+}
+
 /*
   FUNCTION: _XmGetPixmapBasedGC
   SYNOPSIS: GC _XmGetPixmapBasedGC(Widget w, Pixmap pmap, Pixel pix, XtGCMask mask, XGCValues *values)
   DESCRIPTION:
-  This function is an internal Motif 2.0 function.  This a guess at what
+  This function is an internal Motif 2.0 function.  This is a guess at what
   it does since there is no documentation on it that I know of. 
   END:
 */
@@ -90,4 +110,3 @@ _XmGetPixmapBasedGC(
 
    return XtGetGC(w, mask, values);
 }
-
