@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.27 2000/04/30 22:38:31 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.29 2000/11/10 10:42:39 amai Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.27 2000/04/30 22:38:31 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.29 2000/11/10 10:42:39 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -30,8 +31,6 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <XmI/DebugUtil.h>
-
 #include <Xm/SpinBP.h>
 #include <Xm/Text.h>
 #include <Xm/TextF.h>
@@ -40,6 +39,8 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox
 #include <Xm/NavigatorT.h>
 #include <Xm/ScrollFrameT.h>
 
+#include <XmI/DebugUtil.h>
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -280,7 +281,6 @@ char _XmSpinBox_ChildAccelerators[] =
 	"<Key>osfBeginData:		SpinBFirst()\n"
 	"<Key>osfEndData:		SpinBLast()\n";
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmSpinBoxCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -396,7 +396,6 @@ XmSpinBoxClassRec xmSpinBoxClassRec = {
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmSpinBoxWidgetClass = (WidgetClass)&xmSpinBoxClassRec;
@@ -1320,3 +1319,24 @@ _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 	 * By getting this call we can change our appearance (e.g. page number).
 	 */
 }
+
+
+extern int
+XmSpinBoxValidatePosition(Widget textfield,
+                          int *position)
+{
+   int oldpos;
+
+   if (SPBC_Numeric(textfield)) {
+	oldpos = SPBC_Position(textfield);
+	*position = oldpos;
+        _XmWarning(NULL, "XmSpinBoxValidatePosition(): not yet implemented!");
+        return XmCURRENT_VALUE;
+   }
+   else {
+        /* non-numeric */
+	oldpos = SPBC_Position(textfield);
+	*position = oldpos;
+	return XmCURRENT_VALUE;
+   }
+}
