@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.2 1997/10/15 19:26:59 u27113 Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.6 2000/11/09 15:16:42 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,25 +23,23 @@
  *
  **/
 
-static char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.2 1997/10/15 19:26:59 u27113 Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.6 2000/11/09 15:16:42 amai Exp $";
 
 /*
- * This file contains the _XmStrings array
+ * This file contains the _XmStrings array for Motif 2.0 libXm
  */
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
-#include <Xm/XmP.h>
-#if XtSpecificationRelease < 6
-#include <X11/IntrinsicP.h>
-#endif
+/*
+#include <XmI/XmI.h>
+*/
 
 /*
  * The missing commas are intentional.  Let the compiler
  * concatenate the strings
  */
-_XmConst char _XmStrings[] =
+const char _XmStrings[] =
 /* 0     */ "\0"
 /* 1     */ "Accelerator\0"
 /* 13    */ "AcceleratorText\0"
