@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.15 2000/08/15 11:13:01 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Xme.c,v 1.22 2000/11/09 15:16:42 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,13 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.15 2000/08/15 11:13:01 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Xme.c,v 1.22 2000/11/09 15:16:42 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -38,22 +40,24 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v
 #include <Xm/XmosP.h>
 #include <Xm/VirtKeysP.h>
 #include <Xm/VendorSEP.h>
+#include <Xm/ColorObjP.h>
 #include <XmI/MessagesI.h>
 
-/* required prototypes: */
+/* required prototypes of exported, but private Intrinsic stuff: */
 extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
 extern void _XtRemoveCallback(XtCallbackList *, XtCallbackProc, XtPointer);
 
 
 /* DragIcon */
-Widget
+extern Widget
 XmeGetTextualDragIcon(Widget w)
 {
     return _XmGetTextualDragIcon(w);
 }
 
+
 /* GeoUtils */
-XtGeometryResult
+extern XtGeometryResult
 XmeReplyToQueryGeometry(Widget w,
 			XtWidgetGeometry *request,
 			XtWidgetGeometry *reply)
@@ -61,8 +65,9 @@ XmeReplyToQueryGeometry(Widget w,
     return _XmGMReplyToQueryGeometry(w, request, reply);
 }
 
+
 /* GadgetUtil */
-void
+extern void
 XmeConfigureObject(Widget g,
 		   Position x, Position y,
 		   Dimension width, Dimension height, Dimension border_width)
@@ -70,15 +75,17 @@ XmeConfigureObject(Widget g,
     _XmConfigureObject(g, x, y, width, height, border_width);
 }
 
+
 /* GadgetUtil */
-void
+extern void
 XmeRedisplayGadgets(Widget w, XEvent *event, Region region)
 {
     _XmRedisplayGadgets(w, event, region);
 }
 
+
 /* ImageCache */
-Boolean
+extern Boolean
 XmeGetPixmapData(Screen *screen, Pixmap pixmap,
 		 char **image_name,
 		 int *depth, Pixel *foreground, Pixel *background,
@@ -91,67 +98,16 @@ XmeGetPixmapData(Screen *screen, Pixmap pixmap,
 			    hot_x, hot_y, width, height);
 }
 
-/* ResConvert */
-void
-XmeWarning(Widget w, char *fmt,...)
-{
-    va_list arg_list;
-    char buf[256];
 
-    va_start(arg_list, fmt);
-    if (w)
-    {
-	sprintf(buf, "\n    Name: %s\n    Class: %s\n    ",
-		XtName(w), XtClass(w)->core_class.class_name);
-
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-	strcat(buf, "\n");
-
-#ifdef	LESSTIF_PRODUCTION
-	XtAppWarning(XtWidgetToApplicationContext(w), buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
-	}
-#endif
-    }
-    else
-    {
-	buf[0] = '\0';
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-#ifdef	LESSTIF_PRODUCTION
-	XtWarning(buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtWarning(buf);
-	}
-#endif
-    }
-}
-
-/* ResConvert */
-Boolean
+extern Boolean
 XmeNamesAreEqual(char *in_str, char *text_str)
 {
     return _XmStringsAreEqual(in_str, text_str);
 }
 
+
 /* ResInd */
-void
+extern void
 XmeFromHorizontalPixels(Widget widget,
 			int offset,
 			XtArgVal *value)
@@ -159,8 +115,9 @@ XmeFromHorizontalPixels(Widget widget,
     _XmFromHorizontalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-void
+extern void
 XmeFromVerticalPixels(Widget widget,
 		      int offset,
 		      XtArgVal *value)
@@ -168,8 +125,9 @@ XmeFromVerticalPixels(Widget widget,
     _XmFromVerticalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-XmImportOperator
+extern XmImportOperator
 XmeToHorizontalPixels(Widget widget,
 		      int offset,
 		      XtArgVal *value)
@@ -177,8 +135,9 @@ XmeToHorizontalPixels(Widget widget,
     return _XmToHorizontalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-XmImportOperator
+extern XmImportOperator
 XmeToVerticalPixels(Widget widget,
 		    int offset,
 		    XtArgVal *value)
@@ -186,40 +145,44 @@ XmeToVerticalPixels(Widget widget,
     return _XmToVerticalPixels(widget, offset, value);
 }
 
+
 /* Screen */
-Cursor
+extern Cursor
 XmeGetNullCursor(Widget w)
 {
     return _XmGetNullCursor(w);
 }
 
+
 /* Traversal */
-Boolean
+extern Boolean
 XmeFocusIsInShell(Widget wid)
 {
     return _XmFocusIsInShell(wid);
 }
 
+
 /* Traversal */
-void
+extern void
 XmeNavigChangeManaged(Widget w)
 {
     _XmNavigChangeManaged(w);
 }
 
+
 /* Vendor */
-Display *
+extern Display *
 XmeGetDefaultDisplay(void)
 {
     return _XmGetDefaultDisplay();
 }
 
-void 
+
+extern void 
 XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
     XmBaseClassExt *bce;
     XtPointer nsec;
-    Widget desktopParent;
     int size;
 
     if(!XmIsVendorShell(w))
@@ -243,19 +206,17 @@ XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
     ExtObj_LogicalParent(nsec) = w;
     ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
 
-    Desktop_Parent(nsec) = desktopParent;
-
     _XtAddCallback(&VSEP_FocusMovedCallback(nsec),
 		   cp, udata);
     XtFree((char *)nsec);
 }
 
-void
+
+extern void
 XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
     XmBaseClassExt *bce;
     XtPointer nsec;
-    Widget desktopParent;
     int size;
 
     if(!XmIsVendorShell(w))
@@ -279,15 +240,14 @@ XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
     ExtObj_LogicalParent(nsec) = w;
     ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
 
-    Desktop_Parent(nsec) = desktopParent;
-
     _XtRemoveCallback(&VSEP_FocusMovedCallback(nsec),
                       cp, udata);
     XtFree((char *)nsec);
 }
 
+
 /* Visual */
-void
+extern void
 XmeGetDefaultPixel(Widget widget,
 		   int type,
 		   int offset,
@@ -307,11 +267,12 @@ XmeGetDefaultPixel(Widget widget,
 					  XmIsGadget(widget) ?
 					  XmParentBackground(widget) :
 					  XtBackground(widget)),
-			     type);
+					  type);
 }
 
+
 /* VirtKeys */
-void
+extern void
 XmeVirtualToActualKeysym(Display *Dsp,
 			 KeySym VirtualKeysym,
 			 KeySym *RealKeysymReturn,
@@ -321,33 +282,31 @@ XmeVirtualToActualKeysym(Display *Dsp,
 			     ModifierReturn);
 }
 
+
 /* XmString */
-void
+extern void
 XmeStringUpdateWMShellTitle(XmString xmstr, Widget shell)
 {
+   /* This is not specified by Motif 2.1 ... */
     _XmStringUpdateWMShellTitle(xmstr, shell);
 }
 
-void
+
+extern void
 XmeSetWMShellTitle(XmString xmstr, Widget shell)
 {
-	/* Apparently the same thing as the above. */
-	_XmStringUpdateWMShellTitle(xmstr, shell);
+    /* Apparently the same thing as the above. */
+    _XmStringUpdateWMShellTitle(xmstr, shell);
 }
 
+
 /* Xmos */
-int
+extern int
 XmeMicroSleep(long secs)
 {
     return _XmMicroSleep(secs);
 }
 
-/* Xmos */
-String
-XmeGetHomeDirName(void)
-{
-    return _XmOSGetHomeDirName();
-}
 
 XmFontList
 XmeGetDefaultRenderTable(Widget w, unsigned int fontListType)
@@ -355,25 +314,74 @@ XmeGetDefaultRenderTable(Widget w, unsigned int fontListType)
 	return (XmFontList)NULL;
 }
 
-/* "online" references e.g. on
-   http://vireo.gatech.edu/ebt-bin/nph-dweb/dynaweb/SGI_Developer/Motif21_WG/@Generic__BookTextView/35630;td=2;cs=fullhtml;pt=4;lang=de#X
-*/
+
 /* Transfer */
-Atom
+extern Atom
 *XmeStandardTargets(Widget w,
                     int count,
-		    int *count_return)
+                    int *count_return)
 {
- _XmWarning(NULL, "XmeStandardTargets(): not yet implemented!");
- return (Atom *)NULL;
+   _XmWarning(NULL, "XmeStandardTargets(): not yet implemented!");
+   return (Atom *)NULL;
 }
 
 
 /* Transfer */
-void 
+extern void 
 XmeStandardConvert(Widget w,
-                        XtPointer ignore,
-			XmConvertCallbackStruct *call_data)
+                   XtPointer ignore,
+                   XmConvertCallbackStruct *call_data)
 {
- _XmWarning(NULL, "XmeStandardConvert(): not yet implemented!");
+   _XmWarning(NULL, "XmeStandardConvert(): not yet implemented!");
+}
+
+
+extern void
+XmeQueryBestCursorSize(Widget widget, Dimension *width, Dimension *height) 
+{
+   _XmWarning(NULL, "XmeQueryBestCursorSize(): not yet implemented!");
+}
+
+
+extern void
+XmeResolvePartOffsets(WidgetClass widget_class,
+                           XmOffsetPtr *offset,
+                           XmOffsetPtr *constraint_offset)
+{
+   _XmWarning(NULL, "XmeResolvePartOffsets(): not yet implemented!");
+}
+
+
+extern void 
+XmeConvertMerge(XtPointer data, Atom type,
+                     int format, unsigned long length,
+                     XmConvertCallbackStruct *call_data)
+{
+   _XmWarning(NULL, "XmeConvertMerge(): not yet implemented!");
+}
+
+
+extern Boolean
+XmeGetDesktopColorCells(Screen *screen,
+                                Colormap colormap,
+                                XColor *colors,
+                                int n_colors,
+                                int *n_colors_ret)
+{
+   _XmWarning(NULL, "XmeGetDesktopColorCells(): not yet implemented!");
+   return False;
+}
+
+
+extern Boolean
+XmeGetColorObjData(int *screen,
+                   int *coloruse,
+                   XmPixelSet *pixel_set,
+                   unsigned short pixel_set_size,
+                   short *active,  short *inactive,
+		   short *primary, short *secondary,
+		   short *text)
+{
+   _XmWarning(NULL, "XmeGetColorObjData(): not yet implemented!");
+   return False;
 }
