@@ -1,9 +1,9 @@
 /**
  *
- * $Id: BaseClass.c,v 1.17 2000/08/29 15:04:51 amai Exp $
+ * $Id: BaseClass.c,v 1.19 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 2000 LessTif Development Team
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,11 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BaseClass.c,v 1.17 2000/08/29 15:04:51 amai Exp $";
+static const char rcsid[] = "$Id: BaseClass.c,v 1.19 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdio.h>
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/BaseClassP.h>
 #include <Xm/DisplayP.h>
@@ -42,12 +45,9 @@ static const char rcsid[] = "$Id: BaseClass.c,v 1.17 2000/08/29 15:04:51 amai Ex
 
 #include <X11/RectObjP.h>
 #include <X11/Xutil.h>
-#include <X11/Xfuncs.h>
-#include <X11/Xfuncproto.h>
 
 #include <XmI/DebugUtil.h>
 
-#include <stdio.h>
 
 /* For the prototype police */
 
@@ -430,7 +430,7 @@ _XmPushWrapperData(WidgetClass wc)
     {
 	wrapper = (XmWrapperData)XtMalloc(sizeof(XmWrapperDataRec));
 
-	bcopy(bce->wrapperData, wrapper, sizeof(XmWrapperDataRec));
+	memcpy(wrapper, bce->wrapperData, sizeof(XmWrapperDataRec));
 
 	wrapper->widgetClass = wc;
 	wrapper->next = bce->wrapperData;
@@ -439,7 +439,7 @@ _XmPushWrapperData(WidgetClass wc)
     {
 	wrapper = (XmWrapperData)XtMalloc(sizeof(XmWrapperDataRec));
 
-	bzero(wrapper, sizeof(XmWrapperDataRec));
+	memset(wrapper, 0, sizeof(XmWrapperDataRec));
     }
 
     bce->wrapperData = wrapper;
@@ -1054,7 +1054,7 @@ BaseClassPartInitialize(WidgetClass wc)
      * Let us be notorious and always clean the flags. The flags have
      * to be set during the class_part_init method of a widget class.
      */
-    bzero((*ext)->flags, 32);
+    memset((*ext)->flags, 0, 32);
 
     /*
      * If the superclass hasn't a base class extension record, use
@@ -1870,7 +1870,7 @@ _XmTransformSubResources(XtResourceList comp_resources,
 
     if ((int)(comp_resources[0].resource_offset) >= 0)
     {
-	bcopy(comp_resources, res, sizeof(XtResource) * num_comp_resources);
+	memcpy(res, comp_resources, sizeof(XtResource) * num_comp_resources);
     }
     else
     {
