@@ -1,8 +1,9 @@
 /**
  *
- * $Id: BulletinBoard.c,v 1.52 2000/07/25 08:44:11 amai Exp $
+ * $Id: BulletinBoard.c,v 1.57 2000/10/23 07:57:45 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BulletinBoard.c,v 1.52 2000/07/25 08:44:11 amai Exp $";
+static const char rcsid[] = "$Id: BulletinBoard.c,v 1.57 2000/10/23 07:57:45 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -43,6 +45,21 @@ static const char rcsid[] = "$Id: BulletinBoard.c,v 1.52 2000/07/25 08:44:11 ama
 
 #include <XmI/DebugUtil.h>
 
+/* #defines being used in this file:
+      #ifdef USE_WIDGETS
+*/
+
+
+/* We use a 'private', i.e. non-declared but actually
+   exported call from OpenGroup's Intrinsic sources
+   (lib/Xt/Callback.c) in this file.
+   Note that we don't give the precise type here ...
+ */
+extern void 
+_XtRemoveAllCallbacks(
+  /* InternalCallbackList *callbacks; */
+ void *callbacks);
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -234,7 +251,7 @@ static XtActionsRec actions[] =
 
 static XtTranslations mapTrans;
 static XtTranslations defTrans;
-/* *INDENT-OFF* */
+
 #if 0
 static XmBaseClassExtRec _XmBulletinBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -355,7 +372,6 @@ XmBulletinBoardClassRec xmBulletinBoardClassRec = {
 	/* extension			*/ NULL,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmBulletinBoardWidgetClass = (WidgetClass)&xmBulletinBoardClassRec;
@@ -571,6 +587,7 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     BB_OldHeight(new_w) = -1;
 
     BB_GeoCache(new_w) = NULL;
+    MGR_InitialFocus(new_w) = BB_DefaultButton(new_w);
     BB_InSetValues(new_w) = False;
 }
 
@@ -641,6 +658,7 @@ set_values(Widget old,
 
 	_XmBBUpdateDynDefaultButton(new_w);
 
+	MGR_InitialFocus(new_w) = BB_DefaultButton(nw);
 	need_refresh = True;	/* do we need to ? */
     }
 
@@ -1430,6 +1448,19 @@ delete_child(Widget w)
     {
 	BB_CancelButton(bb) = NULL;
     }
+    if (w == BB_DynamicCancelButton(bb))
+    {
+	BB_DynamicCancelButton(bb) = NULL;
+    }
+    if (w == BB_DynamicDefaultButton(bb))
+    {
+	BB_DynamicDefaultButton(bb) = NULL;
+    }
+    if (w == BB_DefaultButton(bb))
+    {
+	BB_DefaultButton(bb) = NULL;
+	MGR_InitialFocus(bb) = NULL;
+    }
 }
 
 static Boolean
@@ -1586,7 +1617,11 @@ _XmBulletinBoardFocusMoved(Widget wid, XtPointer client_data, XtPointer data)
     Widget default_button = NULL;
     Widget par;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmBulletinBoardFocusMoved\n"));
+    DEBUGOUT(XdbDebug(__FILE__, wid, "%s:%d - %s %s %s\n",
+    	__FILE__, __LINE__,
+    	cbs->cont ? "True" : "False",
+    	cbs->old_focus ? XtName(cbs->old_focus) : "NULL",
+    	cbs->new_focus ? XtName(cbs->new_focus) : "NULL"));
 
     if (!cbs->cont)
     {
@@ -1797,6 +1832,10 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 {
     Arg argl[2];
 
+    DEBUGOUT(XdbDebug(__FILE__, wid, "%s:%d - %s\n",
+    	__FILE__, __LINE__,
+    	newDefaultButton ? XtName(newDefaultButton) : "NULL"));
+
     if (newDefaultButton && wid != XtParent(newDefaultButton))
     {
     	return;
@@ -1831,7 +1870,14 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 void
 _XmBBUpdateDynDefaultButton(Widget bb)
 {
-    if (BB_DynamicDefaultButton(bb))
+    DEBUGOUT(XdbDebug(__FILE__, bb, "%s:_XmBBUpdateDynDefault(%d) - %s(%smanaged) %s\n",
+    	__FILE__, __LINE__,
+    	BB_DynamicDefaultButton(bb) ? XtName(BB_DynamicDefaultButton(bb)) : "NULL",
+    	BB_DynamicDefaultButton(bb) ? XtIsManaged(BB_DynamicDefaultButton(bb)) ? "" : "not " : "not ",
+    	BB_DefaultButton(bb) ? XtName(BB_DefaultButton(bb)) : "NULL"));
+
+    if (BB_DynamicDefaultButton(bb) &&
+        XtIsManaged(BB_DynamicDefaultButton(bb)))
     {
 	_XmBulletinBoardSetDynDefaultButton(bb, BB_DynamicDefaultButton(bb));
     }
