@@ -1,8 +1,9 @@
 /**
  *
- * $Id: CascadeB.c,v 1.151 2000/03/21 04:12:58 rwscott Exp $
+ * $Id: CascadeB.c,v 1.154 2000/10/19 13:51:59 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CascadeB.c,v 1.151 2000/03/21 04:12:58 rwscott Exp $";
+static const char rcsid[] = "$Id: CascadeB.c,v 1.154 2000/10/19 13:51:59 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdarg.h>
+
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
-
 #include <Xm/XmP.h>
 #include <Xm/CascadeBP.h>
 #include <Xm/CascadeBGP.h>
@@ -37,11 +40,9 @@ static const char rcsid[] = "$Id: CascadeB.c,v 1.151 2000/03/21 04:12:58 rwscott
 #include <Xm/MenuShellP.h>
 #include <Xm/MenuUtilP.h>
 #include <Xm/ScreenP.h>
-#include <stdarg.h>
 
 #include <XmI/DebugUtil.h>
 
-#include <stdio.h>
 
 #ifndef XmUNSPECIFIED
 #define XmUNSPECIFIED	(~0)
@@ -99,7 +100,7 @@ static void CheckDisarm(Widget, XEvent *, String *, Cardinal *);
 static void ArmAndPost(Widget, XEvent *, String *, Cardinal *);
 #endif
 
-static void MenuProcEntry(int proc, Widget rc,...);
+static void MenuProcEntry(int proc, Widget rc, ...);
 
 /*
  * Resources for the cascade button class
@@ -766,7 +767,10 @@ _XmCascadingPopup(Widget w, XEvent *event, Boolean doCascade)
     Widget sub_pane;
     Boolean was_torn;
 
-	sub_pane = XmIsGadget(w) ?  CBG_Submenu(w) : CB_Submenu(w);
+	if (XmIsGadget(w))
+	    sub_pane = CBG_Submenu(w);
+	else
+	    sub_pane = CB_Submenu(w);
 	if (sub_pane)
 	{
 	    RCClass_MenuProcs(XtClass(sub_pane))(XmMENU_RESTORE_TEAROFF_TO_MENUSHELL,
@@ -779,11 +783,10 @@ _XmCascadingPopup(Widget w, XEvent *event, Boolean doCascade)
 
     XFlush(XtDisplay(w));
 
-    XtCallCallbackList(w,
-		       (XmIsGadget(w)
-			? CBG_CascadeCall(w)
-			: CB_CascadeCall(w)),
-		       &cbs);
+    if(XmIsGadget(w))
+          XtCallCallbackList(w, CBG_CascadeCall(w), &cbs);
+    else
+          XtCallCallbackList(w, CB_CascadeCall(w),  &cbs);
 
     if (doCascade)
     {
@@ -1268,7 +1271,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 
 static void
-MenuProcEntry(int proc, Widget w,...)
+MenuProcEntry(int proc, Widget w, ...)
 {
     va_list arg_list;
 
