@@ -1,8 +1,9 @@
 /**
  *
- * $Id: CascadeBG.c,v 1.136 2000/07/14 15:13:21 danny Exp $
+ * $Id: CascadeBG.c,v 1.139 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CascadeBG.c,v 1.136 2000/07/14 15:13:21 danny Exp $";
+static const char rcsid[] = "$Id: CascadeBG.c,v 1.139 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdarg.h>
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/CacheP.h>
 #include <Xm/CascadeB.h>	/* For XmCascadeButtonHighlight */
@@ -37,8 +41,6 @@ static const char rcsid[] = "$Id: CascadeBG.c,v 1.136 2000/07/14 15:13:21 danny
 #include <Xm/RowColumnP.h>
 #include <Xm/ScreenP.h>
 #include <Xm/MenuUtilP.h>
-#include <X11/Xfuncs.h>
-#include <stdarg.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -378,7 +380,7 @@ secondary_object_create(Widget request, Widget new_w,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
@@ -396,7 +398,7 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmCascadeBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmCascadeButtonGCacheObjPart *)A),
+    return !memcmp(((XmCascadeButtonGCacheObjPart *)A),
 		 ((XmCascadeButtonGCacheObjPart *)B),
 		 sizeof(XmCascadeButtonGCacheObjPart));
 }
@@ -412,7 +414,7 @@ _XmArrowPixmapCacheCompare(XtPointer A, XtPointer B)
      * different shadow thicknesses imply different pixmap sizes (at least
      * for the same size font).
      */
-    return !bcmp(A, B, XtOffsetOf(XmArrowPixmap, pixmap));
+    return !memcmp(A, B, XtOffsetOf(XmArrowPixmap, pixmap));
 }
 
 void
@@ -597,10 +599,10 @@ class_initialize(void)
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
 
-    bcopy(labels, combined, nlabels * sizeof(XtResource));
-    bcopy(cache_resources,
-	  &combined[nlabels],
-	  XtNumber(cache_resources) * sizeof(XtResource));
+    memcpy(combined, labels, nlabels * sizeof(XtResource));
+    memcpy(&combined[nlabels],
+           cache_resources,
+ 	   XtNumber(cache_resources) * sizeof(XtResource));
 
     XtFree((char *)labels);
 
@@ -892,12 +894,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+	  LabG_Cache(new_w),
 	  sizeof(XmLabelGCacheObjPart));
-    bcopy(CBG_Cache(new_w),
-	  &((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
-	  sizeof(XmCascadeButtonGCacheObjPart));
+    memcpy(&((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
+           CBG_Cache(new_w),
+	   sizeof(XmCascadeButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
 
@@ -913,7 +915,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
     LabG_Cache(new_w) = &(((XmCascadeButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmCascadeButtonGCacheObject)rsec)->label_cache);
@@ -1148,12 +1150,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(CBG_Cache(new_w),
-	  &((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
-	  sizeof(XmCascadeButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
+           CBG_Cache(new_w),
+	   sizeof(XmCascadeButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
