@@ -1,8 +1,9 @@
 /**
  *
- * $Id: CutPaste.c,v 1.11 2000/07/07 00:50:30 rwscott Exp $
+ * $Id: CutPaste.c,v 1.16 2000/10/23 14:58:08 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,22 +23,24 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CutPaste.c,v 1.11 2000/07/07 00:50:30 rwscott Exp $";
+static const char rcsid[] = "$Id: CutPaste.c,v 1.16 2000/10/23 14:58:08 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
-#include <X11/Xfuncs.h>
+#include <stdio.h>
+#include <string.h>
+
+#include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/CutPaste.h>
 #include <XmI/CutPasteI.h>
 #include <XmI/AtomMgrI.h>
-#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
+
 #define UNLOCKED	0
 #define LOCKED		1
 
@@ -153,12 +156,6 @@ static Window _XmClipboardInitializeSelection(Display *display,
 
 static Boolean _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip);
 
-/* And one external function for the prototype police */
-
-extern int XmClipboardWithdrawFormat(Display *display, Window window,
-				     int data_id);
-
-
 
 /******************************* low level ******************************/
 
@@ -419,6 +416,7 @@ _XmClipboardDeleteFormats(Display *display, Window window, int id)
     XtFree((char *)data);
 }
 
+
 static void
 _XmClipboardDeleteItem(Display *display, Window window,
 		       XmClipboard * clip, unsigned item)
@@ -528,6 +526,7 @@ _XmClipboardDeleteItem(Display *display, Window window,
     _XmClipboardDeleteId(display, item);
 }
 
+
 static void
 _XmClipboardDeleteMarked(Display *display, Window window, XmClipboard * clip)
 {
@@ -546,13 +545,14 @@ _XmClipboardDeleteMarked(Display *display, Window window, XmClipboard * clip)
     }
 }
 
+
 static int
 _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 			      unsigned **data, int *len,
 			      int *type_return, int *format_return,
 			      Boolean delete)
 {
-    int transfersize;
+    long transfersize;
     long offset;
     Atom actual_type;
     int actual_format;
@@ -560,6 +560,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
     unsigned long bytes_after = 1;
     unsigned char *prop;
     unsigned *ret_buf;
+    Bool req_delete=False;
 
     transfersize = XMaxRequestSize(display);
     *data = NULL;
@@ -572,7 +573,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 
     while (bytes_after)
     {
-	if (XGetWindowProperty(display, win, item, offset, transfersize, False,
+	if (XGetWindowProperty(display, win, item, offset, transfersize, req_delete,
 			       AnyPropertyType, &actual_type, &actual_format,
 			       &nitems, &bytes_after, &prop) != Success)
 	{
@@ -618,7 +619,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 
 	ret_buf = (unsigned *)XtRealloc((char *)ret_buf,
 					alloc_size + alloc_incr + 1);
-	bcopy(prop, &ret_buf[offset], alloc_incr);
+	memcpy(&ret_buf[offset], prop, alloc_incr);
 	alloc_size += alloc_incr;
 
 	switch (actual_format)
@@ -666,6 +667,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
     return XmClipboardSuccess;
 }
 
+
 static Boolean
 _XmClipboardSearchForWindow(Display *display, Window root, Window window)
 {
@@ -707,6 +709,7 @@ _XmClipboardSearchForWindow(Display *display, Window root, Window window)
     return found;
 }
 
+
 static Time
 _XmClipboardGetCurrentTime(Display *display)
 {
@@ -728,6 +731,7 @@ _XmClipboardGetCurrentTime(Display *display)
     return event.xproperty.time;
 }
 
+
 static Bool
 _XmClipboardDataIsReady(Display *display, XEvent *event, XPointer arg)
 {
@@ -758,6 +762,7 @@ _XmClipboardDataIsReady(Display *display, XEvent *event, XPointer arg)
     return False;
 }
 
+
 static Boolean
 _XmClipboardRequestDataAndWait(Display *display, Window win,
 			       XmClipboardFormat * format)
@@ -807,6 +812,7 @@ _XmClipboardRequestDataAndWait(Display *display, Window win,
     return True;
 }
 
+
 static Boolean
 _XmClipboardWindowExists(Display *display, Window window)
 {
@@ -849,6 +855,7 @@ _XmClipboardWindowExists(Display *display, Window window)
     return found;
 }
 
+
 static int
 _XmClipboardFindItem(Display *display, int id, unsigned **data, int *len,
 		     int *format_return, unsigned prop_id)
@@ -889,6 +896,7 @@ _XmClipboardFindItem(Display *display, int id, unsigned **data, int *len,
     return XmClipboardFail;
 }
 
+
 static XmClipboardFormat *
 _XmClipboardFindFormat(Display *display, XmClipboard * clip,
 		       char *format_name, long item_id, int index,
@@ -1042,6 +1050,7 @@ _XmClipboardFindFormat(Display *display, XmClipboard * clip,
     return format;
 }
 
+
 static void
 _XmClipboardReplaceItem(Display *display, int id, unsigned *data, int len,
 			int mode, int format, Boolean free)
@@ -1102,6 +1111,7 @@ _XmClipboardReplaceItem(Display *display, int id, unsigned *data, int len,
     }
 }
 
+
 static int
 _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
 			 unsigned **data, int *len, int *format_return,
@@ -1131,7 +1141,7 @@ _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
 
     if (status == XmClipboardSuccess)
     {
-	bcopy(ldata, buf, *len);
+	memcpy(buf, ldata, *len);
     }
 
     *data = buf;
@@ -1145,6 +1155,7 @@ _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
     return status;
 }
 
+
 static unsigned
 _XmClipboardGetNewItemId(Display *display)
 {
@@ -1162,6 +1173,7 @@ _XmClipboardGetNewItemId(Display *display)
     return ret;
 }
 
+
 static Atom
 _XmClipboardGetAtomFromFormat(Display *display, char *format_name)
 {
@@ -1179,6 +1191,7 @@ _XmClipboardGetAtomFromFormat(Display *display, char *format_name)
     return atom;
 }
 
+
 static Boolean
 _XmClipboardGetLenFromFormat(Display *display, char *format_name, int *format)
 {
@@ -1215,6 +1228,7 @@ _XmClipboardGetLenFromFormat(Display *display, char *format_name, int *format)
     return ret;
 }
 
+
 static Window
 _XmClipboardInitializeSelection(Display *display, XmClipboard * clip,
 				Window window, Time locktime)
@@ -1243,6 +1257,7 @@ _XmClipboardInitializeSelection(Display *display, XmClipboard * clip,
     return clipowner;
 }
 
+
 static Boolean
 _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip)
 {
@@ -1261,6 +1276,7 @@ _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip)
     return False;
 }
 
+
 static void
 _XmAssertClipboardSelection(Display *display, Window window,
 			    XmClipboard * clip, Time locktime)
@@ -1290,6 +1306,7 @@ _XmAssertClipboardSelection(Display *display, Window window,
     XtAddEventHandler(w, None, True, _XmClipboardEventHandler, NULL);
 }
 
+
 static Bool
 _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
 {
@@ -1353,13 +1370,13 @@ _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
 
     buf = (unsigned *)XtMalloc(len + match->len);
 
-    bcopy(match->data, buf, match->len);
+    memcpy(buf, match->data, match->len);
 
     XtFree((char *)match->data);
 
     match->data = buf;
 
-    bcopy(data, (char *)buf + match->len, len);
+    memcpy((char *)buf + match->len, data, len);
 
     XtFree((char *)data);
 
@@ -1373,6 +1390,7 @@ _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
     return True;
 }
 
+
 static Boolean
 _XmClipboardGetSelection(Display *display, Window window, char *format_name,
 			 XmClipboard * clip, unsigned **data, int *len)
@@ -1456,6 +1474,7 @@ _XmClipboardGetSelection(Display *display, Window window, char *format_name,
     return False;
 }
 
+
 static void
 _XmClipboardSetNextItemId(Display *display, int item_id)
 {
@@ -1505,6 +1524,7 @@ _XmClipboardSetNextItemId(Display *display, int item_id)
 			    PropModeReplace, 32, True);
 }
 
+
 static void
 _XmClipboardMarkItem(Display *display, XmClipboard * clip,
 		     unsigned id, Boolean delete_on)
@@ -1538,6 +1558,7 @@ _XmClipboardMarkItem(Display *display, XmClipboard * clip,
 
 }
 
+
 static void
 _XmClipboardSetAccess(Display *display, Window window)
 {
@@ -1551,6 +1572,7 @@ _XmClipboardSetAccess(Display *display, Window window)
 		    PropModeReplace, (unsigned char *)"yes", 3);
 }
 
+
 static XmClipboard *
 _XmClipboardOpen(Display *display, int extra_size)
 {
@@ -1612,6 +1634,7 @@ _XmClipboardOpen(Display *display, int extra_size)
     return clip;
 }
 
+
 static void
 _XmClipboardClose(Display *display, XmClipboard * clip)
 {
@@ -1621,6 +1644,7 @@ _XmClipboardClose(Display *display, XmClipboard * clip)
 			    PropModeReplace, 32, True);
 }
 
+
 static int
 _XmClipboardLock(Display *display, Window window)
 {
@@ -1730,6 +1754,7 @@ _XmClipboardLock(Display *display, Window window)
     return XmClipboardSuccess;
 }
 
+
 static int
 _XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
 {
@@ -1795,6 +1820,7 @@ _XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
     return XmClipboardSuccess;
 }
 
+
 static void
 _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 			 XEvent *ev, Boolean *dontSwallow)
@@ -1885,6 +1911,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 			    PropModeReplace, 32, True);
 }
 
+
 static Boolean
 _XmClipboardSendMessage(Display *display, Window window,
 			XmClipboardFormat * format, int id)
@@ -1951,7 +1978,7 @@ _XmClipboardSendMessage(Display *display, Window window,
 
 /*************************** public functions **************************/
 
-int
+extern int
 XmClipboardBeginCopy(Display *display,
 		     Window window,
 		     XmString clip_label,
@@ -1963,7 +1990,8 @@ XmClipboardBeginCopy(Display *display,
 				widget, callback, item_id);
 }
 
-int
+
+extern int
 XmClipboardCancelCopy(Display *display,
 		      Window window,
 		      long item_id)
@@ -2005,7 +2033,8 @@ XmClipboardCancelCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardCopy(Display *display,
 		Window window,
 		long item_id,
@@ -2141,7 +2170,7 @@ XmClipboardCopy(Display *display,
 
     if (buffer)
     {
-	bcopy(buffer, nbuf, length);
+	memcpy(nbuf, buffer, length);
     }
 
     format->length += length;
@@ -2164,7 +2193,8 @@ XmClipboardCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardCopyByName(Display *display,
 		      Window window,
 		      long data_id,
@@ -2230,7 +2260,7 @@ XmClipboardCopyByName(Display *display,
 
 	bufstart = (unsigned char *)idata + ilen - length;
 
-	bcopy(buffer, bufstart, length);
+	memcpy(bufstart, buffer, length);
 
 	_XmClipboardReplaceItem(display, format->data_id, idata, ilen,
 				PropModeReplace, fmt, True);
@@ -2249,7 +2279,8 @@ XmClipboardCopyByName(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardEndCopy(Display *display,
 		   Window window,
 		   long item_id)
@@ -2331,7 +2362,8 @@ XmClipboardEndCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardEndRetrieve(Display *display,
 		       Window window)
 {
@@ -2349,7 +2381,7 @@ XmClipboardEndRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+extern int
 XmClipboardInquireCount(Display *display,
 			Window window,
 			int *count,
@@ -2424,7 +2456,8 @@ XmClipboardInquireCount(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardInquireFormat(Display *display,
 			 Window window,
 			 int index,
@@ -2504,7 +2537,8 @@ XmClipboardInquireFormat(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardInquireLength(Display *display,
 			 Window window,
 			 char *format_name,
@@ -2570,7 +2604,8 @@ XmClipboardInquireLength(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardInquirePendingItems(Display *display,
 			       Window window,
 			       char *format_name,
@@ -2651,14 +2686,16 @@ XmClipboardInquirePendingItems(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardLock(Display *display,
 		Window window)
 {
     return _XmClipboardLock(display, window);
 }
 
-int
+
+extern int
 XmClipboardRegisterFormat(Display *display,
 			  char *format_name,
 			  int format_length)
@@ -2719,7 +2756,8 @@ XmClipboardRegisterFormat(Display *display,
     return XmClipboardFail;
 }
 
-int
+
+extern int
 XmClipboardRetrieve(Display *display,
 		    Window window,
 		    char *format_name,
@@ -2733,7 +2771,7 @@ XmClipboardRetrieve(Display *display,
     int fetchlen = 0;
     XmClipboardFormat *format;
     Boolean got_format = False;
-    unsigned *data;
+    unsigned *data=NULL;
     unsigned char *bufstart = NULL;
     Boolean partial_copy = False, got_data = False;
 
@@ -2848,40 +2886,43 @@ XmClipboardRetrieve(Display *display,
 	DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(display, window),
 	    "XmClipboardRetrieve: we don't own selection !!\n"));
 
-	_XmClipboardGetSelection(display, window, format_name, clip,
-				 &data, &dlen);
+/* amai-20001018: at least when clipboard is messed up from remaining LT bugs
+   I got data==NULL here ...
+*/
+	if (got_data = _XmClipboardGetSelection(display, window,
+	                                        format_name, clip,
+  				  		&data, &dlen)) {
 
-	bufstart = (unsigned char *)data + clip->offset;
+		bufstart = (unsigned char *)data + clip->offset;
+		if (dlen - clip->offset > length)
+		{
+		    partial_copy = True;
+		    fetchlen = length;
+		}
+		else
+		{
+		    fetchlen = dlen - clip->offset;
+		}
+	
+		if (clip->retrieve_locked)
+		{
+	
+		    if (partial_copy)
+		    {
+			clip->offset += fetchlen;
+		    }
+		    else
+		    {
+			clip->offset = 0;
+		    }
+		}
+	} /* got_data */
 
-	if (dlen - clip->offset > length)
-	{
-	    partial_copy = True;
-	    fetchlen = length;
-	}
-	else
-	{
-	    fetchlen = dlen - clip->offset;
-	}
-
-	if (clip->retrieve_locked)
-	{
-
-	    if (partial_copy)
-	    {
-		clip->offset += fetchlen;
-	    }
-	    else
-	    {
-		clip->offset = 0;
-	    }
-	}
-
-	got_data = True;
     }
 
     if (got_data)
     {
-	bcopy(bufstart, buffer, fetchlen);
+	memcpy(buffer, bufstart, fetchlen);
 
 	XtFree((char *)data);
     }
@@ -2913,7 +2954,8 @@ XmClipboardRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardStartCopy(Display *display,
 		     Window window,
 		     XmString clip_label,
@@ -2991,6 +3033,7 @@ XmClipboardStartCopy(Display *display,
     return XmClipboardSuccess;
 }
 
+
 int
 XmClipboardStartRetrieve(Display *display,
 			 Window window,
@@ -3014,6 +3057,7 @@ XmClipboardStartRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
+
 int
 XmClipboardUndoCopy(Display *display, Window window)
 {
@@ -3072,13 +3116,15 @@ XmClipboardUndoCopy(Display *display, Window window)
     return XmClipboardSuccess;
 }
 
-int
+
+extern int
 XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
 {
     return _XmClipboardUnlock(display, window, remove_all_locks);
 }
 
-int
+
+extern int
 XmClipboardWithdrawFormat(Display *display,
 			  Window window,
 			  int data_id)
