@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Exp $
+ * $Id: DebugUtil.c,v 1.53 2000/11/24 10:20:06 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,25 +23,31 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Exp $";
+static const char rcsid[] = "$Id: DebugUtil.c,v 1.53 2000/11/24 10:20:06 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#include <XmI/XmI.h>
+#include <unistd.h>
 
-#include <XmI/DebugUtil.h>
-#include <X11/Xos.h>
-#include <Xm/GadgetP.h>
 #include <X11/Intrinsic.h>
 #include <X11/IntrinsicP.h>
 #include <X11/Xresource.h>
-#include <Xm/VendorSEP.h>
+#ifdef	USE_DMALLOC
+#include <dmalloc.h>
+#else
+#include <X11/Xlibint.h>
+#endif
+
+#include <XmI/XmI.h>
+#include <Xm/XmP.h>
 #include <Xm/DrawingAP.h>
 #include <Xm/Display.h>
 
+#include <XmI/DebugUtil.h>
+
 /*
  * Functionality in this file is influenced at run time by these
  * environment variables :
@@ -50,7 +57,7 @@ static const char rcsid[] = "$Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Ex
  *      with XdbDebug etc. will also print their widget ID. If the variable
  *      doesn't exist, then they only print their name for identification.
  * - DEBUG_FILE : if this variable exists, then the file is used for output.
- *      If %p is part of the value of DEBUG_FILE, then it is replaced by the
+ *      If "%p" is part of the value of DEBUG_FILE, then it is replaced by the
  *      process id.
  *
  * If the C macro LESSTIF_PRODUCTION is defined, then XdbDebug etc. don't
@@ -64,6 +71,7 @@ static const char rcsid[] = "$Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Ex
 
 static FILE *XdbFile = NULL;
 
+
 static void 
 XdbOpenFile(void)
 {
@@ -75,39 +83,43 @@ XdbOpenFile(void)
     }
 
     s = getenv("DEBUG_FILE");
-    if (s == 0)
+    if (s == NULL)
     {
 	XdbFile = stderr;
 	return;
     }
-
-    p = strstr(s, "%p");
-
     fn = XtMalloc(strlen(s) + 10);
+
+#ifdef HAVE_GETPID
+    p = strstr(s, "%p");
     if (p)
     {
 	*(p + 1) = 'd';
 	sprintf(fn, s, getpid());
     }
     else
+#endif
     {
 	strcpy(fn, s);
     }
 
     /* a means append, create if doesn't exist */
     XdbFile = fopen(fn, "a");
-    if (XdbFile == 0)
+    if (XdbFile == NULL)
     {
 	XdbFile = stderr;
     }
     else
     {
+        /* disable buffering */
 	setbuf(XdbFile, NULL);
     }
+    XtFree(fn);
 }
 
+
 #ifdef	PRINT_STATE
-static char *
+static const char *
 _XdbState(Widget w)
 {
     if (XtIsRealized(w))
@@ -135,7 +147,7 @@ _XdbState(Widget w)
 }
 #endif
 
-#if	0
+
 static void 
 _XdbPrintTree(Widget w, int level)
 {
@@ -177,13 +189,15 @@ _XdbPrintTree(Widget w, int level)
     }
 }
 
-void 
+
+extern void 
 XdbPrintTree(Widget w)
 {
     _XdbPrintTree(w, 0);
 }
 
-void 
+
+extern void 
 XdbPrintCompleteTree(Widget w)
 {
     Widget ww = w;
@@ -196,10 +210,10 @@ XdbPrintCompleteTree(Widget w)
 
     _XdbPrintTree(w, 0);
 }
-#endif
+
 
 #if XmVERSION > 1
-char *
+extern const char *
 XdbComboBoxType2String(unsigned char type)
 {
     switch(type)
@@ -216,7 +230,8 @@ XdbComboBoxType2String(unsigned char type)
 }
 #endif
 
-char *
+
+extern const char *
 XdbGeoAction2String(int action)
 {
 	switch(action)
@@ -234,7 +249,8 @@ XdbGeoAction2String(int action)
 	}
 }
 
-char *
+
+extern const char *
 XdbGeometryResult2String(XtGeometryResult r)
 {
     switch (r)
@@ -256,7 +272,8 @@ XdbGeometryResult2String(XtGeometryResult r)
     }
 }
 
-char *
+
+extern const char *
 XdbDragAndDropMessageType2String(unsigned char r)
 {
     switch (r)
@@ -293,7 +310,8 @@ XdbDragAndDropMessageType2String(unsigned char r)
     }
 }
 
-char *
+
+extern const char *
 XdbDragType2String(unsigned char r)
 {
     switch (r)
@@ -324,7 +342,8 @@ XdbDragType2String(unsigned char r)
     }
 }
 
-static char *
+
+static const char *
 XdbScrollingPolicy2String(unsigned char r)
 {
     switch (r)
@@ -340,7 +359,8 @@ XdbScrollingPolicy2String(unsigned char r)
     }
 }
 
-static char *
+
+static const char *
 XdbDialogStyle2String(int a)
 {
     switch (a)
@@ -372,7 +392,8 @@ XdbDialogStyle2String(int a)
     }
 }
 
-char *
+
+extern const char *
 XdbAttachment2String(int a)
 {
     switch (a)
@@ -403,6 +424,7 @@ XdbAttachment2String(int a)
     }
 }
 
+
 /*
  * See if 'fn' is one of the elements in 'l'.
  * L is a colon-separated list of source files.
@@ -412,10 +434,10 @@ XdbAttachment2String(int a)
  * As of post-0.50, the "fn" can contain a directory prefix.
  */
 static Boolean
-ValidateSource(char *fn, char *l)
+ValidateSource(const char *fn, const char *l)
 {
-#ifndef	LESSTIF_PRODUCTION
-    char *s, *p, *q;
+#ifndef LESSTIF_PRODUCTION
+    const char *s, *p, *q;
     int i;
 
     if (l == NULL)
@@ -450,32 +472,31 @@ ValidateSource(char *fn, char *l)
 
 	s = q;
     }
-#endif
+#endif /* #ifndef LESSTIF_PRODUCTION */
     return False;
 }
 
+
 /*
  * This is the new style debugging support routine for LessTif.
  *
  * It allows us to choose at run time which sources should spit out
  * their guts.
  */
-static char *
-_XdbFindDebugSources(Widget w)
+static const char *
+_XdbFindDebugSources(void)
 {
     static char *env = NULL;
     static int checked=False;
 
     if (!checked) {
-      checked=True;
-      if (env == NULL) 	
-      {
-	env = getenv("DEBUGSOURCES");
-      }
+       env = getenv("DEBUGSOURCES");
+       checked=True;
     }
     return env;
 }
 
+
 static char *
 _XdbPrintWidgetID(void)
 {
@@ -483,21 +504,19 @@ _XdbPrintWidgetID(void)
     static int checked=False;
 
     if (!checked) {
-      checked=True;
-      if (env == NULL)  
-      {
-	env = getenv("DEBUG_PRINT_WIDGETID");
-      }
+       env = getenv("DEBUG_PRINT_WIDGETID");
+       checked=True;
     }
     return env;
 }
 
-void 
-XdbDebug(char *fn, Widget w, char *fmt,...)
+
+extern void 
+XdbDebug(const char *fn, Widget w, const char *fmt, ...)
 {
 #ifndef LESSTIF_PRODUCTION
     va_list ap;
-    char *dbs = _XdbFindDebugSources(w);
+    const char *dbs = _XdbFindDebugSources();
 
     if (ValidateSource(fn, dbs))
     {
@@ -531,12 +550,13 @@ XdbDebug(char *fn, Widget w, char *fmt,...)
 #endif
 }
 
-void 
-XdbDebug2(char *fn, Widget w, Widget c, char *fmt,...)
+
+extern void 
+XdbDebug2(const char *fn, Widget w, Widget c, const char *fmt, ...)
 {
 #ifndef LESSTIF_PRODUCTION
     va_list ap;
-    char *dbs = _XdbFindDebugSources(w);
+    const char *dbs = _XdbFindDebugSources();
 
     if (ValidateSource(fn, dbs))
     {
@@ -584,12 +604,13 @@ XdbDebug2(char *fn, Widget w, Widget c, char *fmt,...)
 #endif
 }
 
-void 
-XdbDebug0(char *fn, Widget w, char *fmt,...)
+
+extern void 
+XdbDebug0(const char *fn, Widget w, const char *fmt, ...)
 {
 #ifndef LESSTIF_PRODUCTION
     va_list ap;
-    char *dbs = _XdbFindDebugSources(w);
+    const char *dbs = _XdbFindDebugSources();
 
     if (ValidateSource(fn, dbs))
     {
@@ -606,17 +627,19 @@ XdbDebug0(char *fn, Widget w, char *fmt,...)
 #undef	XdbInDebug
 #endif
 
-Boolean 
-XdbInDebug(char *fn, Widget w)
+
+extern Boolean 
+XdbInDebug(const char *fn, Widget w)
 {
 #ifdef	LESSTIF_PRODUCTION
     return False;
 #else
-    return ValidateSource(fn, _XdbFindDebugSources(w));
+    return ValidateSource(fn, _XdbFindDebugSources());
 #endif
 }
 
-char *
+
+extern const char *
 XdbMenuFocusOp2String(int f)
 {
     switch (f)
@@ -632,7 +655,8 @@ XdbMenuFocusOp2String(int f)
     }
 }
 
-char *
+
+extern const char *
 XdbMenuEnum2String(int f)
 {
     switch (f)
@@ -699,7 +723,8 @@ XdbMenuEnum2String(int f)
     }
 }
 
-char *
+
+extern const char *
 XdbBoolean2String(int b)
 {
     if (b)
@@ -710,7 +735,8 @@ XdbBoolean2String(int b)
     return "False";
 }
 
-char *
+
+extern const char *
 XdbXmString2String(XmString xms)
 {
   static char *s = NULL;
@@ -731,7 +757,8 @@ XdbXmString2String(XmString xms)
     return s;
 }
 
-char *
+
+extern const char *
 XdbPacking2String(unsigned char p)
 {
     static char res[40];
@@ -753,7 +780,8 @@ XdbPacking2String(unsigned char p)
     }
 }
 
-char *
+
+extern const char *
 XdbRcType2String(unsigned char t)
 {
     static char res[40];
@@ -781,7 +809,8 @@ XdbRcType2String(unsigned char t)
     }
 }
 
-char *
+
+extern const char *
 XdbWidgetGeometry2String(XtWidgetGeometry *g)
 {
     static char o1[128], o2[128], b[20], *out = NULL;
@@ -868,13 +897,12 @@ XdbWidgetGeometry2String(XtWidgetGeometry *g)
 #define XdbSCROLLING_POLICY	19
 #define XdbDRAG_TYPE		20
 
-static struct
+static const struct
 {
-    char *name;
+    const char *name;
     int t;
     char *related;
-}
-XdbTypes[] =
+} XdbTypes[] =
 {
     {
 	XmNdragInitiatorProtocolStyle, XdbDRAG_TYPE, NULL
@@ -1271,12 +1299,13 @@ XdbTypes[] =
     }				/* the end */
 };
 
-void
-XdbPrintArgList(char *fn, Widget w, ArgList al, int n, Boolean Get)
+
+extern void
+XdbPrintArgList(const char *fn, Widget w, ArgList al, int n, Boolean Get)
 {
 #ifndef	LESSTIF_PRODUCTION
     int i, j, num;
-    char *dbs = _XdbFindDebugSources(w), *p;
+    const char *dbs = _XdbFindDebugSources(), *p;
 
     if (ValidateSource(fn, dbs))
     {
@@ -1444,7 +1473,8 @@ XdbPrintArgList(char *fn, Widget w, ArgList al, int n, Boolean Get)
 #endif
 }
 
-char *
+
+extern const char *
 XdbEditMode2String(int n)
 {
     switch (n)
@@ -1460,7 +1490,8 @@ XdbEditMode2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbSelectionPolicy2String(int n)
 {
     switch (n)
@@ -1482,7 +1513,8 @@ XdbSelectionPolicy2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbResizePolicy2String(int n)
 {
     switch (n)
@@ -1504,7 +1536,8 @@ XdbResizePolicy2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbSBDisplayPolicy2String(int n)
 {
     switch (n)
@@ -1520,7 +1553,8 @@ XdbSBDisplayPolicy2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbSBPlacement2String(int n)
 {
     switch (n)
@@ -1542,7 +1576,8 @@ XdbSBPlacement2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbListSizePolicy2String(int n)
 {
     switch (n)
@@ -1561,7 +1596,8 @@ XdbListSizePolicy2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbAlignment2String(int n)
 {
     switch (n)
@@ -1580,7 +1616,8 @@ XdbAlignment2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbMenuType2String(int n)
 {
     switch (n)
@@ -1599,7 +1636,8 @@ XdbMenuType2String(int n)
     }
 }
 
-char *
+
+extern const char *
 XdbNavigability2String(unsigned char n)
 {
     switch (n)
@@ -1629,10 +1667,7 @@ XdbNavigability2String(unsigned char n)
  * Mimick Xt behaviour ...
  */
 
-#ifdef	USE_DMALLOC
-#include <dmalloc.h>
-#else
-#include <X11/Xlibint.h>
+#ifndef	USE_DMALLOC
 #define	_malloc_leap(a,b,c)	Xmalloc(c)
 #define	_calloc_leap(a,b,c,d)	Xcalloc(c,d)
 #define	_realloc_leap(a,b,c,d)	Xrealloc(c,d)
@@ -1641,7 +1676,8 @@ XdbNavigability2String(unsigned char n)
 
 extern void _XtAllocError(char *);
 
-XtPointer
+
+extern XtPointer
 XdbMalloc(char *f, int l, int size)
 {
     XtPointer r;
@@ -1661,7 +1697,8 @@ XdbMalloc(char *f, int l, int size)
     return r;
 }
 
-XtPointer
+
+extern XtPointer
 XdbCalloc(char *f, int l, int count, int size)
 {
     XtPointer p;
@@ -1681,7 +1718,8 @@ XdbCalloc(char *f, int l, int count, int size)
     return p;
 }
 
-XtPointer
+
+extern XtPointer
 XdbRealloc(char *f, int l, XtPointer p, int size)
 {
     XtPointer r;
@@ -1705,7 +1743,8 @@ XdbRealloc(char *f, int l, XtPointer p, int size)
     return r;
 }
 
-void
+
+extern void
 XdbFree(char *f, int l, XtPointer p)
 {
     if (p)
@@ -1714,7 +1753,8 @@ XdbFree(char *f, int l, XtPointer p)
     }
 }
 
-char *
+
+extern const char *
 XdbHighlightMode2String(int mode)
 {
     switch (mode)
@@ -1736,70 +1776,107 @@ XdbHighlightMode2String(int mode)
 /*
  * Allow unconditional printing to the XdbFile
  */
-void
-XdbPrintString(char *s)
+extern void
+XdbPrintString(const char *s)
 {
     XdbOpenFile();
     fprintf(XdbFile, "%s", s);
 }
 
-char *
+
+extern const char *
 XdbReason2String(int reason)
 {
 	switch (reason) {
-	case XmCR_NONE:		return "XmCR_NONE";
-	case XmCR_HELP:		return "XmCR_HELP";
-	case XmCR_VALUE_CHANGED:return "XmCR_VALUE_CHANGED";
-	case XmCR_INCREMENT:	return "XmCR_INCREMENT";
-	case XmCR_DECREMENT:	return "XmCR_DECREMENT";
-	case XmCR_PAGE_INCREMENT:return "XmCR_PAGE_INCREMENT";
-	case XmCR_PAGE_DECREMENT:return "XmCR_PAGE_DECREMENT";
-	case XmCR_TO_TOP:	return "XmCR_TO_TOP";
-	case XmCR_TO_BOTTOM:	return "XmCR_TO_BOTTOM";
-	case XmCR_DRAG:		return "XmCR_DRAG";
-	case XmCR_ACTIVATE:	return "XmCR_ACTIVATE";
-	case XmCR_ARM:		return "XmCR_ARM";
-	case XmCR_DISARM:	return "XmCR_DISARM";
-	case XmCR_DUMMY13:	return "XmCR_DUMMY13";
-	case XmCR_DUMMY14:	return "XmCR_DUMMY14";
-	case XmCR_DUMMY15:	return "XmCR_DUMMY15";
-	case XmCR_MAP:		return "XmCR_MAP";
-	case XmCR_UNMAP:	return "XmCR_UNMAP";
-	case XmCR_FOCUS:	return "XmCR_FOCUS";
-	case XmCR_LOSING_FOCUS:	return "XmCR_LOSING_FOCUS";
-	case XmCR_MODIFYING_TEXT_VALUE:return "XmCR_MODIFYING_TEXT_VALUE";
-	case XmCR_MOVING_INSERT_CURSOR:return "XmCR_MOVING_INSERT_CURSOR";
-	case XmCR_EXECUTE:	return "XmCR_EXECUTE";
-	case XmCR_SINGLE_SELECT:return "XmCR_SINGLE_SELECT";
-	case XmCR_MULTIPLE_SELECT:return "XmCR_MULTIPLE_SELECT";
-	case XmCR_EXTENDED_SELECT:return "XmCR_EXTENDED_SELECT";
-	case XmCR_BROWSE_SELECT:return "XmCR_BROWSE_SELECT";
-	case XmCR_DEFAULT_ACTION:return "XmCR_DEFAULT_ACTION";
-	case XmCR_CLIPBOARD_DATA_REQUEST:return "XmCR_CLIPBOARD_DATA_REQUEST";
-	case XmCR_CLIPBOARD_DATA_DELETE:return "XmCR_CLIPBOARD_DATA_DELETE";
-	case XmCR_CASCADING:	return "XmCR_CASCADING";
-	case XmCR_OK:		return "XmCR_OK";
-	case XmCR_CANCEL:	return "XmCR_CANCEL";
-	case XmCR_DUMMY33:	return "XmCR_DUMMY33";
-	case XmCR_APPLY:	return "XmCR_APPLY";
-	case XmCR_NO_MATCH:	return "XmCR_NO_MATCH";
-	case XmCR_COMMAND_ENTERED:return "XmCR_COMMAND_ENTERED";
-	case XmCR_COMMAND_CHANGED:return "XmCR_COMMAND_CHANGED";
-	case XmCR_EXPOSE:	return "XmCR_EXPOSE";
-	case XmCR_RESIZE:	return "XmCR_RESIZE";
-	case XmCR_INPUT:	return "XmCR_INPUT";
-	case XmCR_GAIN_PRIMARY:	return "XmCR_GAIN_PRIMARY";
-	case XmCR_LOSE_PRIMARY:	return "XmCR_LOSE_PRIMARY";
-	case XmCR_CREATE:	return "XmCR_CREATE";
-	case XmCR_TEAR_OFF_ACTIVATE:return "XmCR_TEAR_OFF_ACTIVATE";
-	case XmCR_TEAR_OFF_DEACTIVATE:return "XmCR_TEAR_OFF_DEACTIVATE";
-	case XmCR_OBSCURED_TRAVERSAL:return "XmCR_OBSCURED_TRAVERSAL";
-	case XmCR_PROTOCOLS:	return "XmCR_PROTOCOLS";
-	default:		return "???";
+	case XmCR_NONE:	                   return "XmCR_NONE";
+	case XmCR_HELP:	                   return "XmCR_HELP";
+	case XmCR_VALUE_CHANGED:           return "XmCR_VALUE_CHANGED";
+	case XmCR_INCREMENT:               return "XmCR_INCREMENT";
+	case XmCR_DECREMENT:               return "XmCR_DECREMENT";
+	case XmCR_PAGE_INCREMENT:          return "XmCR_PAGE_INCREMENT";
+	case XmCR_PAGE_DECREMENT:          return "XmCR_PAGE_DECREMENT";
+	case XmCR_TO_TOP:                  return "XmCR_TO_TOP";
+	case XmCR_TO_BOTTOM:               return "XmCR_TO_BOTTOM";
+	case XmCR_DRAG:                    return "XmCR_DRAG";
+	case XmCR_ACTIVATE:                return "XmCR_ACTIVATE";
+	case XmCR_ARM:                     return "XmCR_ARM";
+	case XmCR_DISARM:                  return "XmCR_DISARM";
+	case XmCR_DUMMY13:                 return "XmCR_DUMMY13";
+	case XmCR_DUMMY14:                 return "XmCR_DUMMY14";
+	case XmCR_DUMMY15:                 return "XmCR_DUMMY15";
+	case XmCR_MAP:                     return "XmCR_MAP";
+	case XmCR_UNMAP:                   return "XmCR_UNMAP";
+	case XmCR_FOCUS:                   return "XmCR_FOCUS";
+	case XmCR_LOSING_FOCUS:            return "XmCR_LOSING_FOCUS";
+	case XmCR_MODIFYING_TEXT_VALUE:    return "XmCR_MODIFYING_TEXT_VALUE";
+	case XmCR_MOVING_INSERT_CURSOR:    return "XmCR_MOVING_INSERT_CURSOR";
+	case XmCR_EXECUTE:                 return "XmCR_EXECUTE";
+	case XmCR_SINGLE_SELECT:           return "XmCR_SINGLE_SELECT";
+	case XmCR_MULTIPLE_SELECT:         return "XmCR_MULTIPLE_SELECT";
+	case XmCR_EXTENDED_SELECT:         return "XmCR_EXTENDED_SELECT";
+	case XmCR_BROWSE_SELECT:           return "XmCR_BROWSE_SELECT";
+	case XmCR_DEFAULT_ACTION:          return "XmCR_DEFAULT_ACTION";
+	case XmCR_CLIPBOARD_DATA_REQUEST:  return "XmCR_CLIPBOARD_DATA_REQUEST";
+	case XmCR_CLIPBOARD_DATA_DELETE:   return "XmCR_CLIPBOARD_DATA_DELETE";
+	case XmCR_CASCADING:               return "XmCR_CASCADING";
+	case XmCR_OK:                      return "XmCR_OK";
+	case XmCR_CANCEL:                  return "XmCR_CANCEL";
+	case XmCR_DUMMY33:                 return "XmCR_DUMMY33";
+	case XmCR_APPLY:                   return "XmCR_APPLY";
+	case XmCR_NO_MATCH:                return "XmCR_NO_MATCH";
+	case XmCR_COMMAND_ENTERED:         return "XmCR_COMMAND_ENTERED";
+	case XmCR_COMMAND_CHANGED:         return "XmCR_COMMAND_CHANGED";
+	case XmCR_EXPOSE:                  return "XmCR_EXPOSE";
+	case XmCR_RESIZE:                  return "XmCR_RESIZE";
+	case XmCR_INPUT:                   return "XmCR_INPUT";
+	case XmCR_GAIN_PRIMARY:            return "XmCR_GAIN_PRIMARY";
+	case XmCR_LOSE_PRIMARY:            return "XmCR_LOSE_PRIMARY";
+	case XmCR_CREATE:                  return "XmCR_CREATE";
+	case XmCR_TEAR_OFF_ACTIVATE:       return "XmCR_TEAR_OFF_ACTIVATE";
+	case XmCR_TEAR_OFF_DEACTIVATE:     return "XmCR_TEAR_OFF_DEACTIVATE";
+	case XmCR_OBSCURED_TRAVERSAL:      return "XmCR_OBSCURED_TRAVERSAL";
+#if XmVERSION >= 2
+	case XmCR_FOCUS_MOVED:             return "XmCR_FOCUS_MOVED";
+	case XmCR_DUMMY48:                 return "XmCR_DUMMY48";
+	case XmCR_DUMMY49:                 return "XmCR_DUMMY49";
+	case XmCR_DUMMY50:                 return "XmCR_DUMMY50";
+	case XmCR_DUMMY51:                 return "XmCR_DUMMY51";
+	case XmCR_DUMMY52:                 return "XmCR_DUMMY52";
+	case XmCR_DUMMY53:                 return "XmCR_DUMMY53";
+	case XmCR_REPOST:                  return "XmCR_REPOST";
+	case XmCR_COLLAPSED:               return "XmCR_COLLAPSED";
+	case XmCR_EXPANDED:                return "XmCR_EXPANDED";
+	case XmCR_SELECT:                  return "XmCR_SELECT";
+	case XmCR_DRAG_START:              return "XmCR_DRAG_START";
+	case XmCR_NO_FONT:                 return "XmCR_NO_FONT";
+	case XmCR_NO_RENDITION:            return "XmCR_NO_RENDITION";
+	case XmCR_POST:                    return "XmCR_POST";
+	case XmCR_SPIN_NEXT:               return "XmCR_SPIN_NEXT";
+	case XmCR_SPIN_PRIOR:              return "XmCR_SPIN_PRIOR";
+	case XmCR_SPIN_FIRST:              return "XmCR_SPIN_FIRST";
+	case XmCR_SPIN_LAST:               return "XmCR_SPIN_LAST";
+	case XmCR_PAGE_SCROLLER_INCREMENT: return "XmCR_PAGE_SCROLLER_INCREMENT";
+	case XmCR_PAGE_SCROLLER_DECREMENT: return "XmCR_PAGE_SCROLLER_DECREMENT";
+	case XmCR_MAJOR_TAB:               return "XmCR_MAJOR_TAB";
+	case XmCR_MINOR_TAB:               return "XmCR_MINOR_TAB";
+#endif /* XmVERSION >= 2 */
+#if XmVersion >=2001
+	case XmCR_PDM_NONE:                return "XmCR_PDM_NONE";
+	case XmCR_PDM_START_VXAUTH:        return "XmCR_PDM_START_VXAUTH";
+	case XmCR_PDM_START_PXAUTH:        return "XmCR_PDM_START_PXAUTH";
+	case XmCR_PDM_UP:                  return "XmCR_PDM_UP";
+	case XmCR_PDM_OK:                  return "XmCR_PDM_OK";
+        case XmCR_PDM_CANCEL:              return "XmCR_PDM_CANCEL";
+        case XmCR_PDM_START_ERROR:         return "XmCR_PDM_START_ERROR";
+        case XmCR_PDM_EXIT_ERROR:          return "XmCR_PDM_EXIT_ERROR";
+#endif /* XmVersion >=2001 */
+	case XmCR_PROTOCOLS:               return "XmCR_PROTOCOLS";
+	default:                           return "???";
 	}
 }
 
-char *
+
+extern const char *
 XdbFocusChange2String(XmFocusChange c)
 {
 	switch (c) {
@@ -1811,7 +1888,8 @@ XdbFocusChange2String(XmFocusChange c)
 	}
 }
 
-char *
+
+extern const char *
 XdbNavigationType2String(XmNavigationType nt)
 {
 	switch (nt) {
@@ -1823,7 +1901,8 @@ XdbNavigationType2String(XmNavigationType nt)
 	}
 }
 
-char *
+
+extern const char *
 XdbEventType2String(int type)
 {
 	switch (type)
@@ -1865,7 +1944,8 @@ XdbEventType2String(int type)
 	}
 }
 
-char *
+
+extern const char *
 XdbFocusMode2String(int type)
 {
 	switch (type)
@@ -1878,7 +1958,8 @@ XdbFocusMode2String(int type)
 	}
 }
 
-char *
+
+extern const char *
 XdbFocusDetail2String(int type)
 {
 	switch (type)
