@@ -1,10 +1,11 @@
 /**
  *
- * $Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott Exp $
+ * $Id: DialogS.c,v 1.26 2000/09/22 20:35:11 amai Exp $
  *
  * derived from Xt Vendor class.c 
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  * Copyright 1989 Massachusetts Institute of Technology
  *
  * This file is part of the GNU LessTif Library.
@@ -25,9 +26,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott Exp $";
-
-#include <stdio.h>
+static const char rcsid[] = "$Id: DialogS.c,v 1.26 2000/09/22 20:35:11 amai Exp $";
 
 /*
  * This controls questionable behavior.  It will go away
@@ -36,15 +35,17 @@ static const char rcsid[] = "$Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott E
  */
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdio.h>
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/DialogSP.h>
 #include <Xm/DialogSEP.h>
 #include <X11/StringDefs.h>
 #include <X11/ShellP.h>
-#include <X11/Xfuncs.h>
 #include <Xm/VendorSP.h>
 #include <Xm/VendorSEP.h>
 #include <Xm/BulletinBP.h>
@@ -52,6 +53,7 @@ static const char rcsid[] = "$Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott E
 
 #include <XmI/DebugUtil.h>
 
+
 static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass wclass);
@@ -266,7 +268,7 @@ class_initialize(void)
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
 
-    bcopy(shells, combined, nshells * sizeof(XtResource));
+    memcpy(combined, shells, nshells * sizeof(XtResource));
 
     /* can't just copy.  We know we need to drop one */
     for (i = 0, addon = 0; i < XtNumber(ext_resources); i++)
