@@ -1,9 +1,9 @@
 /**
  *
- * $Id: DragBS.c,v 1.25 2000/08/21 15:54:37 amai Exp $
+ * $Id: DragBS.c,v 1.31 2000/10/04 11:53:28 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 2000 LessTif Development Team
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,18 +23,18 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragBS.c,v 1.25 2000/08/21 15:54:37 amai Exp $";
+static const char rcsid[] = "$Id: DragBS.c,v 1.31 2000/10/04 11:53:28 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/DisplayP.h>
 #include <Xm/AtomMgr.h>
-#include <X11/Xfuncs.h>
 #include <XmI/AtomMgrI.h>
 #include <XmI/DragDropI.h>
 #include <XmI/CutPasteI.h>
@@ -354,17 +354,17 @@ end_protection(Display *display)
 /*
  * read from a drag buffer (sort of)
  */
-short
+int
 _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
-		  char *retbuf, short bufsize)
+		  char *retbuf, int bufsize)
 {
     int rsize, eaten;
-    short size;
+    int size;
 
     DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s size %i\n",
 		      __FILE__, __LINE__,
 		      read_string ? "True" : "False",
-		      size));
+		      bufsize));
 
     if (read_string)
     {
@@ -377,7 +377,7 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
 			size = bufsize;
 	} else
 		size = bufsize;
-	bcopy(bmgr->name_start, retbuf, size);
+	memcpy(retbuf, bmgr->name_start, size);
 	bmgr->name_start += size;
 	return size;
     }
@@ -392,7 +392,7 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
 			size = bufsize;
 	} else
 		size = bufsize;
-	bcopy(bmgr->atom_start, retbuf, size);
+	memcpy(retbuf, bmgr->atom_start, size);
 	bmgr->atom_start += size;
 	return size;
     }
@@ -401,9 +401,9 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
 /*
  * write to a drag buffer (sort of)
  */
-short
+int
 _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
-		   char *data, short size)
+		   char *data, int size)
 {
     int increase_needed;
 
@@ -425,7 +425,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    if (bmgr->names == bmgr->name_ptr)
 	    {
 		bmgr->names = XtMalloc(bmgr->name_avail);
-		bcopy(bmgr->name_ptr, bmgr->names, bmgr->name_size);
+		memcpy(bmgr->names, bmgr->name_ptr, bmgr->name_size);
 	    }
 	    else
 	    {
@@ -433,7 +433,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    }
 	}
 
-	bcopy(data, bmgr->names + bmgr->name_size, size);
+	memcpy(bmgr->names + bmgr->name_size, data, size);
 	bmgr->name_size += size;
 
 	return size;
@@ -450,7 +450,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    if (bmgr->atoms == bmgr->atom_ptr)
 	    {
 		bmgr->atoms = XtMalloc(bmgr->atom_avail);
-		bcopy(bmgr->atom_ptr, bmgr->atoms, bmgr->atom_size);
+		memcpy(bmgr->atoms, bmgr->atom_ptr, bmgr->atom_size);
 	    }
 	    else
 	    {
@@ -458,7 +458,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    }
 	}
 
-	bcopy(data, bmgr->atoms + bmgr->atom_size, size);
+	memcpy(bmgr->atoms + bmgr->atom_size, data, size);
 	bmgr->atom_size += size;
 
 	return size;
@@ -1477,7 +1477,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     for (i = 0; i < targets->num_entries; i++)
     {
 	if (numTargets == targets->entries[i].num_targets &&
-	    bcmp(atoms, targets->entries[i].targets,
+	    memcmp(atoms, targets->entries[i].targets,
 		 sizeof(Atom) * numTargets) == 0)
 	{
 	    XtFree((char *)atoms);
@@ -1504,7 +1504,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     for (i = 0; i < targets->num_entries; i++)
     {
 	if (numTargets == targets->entries[i].num_targets &&
-	    bcmp(atoms, targets->entries[i].targets,
+	    memcmp(atoms, targets->entries[i].targets,
 		 sizeof(Atom) * numTargets) == 0)
 	{
 	    XtFree((char *)atoms);
