@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DragC.c,v 1.29 2000/08/29 15:04:52 amai Exp $
+ * $Id: DragC.c,v 1.31 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -40,11 +41,13 @@
  * provided "as is" without express or implied warranty.
  */
 
-static const char rcsid[] = "$Id: DragC.c,v 1.29 2000/08/29 15:04:52 amai Exp $";
+static const char rcsid[] = "$Id: DragC.c,v 1.31 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/DragCP.h>
 #include <Xm/DropSMgrP.h>
@@ -54,10 +57,9 @@ static const char rcsid[] = "$Id: DragC.c,v 1.29 2000/08/29 15:04:52 amai Exp $"
 #include <Xm/AtomMgr.h>
 #include <Xm/MenuUtilP.h>	/* for the _XmGrab stuff */
 
-#include <X11/Xfuncs.h>
-
 #include <XmI/DebugUtil.h>
 
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -443,7 +445,7 @@ initialize(Widget request, Widget new_w,
     {
 	exports = (Atom *)XtMalloc(DC_NumExportTargets(new_w) * sizeof(Atom));
 
-	bcopy(DC_ExportTargets(new_w), exports,
+	memcpy(exports, DC_ExportTargets(new_w),
 	      DC_NumExportTargets(new_w) * sizeof(Atom));
 
 	DC_ExportTargets(new_w) = exports;
@@ -523,7 +525,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	exports = (Atom *)XtMalloc(DC_NumExportTargets(new_w) * sizeof(Atom));
 
-	bcopy(DC_ExportTargets(new_w), exports,
+	memcpy(exports, DC_ExportTargets(new_w),
 	      DC_NumExportTargets(new_w) * sizeof(Atom));
 
 	DC_ExportTargets(new_w) = exports;
