@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DragIcon.c,v 1.9 1998/09/12 15:05:24 rwscott Exp $
+ * $Id: DragIcon.c,v 1.13 2000/09/23 15:05:23 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragIcon.c,v 1.9 1998/09/12 15:05:24 rwscott Exp $";
+static const char rcsid[] = "$Id: DragIcon.c,v 1.13 2000/09/23 15:05:23 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/DragDrop.h>
 #include <Xm/DragIconP.h>
@@ -34,7 +35,7 @@ static const char rcsid[] = "$Id: DragIcon.c,v 1.9 1998/09/12 15:05:24 rwscott E
 
 #include <XmI/DebugUtil.h>
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -554,7 +555,7 @@ typedef struct
 }
 XmQuarkToCursorRec;
 
-XmQuarkToCursorRec quarkTo16CursorTable[] =
+static XmQuarkToCursorRec quarkTo16CursorTable[] =
 {
     {&_XmValidCursorIconQuark, &state16CursorDataRec},
     {&_XmInvalidCursorIconQuark, &state16CursorDataRec},
@@ -566,7 +567,7 @@ XmQuarkToCursorRec quarkTo16CursorTable[] =
     {NULL, &text16CursorDataRec},
 };
 
-XmQuarkToCursorRec quarkToCursorTable[] =
+static XmQuarkToCursorRec quarkToCursorTable[] =
 {
     {&_XmValidCursorIconQuark, &state32CursorDataRec},
     {&_XmInvalidCursorIconQuark, &state32CursorDataRec},
@@ -579,14 +580,18 @@ XmQuarkToCursorRec quarkToCursorTable[] =
 };
 
 static void
-class_initialize()
+class_initialize(void)
 {
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
+    	__FILE__, __LINE__));
     _XmDragIconRectClassExtRec.record_type = XmQmotif;
 }
 
 static void
 class_part_initialize(WidgetClass widget_class)
 {
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
+    	__FILE__, __LINE__));
     _XmFastSubclassInit(widget_class, XmDRAG_ICON_BIT);
 }
 
@@ -602,6 +607,18 @@ initialize(Widget request, Widget new_w,
     unsigned int width, height;
     XImage *image;
 
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
+		      "%s:initialize(%d) - %i args\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+
     pscr = XtScreenOfObject(XtParent(new_w));
 
     DI_Region(new_w) = NULL;
@@ -738,6 +755,9 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:destroy(%d)\n",
+    	__FILE__, __LINE__));
+
     if (DI_Region(w))
     {
 	XDestroyRegion(DI_Region(w));
@@ -757,6 +777,21 @@ set_values(Widget current, Widget request, Widget new_w,
 {
     Boolean refresh = False;
 
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
+		      "%s:set_values(%d) - %i args\n"
+		      "\t    old X %5i Y %5i W %5i H %5i\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(current), XtY(current),
+		      XtWidth(current), XtHeight(current),
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+
     if (DI_Depth(new_w) != DI_Depth(current) ||
 	DI_Width(new_w) != DI_Width(current) ||
 	DI_Height(new_w) != DI_Height(current) ||
@@ -814,6 +849,8 @@ _XmDestroyDefaultDragIcon(XmDragIconObject icon)
 {
     Screen *scr = XtScreenOfObject(XtParent(icon));
 
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "_XmDestroyDefaultDragIcon\n"));
+
     if (DI_Pixmap(icon) != XmUNSPECIFIED_PIXMAP)
     {
 	XmDestroyPixmap(scr, DI_Pixmap(icon));
@@ -832,6 +869,8 @@ _XmDestroyDefaultDragIcon(XmDragIconObject icon)
 Boolean
 _XmDragIconIsDirty(XmDragIconObject icon)
 {
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "_XmDragIconIsDirty\n"));
+
     return DI_IsDirty(icon);
 }
 
@@ -840,6 +879,8 @@ _XmDragIconClean(XmDragIconObject icon1,
 		 XmDragIconObject icon2,
 		 XmDragIconObject icon3)
 {
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "_XmDragIconClean\n"));
+
     if (icon1)
 	DI_IsDirty(icon1) = False;
     if (icon2)
@@ -854,6 +895,8 @@ XmCreateDragIcon(Widget widget,
 		 ArgList arglist,
 		 Cardinal argcount)
 {
+    DEBUGOUT(XdbDebug(__FILE__, widget, "XmCreateDragIcon\n"));
+
     return XtCreateWidget(name, xmDragIconObjectClass,
 			  widget, arglist, argcount);
 }
