@@ -1,9 +1,10 @@
-/** -*- Mode: C; tab-width: 8; indent-tabs-mode: nil -*-
+/**
  *
- * $Id: DragOverS.c,v 1.19 2000/03/15 01:23:07 rwscott Exp $
+ * $Id: DragOverS.c,v 1.21 2000/10/04 18:30:33 amai Exp $
  *
  * derived from Xt Vendor class.c 
  *
+ * Copyright (C) 1995-2000 LessTif Development Team 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright 1989 Massachusetts Institute of Technology
  *
@@ -25,12 +26,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragOverS.c,v 1.19 2000/03/15 01:23:07 rwscott Exp $";
+static const char rcsid[] = "$Id: DragOverS.c,v 1.21 2000/10/04 18:30:33 amai Exp $";
 
 #include <LTconfig.h>
-#include <stdlib.h>
-#include <XmI/XmI.h>
 
+#include <stdlib.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/XmosP.h>
 #include <Xm/VendorSP.h>
