@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DragUnder.c,v 1.2 1997/07/10 03:01:41 miers Exp $
+ * $Id: DragUnder.c,v 1.5 2000/09/23 15:05:23 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,17 +23,20 @@
  *
  **/
 
-static char rcsid[] = "$Id: DragUnder.c,v 1.2 1997/07/10 03:01:41 miers Exp $";
+static const char rcsid[] = "$Id: DragUnder.c,v 1.5 2000/09/23 15:05:23 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <XmI/DragDropI.h>
 
 #include <XmI/DebugUtil.h>
 
+
 void
 _XmDragUnderAnimation(Widget w, XtPointer clientData, XtPointer callData)
 {
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragUnderAnimation(%d)\n",
+    	__FILE__, __LINE__));
 }
