@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DrawingArea.c,v 1.30 1998/10/20 19:41:36 rwscott Exp $
+ * $Id: DrawingArea.c,v 1.41 2000/09/29 22:51:55 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DrawingArea.c,v 1.30 1998/10/20 19:41:36 rwscott Exp $";
+static const char rcsid[] = "$Id: DrawingArea.c,v 1.41 2000/09/29 22:51:55 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -38,7 +40,7 @@ static const char rcsid[] = "$Id: DrawingArea.c,v 1.30 1998/10/20 19:41:36 rwsco
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -62,10 +64,12 @@ static XtGeometryResult geometry_manager(Widget w,
 
 static void changed_managed(Widget w);
 
-static void PreferedSize(Widget w, Widget instig, XtWidgetGeometry *ir,
+static void PreferredSize(Widget w, Widget instig, XtWidgetGeometry *ir,
 			 Dimension *wid, Dimension *hei);
 
 static XmNavigability widget_navigable(Widget w);
+static Boolean ConstraintSetValues(Widget curr, Widget req, Widget new_w,
+	ArgList args, Cardinal *num_args);
 
 /*
  * Resources for the Drawing Area class
@@ -103,8 +107,6 @@ static XtResource resources[] =
 	sizeof(unsigned char), Offset(resize_policy),
 	XmRImmediate, (XtPointer)XmRESIZE_ANY
     }
-#if LESSTIF_BACK_COMPAT
-#else
 #if XmVERSION > 1
     ,{
 	XmNconvertCallback, XmCCallback, XmRCallback,
@@ -117,7 +119,6 @@ static XtResource resources[] =
 	XmRImmediate, (XtPointer)NULL
     }
 #endif
-#endif
 };
 
 static XmSyntheticResource syn_resources[] =
@@ -220,7 +221,7 @@ XmDrawingAreaClassRec xmDrawingAreaClassRec = {
         /* constraint_size   */ 0,     
         /* initialize        */ NULL,
         /* destroy           */ NULL,  
-        /* set_values        */ NULL,  
+        /* set_values        */ ConstraintSetValues,  
         /* extension         */ NULL,  
     },
     /* XmManager class part */
@@ -244,7 +245,7 @@ XmDrawingAreaClassRec xmDrawingAreaClassRec = {
 WidgetClass xmDrawingAreaWidgetClass = (WidgetClass)&xmDrawingAreaClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmDrawingACoreClassExtRec.record_type = XmQmotif;
 }
@@ -402,7 +403,7 @@ resize(Widget w)
 }
 
 static void
-PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
+PreferredSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
 	     Dimension *wid, Dimension *hei)
 {
     int i, cnt;
@@ -431,6 +432,7 @@ PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
     {
 	Widget child = MGR_Children(w)[i];
 	XtWidgetGeometry child_geometry;
+	Dimension tmp;
 
 	if (!XtIsManaged(child))
 	{
@@ -441,7 +443,7 @@ PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
 
 	/* we assume that the routines calling this one fill in the
 	   width and height of the child responsible for the resize
-	   request with their prefered size. */
+	   request with their preferred size. */
 	if (instigator == child)
 	{
 	    child_geometry = *ir;
@@ -452,21 +454,23 @@ PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
 	    child_geometry.y = XtY(child);
 	    child_geometry.width = XtWidth(child);
 	    child_geometry.height = XtHeight(child);
-	    child_geometry.border_width = 0;
+		/* T. Straumann: don't forget the border width */
+	    child_geometry.border_width = XtBorderWidth(child);
 	}
 
 	DEBUGOUT(XdbDebug2(__FILE__, w, child,
 			   "Child wants %d %d\n",
 			   child_geometry.width, child_geometry.height));
 
-	if (child_geometry.x + child_geometry.width > *wid)
+	/* T. Straumann: added border width support */
+	if ( (tmp = child_geometry.x + child_geometry.width + 2 * child_geometry.border_width) > *wid)
 	{
-	    *wid = child_geometry.x + child_geometry.width;
+	    *wid = tmp;
 	}
 
-	if (child_geometry.y + child_geometry.height > *hei)
+	if ( (tmp = child_geometry.y + child_geometry.height + 2 * child_geometry.border_width) > *hei)
 	{
-	    *hei = child_geometry.y + child_geometry.height;
+	    *hei = tmp;
 	}
     }
 
@@ -487,7 +491,7 @@ PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
 	}
 	else
 	{
-	    *wid = XtWidth(w);
+	    *wid = XtWidth(w) < DA_MarginWidth(w) ? DA_MarginWidth(w) : XtWidth(w);
 	}
 	if (XtHeight(w) == 0)
 	{
@@ -495,7 +499,7 @@ PreferedSize(Widget w, Widget instigator, XtWidgetGeometry *ir,
 	}
 	else
 	{
-	    *hei = XtHeight(w);
+	    *hei = XtHeight(w) < DA_MarginHeight(w) ? DA_MarginHeight(w) : XtHeight(w);
 	}
 
 	return;
@@ -546,7 +550,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 #if 0
     answer->request_mode = 0;
 
-    PreferedSize(w, NULL, NULL, &wid, &hei);
+    PreferredSize(w, NULL, NULL, &wid, &hei);
 
     answer->request_mode = CWWidth|CWHeight;
     answer->width = wid;
@@ -563,7 +567,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
     return XtGeometryYes;
 #else
-    PreferedSize(w, NULL, NULL, &wid, &hei);
+    PreferredSize(w, NULL, NULL, &wid, &hei);
 
     answer->width = wid;
     answer->height = hei;
@@ -587,17 +591,28 @@ geometry_manager(Widget w,
 		     (DA_ResizePolicy(dw) == XmRESIZE_GROW) ? "XmRESIZE_GROW" :
 		     (DA_ResizePolicy(dw) == XmRESIZE_ANY) ? "XmRESIZE_ANY" :
       (DA_ResizePolicy(dw) == XmRESIZE_SWINDOW) ? "XmRESIZE_SWINDOW" : "???"));
+    DEBUGOUT(XdbDebug2("ITEMBIN", dw, w, "geometry_manager(%s)\n",
+		     (DA_ResizePolicy(dw) == XmRESIZE_NONE) ? "XmRESIZE_NONE" :
+		     (DA_ResizePolicy(dw) == XmRESIZE_GROW) ? "XmRESIZE_GROW" :
+		     (DA_ResizePolicy(dw) == XmRESIZE_ANY) ? "XmRESIZE_ANY" :
+      (DA_ResizePolicy(dw) == XmRESIZE_SWINDOW) ? "XmRESIZE_SWINDOW" : "???"));
 
     if (XtIsSubclass(sw, xmScrolledWindowWidgetClass) &&
 	SW_ScrollPolicy(sw) == XmAUTOMATIC &&
 	(Widget)SW_ClipWindow(sw) == dw)
     {
-	
 	DEBUGOUT(XdbDebug2(__FILE__, dw, w,
 			   "geometry_manager: in ScrolledWindow (%s) => YES\n",
 			   XdbWidgetGeometry2String(request)));
 
+	/* T. Straumann: the ScrolledWindow's code knows that it has
+	 *				 to manage its _grandchild_ (the workWindow).
+	 *				 This kind of magic is not exactly what I thought
+	 *				 encapsulation was about...
+	 */
 	XtMakeGeometryRequest(dw, request, reply);
+	XtWidth(w) = request->request_mode & CWWidth ? request->width : XtWidth(w);
+	XtHeight(w) = request->request_mode & CWHeight ? request->height : XtHeight(w);
 	return XtGeometryYes;
     }
 
@@ -626,8 +641,30 @@ geometry_manager(Widget w,
 	req.border_width = XtBorderWidth(w);
     }
 
+    /*
+     * Danny 6/3/1999
+     * Special case: (See bug 69)
+     *	- we get X, Y but no other geometry requests
+     *  - X+Width <= DAWidth
+     *  - Y+Height <= DAHeight
+     * -> then just say yes.
+     */
+    /* rws 25 May 1999
+       drawingarea/test9 shows this is wrong.
+    if ((req.request_mode & ~(CWX|CWY)) == 0) {
+	if (req.x + req.width <= XtWidth(dw) &&
+			req.y + req.height <= XtHeight(dw)) {
+		return XtGeometryYes;
+	}
+    }
+    */
+
     /* Calculate needed size for DrawingArea widget */
-    PreferedSize(dw, w, &req, &wid, &hei);
+    PreferredSize(dw, w, &req, &wid, &hei);
+    DEBUGOUT(XdbDebug2("ITEMBIN", dw, w, "request (%s) need %ix%i is %ix%i\n",
+    	XdbWidgetGeometry2String(&req), wid, hei,
+    	XtWidth(dw), XtHeight(dw)
+    	));
 
     switch (DA_ResizePolicy(dw))
     {
@@ -705,6 +742,10 @@ geometry_manager(Widget w,
 	    preq.width = wid;
 	    preq.height = hei;
 	    result = _XmMakeGeometryRequest(dw, &preq);
+	    DEBUGOUT(XdbDebug2("ITEMBIN", dw, w, "Parent says %s (%s)\n",
+	    	XdbGeometryResult2String(result),
+	    	XdbWidgetGeometry2String(&preq)
+	    	));
 
 	    if (result == XtGeometryYes)
 	    {
@@ -720,9 +761,16 @@ geometry_manager(Widget w,
 	    }
 	    else
 	    {
+		if ((req.request_mode & CWX ? wid < XtWidth(dw) : True) && 
+		    (req.request_mode & CWY ? hei < XtHeight(dw) : True))
+		{
+		    XtX(w) = req.request_mode & CWX ? req.x : XtX(w);
+		    XtY(w) = req.request_mode & CWY ? req.y : XtY(w);
+		    return XtGeometryYes;
+		}
 		DEBUGOUT(XdbDebug(__FILE__, dw, "Return XtGeometryNo 3\n"));
 
-		return XtGeometryNo;
+		return XtGeometryYes;
 	    }
 	}
 	else
@@ -775,7 +823,7 @@ changed_managed(Widget w)
     if (DA_ResizePolicy(w) != XmRESIZE_NONE)
     {
 	_XmGMEnforceMargin(w, DA_MarginWidth(w), DA_MarginHeight(w), False);
-	PreferedSize(w, NULL, NULL, &wid, &hei);
+	PreferredSize(w, NULL, NULL, &wid, &hei);
 	wid = XtIsRealized(w) ? wid : XtWidth(w) == 0 ? wid : XtWidth(w);
 	hei = XtIsRealized(w) ? hei : XtHeight(w) == 0 ? hei : XtHeight(w);
 	if (wid > XtWidth(w) || hei > XtHeight(w))
@@ -843,6 +891,7 @@ widget_navigable(Widget w)
 	    MGR_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (MGR_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
+#if 0
 	    DEBUGOUT(XdbDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_TAB_NAVIGABLE\n"));
 
@@ -853,6 +902,21 @@ widget_navigable(Widget w)
 	    }
 
 	    return XmDESCENDANTS_TAB_NAVIGABLE;
+#else
+	    {
+	    int i;
+
+	    	for (i = 0; i < MGR_NumChildren(w); i++)
+	    	{
+		    if ((XmIsManager(MGR_Children(w)[i]) && MGR_TraversalOn(MGR_Children(w)[i])) ||
+		        (XmIsPrimitive(MGR_Children(w)[i]) && Prim_TraversalOn(MGR_Children(w)[i])))
+		    {
+			return XmDESCENDANTS_TAB_NAVIGABLE;
+		    }
+	    	}
+		return XmTAB_NAVIGABLE;
+	    }
+#endif
 	}
     }
 
@@ -861,3 +925,21 @@ widget_navigable(Widget w)
     return XmNOT_NAVIGABLE;
 }
 
+static Boolean
+ConstraintSetValues(Widget curr, Widget req, Widget new_w,
+		ArgList args, Cardinal *num_args)
+{
+	/*
+	XtWidgetGeometry preq;
+	XtGeometryResult result;
+	Widget		dw = XtParent(new_w);
+	*/
+
+	if (XtX(curr) != XtX(new_w) || XtY(curr) != XtY(new_w)) {
+		_XmMoveObject(new_w, XtX(new_w), XtY(new_w));
+
+		return True;
+	}
+	return False;
+}
+
