@@ -1,8 +1,9 @@
-/** -*- Mode: C; tab-width: 8; indent-tabs-mode: nil -*-
+/*
  *
- * $Id: DropSMgr.c,v 1.29 2000/07/25 20:10:29 hennessy Exp $
+ * $Id: DropSMgr.c,v 1.31 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropSMgr.c,v 1.29 2000/07/25 20:10:29 hennessy Exp $";
+static const char rcsid[] = "$Id: DropSMgr.c,v 1.31 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/DropSMgrP.h>
@@ -34,10 +38,10 @@ static const char rcsid[] = "$Id: DropSMgr.c,v 1.29 2000/07/25 20:10:29 hennessy
 #include <Xm/DropTrans.h>
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
-#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
+
 #ifndef XmUNSPECIFIED
 #define XmUNSPECIFIED (~0)
 #endif
@@ -1206,7 +1210,7 @@ __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
 
     ndsi = (XmDropSiteInfo) XtMalloc(sizeof(XmDropSiteInfoRec));
 
-    bcopy(dsi, ndsi, sizeof(XmDropSiteInfoRec));
+    memcpy(ndsi, dsi, sizeof(XmDropSiteInfoRec));
 
     XtSetSubvalues((XtPointer)ndsi,
 		   _XmDSResources, _XmNumDSResources,
@@ -1252,7 +1256,7 @@ __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
 		     &ndsi->animationPixmapDepth);
     }
 
-    bcopy(ndsi, dsi, sizeof(XmDropSiteInfoRec));
+    memcpy(dsi, ndsi, sizeof(XmDropSiteInfoRec));
 
     XtFree((char *)ndsi);
 
