@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DropTrans.c,v 1.12 2000/04/18 01:58:06 rwscott Exp $
+ * $Id: DropTrans.c,v 1.14 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,13 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropTrans.c,v 1.12 2000/04/18 01:58:06 rwscott Exp $";
+static const char rcsid[] = "$Id: DropTrans.c,v 1.14 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
-
-#include <X11/Xfuncs.h>
-
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/DropTransP.h>
@@ -36,7 +37,6 @@ static const char rcsid[] = "$Id: DropTrans.c,v 1.12 2000/04/18 01:58:06 rwscott
 #include <XmI/DragDropI.h>
 #include <XmI/AtomMgrI.h>
 #include <Xm/DisplayP.h>
-#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -238,7 +238,7 @@ initialize(Widget request, Widget new_w,
 	entries = (XmDropTransferEntry)XtMalloc(DT_NumDropTransfers(new_w) *
 						sizeof(XmDropTransferEntryRec));
 
-	bcopy(DT_DropTransfers(new_w), entries,
+	memcpy(entries, DT_DropTransfers(new_w),
 	      DT_NumDropTransfers(new_w) * sizeof(XmDropTransferEntryRec));
 
 	DT_DropTransferLists(new_w)[0].transfer_list = entries;
@@ -507,7 +507,7 @@ add_drop_transfer(Widget widget,
 
     entries = (XmDropTransferEntry)XtMalloc(num_transfers *
 					    sizeof(XmDropTransferEntryRec));
-    bcopy(transfers, entries, num_transfers * sizeof(XmDropTransferEntryRec));
+    memcpy(entries, transfers, num_transfers * sizeof(XmDropTransferEntryRec));
 
     DT_DropTransferLists(widget)[idx].transfer_list = entries;
     DT_DropTransferLists(widget)[idx].num_transfers = num_transfers;
