@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ExtObject.c,v 1.4 1998/09/12 15:05:27 rwscott Exp $
+ * $Id: ExtObject.c,v 1.6 2000/09/23 15:05:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,21 +23,20 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ExtObject.c,v 1.4 1998/09/12 15:05:27 rwscott Exp $";
+static const char rcsid[] = "$Id: ExtObject.c,v 1.6 2000/09/23 15:05:24 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/CacheP.h>
-#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
 static XmExtCache *cache = NULL;
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -162,7 +162,7 @@ logical_parent(Widget w,
 }
 
 static void
-class_initialize()
+class_initialize(void)
 {
     DEBUGOUT(XdbDebug(__FILE__, NULL, "ExtObject class initialize\n"));
 
