@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.89 2000/08/29 15:04:53 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.100 2000/10/09 11:56:32 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,14 +23,21 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.89 2000/08/29 15:04:53 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.100 2000/10/09 11:56:32 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
-#include <XmI/MacrosI.h>
 
 #include <stdlib.h>
+#include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_LIBGEN_H
+#include <libgen.h>    /* for basename() */
+#endif
+
+#include <XmI/XmI.h>
+#include <XmI/MacrosI.h>
 #include <Xm/XmP.h>
 #include <Xm/List.h>
 #include <Xm/SelectioBP.h>
@@ -42,7 +50,8 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v
 #include <Xm/TextF.h>
 #include <Xm/DialogS.h>
 #include <Xm/TransltnsP.h>
-#include <X11/Xfuncs.h>
+
+#include "LTmisc.h"   /* for basename() */
 
 #include <XmI/DebugUtil.h>
 
@@ -205,37 +214,32 @@ static XtResource resources[] =
 	sizeof(int), SBOffset(list_item_count),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED
     },
-#if 0
 #if XmVERSION > 1
     {
-	XmNpathMode, XmCPathMode, XtEnum,
-	sizeof(int), SBOffset(path_mode),
-	XmRImmediate, XmPATH_MODE_FULL
+	XmNpathMode, XmCPathMode, XmRPathMode,
+	sizeof(XtEnum), Offset(path_mode),
+	XmRImmediate, (XtPointer)XmPATH_MODE_FULL
+    },
+    {
+	XmNfileFilterStyle, XmCFileFilterStyle, XmRFileFilterStyle,
+	sizeof(XtEnum), Offset(file_filter_style),
+	XmRImmediate, (XtPointer)XmFILTER_NONE
     },
-#endif
 #endif
 };
 
 /* Synthetic resources */
-void FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetDirListLabelString(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetDirMask(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetDirectory(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetFilterLabelString(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetListItemCount(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value);
+static void FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value);
 
-void FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetDirListLabelString(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetDirMask(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetDirectory(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetFilterLabelString(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetListItemCount(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value);
-
-void FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value);
 
 static XmSyntheticResource syn_resources[] =
 {
@@ -311,7 +315,6 @@ static XtActionsRec actions[] =
 	{"SelectionBoxRestore", FileSelectionBoxRestore},
 };
 
-/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmFileSBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -422,7 +425,6 @@ XmFileSelectionBoxClassRec xmFileSelectionBoxClassRec = {
 	/* extension                    */ NULL,
     }
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmFileSelectionBoxWidgetClass = (WidgetClass)&xmFileSelectionBoxClassRec;
@@ -458,6 +460,7 @@ initialize(Widget request, Widget new_w,
     int argc;
     XmString files = NULL;
     XtTranslations save_acc;
+    int dir_set_flag;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
@@ -700,6 +703,7 @@ initialize(Widget request, Widget new_w,
      *
      *		--mu@trends.net, 1998.07.04
      */
+    dir_set_flag = 0;
     if (_XmStringIsSpecified(FS_DirMask(new_w)))
     {
 	String mask;
@@ -721,10 +725,21 @@ initialize(Widget request, Widget new_w,
         	 */
         	*pat = '\0';
         	FS_Directory(new_w) = XmStringCreateLocalized(mask);
+                dir_set_flag = 1;
             }
 
             XtFree(mask);
         }
+
+        FS_DirMask(new_w) = XmStringCopy(FS_DirMask(new_w));
+    }
+
+    if (dir_set_flag == 0) { /* FS_Directory was not set above */
+        if (_XmStringIsSpecified(FS_Directory(new_w))) {
+            FS_Directory(new_w) = XmStringCopy(FS_Directory(new_w));
+        }
+        else
+            FS_Directory(new_w) = NULL;
     }
 
     _XmFileSelectionSearch(new_w);
@@ -738,27 +753,25 @@ destroy(Widget w)
     DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
-    DEBUGOUT(XdbDebug("NEDIT", w,"%s:destroy(%d)\n",
-    	__FILE__, __LINE__
-    	));
+
     XmStringFree(FS_DirListLabelString(w));
     XmStringFree(FS_FileListLabelString(w));
     XmStringFree(FS_FilterLabelString(w));
     XmStringFree(FS_NoMatchString(w));
 	/* T. Straumann: don't forget to free these */
-	XmStringFree(FS_DirMask(w));
-	XmStringFree(FS_Pattern(w));
-	XmStringFree(FS_Directory(w));
+    XmStringFree(FS_DirMask(w));
+    XmStringFree(FS_Pattern(w));
+    XmStringFree(FS_Directory(w));
 }
 
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Arg al[10];
+    Arg al[6];
     int ac;
     Boolean refresh = False;
-	Boolean reSearch;
+    Boolean reSearch;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
@@ -1801,6 +1814,31 @@ noGeoRequest(XmGeoMatrix _geoSpec)
 
 /******************************* SEARCHING **********************************/
 
+
+#if XmVERSION > 1
+/* Keep it short and simple - make it a function (instead of a macro)
+   for easier debugging purposes but give it a more than reasonable chance
+   to be optimized out (or inlined in :-)  ... */
+static Boolean
+FileIsHidden(String name) {
+
+  const char *ptr;
+  
+  ptr=basename(name);
+  if (*ptr=='.') {
+     ptr++;
+     if ( (*ptr=='\0') || ((*ptr=='.')&&(*(ptr+1)=='\0')) )
+       /* keep special entries visible */
+        return False;
+     else
+        return True;
+  }
+  else
+     return False;
+}
+#endif
+
+
 static void
 defaultDirSearchProc(Widget widget,
 		     XtPointer data)
@@ -1808,7 +1846,7 @@ defaultDirSearchProc(Widget widget,
     String *entries, dir, pat;
     XmFileSelectionBoxCallbackStruct *cbs = (XmFileSelectionBoxCallbackStruct *)data;
     unsigned int numents, numalloc, argc, i, max;
-    Arg argl[5];
+    Arg argl[3];
     XmString *table;
 
     if (!XmStringGetLtoR(cbs->dir, XmFONTLIST_DEFAULT_TAG, &dir))
@@ -1816,8 +1854,9 @@ defaultDirSearchProc(Widget widget,
 	dir = XtNewString("");
     }
 
-    entries = NULL;
-    numents = numalloc = 0;
+    entries  = NULL;
+    numents  = 0;
+    numalloc = 0;
 
     /*
      * I think pattern should always be "*" for directories.
@@ -1836,6 +1875,33 @@ defaultDirSearchProc(Widget widget,
 
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
+   
+#if XmVERSION > 1
+    /* we use two versions of this loop for better performance */
+    if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
+
+        int visible=0;
+    
+        for (i = 0; i < numents; i++)
+         {
+	 if (FileIsHidden(entries[i])) {
+	    XtFree(entries[i]);
+	 }
+	 else {
+	   if (i == max)
+	    {
+	    max *= 2;
+	    table = (XmString *)XtRealloc((char *)table, max * sizeof(XmString));
+	    }
+	    table[visible] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
+	    visible++;
+	    XtFree(entries[i]);
+         } /* not hidden */
+        } /* for */
+	numents = visible;
+    }  /* XmFILTER_HIDDEN_FILES */
+    else
+#endif
     for (i = 0; i < numents; i++)
     {
 	if (i == max)
@@ -1843,11 +1909,10 @@ defaultDirSearchProc(Widget widget,
 	    max *= 2;
 	    table = (XmString *)XtRealloc((char *)table, max * sizeof(XmString));
 	}
-
 	table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
-
 	XtFree(entries[i]);
     }
+
     if (entries)
     {
 	XtFree((char *)entries);
@@ -1874,7 +1939,7 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     XmFileSelectionBoxCallbackStruct *cbs =
 	(XmFileSelectionBoxCallbackStruct *)data;
     unsigned int numents, numalloc, argc, i, max;
-    Arg argl[5];
+    Arg argl[3];
     XmString *table;
 
     DEBUGOUT(XdbDebug(__FILE__, widget, "defaultFileSearchProc\n"));
@@ -1903,8 +1968,9 @@ defaultFileSearchProc(Widget widget, XtPointer data)
 			  "defaultFileSearchProc: pattern '%s'\n", pat));
     }
 
-    entries = NULL;
-    numents = numalloc = 0;
+    entries  = NULL;
+    numents  = 0;
+    numalloc = 0;
 
     _XmOSBuildFileList(dir, pat, FS_FileTypeMask(widget),  /* FIX ME: leaks */
 		       &entries, &numents, &numalloc);
@@ -1917,17 +1983,45 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
 
-    for (i = 0; i < numents; i++)
-    {
-	if (i == max)
-	{
-	    max *= 2;
-	    table = (XmString *)XtRealloc((char *)table,
+#if XmVERSION > 1
+    /* we use two versions of this loop for better performance */
+    if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
+
+        int visible=0;
+
+        for (i = 0; i < numents; i++)
+        {
+	 if (FileIsHidden(entries[i])) {
+	    XtFree(entries[i]);
+	 } else {
+   	   if (i == max)
+ 	    {
+	     max *= 2;
+	     table = (XmString *)XtRealloc((char *)table,
 					  max * sizeof(XmString));
-	}
-	table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
-	XtFree(entries[i]);
-    }
+ 	    }
+	    table[visible] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
+	    visible++;
+	    XtFree(entries[i]);
+         } /* not hidden */
+	 } /* for */
+    numents = visible;
+    } /* XmFILTER_HIDDEN_FILES */
+    else
+#endif
+     for (i = 0; i < numents; i++)
+        {
+   	 if (i == max)
+ 	{
+	     max *= 2;
+	     table = (XmString *)XtRealloc((char *)table,
+					  max * sizeof(XmString));
+ 	  }
+	  table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
+	  XtFree(entries[i]);
+        }
+
+
     if (entries)
     {
 	XtFree((char *)entries);
@@ -2885,14 +2979,16 @@ FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value)
 void 
 FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value)
 {
-    /* FIX ME : a copy or the real thing ? */
-    *value = (XtArgVal)FS_NoMatchString(wid);
+    /* Return a copy of the internal string because the */
+    /* application expects to be able to free the returned string. */
+    *value = (XtArgVal)XmStringCopy(FS_NoMatchString(wid));
 }
 
 void 
 FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value)
 {
-    /* FIX ME : a copy or the real thing ? */
+    /* Return a copy of the internal string because the */
+    /* application expects to be able to free the returned string. */
     *value = (XtArgVal)XmStringCopy(FS_Pattern(wid));
 }
 
@@ -3012,7 +3108,6 @@ FileSelectionBoxUpOrDown(Widget w, XEvent *event, String *params, Cardinal *num_
 static void
 FileSelectionBoxRestore(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    /* Arg args[2]; */
     Widget text, list, focus;
     /* XmStringTable items; */
     /* int item_count, *position_list, position_count; */
