@@ -1,8 +1,9 @@
 /** 
  *
- * $Id: Frame.c,v 1.44 1998/10/13 16:09:58 rwscott Exp $
+ * $Id: Frame.c,v 1.49 2000/11/12 18:25:31 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Frame.c,v 1.44 1998/10/13 16:09:58 rwscott Exp $";
+static const char rcsid[] = "$Id: Frame.c,v 1.49 2000/11/12 18:25:31 rwscott Exp $";
 
 /*
  * Warning : this widget has a small amount of Motif 2.0 support.
@@ -418,7 +419,7 @@ set_values(Widget current, Widget request, Widget new_w,
 	redisplay = True;
     }
 
-    if (redisplay)
+    if (redisplay && XtIsRealized(new_w) && XtIsManaged(new_w))
     {
 	DEBUGOUT(XdbDebug(__FILE__, new_w,
 			  "Frame set_values %p W %i H %i\n",
@@ -465,7 +466,14 @@ resize(Widget w)
     }
 #endif
 
+    _XmClearShadowType(w, 
+    	Frame_OldWidth(w), 
+    	Frame_OldHeight(w),
+    	Frame_OldShadowThickness(w),
+    	0);
     _XmFrameConfigureChildren(w, NULL, NULL, XtWidth(w), XtHeight(w), True);
+    Frame_OldWidth(w) = XtWidth(w);
+    Frame_OldHeight(w) = XtHeight(w);
 }
 
 static void
@@ -659,11 +667,21 @@ geometry_manager(Widget w,
 			"geometry_manager : _XmFrameConfigureChildren => %s\n",
 			   XdbWidgetGeometry2String(reply)));
 
+	_XmClearShadowType(fw, 
+	    Frame_OldWidth(fw), 
+	    Frame_OldHeight(fw),
+	    Frame_OldShadowThickness(fw),
+	    0);
 	_XmFrameConfigureChildren(fw, w, reply, XtWidth(fw), XtHeight(fw),
 				  False);
     }
     else
     {
+	_XmClearShadowType(fw, 
+	    Frame_OldWidth(fw), 
+	    Frame_OldHeight(fw),
+	    Frame_OldShadowThickness(fw),
+	    0);
 	_XmFrameConfigureChildren(fw, w, reply, XtWidth(fw), XtHeight(fw),
 				  False);
 	DEBUGOUT(XdbDebug2(__FILE__, fw, w,
@@ -765,6 +783,11 @@ change_managed(Widget w)
 		      "Frame change_managed %p W %i H %i\n",
 		       w, XtWidth(w), XtHeight(w)));
 
+    _XmClearShadowType(w, 
+    	Frame_OldWidth(w), 
+    	Frame_OldHeight(w),
+    	Frame_OldShadowThickness(w),
+    	0);
     _XmFrameComputeSize(w, NULL, NULL, &wd, &ht);
 
     request.request_mode = (CWWidth | CWHeight | CWBorderWidth);
