@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Gadget.c,v 1.12 1998/09/12 15:05:28 rwscott Exp $
+ * $Id: Gadget.c,v 1.17 2000/09/23 15:05:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,20 +23,21 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Gadget.c,v 1.12 1998/09/12 15:05:28 rwscott Exp $";
+static const char rcsid[] = "$Id: Gadget.c,v 1.17 2000/09/23 15:05:24 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/GadgetP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/RepType.h>
-#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -118,7 +120,7 @@ static XtResource resources[] =
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
 	sizeof(Dimension), Offset(highlight_thickness),
-	XmRCallProc, (XtPointer)_XmPrimitiveHighlightThicknessDefault
+	XmRImmediate, (XtPointer)2
     },
     {
 	XmNshadowThickness, XmCShadowThickness, XmRHorizontalDimension,
@@ -294,7 +296,7 @@ XmGadgetClassRec xmGadgetClassRec = {
 WidgetClass xmGadgetClass = (WidgetClass)&xmGadgetClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmRegisterConverters();
     _XmRegisterPixmapConverters();
@@ -413,6 +415,9 @@ initialize(Widget request,
 {
     XmBaseClassExt bce;
 
+    /* Force the borderWidth to 0 */
+    new_w->core.border_width = 0;
+
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRNavigationType),
 			     G_NavigationType(new_w),
 			     new_w))
@@ -476,6 +481,9 @@ set_values(Widget current,
 {
     Boolean need_refresh = False;
 
+    /* Force the borderWidth to 0 */
+    new_w->core.border_width = 0;
+
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRUnitType),
 			     G_UnitType(new_w),
 			     new_w))
@@ -582,7 +590,7 @@ visual_change(Widget w,
  * ENTER/LEAVE should only happen when mwm is in pointer-follows-mouse mode.
  * FOCUS_IN/FOCUS_OUT otherwise.
  */
-void
+static void
 focus_change(Widget w, XmFocusChange change)
 {
     XmGadgetClass gc = (XmGadgetClass)XtClass(w);
