@@ -1,8 +1,9 @@
 /**
  *
- * $Id: GeoUtils.c,v 1.35 1998/10/16 23:41:37 rwscott Exp $
+ * $Id: GeoUtils.c,v 1.50 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,18 +23,19 @@
  *
  **/
 
-static const char rcsid[] = "$Id: GeoUtils.c,v 1.35 1998/10/16 23:41:37 rwscott Exp $";
+static const char rcsid[] = "$Id: GeoUtils.c,v 1.50 2000/09/22 20:35:11 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdlib.h>		/* for qsort */
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/BulletinBP.h>
 #include <Xm/SeparatorP.h>
 #include <Xm/SeparatoGP.h>
 #include <Xm/RowColumnP.h>
-#include <X11/Xfuncs.h>
-#include <stdlib.h>		/* for qsort */
 
 #include <XmI/DebugUtil.h>
 
@@ -169,7 +171,7 @@ FitBoxesProportional(XmKidGeometry boxes, Dimension box_count,
     }
     else
     {
-	tmp = -fill_wd;
+	tmp = box_wd -fill_wd;
 
 	if (tmp > box_count && box_count > 0)
 	{
@@ -714,7 +716,7 @@ _XmGeoStretchVertical(XmGeoMatrix geoSpec, Dimension height, Dimension maxh)
 /*
  * also called from arrange boxes
  */
-Dimension
+static Dimension
 _XmGeoFillVertical(XmGeoMatrix geoSpec, Dimension height, Dimension maxh)
 {
     register XmGeoRowLayout layout;
@@ -739,24 +741,30 @@ _XmGeoFillVertical(XmGeoMatrix geoSpec, Dimension height, Dimension maxh)
 	layout++;
     }
 
-    fill = ((int)maxh - (int)height) / stretch;
+    fill = (10 * ((int)maxh - (int)height)) / (stretch + 1);
 
     layout = &(geoSpec->layouts->row);
     boxPtr = geoSpec->boxes;
 
     fill_used = 0;
-    while (!layout->end)
+    if (fill > 0)
     {
-	while (boxPtr->kid)
+    int i = 1;
+
+	while (!layout->end)
 	{
-	    boxPtr->box.y += fill_used;
+	    while (boxPtr->kid)
+	    {
+		boxPtr->box.y += ((i * fill) / 10);
+		boxPtr++;
+	    }
+
 	    boxPtr++;
+	    fill_used += (fill / 10);
+
+	    layout++;
+	    i++;
 	}
-
-	boxPtr++;
-	fill_used += fill;
-
-	layout++;
     }
 
     return height + fill_used;
@@ -891,7 +899,11 @@ _XmGeoArrangeBoxes(XmGeoMatrix geoSpec,
 
     y -= oy;
 
-    if (*pH != 0 && *pH > y)
+    /* thumpers FFT dialog when shrinking it */
+    /* messagebox/test20 */
+    /* messagebox/test3 */
+
+    if (*pH != 0 /*&& *pH > y*/)
     {
 	if (geoSpec->stretch_boxes)
 	{
@@ -944,8 +956,11 @@ _XmGeoBoxesSameWidth(XmKidGeometry rowPtr,
 	    }
 	    boxes++;
 	}
+	if (width > 1)
+	{
+	    wd += width;
+	}
     }
-    wd += width;
 
     DEBUGOUT(XdbDebug0(__FILE__, NULL, " %i", wd));
     boxes = rowPtr;
@@ -989,8 +1004,11 @@ _XmGeoBoxesSameHeight(XmKidGeometry rowPtr,
 	    }
 	    boxes++;
 	}
+	if (height > 1)
+	{
+	    ht += height;
+	}
     }
-    ht += height;
 
     DEBUGOUT(XdbDebug0(__FILE__, NULL, " %i", ht));
     boxes = rowPtr;
@@ -1351,6 +1369,19 @@ _XmGeoMatrixGet(XmGeoMatrix geoSpec,
 
 	if (boxPtr->kid == geoSpec->instigator)
 	{
+#if 1
+	    /* rws 22 Apr 1998
+	       messagebox/test19
+	     */
+	    if (layoutPtr->even_width > 1)
+	    {
+		boxPtr->box.width -= layoutPtr->even_width;
+	    }
+	    if (layoutPtr->even_height > 1)
+	    {
+		boxPtr->box.height -= layoutPtr->even_height;
+	    }
+#endif
 	    geoSpec->in_layout = &boxPtr->box;
 	}
 
@@ -1495,7 +1526,7 @@ Boolean
 _XmGeoSetupKid(XmKidGeometry geo,
 	       Widget kidWid)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(kidWid), kidWid, "_XmGeoSetupKid\n"));
+    DEBUGOUT(XdbDebug2(__FILE__, kidWid ? XtParent(kidWid) : NULL, kidWid, "_XmGeoSetupKid\n"));
 
     if (!kidWid)
     {
@@ -1524,7 +1555,7 @@ _XmGeometryEqual(Widget wid,
     	XdbWidgetGeometry2String(geoA),
     	XdbWidgetGeometry2String(geoB)));
 
-    return (bcmp(geoA, geoB, sizeof(XtWidgetGeometry)) == 0);
+    return (memcmp(geoA, geoB, sizeof(XtWidgetGeometry)) == 0);
 }
 
 /*
@@ -1917,9 +1948,10 @@ _XmHandleGeometryManager(Widget w,
     XtGeometryResult res = XtGeometryNo;
     XtWidgetGeometry want;
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, instigator, "_XmHandleGeometryManager\n"));
+    DEBUGOUT(XdbDebug2(__FILE__, w, instigator, "_XmHandleGeometryManager (%s)\n",
+    	XdbWidgetGeometry2String(desired)));
 
-    bzero((void *)&want, sizeof(XtWidgetGeometry));
+    memset((void *)&want, 0, sizeof(XtWidgetGeometry));
 
     if (cachePtr && *cachePtr)
     {
@@ -1988,32 +2020,46 @@ _XmHandleGeometryManager(Widget w,
     switch (res)
     {
     case XtGeometryYes:
-	if (_XmGeometryEqual(instigator, desired, cache->in_layout))
+	if (cache->in_layout)
 	{
-	    if (desired->request_mode & XtCWQueryOnly)
+	    if (_XmGeometryEqual(instigator, desired, cache->in_layout))
 	    {
-		cache->parent_request = want;
-		*allowed = *cache->in_layout;
-		*cachePtr = cache;
+		if (desired->request_mode & XtCWQueryOnly)
+		{
+		    cache->parent_request = want;
+		    *allowed = *cache->in_layout;
+		    *cachePtr = cache;
+		}
+		else
+		{
+		    want.request_mode &= ~XtCWQueryOnly;
+
+		    _XmMakeGeometryRequest(cache->composite, &want);
+
+		    *allowed = *cache->in_layout;
+
+		    _XmGeoMatrixSet(cache);
+		    _XmGeoMatrixFree(cache);
+
+		    *cachePtr = NULL;
+		}
 	    }
 	    else
 	    {
-		want.request_mode &= ~XtCWQueryOnly;
-
-		_XmMakeGeometryRequest(cache->composite, &want);
-
+		res = XtGeometryAlmost;
 		*allowed = *cache->in_layout;
-
-		_XmGeoMatrixSet(cache);
-		_XmGeoMatrixFree(cache);
-
-		*cachePtr = NULL;
 	    }
 	}
 	else
 	{
-	    res = XtGeometryAlmost;
-	    *allowed = *cache->in_layout;
+	    /* rws 1 Jul 1999 (Canada Day)
+	       selectionbox/test10 deals with this case. The list gets
+	       un-managed and therefore the instigator, which is the SW,
+	       never gets into the GeoMatrix.
+	     */
+	    res = XtGeometryNo;
+	    _XmGeoMatrixFree(cache);
+	    *cachePtr = NULL;
 	}
 	break;
 
@@ -2102,7 +2148,19 @@ _XmMakeGeometryRequest(Widget w,
 	 * proposed just a second (or so) before, we'll cry as loud
 	 * as we can (hoping no one has set the sink to /dev/null...)
 	 */
-	bcopy(&response, desired, sizeof(XtWidgetGeometry));
+	/*
+	memcpy(desired, &response, sizeof(XtWidgetGeometry));
+	*/
+	*desired = response;
+
+#if 1
+	/* rws 31 Jan 1999
+	   grok is causing an X error when you start it up with the name
+	   of a database.  This protects against that.
+	 */
+	desired->width = desired->width == 0 ? 1 : desired->width;
+	desired->height = desired->height == 0 ? 1 : desired->height;
+#endif
 
 	g2 = *desired;
 
@@ -2796,20 +2854,10 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
     Boolean		adjust;
     XtWidgetGeometry	instgeo;
 
-#if 0
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmGMHandleGeometryManager\n"));
-#endif
     DEBUGOUT(XdbDebug2(__FILE__, w, instigator,
-		       "_XmGMHandleGeometryManager (desired "));
-    if (Wants(CWX))
-	DEBUGOUT(XdbDebug0(__FILE__, w, "X %d ", desired->x));
-    if (Wants(CWY))
-	DEBUGOUT(XdbDebug0(__FILE__, w, "Y %d ", desired->y));
-    if (Wants(CWWidth))
-	DEBUGOUT(XdbDebug0(__FILE__, w, "W %d ", desired->width));
-    if (Wants(CWHeight))
-	DEBUGOUT(XdbDebug0(__FILE__, w, "H %d ", desired->height));
-    DEBUGOUT(XdbDebug0(__FILE__, w, ")\n"));
+		       "%s:_XmGMHandleGeometryManager(%d) desired (%s)\n",
+		       __FILE__, __LINE__,
+		       XdbWidgetGeometry2String(desired)));
 
     /* Save instigator's geometry */
     instgeo.x = XtX(instigator);
@@ -2869,7 +2917,9 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
     /*
      * if we don't fit in the MarginWidth/MarginHeight bounding box, say no
      */
-    if (x < margin_width || x + width > XtWidth(w) - margin_width)
+    allowed->request_mode = CWHeight;
+    allowed->height = 1;
+    if (x < margin_width || x + width + 2 * XtBorderWidth(instigator) > XtWidth(w) - margin_width)
     {
 	DEBUGOUT(XdbDebug2(__FILE__, w, instigator,
 		"\tx %d margin_width %d width %d XtWidth(w) %d\n",
@@ -2887,7 +2937,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 	return XtGeometryNo;
     }
 
-    if (y < margin_height || y + height > XtHeight(w) - margin_height)
+    if (y < margin_height || y + height + 2 * XtBorderWidth(instigator) > XtHeight(w) - margin_height)
     {
 	DEBUGOUT(XdbDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
@@ -2902,7 +2952,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 	return XtGeometryNo;
     }
 
-    if (XtWidth(w) < width + 2 * margin_width)
+    if (XtWidth(w) < width + 2 * (margin_width + XtBorderWidth(instigator)))
     {
 	DEBUGOUT(XdbDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
@@ -2917,7 +2967,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 	return XtGeometryNo;
     }
 
-    if (XtHeight(w) < height + 2 * margin_height)
+    if (XtHeight(w) < height + 2 * (margin_height + XtBorderWidth(instigator)))
     {
 	DEBUGOUT(XdbDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
