@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Hash.c,v 1.6 1999/02/02 18:23:11 gritton Exp $
+ * $Id: Hash.c,v 1.8 2000/09/22 20:35:11 amai Exp $
  *
  * Copyright (C) 1995-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -24,9 +25,10 @@
 
 #include <LTconfig.h>
 
+#include <string.h>
+
 #include <XmI/XmI.h>
 #include <XmI/HashI.h>
-#include <X11/Xfuncs.h>
 
 /*
  * This is a general-purpose hash table module. It can be used to implement
@@ -345,7 +347,7 @@ LTHashTableAddItem(LTHashTable ht,
 	    else
 	    {
 		Bucket->ItemID = (LTHashItemID) XtMalloc(ht->IDSize);
-		bcopy(id, Bucket->ItemID, ht->IDSize);
+		memcpy(Bucket->ItemID, id, ht->IDSize);
 	    }
 	}
 	else
@@ -408,7 +410,7 @@ LTHashTableReplaceItem(LTHashTable ht,
 	    else
 	    {
 		Bucket->ItemID = (LTHashItemID) XtMalloc(ht->IDSize);
-		bcopy(id, Bucket->ItemID, ht->IDSize);
+		memcpy(Bucket->ItemID, id, ht->IDSize);
 	    }
 	}
 	else
@@ -477,7 +479,7 @@ LTHashTableReplaceItemAndID(LTHashTable ht,
 	    else
 	    {
 		Bucket->ItemID = (LTHashItemID) XtMalloc(ht->IDSize);
-		bcopy(id, Bucket->ItemID, ht->IDSize);
+		memcpy(Bucket->ItemID, id, ht->IDSize);
 	    }
 	}
 	else
@@ -513,7 +515,7 @@ LTHashTableReplaceItemAndID(LTHashTable ht,
 	else
 	{
 	    Bucket->ItemID = (LTHashItemID) XtMalloc(ht->IDSize);
-	    bcopy(id, Bucket->ItemID, ht->IDSize);
+	    memcpy(Bucket->ItemID, id, ht->IDSize);
 	}
     }
     else
