@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ImageCache.c,v 1.19 2000/08/08 22:21:08 danny Exp $
+ * $Id: ImageCache.c,v 1.21 2000/11/07 20:33:28 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,31 +23,32 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ImageCache.c,v 1.19 2000/08/08 22:21:08 danny Exp $";
+static const char rcsid[] = "$Id: ImageCache.c,v 1.21 2000/11/07 20:33:28 amai Exp $";
 
 /*
  * --aldi 97/01/11: changed to use the generic hashtable module.
  */
 #include <LTconfig.h>
-#include <XmI/XmI.h>
-#include <XmI/HashI.h>
-#include <X11/Xfuncs.h>
-#include <XmI/ImageCacheI.h>
-#include <Xm/XmosP.h>
 
-#include <Xm/XmP.h>
-#include <Xm/ScreenP.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include <XmI/DebugUtil.h>
+#include <XmI/XmI.h>
+#include <XmI/HashI.h>
+#include <XmI/ImageCacheI.h>
+#include <Xm/XmosP.h>
+#include <Xm/XmP.h>
+#include <Xm/ScreenP.h>
+
 #if XmVERSION >= 2
 #include <Xm/XpmP.h>
 #else
 #include <XmI/XmXpm.h>
 #endif
 
+#include <XmI/DebugUtil.h>
+
 /*
  * The actual caches for images and for pixmaps... we now use the generic
  * hash table module in Hash.c. We don't need to re-invent the wheel every
@@ -245,7 +247,7 @@ _XmGetImage(Screen *screen, char *image_name, XImage **image)
  * A pixmap caching function that generates a pixmap, stores it in a pixmap
  * cache and returns the pixmap.
  */
-Pixmap
+extern Pixmap
 XmGetPixmap(Screen *screen, char *image_name,
 	    Pixel foreground, Pixel background)
 {
@@ -266,7 +268,7 @@ XmGetPixmap(Screen *screen, char *image_name,
  * Almost the same as XmGetPixmap() above, but this time the programmer can
  * even control the depth of the pixmap she/he wants.
  */
-Pixmap
+extern Pixmap
 XmGetPixmapByDepth(Screen *screen, char *image_name,
 		   Pixel foreground, Pixel background, int depth)
 {
@@ -550,10 +552,11 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     return new_pix;
 }
 
+
 /*
  * Removes a pixmap from the pixmap cache.
  */
-Boolean
+extern Boolean
 XmDestroyPixmap(Screen *screen, Pixmap pixmap)
 {
     LTPixmapDescRec PixmapDesc;
@@ -594,6 +597,7 @@ XmDestroyPixmap(Screen *screen, Pixmap pixmap)
     return False;
 }
 
+
 /*
  * This one is going to be obsolete in Motif 2.0...
  */
@@ -1060,7 +1064,7 @@ LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
 }
 
 
-void
+extern void
 LTCreateSearchPath(void)
 {
     char *XBMLANGPATH = XtNewString((String)getenv("XBMLANGPATH"));
@@ -1110,3 +1114,21 @@ LTCreateSearchPath(void)
     DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "Using %s for search path\n", _search_path));
 }
+
+
+#if XmVERSION >= 2
+extern XtEnum 
+XmGetScaledPixmap(Widget widget,
+                  String image_name,
+                  Pixel foreground,
+                  Pixel background,
+                  int depth,
+                  double scaling_ratio)
+{
+   if (!widget || !image_name)
+      return 0;
+
+   _XmWarning(NULL, "XmGetScaledPixmap() is not yet implemented!");
+   return 0;
+}
+#endif
