@@ -1,8 +1,9 @@
 /**
  *
- * $Id: LTCvt.c,v 1.10 2000/08/08 22:21:08 danny Exp $
+ * $Id: LTCvt.c,v 1.15 2000/09/27 12:26:58 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,30 +23,28 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTCvt.c,v 1.10 2000/08/08 22:21:08 danny Exp $";
-
-#ifdef NONSTANDARD_CONVERTERS 
+static const char rcsid[] = "$Id: LTCvt.c,v 1.15 2000/09/27 12:26:58 amai Exp $";
 
 #include <LTconfig.h>
+
+#ifdef NONSTANDARD_CONVERTERS
+
+#include <stdio.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 #include <XmI/HashI.h>
-#include <X11/Xfuncs.h>
 #include <XmI/ImageCacheI.h>
-
 #include <Xm/XmP.h>
 #include <Xm/ScreenP.h>
-
 #if XmVERSION >= 2
-#include <Xm/Xpm.h>
+#include <Xm/XpmP.h>
 #else
 #include <XmI/XmXpm.h>
 #endif
 
 #include <XmI/DebugUtil.h>
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 
 static char *_search_path = NULL;
 
@@ -56,6 +55,52 @@ extern Boolean LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap,
 				  int depth, int width, int height,
 				  int hot_x, int hot_y);
 
+
+/* Prototypes to ensure proper type for the definitions below: */
+static Boolean
+_XmNSECvtStringToBitmap
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtStringToPixmap
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtShapeStyleToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtBooleanToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtBoolToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtAttachmentToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtPositionToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtCardinalToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtPixelToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtColorToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtUnsignedCharToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtDimensionToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtXmStringToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+static Boolean
+_XmNSECvtWidgetToString
+(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+
+
 /*
  * _XmNSEGetPixmap is not part of the OSF/Motif API.
  * This routine is used with the string to pixmap converter
@@ -171,6 +216,21 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
     return pmap;
 }
 
+
+static Boolean
+_XmNSECvtStringToBitmap(Display *dpy,
+		        XrmValue *args,
+		        Cardinal *num_args,
+		        XrmValue *from,
+		        XrmValue *to,
+		        XtPointer *converter_data)
+
+{
+fprintf(stderr, "_XmNSECvtStringToBitmap(from=%s) called\n",
+        (char *)from->addr);
+  return False;
+}
+
 /*
  * _XmNSECvtStringToPixmap is not part of the OSF/Motif API.
  * This routine is used to convert a string to a pixmap.
@@ -239,8 +299,6 @@ _XmNSECvtStringToPixmap(Display *dpy,
 	}
     }
 
-    converter_data = converter_data;	/* keeps compiler happy */
-
     return True;
 }
 
@@ -268,8 +326,7 @@ typedef struct
     int value;
     char *name;
     int size;
-}
-ConversionMap;
+} ConversionMap;
 
 static ConversionMap boolean_map[] =
 {
@@ -407,7 +464,7 @@ _XmNSECvtAttachmentToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
 {
     int size;
-    char *buffer;
+    const char *buffer;
 
     if (*numArgs != 0)
     {
@@ -417,6 +474,7 @@ _XmNSECvtAttachmentToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			(String *)NULL, (Cardinal *)NULL);
     }
 
+    /* buffer must not be freed! */
     buffer = XdbAttachment2String(*(Position *)fromVal->addr);
     size = strlen(buffer);
     string_convert_done(buffer);
@@ -587,11 +645,38 @@ _XmNSECvtXmStringToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 	/* There's a memory leak here : nobody does free(s) */
 	size = strlen(s);
 	string_convert_done(s);
-    }
-    return False;		/* Conversion failed */
+    } 
+    else
+       return False;		/* Conversion failed */
 }
 
-/* this is needed for the string to pixmap converter */
+static Boolean
+_XmNSECvtWidgetToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
+			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
+{
+    int size;
+    Widget w;
+    static char *s = NULL; /* amai: a small(?) memory leak - see below */
+
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmNSECvtWidgetToString\n"));
+
+    if (*numArgs != 0)
+    {
+	XtAppWarningMsg(XtDisplayToApplicationContext(dpy),
+		 XtNwrongParameters, "cvtWidgetToString", XtCXtToolkitError,
+		      "Widget to String conversion needs extra arguments",
+			(String *)NULL, (Cardinal *)NULL);
+    }
+
+    if (s)
+      XtFree(s);
+    w = *(Widget *)fromVal->addr;
+    s = XtNewString(XtName(w));
+    size = strlen(s);
+    string_convert_done(s);
+}
+
+/* this is needed for the string to pixmap converters */
 static XtConvertArgRec args[] =
 {
     {
@@ -607,23 +692,30 @@ static XtConvertArgRec args[] =
 void
 _XmRegisterNSEConverters(void)
 {
-#if 1
     XtSetTypeConverter(XmRString,	/* source type */
 		       XmRPixmap,	/* target type */
 		       _XmNSECvtStringToPixmap,	/* converter routine */
-		       args,	/* args for converter routine */
+		       args,		/* args for converter routine */
 		       XtNumber(args),	/* number of args for converter */
 		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+		       NULL);		/* destructor function */
+#if 0
+/* amai: see thread about DragIcon/Ishmail */
+    XtSetTypeConverter(XmRString,
+		       XmRBitmap,
+		       _XmNSECvtStringToBitmap,
+		       args,
+		       XtNumber(args),
+		       XtCacheNone,
+		       NULL);
 #endif
-
-    XtSetTypeConverter(XmRString,	/* source type */
-		       XmRXmBackgroundPixmap,	/* target type */
-		       _XmNSECvtStringToPixmap,	/* converter routine */
-		       args,	/* args for converter routine */
-		       XtNumber(args),	/* number of args for converter */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+    XtSetTypeConverter(XmRString,
+		       XmRXmBackgroundPixmap,
+		       _XmNSECvtStringToPixmap,
+		       args,
+		       XtNumber(args),
+		       XtCacheNone,
+		       NULL);
 
     /* Converters for reverse-direction Editres below */
     XtSetTypeConverter(XtRShapeStyle, XtRString, _XmNSECvtShapeStyleToString,
@@ -657,6 +749,8 @@ _XmRegisterNSEConverters(void)
 		       NULL, 0, XtCacheNone, NULL);
     XtSetTypeConverter(XmRXmString, XtRString, _XmNSECvtXmStringToString,
 		       NULL, 0, XtCacheNone, NULL);
+    XtSetTypeConverter(XmRWidget, XtRString, _XmNSECvtWidgetToString,
+		       NULL, 0, XtCacheNone, NULL);
 }
 
 #endif /* NONSTANDARD_CONVERTERS */
