@@ -32,8 +32,11 @@
  */
 
 #include <LTconfig.h>
+
+#include <stdio.h>
+#include <string.h>
+
 #include <XmI/DebugUtil.h>
-#include <X11/Xfuncproto.h>
 #include <X11/IntrinsicP.h>	/* To get into the composite and core widget
 				   structures. */
 #include <X11/ObjectP.h>	/* For XtIs<Classname> macros. */
@@ -41,12 +44,26 @@
 #include <X11/ShellP.h>		/* for Application Shell Widget class. */
 
 #include <X11/Xatom.h>
-#include <X11/Xos.h>		/* for strcpy declaration */
-#include <XmI/LTV6EditresP.h>
 #include <X11/Xmd.h>
 #include <Xm/XmP.h>
+#include <XmI/LTV6EditresP.h>
+
+
+/* local prototypes */
+static void _LesstifEditResPutString8(ProtocolStream *stream, char *str);
+static void _LesstifEditResPut8(ProtocolStream *stream, unsigned int value);
+static void _LesstifEditResPut16(ProtocolStream *stream, unsigned int value);
+static void _LesstifEditResPut32(ProtocolStream *stream, unsigned long value);
+static void _LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info);
+static void _LesstifEditResResetStream(ProtocolStream *stream);
+
+static Boolean _LesstifEditResGet8(ProtocolStream *stream, unsigned char *val);
+static Boolean _LesstifEditResGet16(ProtocolStream *stream, unsigned short *val);
+static Boolean _LesstifEditResGetSigned16(ProtocolStream *stream, short *val);
+static Boolean _LesstifEditResGet32(ProtocolStream *stream, unsigned long *val);
+static Boolean _LesstifEditResGetString8(ProtocolStream *stream, char **str);
+static Boolean _LesstifEditResGetWidgetInfo(ProtocolStream *stream, WidgetInfo *info);
 
-#include <stdio.h>
 
 #define _LesstifEditResPutBool _LesstifEditResPut8
 #define _LesstifEditResPutResourceType _LesstifEditResPut8
@@ -156,16 +173,35 @@ static Atom res_editor_command, res_editor_protocol, client_value;
 
 static Globals globals;
 
-static void SendFailure(), SendCommand(), InsertWidget(), ExecuteCommand();
-static void FreeEvent(), ExecuteSetValues(), ExecuteGetGeometry();
-static void ExecuteGetResources();
+static void SendFailure(Widget w, Atom sel, ResIdent ident, char *str);
+static void SendCommand(Widget w, Atom sel, ResIdent ident,
+			EditresCommand command, ProtocolStream *stream);
+static void InsertWidget(ProtocolStream * stream, Widget w);
+static void ExecuteCommand(Widget w, Atom sel, ResIdent ident,
+			   EditresEvent * event);
+static void FreeEvent(EditresEvent *event);
+static void ExecuteSetValues(Widget w, SetValuesEvent *sv_event,
+			     WidgetInfo *entry, ProtocolStream *stream,
+			     unsigned short *count);
+static void ExecuteGetGeometry(Widget w, ProtocolStream *stream);
+static void ExecuteGetResources(Widget w, ProtocolStream *stream);
 
-static void GetCommand();
-static void LoadResources();
-static Boolean IsChild();
-static void DumpChildren();
-static char *DumpWidgets(), *DoSetValues(), *DoFindChild();
-static char *DoGetGeometry(), *DoGetResources(), *DumpValues();
+static void GetCommand(Widget w, XtPointer data, Atom *selection, Atom *type,
+		       XtPointer value, unsigned long *length, int *format);
+static void LoadResources(Widget w);
+static void DumpChildren(Widget w, ProtocolStream *stream,
+			 unsigned short *count);
+static char *DumpWidgets(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoSetValues(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoFindChild(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoGetGeometry(Widget w, EditresEvent *event,
+			   ProtocolStream *stream);
+static char *DoGetResources(Widget w, EditresEvent *event,
+			    ProtocolStream *stream);
+static char *DumpValues(Widget w, EditresEvent *event, ProtocolStream *stream);
 
 #if XtSpecificationRelease < 6
 static Status
@@ -226,12 +262,11 @@ XmuCopyISOLatin1Lowered(char *dst, XmConst char *src)
  */
 
 /* ARGSUSED */
-void
-_XmNSEEditResCheckMessages(w, data, event, cont)
-     Widget w;
-     XtPointer data;
-     XEvent *event;
-     Boolean *cont;
+extern void
+_XmNSEEditResCheckMessages(Widget w,
+                           XtPointer data, 
+                           XEvent *event,
+                           Boolean *cont)
 {
     Time time;
     ResIdent ident;
@@ -278,7 +313,7 @@ _XmNSEEditResCheckMessages(w, data, event, cont)
 	}
 
 	XtGetSelectionValue(w, res_comm, res_editor_command,
-			    GetCommand, (XtPointer)((unsigned)ident), time);
+			    GetCommand, (XtPointer)(unsigned long)ident, time);
     }
 }
 
@@ -296,12 +331,8 @@ _XmNSEEditResCheckMessages(w, data, event, cont)
 #define ERROR_MESSAGE ("Client: Improperly formatted protocol request")
 
 static EditresEvent *
-BuildEvent(w, sel, data, ident, length)
-     Widget w;
-     Atom sel;
-     XtPointer data;
-     ResIdent ident;
-     unsigned long length;
+BuildEvent(Widget w, Atom sel, XtPointer data, ResIdent ident,
+	   unsigned long length)
 {
     EditresEvent *event;
     ProtocolStream alloc_stream, *stream;
@@ -319,7 +350,7 @@ BuildEvent(w, sel, data, ident, length)
 
     if (length < HEADER_SIZE)
     {
-	SendFailure(w, sel, ident, Failure, ERROR_MESSAGE);
+	SendFailure(w, sel, ident, ERROR_MESSAGE);
 	return (NULL);
     }
 
@@ -461,8 +492,7 @@ BuildEvent(w, sel, data, ident, length)
  */
 
 static void
-FreeEvent(event)
-     EditresEvent *event;
+FreeEvent(EditresEvent *event)
 {
     if (event->any_event.widgets != NULL)
     {
@@ -489,14 +519,10 @@ FreeEvent(event)
 
 /* ARGSUSED */
 static void
-GetCommand(w, data, selection, type, value, length, format)
-     Widget w;
-     XtPointer data, value;
-     Atom *selection, *type;
-     unsigned long *length;
-     int *format;
+GetCommand(Widget w, XtPointer data, Atom *selection, Atom *type,
+	   XtPointer value, unsigned long *length, int *format)
 {
-    ResIdent ident = (ResIdent)((unsigned)data);
+    ResIdent ident = (ResIdent)(unsigned long)data;
     EditresEvent *event;
 
     if ((*type != res_editor_protocol) || (*format != EDITRES_FORMAT))
@@ -522,13 +548,9 @@ GetCommand(w, data, selection, type, value, length, format)
 
 /* ARGSUSED */
 static void
-ExecuteCommand(w, sel, ident, event)
-     Widget w;
-     Atom sel;
-     ResIdent ident;
-     EditresEvent *event;
+ExecuteCommand(Widget w, Atom sel, ResIdent ident, EditresEvent * event)
 {
-    char *(*func) ();
+    char *(*func)(Widget, EditresEvent *, ProtocolStream *);
     char *str;
 
     if (globals.block == BlockAll)
@@ -601,13 +623,9 @@ ExecuteCommand(w, sel, ident, event)
 
 /* ARGSUSED */
 static Boolean
-ConvertReturnCommand(w, selection, target,
-		     type_ret, value_ret, length_ret, format_ret)
-     Widget w;
-     Atom *selection, *target, *type_ret;
-     XtPointer *value_ret;
-     unsigned long *length_ret;
-     int *format_ret;
+ConvertReturnCommand(Widget w, Atom *selection, Atom *target, Atom *type_ret,
+		     XtPointer *value_ret, unsigned long *length_ret,
+		     int *format_ret)
 {
     /*
      * I assume the intrinsics give me the correct selection back.
@@ -632,10 +650,7 @@ ConvertReturnCommand(w, selection, target,
 
 /* ARGSUSED */
 static void
-CommandDone(widget, selection, target)
-     Widget widget;
-     Atom *selection;
-     Atom *target;
+CommandDone(Widget widget, Atom *selection, Atom *target)
 {
     /* Keep the toolkit from automaticaly freeing the selection value */
 }
@@ -650,11 +665,7 @@ CommandDone(widget, selection, target)
  */
 
 static void
-SendFailure(w, sel, ident, str)
-     Widget w;
-     Atom sel;
-     ResIdent ident;
-     char *str;
+SendFailure(Widget w, Atom sel, ResIdent ident, char *str)
 {
     _LesstifEditResResetStream(&globals.stream);
     _LesstifEditResPutString8(&globals.stream, str);
@@ -670,10 +681,8 @@ SendFailure(w, sel, ident, str)
  */
 
 static XtPointer
-BuildReturnPacket(ident, command, stream)
-     ResIdent ident;
-     EditresCommand command;
-     ProtocolStream *stream;
+BuildReturnPacket(ResIdent ident, EditresCommand command,
+		  ProtocolStream *stream)
 {
     long old_alloc, old_size;
     unsigned char *old_current;
@@ -718,12 +727,8 @@ BuildReturnPacket(ident, command, stream)
  */
 
 static void
-SendCommand(w, sel, ident, command, stream)
-     Widget w;
-     Atom sel;
-     ResIdent ident;
-     EditresCommand command;
-     ProtocolStream *stream;
+SendCommand(Widget w, Atom sel, ResIdent ident, EditresCommand command,
+	    ProtocolStream *stream)
 {
     BuildReturnPacket(ident, command, stream);
     globals.command_stream = stream;
@@ -755,9 +760,7 @@ SendCommand(w, sel, ident, command, stream)
  */
 
 static int
-FindChildren(parent, children, normal, popup)
-     Widget parent, **children;
-     Boolean normal, popup;
+FindChildren(Widget parent, Widget **children, Boolean normal, Boolean popup)
 {
     CompositeWidget cw = (CompositeWidget)parent;
     int i, num_children, current = 0;
@@ -798,8 +801,7 @@ FindChildren(parent, children, normal, popup)
  */
 
 static Boolean
-IsChild(top, parent, child)
-     Widget top, parent, child;
+IsChild(Widget top, Widget parent, Widget child)
 {
     int i, num_children;
     Widget *children;
@@ -830,9 +832,7 @@ IsChild(top, parent, child)
  */
 
 static char *
-VerifyWidget(w, info)
-     Widget w;
-     WidgetInfo *info;
+VerifyWidget(Widget w, WidgetInfo *info)
 {
     Widget top;
 
@@ -879,10 +879,7 @@ VerifyWidget(w, info)
  */
 
 static char *
-DoSetValues(w, event, stream)
-     Widget w;
-     EditresEvent *event;
-     ProtocolStream *stream;
+DoSetValues(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     char *str;
     register unsigned i;
@@ -927,9 +924,8 @@ DoSetValues(w, event, stream)
 
 /* ARGSUSED */
 static void
-HandleToolkitErrors(name, type, class, msg, params, num_params)
-     String name, type, class, msg, *params;
-     Cardinal *num_params;
+HandleToolkitErrors(String name, String type, String class, String msg,
+		    String *params, Cardinal *num_params)
 {
     SVErrorInfo *info = &globals.error_info;
     char buf[BUFSIZ];
@@ -941,7 +937,7 @@ HandleToolkitErrors(name, type, class, msg, params, num_params)
 	sprintf(buf, msg, params[0]);
     else if (streq(name, "conversionFailed") || streq(name, "conversionError"))
     {
-	if (streq(info->event->value, XtRString))
+	if (streq((char *)info->event->value, XtRString))
 	    sprintf(buf,
 		    "Could not convert the string '%s' for the `%s' resource.",
 		    (char *)info->event->value, info->event->name);
@@ -971,12 +967,8 @@ HandleToolkitErrors(name, type, class, msg, params, num_params)
  */
 
 static void
-ExecuteSetValues(w, sv_event, entry, stream, count)
-     Widget w;
-     SetValuesEvent *sv_event;
-     WidgetInfo *entry;
-     ProtocolStream *stream;
-     unsigned short *count;
+ExecuteSetValues(Widget w, SetValuesEvent *sv_event, WidgetInfo *entry,
+		 ProtocolStream *stream, unsigned short *count)
 {
     XtErrorMsgHandler old;
 
@@ -1017,10 +1009,7 @@ ExecuteSetValues(w, sv_event, entry, stream, count)
 
 /* ARGSUSED */
 static char *
-DumpWidgets(w, event, stream)
-     Widget w;
-     EditresEvent *event;	/* UNUSED */
-     ProtocolStream *stream;
+DumpWidgets(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned short count = 0;
 
@@ -1069,8 +1058,7 @@ DumpWidgets(w, event, stream)
  * class by looking for an explicit class name.  Seems pretty safe.
  */
 static Bool
-isApplicationShell(w)
-     Widget w;
+isApplicationShell(Widget w)
 {
     register WidgetClass c;
 
@@ -1085,10 +1073,7 @@ isApplicationShell(w)
 }
 
 static void
-DumpChildren(w, stream, count)
-     Widget w;
-     ProtocolStream *stream;
-     unsigned short *count;
+DumpChildren(Widget w, ProtocolStream *stream, unsigned short *count)
 {
     int i, num_children;
     Widget *children;
@@ -1146,10 +1131,7 @@ DumpChildren(w, stream, count)
  */
 
 static char *
-DoGetGeometry(w, event, stream)
-     Widget w;
-     EditresEvent *event;
-     ProtocolStream *stream;
+DoGetGeometry(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned i;
     char *str;
@@ -1185,9 +1167,7 @@ DoGetGeometry(w, event, stream)
  */
 
 static void
-ExecuteGetGeometry(w, stream)
-     Widget w;
-     ProtocolStream *stream;
+ExecuteGetGeometry(Widget w, ProtocolStream *stream)
 {
     int i;
     Boolean mapped_when_man;
@@ -1267,9 +1247,7 @@ ExecuteGetGeometry(w, stream)
  */
 
 static Boolean
-PositionInChild(child, x, y)
-     Widget child;
-     int x, y;
+PositionInChild(Widget child, int x, int y)
 {
     Arg args[6];
     Cardinal num;
@@ -1288,6 +1266,11 @@ PositionInChild(child, x, y)
     XtSetArg(args[num], XtNy, &child_y); num++;
     XtSetArg(args[num], XtNborderWidth, &border_width); num++;
     XtGetValues(child, args, num);
+    if (XmIsVendorShell(XtParent(child)))
+    {
+    	child_x = -border_width;
+    	child_y = -border_width;
+    }
 
     /*
      * The only way we will know of the widget is mapped is to see if
@@ -1324,9 +1307,7 @@ PositionInChild(child, x, y)
  */
 
 static Widget
-_FindChild(parent, x, y)
-     Widget parent;
-     int x, y;
+_FindChild(Widget parent, int x, int y)
 {
     Widget *children;
     int i = FindChildren(parent, &children, True, False);
@@ -1358,10 +1339,7 @@ _FindChild(parent, x, y)
  */
 
 static char *
-DoFindChild(w, event, stream)
-     Widget w;
-     EditresEvent *event;
-     ProtocolStream *stream;
+DoFindChild(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     char *str;
     Widget parent, child;
@@ -1398,10 +1376,7 @@ DoFindChild(w, event, stream)
  */
 
 static char *
-DoGetResources(w, event, stream)
-     Widget w;
-     EditresEvent *event;
-     ProtocolStream *stream;
+DoGetResources(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned int i;
     char *str;
@@ -1440,9 +1415,7 @@ DoGetResources(w, event, stream)
  */
 
 static void
-ExecuteGetResources(w, stream)
-     Widget w;
-     ProtocolStream *stream;
+ExecuteGetResources(Widget w, ProtocolStream *stream)
 {
     XtResourceList norm_list, cons_list;
     Cardinal num_norm, num_cons;
@@ -1500,11 +1473,9 @@ ExecuteGetResources(w, stream)
  *    Returns: NULL
  */
 
+/* ARGSUSED */
 static char *
-DumpValues(w, event, stream)	/* ARGSUSED */
-     Widget w;
-     EditresEvent *event;
-     ProtocolStream *stream;
+DumpValues(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     Arg warg[1];
     String res_value = NULL;
@@ -1553,9 +1524,7 @@ DumpValues(w, event, stream)	/* ARGSUSED */
  */
 
 static void
-InsertWidget(stream, w)
-     ProtocolStream *stream;
-     Widget w;
+InsertWidget(ProtocolStream * stream, Widget w)
 {
     Widget temp;
     unsigned long *widget_list;
@@ -1597,10 +1566,8 @@ InsertWidget(stream, w)
  *    Returns: none.
  */
 
-void
-_LesstifEditResPutString8(stream, str)
-     ProtocolStream *stream;
-     char *str;
+static void
+_LesstifEditResPutString8(ProtocolStream *stream, char *str)
 {
     int i, len = strlen(str);
 
@@ -1616,10 +1583,8 @@ _LesstifEditResPutString8(stream, str)
  *    Returns: none
  */
 
-void
-_LesstifEditResPut8(stream, value)
-     ProtocolStream *stream;
-     unsigned int value;
+static void
+_LesstifEditResPut8(ProtocolStream *stream, unsigned int value)
 {
     unsigned char temp;
 
@@ -1645,10 +1610,8 @@ _LesstifEditResPut8(stream, value)
  *    Returns: void
  */
 
-void
-_LesstifEditResPut16(stream, value)
-     ProtocolStream *stream;
-     unsigned int value;
+static void
+_LesstifEditResPut16(ProtocolStream *stream, unsigned int value)
 {
     _LesstifEditResPut8(stream, (value >> XER_NBBY) & BYTE_MASK);
     _LesstifEditResPut8(stream, value & BYTE_MASK);
@@ -1661,10 +1624,8 @@ _LesstifEditResPut16(stream, value)
  *    Returns: void
  */
 
-void
-_LesstifEditResPut32(stream, value)
-     ProtocolStream *stream;
-     unsigned long value;
+static void
+_LesstifEditResPut32(ProtocolStream *stream, unsigned long value)
 {
     int i;
 
@@ -1679,10 +1640,8 @@ _LesstifEditResPut32(stream, value)
  *    Returns: none
  */
 
-void
-_LesstifEditResPutWidgetInfo(stream, info)
-     ProtocolStream *stream;
-     WidgetInfo *info;
+static void
+_LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
 
@@ -1703,9 +1662,8 @@ _LesstifEditResPutWidgetInfo(stream, info)
  *    Returns: none.
  */
 
-void
-_LesstifEditResResetStream(stream)
-     ProtocolStream *stream;
+static void
+_LesstifEditResResetStream(ProtocolStream *stream)
 {
     stream->current = stream->top;
     stream->size = 0;
@@ -1736,10 +1694,8 @@ _LesstifEditResResetStream(stream)
  *    Returns: True if sucessful.
  */
 
-Boolean
-_LesstifEditResGet8(stream, val)
-     ProtocolStream *stream;
-     unsigned char *val;
+static Boolean
+_LesstifEditResGet8(ProtocolStream *stream, unsigned char *val)
 {
     if (stream->size < (stream->current - stream->top))
 	return (False);
@@ -1756,10 +1712,8 @@ _LesstifEditResGet8(stream, val)
  *    Returns: True if sucessful.
  */
 
-Boolean
-_LesstifEditResGet16(stream, val)
-     ProtocolStream *stream;
-     unsigned short *val;
+static Boolean
+_LesstifEditResGet16(ProtocolStream *stream, unsigned short *val)
 {
     unsigned char temp1, temp2;
 
@@ -1778,10 +1732,8 @@ _LesstifEditResGet16(stream, val)
  *      Returns: True if sucessful.
  */
 
-Boolean
-_LesstifEditResGetSigned16(stream, val)
-     ProtocolStream *stream;
-     short *val;
+static Boolean
+_LesstifEditResGetSigned16(ProtocolStream *stream, short *val)
 {
     unsigned char temp1, temp2;
 
@@ -1809,10 +1761,8 @@ _LesstifEditResGetSigned16(stream, val)
  *    Returns: True if sucessful.
  */
 
-Boolean
-_LesstifEditResGet32(stream, val)
-     ProtocolStream *stream;
-     unsigned long *val;
+static Boolean
+_LesstifEditResGet32(ProtocolStream *stream, unsigned long *val)
 {
     unsigned short temp1, temp2;
 
@@ -1832,10 +1782,8 @@ _LesstifEditResGet32(stream, val)
  *    Returns: True if retrieval was successful.
  */
 
-Boolean
-_LesstifEditResGetString8(stream, str)
-     ProtocolStream *stream;
-     char **str;
+static Boolean
+_LesstifEditResGetString8(ProtocolStream *stream, char **str)
 {
     unsigned short len;
     register unsigned i;
@@ -1868,10 +1816,8 @@ _LesstifEditResGetString8(stream, str)
  *    Returns: True if retrieval was successful.
  */
 
-Boolean
-_LesstifEditResGetWidgetInfo(stream, info)
-     ProtocolStream *stream;
-     WidgetInfo *info;
+static Boolean
+_LesstifEditResGetWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
 
@@ -1912,12 +1858,9 @@ _LesstifEditResGetWidgetInfo(stream, info)
 
 /* ARGSUSED */
 static Boolean
-CvtStringToBlock(dpy, args, num_args, from_val, to_val, converter_data)
-     Display *dpy;
-     XrmValue *args;
-     Cardinal *num_args;
-     XrmValue *from_val, *to_val;
-     XtPointer *converter_data;
+CvtStringToBlock(Display *dpy, XrmValue *args, Cardinal *num_args,
+		 XrmValue *from_val, XrmValue *to_val,
+		 XtPointer *converter_data)
 {
     char ptr[BUFSIZ];
     static EditresBlock block;
@@ -1969,8 +1912,7 @@ CvtStringToBlock(dpy, args, num_args, from_val, to_val, converter_data)
  */
 
 static void
-LoadResources(w)
-     Widget w;
+LoadResources(Widget w)
 {
     static XtResource resources[] =
     {
