@@ -1,10 +1,11 @@
 /**
- * $Id: LTglob.c,v 1.11 2000/08/29 16:35:12 amai Exp $
+ * $Id: LTglob.c,v 1.19 2000/10/14 19:08:53 amai Exp $
  *
  * derived from GNU libc glob.c
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1991, 1992, 1993 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -24,24 +25,24 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTglob.c,v 1.11 2000/08/29 16:35:12 amai Exp $";
+static const char rcsid[] = "$Id: LTglob.c,v 1.19 2000/10/14 19:08:53 amai Exp $";
 
 #if defined (_AIX) && !defined (__GNUC__)
 #pragma alloca
 #endif
 
 #include <LTconfig.h>
-#include <X11/Intrinsic.h>
-#include <X11/Xfuncs.h>
 
+#include <stdlib.h>      /* -> qsort() */
+#include <string.h>
 #include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <stdio.h>
-
-
-#ifdef STDC_HEADERS
 #include <stddef.h>
+
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
 #endif
 
 #ifdef HAVE_UNISTD_H
@@ -53,14 +54,7 @@ static const char rcsid[] = "$Id: LTglob.c,v 1.11 2000/08/29 16:35:12 amai Exp $
 #endif
 #endif
 
-#if !defined(__GNU_LIBRARY__) && !defined(STDC_HEADERS)
-extern int errno;
-#endif
-
-#ifndef	NULL
-#define	NULL	0
-#endif
-
+#include <X11/Intrinsic.h>  /* for Xt*alloc() */
 
 #if	defined (POSIX) || defined (HAVE_DIRENT_H) || defined (__GNU_LIBRARY__)
 #include <dirent.h>
@@ -91,59 +85,6 @@ extern int errno;
 #define REAL_DIR_ENTRY(dp) (dp->d_ino != 0)
 #endif /* POSIX */
 
-#if	(defined (STDC_HEADERS) || defined (__GNU_LIBRARY__))
-#include <stdlib.h>
-#include <string.h>
-#define	ANSI_STRING
-#else /* No standard headers.  */
-
-#ifdef HAVE_STRING_H
-#include <string.h>
-#define	ANSI_STRING
-#else
-#include <strings.h>
-#endif
-#ifdef	HAVE_MEMORY_H
-#include <memory.h>
-#endif
-
-extern void qsort();
-
-#endif /* Standard headers.  */
-
-#ifdef __EMX__   /* -> OS/2 drive letters support */
-#define  INCL_DOS
-#define  INCL_DOSMISC
-#define  INCL_ERRORS
-#include <os2.h>
-static const char *GetDriveMap(void); /* local prototype */
-#endif
-
-#ifndef	HAVE_STRCOLL
-#define	strcoll	strcmp
-#endif
-
-
-#if 0
-#ifndef	__GNU_LIBRARY__
-#ifdef	__GNUC__
-__inline
-#endif
-static void *
-my_realloc(void *p,
-	   unsigned int n)
-{
-    /* These casts are the for sake of the broken Ultrix compiler,
-       which warns of illegal pointer combinations otherwise.  */
-    if (p == NULL)
-	return (char *)XtMalloc(n);
-    return (char *)XtRealloc(p, n);
-}
-#define	realloc	my_realloc
-#endif
-#endif
-
-
 #if !defined(__alloca)
 #ifdef	__GNUC__
 #undef	alloca
@@ -157,36 +98,22 @@ extern char *alloca(size_t size_to_allocate);
 #endif /* Not _AIX.  */
 #endif /* sparc or HAVE_ALLOCA_H.  */
 #endif /* GCC.  */
-
 #define	__alloca	alloca
-
 #endif
 
-#if 0
-/* rws 5 Nov 1998
-   What is all this for??  IMO a link to a directory is still a directory.
+/*
+   rws 5 Nov 1998
+   IMO a link to a directory is still a directory.
    We shouldn't care whether it is a link or not, therefore I think stat is
    the correct call here, whether we have lstat or not.  If I'm wrong, write
    a test and prove it by doing a FileSelectionSearch on a directory with
    links to directories and comparing the results.
- */
 
-#ifndef __GNU_LIBRARY__
-#  define __lstat lstat
-#  ifndef HAVE_LSTAT
-#    define lstat stat
-#  endif
-#  ifdef STAT_MACROS_BROKEN
-#    undef S_ISDIR
-#  endif
-#  ifndef S_ISDIR
-#    define S_ISDIR(mode) (((mode) & S_IFMT) == S_IFDIR)
-#  endif
-#endif
+#  define LTstat lstat
+*/
 
-#else
+#define LTstat stat
 
-#define __lstat stat
 #ifdef STAT_MACROS_BROKEN
 #  undef S_ISDIR
 #endif
@@ -194,19 +121,13 @@ extern char *alloca(size_t size_to_allocate);
 #  define S_ISDIR(mode) (((mode) & S_IFMT) == S_IFDIR)
 #endif
 
-#endif
-
-#ifndef	STDC_HEADERS
-#undef	size_t
-#define	size_t	unsigned int
-#endif
 
 /* Some system header files erroneously define these.
    We want our own definitions from <fnmatch.h> to take precedence.  */
 #undef	FNM_PATHNAME
 #undef	FNM_NOESCAPE
 #undef	FNM_PERIOD
-#include <LTfnmatch.h>
+#include "LTfnmatch.h"
 
 /* Some system header files erroneously define these.
    We want our own definitions from <glob.h> to take precedence.  */
@@ -218,19 +139,28 @@ extern char *alloca(size_t size_to_allocate);
 #undef	GLOB_APPEND
 #undef	GLOB_NOESCAPE
 #undef	GLOB_PERIOD
-#include <LTglob.h>
-
-__ptr_t(*__glob_opendir_hook) __P((const char *directory));
-     const char *(*__glob_readdir_hook) __P((__ptr_t stream));
-     void (*__glob_closedir_hook) __P((__ptr_t stream));
+#include "LTglob.h"
 
-     static int glob_pattern_p __P((const char *pattern, int quote));
-     static int glob_in_dir __P((const char *pattern, const char *directory,
-				 int flags,
-				 int (*errfunc) __P((const char *, int)),
-				 glob_t *pglob));
-     static int prefix_array __P((const char *prefix, char **array, size_t n));
-     static int collated_compare __P((const __ptr_t, const __ptr_t));
+
+#if 1
+/* amai: We don't use external hooks. If you want to do so -
+   also change <LTglob.h> */
+static void *(*__glob_opendir_hook) (const char *directory)=NULL;
+static const char *(*__glob_readdir_hook) (void * stream)=NULL;
+static void (*__glob_closedir_hook) (void * stream)=NULL;
+#else
+void *(*__glob_opendir_hook) (const char *directory);
+const char *(*__glob_readdir_hook) (void * stream);
+void (*__glob_closedir_hook) (void * stream);
+#endif /* */
+
+static int glob_pattern_p (const char *pattern, int quote);
+static int glob_in_dir (const char *pattern, const char *directory,
+                        int flags,
+				int (*errfunc) (const char *, int),
+				glob_t *pglob);
+static int prefix_array (const char *prefix, char **array, size_t n);
+static int collated_compare (const void *, const void *);
 
 /* Do glob searching for PATTERN, placing results in PGLOB.
    The bits defined above may be set in FLAGS.
@@ -243,7 +173,7 @@ __ptr_t(*__glob_opendir_hook) __P((const char *directory));
  */
 int
  _Lesstif_glob(const char *pattern, int flags,
-	       int (*errfunc) __P((const char *, int)),
+	       int (*errfunc) (const char *, int),
 	       glob_t *pglob)
 {
     const char *filename;
@@ -277,7 +207,7 @@ int
     {
 	dirlen = filename - pattern;
 	dirname = (char *)__alloca(dirlen + 1);
-	bcopy(pattern, dirname, dirlen);
+	memcpy(dirname, pattern, dirlen);
 	dirname[dirlen] = '\0';
 	++filename;
     }
@@ -373,7 +303,7 @@ int
 		char *patcopy = (char *)XtMalloc(len);
 		if (patcopy == NULL)
 		    return GLOB_NOSPACE;
-		bcopy(pattern, patcopy, len);
+		memcpy(patcopy, pattern, len);
 
 		pglob->gl_pathv =
 		    (char **)XtRealloc((char *)pglob->gl_pathv,
@@ -421,7 +351,7 @@ int
 
     if (!(flags & GLOB_NOSORT))
 	/* Sort the vector.  */
-	qsort((__ptr_t) & pglob->gl_pathv[oldcount],
+	qsort((void *) & pglob->gl_pathv[oldcount],
 	      pglob->gl_pathc - oldcount,
 	      sizeof(char *), collated_compare);
 
@@ -435,7 +365,7 @@ int
 	int i;
 	struct stat st;
 	for (i = oldcount; i < pglob->gl_pathc; ++i)
-	    if (__lstat(pglob->gl_pathv[i], &st) == 0 &&
+	    if (LTstat(pglob->gl_pathv[i], &st) == 0 &&
 		S_ISDIR(st.st_mode))
 		strcat(pglob->gl_pathv[i], "/");
     }
@@ -453,15 +383,15 @@ _Lesstif_globfree(register glob_t *pglob)
 	register int i;
 	for (i = 0; i < pglob->gl_pathc; ++i)
 	    if (pglob->gl_pathv[i] != NULL)
-		XtFree((__ptr_t) pglob->gl_pathv[i]);
-	XtFree((__ptr_t) pglob->gl_pathv);
+		XtFree((void *) pglob->gl_pathv[i]);
+	XtFree((void *) pglob->gl_pathv);
     }
 }
 
 
 /* Do a collated comparison of A and B.  */
 static int
-collated_compare(const __ptr_t a, const __ptr_t b)
+collated_compare(const void * a, const void * b)
 {
     const char *const s1 = *(const char *const *const)a;
     const char *const s2 = *(const char *const *const)b;
@@ -504,14 +434,14 @@ prefix_array(const char *dirname, char **array, size_t n)
 	if (new_w == NULL)
 	{
 	    while (i > 0)
-		XtFree((__ptr_t) array[--i]);
+		XtFree((void *) array[--i]);
 	    return 1;
 	}
 
-	bcopy(dirname, new_w, dirlen);
+	memcpy(new_w, dirname, dirlen);
 	new_w[dirlen] = '/';
-	bcopy(array[i], &new_w[dirlen + 1], eltlen);
-	XtFree((__ptr_t) array[i]);
+	memcpy(&new_w[dirlen + 1], array[i], eltlen);
+	XtFree((void *) array[i]);
 	array[i] = new_w;
     }
 
@@ -560,17 +490,17 @@ glob_pattern_p(const char *pattern, int quote)
  */
 static int
 glob_in_dir(const char *pattern, const char *directory, int flags,
-	    int (*errfunc) __P((const char *, int)),
+	    int (*errfunc) (const char *, int),
 	    glob_t *pglob)
 {
-    __ptr_t stream;
+    void * stream;
 
     struct globlink
     {
 	struct globlink *next;
 	char *name;
     };
-    struct globlink *names = NULL, *tail = NULL;
+    struct globlink *names = NULL;
     size_t nfound = 0;
 
     if (!glob_pattern_p(pattern, !(flags & GLOB_NOESCAPE)))
@@ -583,7 +513,7 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 	flags |= GLOB_MAGCHAR;
 
 	stream = (__glob_opendir_hook ? (*__glob_opendir_hook) (directory)
-		  : (__ptr_t) opendir(directory));
+		  : (void *) opendir(directory));
 	if (stream == NULL)
 	{
 	    if ((errfunc != NULL && (*errfunc) (directory, errno)) ||
@@ -630,21 +560,10 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 			= (char *)XtMalloc(len + ((flags & GLOB_MARK) ? 1 : 0) + 1);
 		    if (new_w->name == NULL)
 			goto memory_error;
-		    bcopy(name, (__ptr_t) new_w->name, len);
+		    memcpy((void *) new_w->name, name, len);
 		    new_w->name[len] = '\0';
-#ifdef READDIR_LEXICOGRAPHIC_ORDER
-		    if (names == NULL)
-			names = tail = new_w;
-		    else
-		    {
-			tail->next = new_w;
-			tail = new_w;
-		    }
-		    new_w->next = NULL;
-#else
 		    new_w->next = names;
 		    names = new_w;
-#endif
 		    ++nfound;
 		}
 	    }
@@ -659,7 +578,7 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 	names->name = (char *)XtMalloc(len + 1);
 	if (names->name == NULL)
 	    goto memory_error;
-	bcopy(pattern, names->name, len);
+	memcpy(names->name, pattern, len);
 	names->name[len] = '\0';
     }
 
@@ -705,53 +624,8 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
     while (names != NULL)
     {
 	if (names->name != NULL)
-	    XtFree((__ptr_t) names->name);
+	    XtFree((void *) names->name);
 	names = names->next;
     }
     return GLOB_NOSPACE;
 }
-
-#ifdef __EMX__
-/*
-   Under OS/2 we may need to deal with drive letters.
-   Question is whether this "manual" implementation or
-   libExt will be faster in providing this feature ...
-*/
-
-static const char 
-*GetDriveMap(void)
-{
-  /* returns a string containing a list of all drives: e.g. "C: D: E:" */
-
-#define MAXDRIVELETTERS 26
-  static char drivelist[3*MAXDRIVELETTERS +1] = "";
-  static char tmpstr[4] = " : ";
-  ULONG  CurDrive;
-  ULONG  DriveMap;
-  int    dnum;
-  int    start = 3;  /* this should correspond to a hard coded limit
-                        to 'C', i.e. no check for floppy disk ?! */
-  static char offset = 'A' -1;
-
-/* DosError(0); */
-
-  DosQueryCurrentDisk(&CurDrive, &DriveMap);
-  DriveMap>>=start-1;
-  for (dnum = start; dnum <= MAXDRIVELETTERS; dnum++) {
-     if ((DriveMap & (ULONG)1)) {
-        tmpstr[0] = (char)dnum + offset;
-        strcat(drivelist, tmpstr);
-     }
-      DriveMap>>=1; 
-  } /* for dnum */
-
-  /* cosmetics: strip trailing blank: */ 
-  if (drivelist[strlen(drivelist)-1]== ' ')
-    drivelist[strlen(drivelist)-1] = '\0';
-
-/* DosError(1); */
-
-  return strdup(drivelist);
-}
-
-#endif
