@@ -1,8 +1,9 @@
 /**
  *
- * $Id: LabelG.c,v 1.93 2000/04/02 15:21:10 rwscott Exp $
+ * $Id: LabelG.c,v 1.96 2000/09/22 20:35:12 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LabelG.c,v 1.93 2000/04/02 15:21:10 rwscott Exp $";
+static const char rcsid[] = "$Id: LabelG.c,v 1.96 2000/09/22 20:35:12 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -40,7 +44,6 @@ static const char rcsid[] = "$Id: LabelG.c,v 1.93 2000/04/02 15:21:10 rwscott Ex
 #include <Xm/ScreenP.h>
 #include <Xm/DragIconP.h>
 #include <XmI/AtomMgrI.h>
-#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -501,7 +504,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -513,7 +516,7 @@ secondary_object_create(Widget request,
 int
 _XmLabelCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmLabelGCacheObjPart *)A),
+    return !memcmp(((XmLabelGCacheObjPart *)A),
 		 ((XmLabelGCacheObjPart *)B),
 		 sizeof(XmLabelGCacheObjPart));
 }
@@ -607,9 +610,9 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -652,9 +655,9 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -695,9 +698,9 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -738,9 +741,9 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -781,9 +784,9 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -824,9 +827,9 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -1362,9 +1365,9 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -1379,7 +1382,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     LabG_Cache(new_w) = &(((XmLabelGCacheObject)nsec)->label_cache);
@@ -1702,9 +1705,9 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
