@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Manager.c,v 1.86 2000/08/29 15:04:54 amai Exp $
+ * $Id: Manager.c,v 1.89 2000/09/29 22:51:55 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,16 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.86 2000/08/29 15:04:54 amai Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.89 2000/09/29 22:51:55 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
 
 #include <XmI/XmI.h>
 #include <XmI/TraversalI.h>
@@ -43,7 +41,6 @@ static const char rcsid[] = "$Id: Manager.c,v 1.86 2000/08/29 15:04:54 amai Exp
 #include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
 #include <X11/keysym.h>
-#include <X11/Xfuncs.h>
 #include <Xm/VirtKeysP.h>
 
 #include <XmI/DebugUtil.h>
@@ -337,15 +334,12 @@ static XtResource resources[] =
     }
 
 #if XmVERSION > 1
-#if LESSTIF_BACK_COMPAT
-#else
     ,
     {
 	XmNpopupHandlerCallback, XmCCallback, XmRCallback,
 	sizeof(XtCallbackList), Offset(popup_handler_callback),
 	XtRPointer, (XtPointer)NULL
     }
-#endif
     ,
     {
 	XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
@@ -1944,7 +1938,7 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 
 	if (MGR_SizeKeyboardList(m) > i)
 	{
-	    bzero(&MGR_KeyboardList(m)[i],
+	    memset(&MGR_KeyboardList(m)[i], 0,
 		  (MGR_SizeKeyboardList(m) - i) * sizeof(XmKeyboardData));
 	}
     }
@@ -1958,7 +1952,7 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 	_XmError(m, "This should not happen: %d\n", i);
     }
 
-    bcopy(item, &MGR_KeyboardList(m)[i], sizeof(XmKeyboardData));
+    memcpy(&MGR_KeyboardList(m)[i], item, sizeof(XmKeyboardData));
 
     MGR_NumKeyboardEntries(m)++;
 
@@ -2013,18 +2007,19 @@ DeleteKeyboardEntry(Widget m, Widget w, Boolean isMnemonic)
 
 	    if (i < MGR_NumKeyboardEntries(m) - 1)
 	    {
-		bcopy(&MGR_KeyboardList(m)[i + 1],
-		      &MGR_KeyboardList(m)[i],
-		      sizeof(XmKeyboardData) *
+		memcpy(&MGR_KeyboardList(m)[i],
+                       &MGR_KeyboardList(m)[i + 1],
+		       sizeof(XmKeyboardData) *
 		        (MGR_NumKeyboardEntries(m) - i - 1));
 
-		bzero(&MGR_KeyboardList(m)[MGR_NumKeyboardEntries(m) - 1],
+		memset(&MGR_KeyboardList(m)[MGR_NumKeyboardEntries(m) - 1], 0,
 		      sizeof(XmKeyboardData));
 	    }
 	    /* end of list */
 	    else
 	    {
-		bzero(&MGR_KeyboardList(m)[i], sizeof(XmKeyboardData));
+		memset(&MGR_KeyboardList(m)[i], 0,
+		       sizeof(XmKeyboardData));
 	    }
 
 	    MGR_NumKeyboardEntries(m)--;
