@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MapEvent.c,v 1.12 1998/09/12 15:05:33 rwscott Exp $
+ * $Id: MapEvent.c,v 1.15 2000/09/22 20:35:12 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MapEvent.c,v 1.12 1998/09/12 15:05:33 rwscott Exp $";
+static const char rcsid[] = "$Id: MapEvent.c,v 1.15 2000/09/22 20:35:12 amai Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -49,23 +50,19 @@ static const char rcsid[] = "$Id: MapEvent.c,v 1.12 1998/09/12 15:05:33 rwscott
  * SOFTWARE.
  */
 #include <LTconfig.h>
+
+#include <ctype.h>
+#include <stdlib.h>    /* -> qsort() */
+#include <string.h>
+
 #include <XmI/XmI.h>
-
 #include <Xm/XmP.h>
-
 #include <XmI/DebugUtil.h>
 
 #define XK_MISCELLANY
 #define XK_LATIN1
 #include <X11/keysymdef.h>
-#include <X11/Xfuncs.h>
 
-#include <ctype.h>
-#include <stdlib.h>
-
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
 
 #define COLON	':'
 
@@ -149,8 +146,8 @@ static void ParseModImmed(Value value, LateBindingsPtr *lateBindings,
 static void ParseModSym(Value value, LateBindingsPtr *lateBindings,
 			Boolean notFlag, Value *valueP);
 
-static String PanicModeRecovery();
-static KeySym StringToKeySym();
+static String PanicModeRecovery(String str);
+static KeySym StringToKeySym(String str, Boolean *error);
 
 static ModifierRec modifiers[] =
 {
@@ -211,13 +208,20 @@ static NameValueRec mappingNotify[] = {
     {NULL,		NULLQUARK,	0},
 };
 
-static String ParseKeySym();
-static String ParseKeyAndModifiers();
-static String ParseTable();
-static String ParseImmed();
-static String ParseAddModifier();
-static String ParseNone();
-static String ParseAtom();
+static String ParseKeySym(String str, XtPointer closure, EventPtr event,
+			  Boolean *error);
+static String ParseKeyAndModifiers(String str, XtPointer closure,
+				   EventPtr event, Boolean *error);
+static String ParseTable(String str, XtPointer closure, EventPtr event,
+			 Boolean *error);
+static String ParseImmed(String str, XtPointer closure, EventPtr event,
+			 Boolean *error);
+static String ParseAddModifier(String str, XtPointer closure, EventPtr event,
+			       Boolean *error);
+static String ParseNone(String str, XtPointer closure, EventPtr event,
+			Boolean *error);
+static String ParseAtom(String str, XtPointer closure, EventPtr event
+			, Boolean *error);
 
 static EventKey events[] =
 {
@@ -702,7 +706,7 @@ FetchModifierToken(String str, XrmQuark *token_return)
     if (start != str)
     {
 	char modStr[100];
-	bcopy(start, modStr, str-start);
+	memcpy(modStr, start, str-start);
 	modStr[str-start] = '\0';
 	*token_return = XrmStringToQuark(modStr);
 
@@ -838,7 +842,7 @@ ParseXtEventType(String str, EventPtr event, Cardinal *tmEventP, Boolean *error)
     char eventTypeStr[100];
 
     ScanAlphanumeric(str);
-    bcopy(start, eventTypeStr, str-start);
+    memcpy(eventTypeStr, start, str-start);
     eventTypeStr[str-start] = '\0';
     *tmEventP = LookupTMEventType(eventTypeStr,error);
     if (*error) 
@@ -1067,7 +1071,7 @@ ParseKeySym(String str, XP closure, EventPtr event, Boolean *error)
 	    str++;
 	}
 
-	bcopy(start, keySymName, str-start);
+	memcpy(keySymName, start, str-start);
 
 	keySymName[str-start] = '\0';
 
@@ -1110,7 +1114,7 @@ ParseTable(String str, XP closure, EventPtr event, Boolean *error)
 	return str;
     }
 
-    bcopy(start, tableSymName, str-start);
+    memcpy(tableSymName, start, str-start);
     tableSymName[str-start] = '\0';
 
     if (!_XtLookupTableSym((NameValueTable)closure, tableSymName, 
@@ -1167,7 +1171,7 @@ ParseAtom(String str, XP closure, EventPtr event, Boolean *error)
 	    return str;
 	}
 
-	bcopy(start, atomName, str-start);
+	memcpy(atomName, start, str-start);
 	atomName[str-start] = '\0';
 	event->event.eventCode = XrmStringToQuark(atomName);
     }
@@ -1179,7 +1183,8 @@ static short buttonModifierMasks[] =
 {
     0, Button1Mask, Button2Mask, Button3Mask, Button4Mask, Button5Mask
 };
-static String ParseRepeat();
+static String ParseRepeat(String str, int *reps, Boolean *plus,
+			  Boolean *error);
 
 static String
 ParseEvent(String str, EventPtr event, int *reps, Boolean *plus, Boolean *error)
@@ -1608,7 +1613,7 @@ ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
 	len = (str - start);
 	if (len < sizeof repStr)
 	{
-	    bcopy(start, repStr, len);
+	    memcpy(repStr, start, len);
 	    repStr[len] = '\0';
 	    *reps = StrToNum(repStr);
 	}
@@ -1801,7 +1806,7 @@ PrintEventSeq(EventSeqPtr evs)
 }
 
 static void
-_XmTransParseInit()
+_XmTransParseInit(void)
 {
     if (initialized)
     {
