@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MessageB.c,v 1.39 2000/08/29 15:04:55 amai Exp $
+ * $Id: MessageB.c,v 1.42 2000/09/23 15:05:24 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MessageB.c,v 1.39 2000/08/29 15:04:55 amai Exp $";
+static const char rcsid[] = "$Id: MessageB.c,v 1.42 2000/09/23 15:05:24 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <XmI/XmI.h>
-#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/MessageBP.h>
 #ifdef USE_WIDGETS
@@ -418,6 +418,10 @@ initialize(Widget request, Widget new_w,
     {
 	MB_OKButton(new_w) = NULL;
     }
+    if (MB_OKLabelString(new_w) != NULL)
+    {
+        MB_OKLabelString(new_w) = XmStringCopy(MB_OKLabelString(new_w));
+    }
 
     if (MB_DialogType(new_w) != XmDIALOG_TEMPLATE ||
 	MB_CancelLabelString(new_w) != NULL ||
@@ -432,6 +436,10 @@ initialize(Widget request, Widget new_w,
     {
 	BB_CancelButton(new_w) = NULL;
     }
+    if (MB_CancelLabelString(new_w) != NULL)
+    {
+        MB_CancelLabelString(new_w) = XmStringCopy(MB_CancelLabelString(new_w));
+    }
 
     if (MB_DialogType(new_w) != XmDIALOG_TEMPLATE ||
 	MB_HelpLabelString(new_w) != NULL ||
@@ -445,6 +453,10 @@ initialize(Widget request, Widget new_w,
     {
 	MB_HelpButton(new_w) = NULL;
     }
+    if (MB_HelpLabelString(new_w) != NULL)
+    {
+        MB_HelpLabelString(new_w) = XmStringCopy(MB_HelpLabelString(new_w));
+    }
 
     /* Remove auto_unmanage */
     if (MB_HelpButton(new_w))
