@@ -1,8 +1,9 @@
 /**
  *
- * $Id: PanedW.c,v 1.45 1999/11/19 13:13:14 amai Exp $
+ * $Id: PanedW.c,v 1.48 2000/09/22 20:35:12 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PanedW.c,v 1.45 1999/11/19 13:13:14 amai Exp $";
+static const char rcsid[] = "$Id: PanedW.c,v 1.48 2000/09/22 20:35:12 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -32,9 +38,6 @@ static const char rcsid[] = "$Id: PanedW.c,v 1.45 1999/11/19 13:13:14 amai Exp $
 #include <Xm/PanedWP.h>
 #include <Xm/SashP.h>
 #include <Xm/SeparatorP.h>
-#include <X11/Xfuncs.h>
-#include <stdlib.h>
-#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -1295,7 +1298,7 @@ change_managed(Widget w)
 
 	    if ((PW_NumManagedChildren(w) - i) > 0)
 	    {
-		bcopy(&PW_ManagedChildren(w)[i + 1], &PW_ManagedChildren(w)[i],
+		memcpy(&PW_ManagedChildren(w)[i], &PW_ManagedChildren(w)[i + 1],
 		      sizeof(Widget) * (PW_NumManagedChildren(w) - i));
 	    }
 	}
