@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Primitive.c,v 1.34 1998/10/10 07:38:59 gritton Exp $
+ * $Id: Primitive.c,v 1.44 2000/09/29 22:51:55 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Primitive.c,v 1.34 1998/10/10 07:38:59 gritton Exp $";
+static const char rcsid[] = "$Id: Primitive.c,v 1.44 2000/09/29 22:51:55 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -34,17 +36,17 @@ static const char rcsid[] = "$Id: Primitive.c,v 1.34 1998/10/10 07:38:59 gritton
 #include <Xm/ManagerP.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/VirtKeysP.h>
-
-#include <XmI/DebugUtil.h>
-
 #if XmVERSION > 1
 /* Includes for 2.0 features */
 #include <XmI/DirectionI.h>
 #endif
 
+#include <XmI/DebugUtil.h>
+
+
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -67,9 +69,9 @@ static void primitive_border_unhighlight(Widget w);
 
 static void primitive_border_highlight(Widget w);
 
-void _XmPrimitiveHighlightThicknessDefault(Widget w, int offset, XrmValue *val);
+static void _XmPrimitiveExportY(Widget widget, int offset, XtArgVal *value);
 
-void _XmPrimitiveShadowThicknessDefault(Widget w, int offset, XrmValue *val);
+static void _XmPrimitiveExportX(Widget widget, int offset, XtArgVal *value);
 
 /*
  * Resources for the primitive class
@@ -140,7 +142,7 @@ static XtResource resources[] =
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
 	sizeof(Dimension), Offset(highlight_thickness),
-	XmRCallProc, (XtPointer)_XmPrimitiveHighlightThicknessDefault
+	XmRImmediate, (XtPointer)2
     },
     {
 	XmNhighlightColor, XmCHighlightColor, XmRPixel,
@@ -188,26 +190,23 @@ static XtResource resources[] =
 	XmRImmediate, (XtPointer)NULL
     }
 
-#if LESSTIF_BACK_COMPAT
-#else
 #if XmVERSION > 1
     ,{
-        XmNconvertCallback, XmCCallback, XmRCallback,
-        sizeof(XtCallbackList), Offset(convert_callback),
-        XtRPointer, (XtPointer)NULL
+	XmNconvertCallback, XmCCallback, XmRCallback,
+	sizeof(XtCallbackList), Offset(convert_callback),
+	XtRPointer, (XtPointer)NULL
     },
     {
-        XmNpopupHandlerCallback, XmCCallback, XmRCallback,
-        sizeof(XtCallbackList), Offset(popup_handler_callback),
-        XtRPointer, (XtPointer)NULL
+	XmNpopupHandlerCallback, XmCCallback, XmRCallback,
+	sizeof(XtCallbackList), Offset(popup_handler_callback),
+	XtRPointer, (XtPointer)NULL
     },
     {
-        XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
-        sizeof(XmDirection), Offset(layout_direction),
+	XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
+	sizeof(XmDirection), Offset(layout_direction),
 	XmRCallProc, (XtPointer)_XmDirectionDefault
     }
 #endif
-#endif
 
 };
 
@@ -219,12 +218,12 @@ static XmSyntheticResource syn_resources[] =
     {
 	XmNx,
 	sizeof(Position), COffset(x),
-	_XmFromHorizontalPixels, _XmToHorizontalPixels
+	_XmPrimitiveExportX, _XmToHorizontalPixels
     },
     {
 	XmNy,
 	sizeof(Position), COffset(y),
-	_XmFromVerticalPixels, _XmToVerticalPixels
+	_XmPrimitiveExportY, _XmToVerticalPixels
     },
     {
 	XmNwidth,
@@ -286,7 +285,7 @@ static XtActionsRec actions[] =
 /* *INDENT-OFF* */
 static XmBaseClassExtRec _XmPrimitiveCoreClassExtRec = {
     /* next_extension            */ NULL,
-    /* record_type               */ NULLQUARK,                             
+    /* record_type               */ NULLQUARK,
     /* version                   */ XmBaseClassExtVersion,
     /* size                      */ sizeof(XmBaseClassExtRec),
     /* initialize_prehook        */ NULL,
@@ -315,16 +314,16 @@ XmPrimitiveClassExtRec _XmPrimClassExtRec = {
     /* record_type         */ NULLQUARK,
     /* version             */ XmPrimitiveClassExtVersion,
     /* record_size         */ sizeof(XmPrimitiveClassExtRec),
-    /* widget_baseline     */ NULL, /* FIX ME */
-    /* widget_display_rect */ NULL, /* FIX ME */
-    /* widget_margins      */ NULL  /* FIX ME */
+    /* widget_baseline     */ NULL,
+    /* widget_display_rect */ NULL,
+    /* widget_margins      */ NULL
 };
 
 XmPrimitiveClassRec xmPrimitiveClassRec = {
     /* Core class part */
     {
 	/* superclass            */ (WidgetClass) &coreClassRec,
-        /* class_name            */ "XmPrimitive",
+	/* class_name            */ "XmPrimitive",
 	/* widget_size           */ sizeof(XmPrimitiveRec),
 	/* class_initialize      */ class_initialize,
 	/* class_part_initialize */ class_part_initialize,
@@ -349,7 +348,7 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ _XmPrimitiveGetValuesHook,
 	/* accept_focus          */ NULL,
-	/* version               */ XtVersion,
+	/* version               */ XtVersionDontCheck,
 	/* callback offsets      */ NULL,
 	/* tm_table              */ NULL,
 	/* query_geometry        */ NULL,
@@ -359,12 +358,12 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
     /* Primitive Class part */
     {
 	/* border_highlight      */ primitive_border_highlight,
-        /* border_unhighlight    */ primitive_border_unhighlight,
-        /* translations          */ _XmPrimitive_defaultTranslations,
-        /* arm_and_activate_proc */ NULL,
-        /* Synthetic Resources   */ syn_resources,
+	/* border_unhighlight    */ primitive_border_unhighlight,
+	/* translations          */ _XmPrimitive_defaultTranslations,
+	/* arm_and_activate_proc */ NULL,
+	/* Synthetic Resources   */ syn_resources,
 	/* num syn res           */ XtNumber(syn_resources),
-        /* extension             */ (XtPointer)&_XmPrimClassExtRec
+	/* extension             */ (XtPointer)&_XmPrimClassExtRec
     }
 };
 /* *INDENT-ON* */
@@ -372,7 +371,7 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 WidgetClass xmPrimitiveWidgetClass = (WidgetClass)&xmPrimitiveClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmRegisterConverters();
     _XmRegisterPixmapConverters();
@@ -532,8 +531,8 @@ CreateTopShadowGC(XmPrimitiveWidget pw)
     values.foreground = Prim_TopShadowColor(pw);
     values.background = XtBackground(pw);
 
-    if (Prim_TopShadowPixmap(pw) != None
-	&& Prim_TopShadowPixmap(pw) != XmUNSPECIFIED_PIXMAP)
+    if (Prim_TopShadowPixmap(pw) != None &&
+	Prim_TopShadowPixmap(pw) != XmUNSPECIFIED_PIXMAP)
     {
 	/* we're dealing with a pixmap'ed top shadow */
 	mask |= GCTile | GCFillStyle;
@@ -571,18 +570,18 @@ initialize(Widget request, Widget new_w,
 	Prim_Highlighted(new_w) =
 	Prim_HighlightDrawn(new_w) = False;
 
-    /* validate the entries in XmNnavigationType and XmNunitType 
-       Are these correct?  Or do we need to call a defaultProc? FIX ME */
+    /* validate the entries in XmNnavigationType and XmNunitType
+     * Are these correct?  Or do we need to call a defaultProc?
+     * 14 Nov 1998: no CallProc: XmPIXELS is correct - Jamie
+     */
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRNavigationType),
-			     pw->primitive.navigation_type,
-			     new_w))
+			     pw->primitive.navigation_type, new_w))
     {
 	pw->primitive.navigation_type = XmNONE;
     }
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRUnitType),
-			     pw->primitive.unit_type,
-			     new_w))
+			     pw->primitive.navigation_type, new_w))
     {
 	pw->primitive.unit_type = XmPIXELS;
     }
@@ -624,7 +623,7 @@ initialize(Widget request, Widget new_w,
 					    Prim_Foreground(new_w),
 					    XtBackground(new_w),
 					    CoreDepth(new_w));
-        _XmClearBGPixmap();
+	_XmClearBGPixmap();
     }
 
     /* create all the initial GC's */
@@ -639,11 +638,9 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
-    XmPrimitiveWidget pw = (XmPrimitiveWidget)w;
-
-    XtReleaseGC(w, Prim_TopShadowGC(pw));
-    XtReleaseGC(w, Prim_BottomShadowGC(pw));
-    XtReleaseGC(w, Prim_HighlightGC(pw));
+    XtReleaseGC(w, Prim_TopShadowGC(w));
+    XtReleaseGC(w, Prim_BottomShadowGC(w));
+    XtReleaseGC(w, Prim_HighlightGC(w));
 
     _XmNavigDestroy(w);
 }
@@ -694,9 +691,18 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean need_refresh = False;
+    Boolean need_refresh;
 
-    if (_XmGetBGPixmapName() != NULL)
+    if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0) {
+        _XmWarning(new_w, "XmPrimitive SetValues: won't set width of widget to 0\n");
+	XtWidth(new_w) = XtWidth(old);
+    }
+    if (XtHeight(new_w) != XtHeight(old) && XtHeight(new_w) == 0) {
+        _XmWarning(new_w, "XmPrimitive SetValues: won't set height of widget to 0\n");
+	XtHeight(new_w) = XtHeight(old);
+    }
+
+    if (_XmGetBGPixmapName() != NULL && XtIsRealized(new_w))
     {
 	XSetWindowAttributes attr;
 
@@ -709,21 +715,19 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	attr.background_pixmap = CoreBackgroundPixmap(new_w);
 	XChangeWindowAttributes(XtDisplay(new_w), XtWindow(new_w),
-			        CWBackPixmap, &attr);
+				CWBackPixmap, &attr);
 
-        _XmClearBGPixmap();
+	_XmClearBGPixmap();
     }
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRNavigationType),
-			     Prim_NavigationType(new_w),
-			     new_w))
+			     Prim_NavigationType(new_w), new_w))
     {
 	Prim_NavigationType(new_w) = Prim_NavigationType(old);
     }
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRUnitType),
-			     Prim_UnitType(new_w),
-			     new_w))
+			     Prim_UnitType(new_w), new_w))
     {
 	Prim_UnitType(new_w) = Prim_UnitType(old);
     }
@@ -745,34 +749,41 @@ set_values(Widget old, Widget request, Widget new_w,
 	need_refresh = True;
     }
 
-    if (Prim_HighlightColor(old) != Prim_HighlightColor(new_w)
-	|| Prim_HighlightPixmap(old) != Prim_HighlightPixmap(new_w))
+    if (Prim_HighlightPixmap(old) != Prim_HighlightPixmap(new_w) ||
+	((Prim_HighlightPixmap(new_w) == None ||
+	  Prim_HighlightPixmap(new_w) == XmUNSPECIFIED_PIXMAP) &&
+	 Prim_HighlightColor(old) != Prim_HighlightColor(new_w)))
     {
 	XtReleaseGC(new_w, Prim_HighlightGC(new_w));
 
 	CreateHighlightGC((XmPrimitiveWidget)new_w);
 
-	need_refresh = True;
+	need_refresh |=
+	    Prim_HighlightDrawn(new_w) && Prim_HighlightThickness(new_w);
     }
 
-    if (Prim_TopShadowColor(old) != Prim_TopShadowColor(new_w)
-	|| Prim_TopShadowPixmap(old) != Prim_TopShadowPixmap(new_w))
+    if (Prim_TopShadowPixmap(old) != Prim_TopShadowPixmap(new_w) ||
+	((Prim_TopShadowPixmap(new_w) == None ||
+	  Prim_TopShadowPixmap(new_w) == XmUNSPECIFIED_PIXMAP) &&
+	 Prim_TopShadowColor(old) != Prim_TopShadowColor(new_w)))
     {
 	XtReleaseGC(new_w, Prim_TopShadowGC(new_w));
 
 	CreateTopShadowGC((XmPrimitiveWidget)new_w);
 
-	need_refresh = True;
+	need_refresh |= Prim_ShadowThickness(new_w);
     }
 
-    if (Prim_BottomShadowColor(old) != Prim_BottomShadowColor(new_w)
-	|| Prim_BottomShadowPixmap(old) != Prim_BottomShadowPixmap(new_w))
+    if (Prim_BottomShadowPixmap(old) != Prim_BottomShadowPixmap(new_w) ||
+	((Prim_BottomShadowPixmap(new_w) == None ||
+	  Prim_BottomShadowPixmap(new_w) == XmUNSPECIFIED_PIXMAP) &&
+	 Prim_BottomShadowColor(old) != Prim_BottomShadowColor(new_w)))
     {
 	XtReleaseGC(new_w, Prim_BottomShadowGC(new_w));
 
 	CreateBottomShadowGC((XmPrimitiveWidget)new_w);
 
-	need_refresh = True;
+	need_refresh |= Prim_ShadowThickness(new_w);
     }
 
     if ((Prim_HighlightDrawn(new_w) || !XtSensitive(new_w))
@@ -794,7 +805,7 @@ set_values(Widget old, Widget request, Widget new_w,
  * ENTER/LEAVE should only happen when mwm is in pointer-follows-mouse mode.
  * FOCUS_IN/FOCUS_OUT otherwise.
  */
-void
+static void
 focus_change(Widget w, XmFocusChange change)
 {
     XmPrimitiveWidgetClass pc = (XmPrimitiveWidgetClass)XtClass(w);
@@ -883,7 +894,7 @@ primitive_border_unhighlight(Widget w)
 
     if (!XtIsRealized(w))
     {
-        return;
+	return;
     }
 
     /* with zero width, we don't need this... */
@@ -894,9 +905,10 @@ primitive_border_unhighlight(Widget w)
 
     if (XmIsManager(XtParent(w)))
     {
-	_XmDrawHighlight(XtDisplay(w), XtWindow(w), XmParentBackgroundGC(w),
-			 0, 0, XtWidth(w), XtHeight(w),
-			 Prim_HighlightThickness(w), LineSolid);
+	_XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w),
+			       XmParentBackgroundGC(w),
+			       0, 0, XtWidth(w), XtHeight(w),
+			       Prim_HighlightThickness(w));
     }
     else
     {
@@ -918,7 +930,7 @@ primitive_border_highlight(Widget w)
 
     if (!XtIsRealized(w))
     {
-        return;
+	return;
     }
 
     /* with zero width, we don't need this... */
@@ -927,9 +939,9 @@ primitive_border_highlight(Widget w)
 	return;
     }
 
-    _XmDrawHighlight(XtDisplay(w), XtWindow(w), Prim_HighlightGC(w),
-		     0, 0, XtWidth(w), XtHeight(w),
-		     Prim_HighlightThickness(w), LineSolid);
+    _XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w), Prim_HighlightGC(w),
+			   0, 0, XtWidth(w), XtHeight(w),
+			   Prim_HighlightThickness(w));
 
     Prim_Highlighted(w) = True;
     Prim_HighlightDrawn(w) = True;
@@ -1092,7 +1104,7 @@ _XmDifferentBackground(Widget w, Widget parent)
 void
 _XmPrimitiveHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
-    static Pixmap pixmap;  
+    static Pixmap pixmap;
 
     DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveHighlightPixmapDefault\n"));
 
@@ -1138,30 +1150,6 @@ _XmPrimitiveTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
     }
 }
 
-/*
- * Motif show _XmPrimitiveHightThicknessDefault and
- * _XmPrimitiveShadowThicknessDefault as having the same address!
- */
-void _XmPrimitiveHighlightThicknessDefault(Widget w, int offset, XrmValue *val)
-{
-    static Dimension thickness = 2;
-
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveHighlightThicknessDefault\n"));
-
-    val->addr = (XtPointer)&thickness;
-    val->size = sizeof(thickness);
-}
-
-void _XmPrimitiveShadowThicknessDefault(Widget w, int offset, XrmValue *val)
-{
-    static Dimension thickness = 2;
-
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveShadowThicknessDefault\n"));
-
-    val->addr = (XtPointer)&thickness;
-    val->size = sizeof(thickness);
-}
-
 /* Public Functions */
 
 /* An implementation for the file `lib/Xm/Primitive.c'
@@ -1210,7 +1198,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
     Cardinal	 widget_part_size, constraint_part_size;
     XmOffsetPtr	 offset=0, constraint_offset=0;
     XmPartResource *		resources;
-    Cardinal			num_resources;    
+    Cardinal			num_resources;
     ConstraintWidgetClass	superclass, thisclass, tmp;
 
     DEBUGOUT(XdbDebug0(__FILE__, NULL,
@@ -1222,7 +1210,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
      * casting.
      */
     thisclass = (ConstraintWidgetClass)w_class;
-    
+
     /* The widget class must have `XtVersionDontCheck' instead of XtVersion
      * in its class record.
      */
@@ -1279,7 +1267,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 		superclass->constraint_class.constraint_size;
 	}
     }
-    
+
     /*
      * Now count the number of super classes, by traversing up the
      * class hierarchy.
@@ -1309,7 +1297,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	constraint_offset =
 	    (XmOffsetPtr)XtCalloc( array_size, sizeof(XmOffset) );
     }
-    
+
     if (offset_return)
     {
 	*offset_return = offset;
@@ -1343,7 +1331,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	DEBUGOUT(XdbDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
 			   k, offset[k], tmp->core_class.class_name));
     }
-    
+
     if (bfIsConstraint)
     {
 	/*
@@ -1414,7 +1402,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	{
 	    int	widget_index =
 		resources[j].resource_offset >> XmOFFSETBITS;
-	    int	true_offset = 	
+	    int	true_offset =
 		resources[j].resource_offset &  XmOFFSETMASK;
 	    resources[j].resource_offset = constraint_offset[widget_index] +
 						true_offset;
@@ -1426,19 +1414,19 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 			       resources[j].resource_offset));
 	}
     }
-    
+
 
     if ( !constraint_offset_return && constraint_offset )
     {
-	/* Release constraint offset that were allocated, 
-	 * silly caller supplied a NULL referenced parameter 
+	/* Release constraint offset that were allocated,
+	 * silly caller supplied a NULL referenced parameter
 	 */
 	XtFree((void*)constraint_offset);
     }
     if ( !offset_return && offset )
     {
-	/* Release offsets that were allocated, 
-	 * silly caller supplied a NULL referenced parameter 
+	/* Release offsets that were allocated,
+	 * silly caller supplied a NULL referenced parameter
 	 */
 	XtFree((void*)offset);
     }
@@ -1507,3 +1495,42 @@ XmWidgetGetDisplayRect(Widget w, XRectangle *displayrect)
 
     return False;
 }
+
+static void
+_XmPrimitiveExportX(Widget widget, int offset, XtArgVal *value)
+{
+    unsigned char unitType = _XmGetUnitType(widget);
+    int converted_value;
+
+    if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget)))
+    {
+    	*value = XtX(XtParent(widget));
+    }
+    converted_value = XmConvertUnits(widget,
+				     XmHORIZONTAL,
+				     XmPIXELS,
+				     *value,
+				     unitType);
+
+    *value = converted_value;
+}
+
+static void
+_XmPrimitiveExportY(Widget widget, int offset, XtArgVal *value)
+{
+    unsigned char unitType = _XmGetUnitType(widget);
+    int converted_value;
+
+    if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget)))
+    {
+    	*value = XtY(XtParent(widget));
+    }
+    converted_value = XmConvertUnits(widget,
+				     XmVERTICAL,
+				     XmPIXELS,
+				     *value,
+				     unitType);
+
+    *value = converted_value;
+}
+
