@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Protocols.c,v 1.9 2000/07/09 11:33:02 rwscott Exp $
+ * $Id: Protocols.c,v 1.10 2000/09/13 11:17:57 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Protocols.c,v 1.9 2000/07/09 11:33:02 rwscott Exp $";
+static const char rcsid[] = "$Id: Protocols.c,v 1.10 2000/09/13 11:17:57 amai Exp $";
 
 #include <LTconfig.h>
+#include <string.h>
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
 
@@ -301,8 +303,8 @@ __XmAddProtocol(XmAllProtocolsMgr mgrs, Atom property, Atom protocol)
     ExtObj_LogicalParent(w) = mgrs->shell;
     ExtObj_ExtensionType(w) = XmPROTOCOL_EXTENSION;
 
-    bzero(&Protocol_PreHook(w), sizeof(XtCallbackRec));
-    bzero(&Protocol_PostHook(w), sizeof(XtCallbackRec));
+    memset(&Protocol_PreHook(w), 0, sizeof(XtCallbackRec));
+    memset(&Protocol_PostHook(w), 0, sizeof(XtCallbackRec));
     Protocol_Callbacks(w) = NULL;
 
     Protocol_Atom(w) = protocol;
