@@ -1,8 +1,9 @@
 /**
  *
- * $Id: PushB.c,v 1.75 2000/03/17 17:48:50 danny Exp $
+ * $Id: PushB.c,v 1.77 2000/09/23 15:05:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushB.c,v 1.75 2000/03/17 17:48:50 danny Exp $";
+static const char rcsid[] = "$Id: PushB.c,v 1.77 2000/09/23 15:05:24 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdarg.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/PushBP.h>
 #include <Xm/RepType.h>
@@ -36,14 +39,15 @@ static const char rcsid[] = "$Id: PushB.c,v 1.75 2000/03/17 17:48:50 danny Exp $
 #include <Xm/MenuShell.h>
 #include <Xm/CascadeB.h>
 #include <Xm/CascadeBG.h>
-#include <stdarg.h>
-
-#include <XmI/DebugUtil.h>
-
 #if XmVERSION > 1
 #include <Xm/TraitP.h>
 #include <Xm/ActivatableT.h>
+#endif
 
+#include <XmI/DebugUtil.h>
+
+
+#if XmVERSION > 1
 void _XmPushB_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmPushBTraitRec = {
@@ -548,8 +552,10 @@ initialize(Widget request, Widget new_w,
 
 	    Lab_TextRect_x(new_w) += margin;
 	    Lab_TextRect_y(new_w) += margin;
-	    Lab_AccTextRect(new_w).x += margin;
-	    Lab_AccTextRect(new_w).y += margin;
+	    if (Lab_AcceleratorText(new_w)) {
+		Lab_AccTextRect(new_w).x += margin;
+		Lab_AccTextRect(new_w).y += margin;
+	    }
 
 	    /* rws 19 Aug 1997
 	     * This does not seem to make sense! Without this the width and
@@ -698,8 +704,10 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	    Lab_TextRect_x(new_w) += margin;
 	    Lab_TextRect_y(new_w) += margin;
-	    Lab_AccTextRect(new_w).x += margin;
-	    Lab_AccTextRect(new_w).y += margin;
+	    if (Lab_AcceleratorText(new_w) != NULL) {
+		Lab_AccTextRect(new_w).x += margin;
+		Lab_AccTextRect(new_w).y += margin;
+	    }
 #endif
 	    refresh_needed = True;
 	}
