@@ -1,8 +1,9 @@
 /**
  *
- * $Id: PushBG.c,v 1.78 2000/03/17 17:48:50 danny Exp $
+ * $Id: PushBG.c,v 1.82 2000/09/22 20:35:12 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushBG.c,v 1.78 2000/03/17 17:48:50 danny Exp $";
+static const char rcsid[] = "$Id: PushBG.c,v 1.82 2000/09/22 20:35:12 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdarg.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -38,11 +43,8 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.78 2000/03/17 17:48:50 danny Exp
 #include <Xm/RepType.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/LabelP.h>
-#include <X11/Xfuncs.h>
 #include <X11/ShellP.h>
 
-#include <stdarg.h>
-
 #include <XmI/DebugUtil.h>
 
 /*
@@ -456,7 +458,7 @@ secondary_object_create(Widget request, Widget new_w,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -471,7 +473,7 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmPushBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmPushButtonGCacheObjPart *)A),
+    return !memcmp(((XmPushButtonGCacheObjPart *)A),
 		 ((XmPushButtonGCacheObjPart *)B),
 		 sizeof(XmPushButtonGCacheObjPart));
 }
@@ -509,10 +511,10 @@ class_initialize(void)
 			     &labels, &nlabels);
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
-    bcopy(labels, combined, nlabels * sizeof(XtResource));
-    bcopy(cache_resources,
-	  &combined[nlabels],
-	  XtNumber(cache_resources) * sizeof(XtResource));
+    memcpy(combined, labels, nlabels * sizeof(XtResource));
+    memcpy(&combined[nlabels],
+           cache_resources,
+	   XtNumber(cache_resources) * sizeof(XtResource));
     XtFree((char *)labels);
 
     xmPushButtonGCacheObjClassRec.object_class.resources = combined;
@@ -723,8 +725,10 @@ initialize(Widget request, Widget new_w,
 
 	    LabG_TextRect_x(new_w) += margin;
 	    LabG_TextRect_y(new_w) += margin;
-	    LabG_AccTextRect(new_w).x += margin;
-	    LabG_AccTextRect(new_w).y += margin;
+	    if (LabG_AcceleratorText(new_w) != NULL) {
+		LabG_AccTextRect(new_w).x += margin;
+		LabG_AccTextRect(new_w).y += margin;
+	    }
 	}
     }
 
@@ -776,12 +780,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(PBG_Cache(new_w),
-	  &((XmPushButtonGCacheObject)nsec)->pushbutton_cache,
-	  sizeof(XmPushButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmPushButtonGCacheObject)nsec)->pushbutton_cache,
+           PBG_Cache(new_w),
+	   sizeof(XmPushButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -796,7 +800,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
     LabG_Cache(new_w) = &(((XmPushButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmPushButtonGCacheObject)rsec)->label_cache);
@@ -952,8 +956,10 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	    LabG_TextRect_x(new_w) += margin;
 	    LabG_TextRect_y(new_w) += margin;
-	    LabG_AccTextRect(new_w).x += margin;
-	    LabG_AccTextRect(new_w).y += margin;
+	    if (LabG_AcceleratorText(new_w)) {
+		LabG_AccTextRect(new_w).x += margin;
+		LabG_AccTextRect(new_w).y += margin;
+	    }
 
 	    refresh_needed = True;
 	}
@@ -1073,12 +1079,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(PBG_Cache(new_w),
-	  &((XmPushButtonGCacheObject)nsec)->pushbutton_cache,
-	  sizeof(XmPushButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmPushButtonGCacheObject)nsec)->pushbutton_cache,
+           PBG_Cache(new_w),
+	   sizeof(XmPushButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
