@@ -1,8 +1,9 @@
 /**
  *
- * $Id: RCUtils.c,v 1.90 1998/10/26 21:38:37 rwscott Exp $
+ * $Id: RCUtils.c,v 1.108 2000/09/23 15:05:25 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: RCUtils.c,v 1.90 1998/10/26 21:38:37 rwscott Exp $";
+static const char rcsid[] = "$Id: RCUtils.c,v 1.108 2000/09/23 15:05:25 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
-#include <X11/Xfuncs.h>
+#include <stdio.h>
+#include <string.h>
+#include <stdarg.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/BaseClassP.h>
 #include <Xm/CascadeBP.h>
@@ -50,11 +54,6 @@ static const char rcsid[] = "$Id: RCUtils.c,v 1.90 1998/10/26 21:38:37 rwscott E
 #include <Xm/ToggleBGP.h>
 #include <Xm/TransltnsP.h>
 
-#include <stdio.h>
-#include <string.h>
-#include <stdarg.h>
-#include <assert.h>
-
 #include <XmI/DebugUtil.h>
 
 /*
@@ -91,7 +90,16 @@ static void DoLayoutVC(Widget rc, Widget instig,
 		       XtWidgetGeometry *instig_request,
 		       int max_width, int max_height);
 
-void
+/* For the prototype police */
+extern XmRCKidGeometry _XmRCGetKidGeo(Widget w, Widget instig,
+				      XtWidgetGeometry *instig_request,
+				      int uniform_border, Dimension border,
+				      int uniform_width_margins,
+				      int uniform_height_margins, Widget help,
+				      Widget toc, int geoType);
+
+#if 0
+static void
 dump_boxes(WidgetList wl, XmRCKidGeometry boxes, int cnt)
 {
     int i;
@@ -111,6 +119,7 @@ dump_boxes(WidgetList wl, XmRCKidGeometry boxes, int cnt)
 	       boxes[i].margin_top, boxes[i].margin_bottom);
     }
 }
+#endif
 
 /*
  * This function computes the preferred size when the packing is PACK_NONE
@@ -210,8 +219,11 @@ PreferredSizeHT(Widget rc, XtWidgetGeometry *rcg,
 	if ((RC_FromResize(rc) || (rcg->request_mode & CWWidth)) &&
 	    current_x + kid_geometry->box.width > (rcg->request_mode & CWWidth ? rcg->width : XtWidth(rc)))
 	{
-	    current_y += *max_height + RC_Spacing(rc) + RC_MarginW(rc) + MGR_ShadowThickness(rc);
-	    current_x = RC_MarginW(rc) + MGR_ShadowThickness(rc);
+	    if (RC_Type(rc) != XmMENU_OPTION) /* rowcolumn/test58 */
+	    {
+		current_y += *max_height + RC_Spacing(rc) + RC_MarginW(rc) + MGR_ShadowThickness(rc);
+		current_x = RC_MarginW(rc) + MGR_ShadowThickness(rc);
+	    }
 	}
 
 	current_x += kid_geometry->box.width;
@@ -295,33 +307,37 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	}
 
 	/* Height treatment */
-	kid_geometry->box.height = max_height;
+	if (!(RC_Type(rc) == XmMENU_OPTION && XmIsCascadeButtonGadget(kid)))
+	    kid_geometry->box.height = max_height;
 
 	/*
 	 * check for row adjustment
 	 */
-	if (current_x + kid_geometry->box.width > XtWidth(rc) &&
-	    current_x > RC_MarginW(rc) + MGR_ShadowThickness(rc))
+	if (RC_Type(rc) != XmMENU_OPTION) /* rowcolumn/test58 */
 	{
-	    /* compute the local max_height */
-	    lmh = 0;
-	    for (j = first_in_row; j < i; j++)
+	    if (current_x + kid_geometry->box.width > XtWidth(rc) &&
+		current_x > RC_MarginW(rc) + MGR_ShadowThickness(rc))
 	    {
-		if (XtIsManaged(RC_Boxes(rc)[j].kid) &&
-		    RC_Boxes(rc)[j].box.height > lmh)
-		    lmh = RC_Boxes(rc)[j].box.height;
-	    }
-	    /* set the local max_height */
-	    for (j = first_in_row; j < i; j++)
-	    {
-		RC_Boxes(rc)[j].box.height = lmh;
-	    }
+		/* compute the local max_height */
+		lmh = 0;
+		for (j = first_in_row; j < i; j++)
+		{
+		    if (XtIsManaged(RC_Boxes(rc)[j].kid) &&
+			RC_Boxes(rc)[j].box.height > lmh)
+			lmh = RC_Boxes(rc)[j].box.height;
+		}
+		/* set the local max_height */
+		for (j = first_in_row; j < i; j++)
+		{
+		    RC_Boxes(rc)[j].box.height = lmh;
+		}
 
-	    printf("lmh %d spacing %d %d %d\n", lmh, RC_Spacing(rc),
-	    	RC_MarginW(rc), MGR_ShadowThickness(rc));
-	    current_y += lmh + RC_MarginW(rc) + MGR_ShadowThickness(rc); /* mainw/test14 */
-	    current_x = RC_MarginW(rc) + MGR_ShadowThickness(rc);
-	    first_in_row = i;
+		/* printf("lmh %d spacing %d %d %d\n", lmh, RC_Spacing(rc),
+		   RC_MarginW(rc), MGR_ShadowThickness(rc)); */
+		current_y += lmh + RC_MarginW(rc) + MGR_ShadowThickness(rc); /* mainw/test14 */
+		current_x = RC_MarginW(rc) + MGR_ShadowThickness(rc);
+		first_in_row = i;
+	    }
 	}
 
 	kid_geometry->box.x = current_x;
@@ -330,6 +346,9 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	if (kid == instig && instig_request != NULL)
 	{
 	    *instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	}
 
 	current_x += RC_Spacing(rc) + kid_geometry->box.width;
@@ -379,6 +398,9 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	if (kid == instig && instig_request != NULL)
 	{
 	    *instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	}
 
 	current_x += RC_Spacing(rc) + kid_geometry->box.width;
@@ -398,7 +420,9 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
     /* set the local max_height */
     for (j = first_in_row; j < i; j++)
     {
-	RC_Boxes(rc)[j].box.height = lmh;
+	if (!(RC_Type(rc) == XmMENU_OPTION &&
+	      XmIsCascadeButtonGadget(RC_Boxes(rc)[j].kid)))
+	    RC_Boxes(rc)[j].box.height = lmh;
     }
 
     /* now we fill in the last row, so it takes up the remaining height, 
@@ -415,20 +439,27 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 		continue;
 	    }
 
-	    if ((XtHeight(rc) <= current_y + RC_MarginH(rc)) ||
-		(max_height + RC_MarginH(rc) > XtHeight(rc)))
+	    if (!(RC_Type(rc) == XmMENU_OPTION &&
+		  XmIsCascadeButtonGadget(kid)))
 	    {
-		kid_geometry->box.height = max_height;
-	    }
-	    else
-	    {
-		kid_geometry->box.height = (XtHeight(rc)
-		     - (current_y + RC_MarginH(rc) + MGR_ShadowThickness(rc)));
+		if ((XtHeight(rc) <= current_y + RC_MarginH(rc)) ||
+		    (max_height + RC_MarginH(rc) > XtHeight(rc)))
+		{
+		    kid_geometry->box.height = max_height;
+		}
+		else
+		{
+		    kid_geometry->box.height = XtHeight(rc) -
+			(current_y + RC_MarginH(rc) + MGR_ShadowThickness(rc));
+		}
 	    }
 
 	    if (kid == instig && instig_request != NULL)
 	    {
 		*instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	    }
 	}
     }
@@ -510,7 +541,14 @@ PreferredSizeHC(Widget rc, XtWidgetGeometry *rcg,
 
     if (number_per_row > 1 || nrows > RC_NCol(rc))
     {
+    int num_man = nrows;
+
 	nrows = RC_NCol(rc);
+	while (nrows * number_per_row >= num_man)
+	{
+	    nrows--;
+	}
+	nrows++;
     }
 
     /* Determine the RC's size */
@@ -546,6 +584,10 @@ DoLayoutHC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 
     number_per_row = ((_XmGeoCount_kids((CompositeWidget)rc) - 1) /
 		      RC_NCol(rc)) + 1;
+    if (number_per_row < 1)
+    {
+    	number_per_row = 1;
+    }
     if (XtIsRealized(rc) && max_width < (XtWidth(rc) - 2 * (RC_MarginW(rc) + MGR_ShadowThickness(rc)) - (RC_Spacing(rc) * (number_per_row - 1))) / number_per_row)
     {
 	box_width = (XtWidth(rc) - 2 * (RC_MarginW(rc) + MGR_ShadowThickness(rc)) - (RC_Spacing(rc) * (number_per_row - 1))) / number_per_row;
@@ -584,6 +626,9 @@ DoLayoutHC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	if (kid == instig && instig_request != NULL)
 	{
 	    *instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	}
 
 	current_x += RC_Spacing(rc) + box_width;
@@ -618,6 +663,9 @@ DoLayoutHC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	    if (kid == instig && instig_request != NULL)
 	    {
 		*instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	    }
 
 	}
@@ -699,7 +747,7 @@ PreferredSizeVT(Widget rc, XtWidgetGeometry *rcg,
     rcg->request_mode = CWWidth | CWHeight | CWBorderWidth;
     rcg->width = curw + RC_MarginW(rc) + MGR_ShadowThickness(rc);
 
-    if (RC_FromResize(rc) && rcg->width > XtWidth(rc))
+    if ((!RC_ResizeWidth(rc) || RC_FromResize(rc)) && rcg->width > XtWidth(rc) && XtWidth(rc) > 0)
     {
     	/* rws 25 Oct 1998 (rowcolumn/test42, xephem, xmgrace)
     	   If we are being resized then we can't be any wider than the RC.
@@ -790,6 +838,9 @@ DoLayoutVT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	if (kid == instig && instig_request != NULL)
 	{
 	    *instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	}
 
 	current_y += RC_Spacing(rc) + kid_geometry->box.height;
@@ -846,6 +897,9 @@ DoLayoutVT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	    if (kid == instig && instig_request != NULL)
 	    {
 		*instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	    }
 	}
     }
@@ -913,7 +967,14 @@ PreferredSizeVC(Widget rc, XtWidgetGeometry *rcg,
 
     if (number_per_column > 1 || ncols > RC_NCol(rc))
     {
+    int num_man = ncols;
+
 	ncols = RC_NCol(rc);
+	while (ncols * number_per_column >= num_man)
+	{
+	    ncols--;
+	}
+	ncols++;
     }
 
     /* Figure out how big we need to be */
@@ -983,6 +1044,9 @@ DoLayoutVC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	if (kid == instig && instig_request != NULL)
 	{
 	    *instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	    DEBUGOUT(XdbDebug(__FILE__, rc,
 			      "LayoutVC: instig set to %s\n",
 			      XdbWidgetGeometry2String(instig_request)));
@@ -1029,6 +1093,9 @@ DoLayoutVC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	    if (kid == instig && instig_request != NULL)
 	    {
 		*instig_request = kid_geometry->box;
+		/* T. Straumann: account for border width */
+		instig_request->width -= 2*kid_geometry->box.border_width;
+		instig_request->height -= 2*kid_geometry->box.border_width;
 	        DEBUGOUT(XdbDebug(__FILE__, rc,
 			          "LayoutVC: instig set to %s after AdjLast\n",
 			          XdbWidgetGeometry2String(instig_request)));
@@ -1105,7 +1172,7 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 	       Widget help, Widget toc, int geoType)
 {
     int i;
-    XmRCKidGeometry kid_geometry;
+    XmRCKidGeometry kid_geometry = NULL;
     Dimension mmt = 0, mmb = 0;
     XmRCKidGeometry boxes = NULL;
 
@@ -1237,8 +1304,10 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 	    kid_geometry = &boxes[i];
 
 	    if (!XtIsManaged(kid_geometry->kid) ||
-		(!XmIsLabel(kid_geometry->kid) &&
-		 !XmIsLabelGadget(kid_geometry->kid)))
+		((!XmIsLabel(kid_geometry->kid) ||
+		  XtClass(kid_geometry->kid) == xmLabelWidgetClass) &&
+		 (!XmIsLabelGadget(kid_geometry->kid) ||
+		  XtClass(kid_geometry->kid) == xmLabelGadgetClass)))
 	    {
 		continue;
 	    }
@@ -1277,20 +1346,34 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 	}
 	if (obg == kid_geometry->kid)
 	{
-	    find_largest_option_selection(CBG_Submenu(obg), &width,
-					  &height);
-	    width += LabG_MarginRight(obg) + 
-		2 * G_HighlightThickness(obg) + G_ShadowThickness(obg) +
-		Xm3D_ENHANCE_PIXEL;
-	    height += 2 * G_HighlightThickness(obg);
-	    if (width > kid_geometry->box.width)
+	    Widget submenu = CBG_Submenu(obg);
+
+	    if (CBG_Submenu(obg))
 	    {
-		kid_geometry->box.width = width;
+		find_largest_option_selection(submenu, &width, &height);
+		width += (LabG_Highlight(obg) << 1)
+		    + (LabG_StringDirection(obg) == XmSTRING_DIRECTION_L_TO_R
+		       ? LabG_MarginRight(obg) : LabG_MarginLeft(obg))
+		    + LabG_Shadow(obg)
+		    - Xm3D_ENHANCE_PIXEL;
+		if (submenu)
+		{
+		    width += MGR_ShadowThickness(submenu) << 1;
+		}
+		height += (LabG_Highlight(obg) << 1);
+		/* rowcolumn/test61 */
+		if (RC_Orientation(w) == XmHORIZONTAL)
+		{
+		    height += RCC_MarginTop(obg) + RCC_MarginBottom(obg);
+		}
 	    }
-	    if (height > kid_geometry->box.height)
+	    else
 	    {
-		kid_geometry->box.height = height;
+	    	width = XtWidth(obg);
+	    	height = XtHeight(obg);
 	    }
+	    kid_geometry->box.width = width;
+	    kid_geometry->box.height = height;
 	}
     }
 
@@ -1319,11 +1402,13 @@ _XmRCSetKidGeo(XmRCKidGeometry kg, Widget instigator)
 	{
 	    if (kg->box.request_mode & CWX)
 	    {
-		XtX(instigator) = kg->box.x - kg->box.border_width;
+		/* T. Straumann: origin of instigator should coincide with the box origin */
+		XtX(instigator) = kg->box.x /*  - kg->box.border_width */;
 	    }
 	    if (kg->box.request_mode & CWY)
 	    {
-		XtY(instigator) = kg->box.y - kg->box.border_width;
+		/* T. Straumann: origin of instigator should coincide with the box origin */
+		XtY(instigator) = kg->box.y /*  - kg->box.border_width */;
 	    }
 	    if (kg->box.request_mode & CWWidth)
 	    {
@@ -1344,10 +1429,11 @@ _XmRCSetKidGeo(XmRCKidGeometry kg, Widget instigator)
 		 kg->box.height != XtHeight(kg->kid) ||
 		 kg->box.border_width != XtBorderWidth(kg->kid))
 	{
+		/* T. Straumann: account for border width */
 	    _XmConfigureObject(kg->kid,
-			       kg->box.x - kg->box.border_width,
-			       kg->box.y - kg->box.border_width,
-			       kg->box.width, kg->box.height,
+			       kg->box.x,
+			       kg->box.y,
+			       kg->box.width-2*kg->box.border_width, kg->box.height-2*kg->box.border_width,
 			       kg->box.border_width);
 	}
 
@@ -1365,7 +1451,9 @@ _XmRCSetMargins(Widget rc)
 	XmRCKidGeometry kg = &RC_Boxes(rc)[i];
 
 	if (RC_DoMarginAdjust(rc) && XtIsManaged(kg->kid) &&
-	    (XmIsLabel(kg->kid) || XmIsLabelGadget(kg->kid)))
+	    ((XmIsLabel(kg->kid) && XtClass(kg->kid) != xmLabelWidgetClass) ||
+	     (XmIsLabelGadget(kg->kid) &&
+	      XtClass(kg->kid) != xmLabelGadgetClass)))
 	{
 	    DEBUGOUT(XdbDebug(__FILE__, kg->kid, "Setting margins to %d %d\n",
 			      kg->margin_top, kg->margin_bottom));
@@ -1523,15 +1611,21 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
 			  "_XmRCAdjustSize: requesting %s from parent %s\n",
 			XdbWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 
-	if (!RC_ResizeWidth(rc) /* && XtIsRealized(rc) */)
+	if (XtWidth(rc) != 0 && !RC_ResizeWidth(rc) /* && XtIsRealized(rc) */)
 	{
 	    rcg.request_mode &= ~CWWidth;
 	    rcg.width = XtWidth(rc);
+	    DEBUGOUT(XdbDebug(__FILE__, rc,
+			  "_XmRCAdjustSize: Dis-allow width change requesting %s from parent %s\n",
+			XdbWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 	}
-	if (!RC_ResizeHeight(rc) /* && XtIsRealized(rc) */)
+	if (XtHeight(rc) != 0 && !RC_ResizeHeight(rc) /* && XtIsRealized(rc) */)
 	{
 	    rcg.request_mode &= ~CWHeight;
 	    rcg.height = XtHeight(rc);
+	    DEBUGOUT(XdbDebug(__FILE__, rc,
+			  "_XmRCAdjustSize: Dis-allow height change requesting %s from parent %s\n",
+			XdbWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 	}
 #if 0
 	if (!XtIsRealized(rc))
@@ -1744,7 +1838,7 @@ MakePrivateShell(Widget parent, char *name, Arg *args, Cardinal num_args)
     shell_num_args = num_args + n;
                      
     /* put together the new name */
-    shell_name = XtMalloc(strlen(name) + 7);
+    shell_name = XtMalloc((name ? strlen(name) : 0) + 7);
     sprintf(shell_name, "popup_%s", name);
 
     /* create the shell */
@@ -1917,9 +2011,13 @@ XmCreatePulldownMenu(Widget parent, char *name,
     }
 
     XtSetArg(myArgList[n], XmNrowColumnType, XmMENU_PULLDOWN); n++;
+    /* rws 17 Aug 1999
+       These are handled by initialize. Setting them here prevents changing
+       these with resources.
     XtSetArg(myArgList[n], XmNorientation, XmVERTICAL); n++;
     XtSetArg(myArgList[n], XmNpacking, XmPACK_TIGHT); n++;
     XtSetArg(myArgList[n], XmNnumColumns, 1); n++;
+    */
 
     combined = XtMergeArgLists(myArgList, n, arglist, argcount);
 
