@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Region.c,v 1.6 2000/04/30 22:38:23 amai Exp $
+ * $Id: Region.c,v 1.7 2000/09/23 15:05:25 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,11 +22,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: Region.c,v 1.6 2000/04/30 22:38:23 amai Exp $";
+static const char rcsid[] = "$Id: Region.c,v 1.7 2000/09/23 15:05:25 amai Exp $";
 
 #include <LTconfig.h>
 
-#include <stdio.h>
 #include <stdlib.h>
 
 #include <XmI/XmI.h>
@@ -282,7 +282,7 @@ _XmRegionIntersectRectWithRegion(XRectangle *rect,
 	    continue;
 	}
 
-	printf("Rectangle %d intersects\n", i);
+/*	printf("Rectangle %d intersects\n", i); */
 
 	/* if we're here the rectangles intersect */
 
