@@ -1,8 +1,9 @@
 /**
  *
- * $Id: RepType.c,v 1.11 2000/01/21 16:04:22 amai Exp $
+ * $Id: RepType.c,v 1.14 2000/11/06 09:40:17 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,24 +22,18 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: RepType.c,v 1.11 2000/01/21 16:04:22 amai Exp $";
+static const char rcsid[] = "$Id: RepType.c,v 1.14 2000/11/06 09:40:17 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
-
-#include <Xm/Xm.h>
-#include <Xm/XmP.h>
-#include <Xm/RepType.h>
 
 #include <stdio.h>
-#ifdef HAVE_STRING_H
-#define ANSI_STRING
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 #include <ctype.h>
 
+#include <XmI/XmI.h>
+#include <Xm/XmP.h>
+#include <Xm/RepType.h>
+
 #include <XmI/DebugUtil.h>
 
 static XmRepTypeList rep_types = NULL;
@@ -558,7 +553,7 @@ XmRepTypeRegister(String rep_type,
     /* now install the forward converter */
 
     Args[0].address_mode = XtImmediate;
-    Args[0].address_id = (XtPointer)number_of_types;
+    Args[0].address_id = (XtPointer)(long)number_of_types;
     Args[0].size = sizeof(XmRepTypeId);
 
     XtSetTypeConverter(XmRString, rep_type,
