@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ResConvert.c,v 1.59 2000/08/04 15:19:59 amai Exp $
+ * $Id: ResConvert.c,v 1.68 2000/12/03 00:12:11 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.59 2000/08/04 15:19:59 amai Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.68 2000/12/03 00:12:11 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -30,10 +31,7 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.59 2000/08/04 15:19:59 amai E
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#endif
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
@@ -44,7 +42,6 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.59 2000/08/04 15:19:59 amai E
 #include <Xm/VendorSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/XmosP.h>
-#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -112,6 +109,7 @@ static Boolean _XmCvtStringToRenderTable(Display *display, XrmValue *args,
 		       XtPointer *converter_data);
 #endif
 
+
 int	xmUseVersion = 0;
 
 /* please be careful if you're editting these arrays, as
@@ -612,7 +610,8 @@ static unsigned char indicator_on_values[] =
 
 #endif
 
-void
+
+extern void
 XmRegisterConverters(void)
 {
     /* don't really know the difference between the two, so
@@ -621,7 +620,8 @@ XmRegisterConverters(void)
     _XmRegisterConverters();
 }
 
-void
+
+extern void
 _XmRegisterConverters(void)
 {
     static Boolean first = True;
@@ -1005,32 +1005,121 @@ _XmRegisterConverters(void)
 #endif
 }
 
+
 /*
  * error convenience
  */
 void
-_XmError(Widget w, char *fmt,...)
+_XmError(Widget w, const char *fmt, ...)
 {
     va_list arg_list;
-    char buf[256];
+    char buf[1024];
+    int charsleft=sizeof(buf);
 
     va_start(arg_list, fmt);
+#ifdef HAVE_VSNPRINTF
+    charsleft -= vsnprintf(buf, sizeof(buf),
+                           fmt, arg_list);
+#else
+    charsleft -= vsprintf(buf,
+                          fmt, arg_list);
+    /* one might add a catch here ... */
+#endif
+    va_end(arg_list);
     if (w)
     {
-	vsprintf(buf, fmt, arg_list);
-	va_end(arg_list);
-
 	XtAppError(XtWidgetToApplicationContext(w), buf);
     }
     else
     {
-	vsprintf(buf, fmt, arg_list);
-	va_end(arg_list);
-
 	XtError(buf);
     }
 }
 
+
+/*
+ * Warning convenience
+ *
+ * Added XdbDebug stuff here to be able to avoid infinite loops in applications
+ * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
+ * bugs of cource :-(
+ */
+static void
+_LtWarning(Widget w, const char *fmt, va_list arg_list)
+{
+ /* Somewhere it's pointed out that we shouldn't exceed 1024 characters here.
+    Let's reserve two chars for \n\000
+    If we don't have (v)snprintf() we have a vulnerable piece of
+    code here ...  */
+#define BUFLEN 1026
+    char buf[BUFLEN]="";
+    int charsleft=BUFLEN;
+    static Boolean redirect=False;
+#ifndef	LESSTIF_PRODUCTION
+    static Boolean init=False;
+
+
+    if (!init) {
+    	if (getenv("DEBUG_REDIRECT_XMWARNING"))
+	   redirect = True;
+	init=True;
+    }
+#endif /* !LESSTIF_PRODUCTION */
+
+    if (w)
+    {
+#ifdef HAVE_SNPRINTF
+	charsleft -= snprintf(buf, charsleft,
+    	                      "\n    Name: %s\n    Class: %s\n    ",
+		              XtName(w), XtClass(w)->core_class.class_name);
+#else
+	charsleft -= sprintf(buf,
+	                     "\n    Name: %s\n    Class: %s\n    ",
+		             XtName(w), XtClass(w)->core_class.class_name);
+        /* one might add a catch here ... */
+#endif
+
+#ifdef HAVE_VSNPRINTF
+	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
+	                       fmt, arg_list);
+#else
+	charsleft -= vsprintf(buf + strlen(buf),
+	                      fmt, arg_list);
+        /* one might add a catch here ... */
+#endif
+
+	strcat(buf, "\n");
+
+	if (redirect)
+	{
+	    XdbPrintString(buf);
+	}
+	else
+	{
+	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
+	}
+    }
+    else
+    {
+#ifdef HAVE_VSNPRINTF
+	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
+	          fmt, arg_list);
+#else
+	charsleft -= vsprintf(buf + strlen(buf),
+	         fmt, arg_list);
+#endif
+
+	if (redirect)
+	{
+	    XdbPrintString(buf);
+	}
+	else
+	{
+	    XtWarning(buf);
+	}
+    } /* if(w) */
+}
+
 /*
  * Warning convenience
  *
@@ -1038,76 +1127,58 @@ _XmError(Widget w, char *fmt,...)
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
  * bugs of cource :-(
  */
-void
-_XmWarning(Widget w, char *fmt,...)
+
+/* unshadow for the Motif 2.x build */
+#ifdef _XmWarning
+#undef _XmWarning
+#endif
+
+extern void
+_XmWarning(Widget w, const char *fmt, ...)
 {
     va_list arg_list;
-    char buf[1024];
 
     va_start(arg_list, fmt);
-    if (w)
-    {
-	sprintf(buf, "\n    Name: %s\n    Class: %s\n    ",
-		XtName(w), XtClass(w)->core_class.class_name);
-
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-	strcat(buf, "\n");
-
-#ifdef	LESSTIF_PRODUCTION
-	XtAppWarning(XtWidgetToApplicationContext(w), buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
-	}
-#endif
-    }
-    else
-    {
-	buf[0] = '\0';
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-#ifdef	LESSTIF_PRODUCTION
-	XtWarning(buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtWarning(buf);
-	}
-#endif
-    }
+    _LtWarning(w, fmt, arg_list);
+    va_end(arg_list);
 }
 
-char *
+
+#if XmVERSION >= 2
+extern void
+XmeWarning(Widget w, const char *fmt, ...)
+{
+    va_list arg_list;
+
+    va_start(arg_list, fmt);
+    _LtWarning(w, fmt, arg_list);
+    va_end(arg_list);
+}
+#endif
+
+
+extern char *
 XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding)
 {
     return NULL;
 }
 
-char *
+
+extern char *
 XmMapSegmentEncoding(char *fontlist_tag)
 {
     return NULL;
 }
 
-XmString
+
+extern XmString
 XmCvtCTToXmString(char *text)
 {
     return XmStringCreate(text, XmFONTLIST_DEFAULT_TAG);
 }
 
-Boolean
+
+extern Boolean
 XmCvtTextToXmString(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1115,7 +1186,8 @@ XmCvtTextToXmString(Display *display, XrmValuePtr args,
     return False;
 }
 
-char *
+
+extern char *
 XmCvtXmStringToCT(XmString string)
 {
     char *text = (char *)NULL;
@@ -1166,7 +1238,7 @@ XmCvtXmStringToCT(XmString string)
     return text;
 }
 
-Boolean
+extern Boolean
 XmCvtXmStringToText(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1236,13 +1308,14 @@ XmCvtXmStringToText(Display *display, XrmValuePtr args,
     return True;
 }
 
+
 /*
  * Compare two strings to see if they're equivalent. This one is used
  * whenever comparing motif constants with resource string values. The
  * motif constants must have the Xm prefix stripped off and must be
  * in lower case.
  */
-Boolean
+extern Boolean
 _XmStringsAreEqual(char *in_str,
 		   char *text_str)
 {
@@ -1263,17 +1336,24 @@ _XmStringsAreEqual(char *in_str,
     return *text_str ? False : True;
 }
 
+
 /*
  * Fixed this thing to make a COPY of the fontlist it returns.
  * Danny 16/4/1996
  */
-XmFontList
+extern XmFontList
 _XmGetDefaultFontList(Widget w,
 		      unsigned char fontListType)
 {
+#if 1
+    XmFontList labelFontList = NULL;
+    XmFontList buttonFontList = NULL;
+    XmFontList textFontList = NULL;
+#else
     static XmFontList labelFontList = NULL;
     static XmFontList buttonFontList = NULL;
     static XmFontList textFontList = NULL;
+#endif
     Widget par = w;
     XmFontList fontlist;
     XmVendorShellExtObject ve = NULL;
@@ -1349,8 +1429,9 @@ _XmGetDefaultFontList(Widget w,
 		}
 	    }
 	}
-	if (fontlist)
-	    return XmFontListCopy(fontlist);
+	if (fontlist) {
+		return XmFontListCopy(fontlist);
+	}
 
 	if (!buttonFontList)
 	{
@@ -1419,13 +1500,14 @@ _XmGetDefaultFontList(Widget w,
 
 /* resource converters, of various types */
 
-char *
+extern char *
 _XmConvertCSToString(XmString cs)
 {
     return NULL;
 }
 
-Boolean
+
+extern Boolean
 _XmCvtXmStringToCT(XrmValue *from,
 		   XrmValue *to)
 {
@@ -1506,6 +1588,7 @@ __XmFontListResourceAddEntry(Display *display,
 			     XmFontList oldFontList)
 {
     XmFontList newFontList;
+    XmFontListEntry newEntry;
     char *eq, *end, *fn, *ft, *tag, *font, *semi, *colon;
 
     DEBUGOUT(XdbDebug(__FILE__, NULL,
@@ -1557,11 +1640,9 @@ __XmFontListResourceAddEntry(Display *display,
 	    *end = 0;
 	}
 
-	newFontList = XmFontListAppendEntry(oldFontList,
-					    XmFontListEntryLoad(display,
-								font,
-								XmFONT_IS_FONT,
-								tag));
+        newEntry = XmFontListEntryLoad(display,
+                                       font, XmFONT_IS_FONT, tag);
+	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
 
 	XtFree(ft);
 	XtFree(fn);
@@ -1608,11 +1689,9 @@ __XmFontListResourceAddEntry(Display *display,
 	{
 	    *colon = '\0';
 	}
-	newFontList = XmFontListAppendEntry(oldFontList,
-					    XmFontListEntryLoad(display,
-								fn,
-							      XmFONT_IS_FONTSET,
-								tag));
+	newEntry = XmFontListEntryLoad(display,
+                                       fn, XmFONT_IS_FONTSET, tag);
+	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
 
 	XtFree(fn);
 
@@ -1638,10 +1717,9 @@ __XmFontListResourceAddEntry(Display *display,
 	end++;
 	*end = 0;
     }
-    newFontList = XmFontListAppendEntry(oldFontList,
-					XmFontListEntryLoad(display, full_entry,
-							    XmFONT_IS_FONT,
-						      XmFONTLIST_DEFAULT_TAG));
+    newEntry = XmFontListEntryLoad(display,
+                                   full_entry, XmFONT_IS_FONT, XmFONTLIST_DEFAULT_TAG);
+    newFontList = XmFontListAppendEntry(oldFontList, newEntry);
     XtFree(fn);
     return newFontList;
 }
@@ -1865,11 +1943,7 @@ _XmCvtStringToCardinal(Display *display,
 		    (String *)NULL, (Cardinal *)NULL);
 	}
 
-#ifdef	HAVE_STRTOUL
 	value = strtoul((char *)from->addr, &end, 10);
-#else
-	value = (Cardinal)strtol((char *)from->addr, &end, 10);
-#endif
 
 	if (*end == '\0')
 	{
@@ -1946,6 +2020,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
     return False;
 }
 
+
 static Boolean
 _XmCvtStringToResIndPosition(Display *display,
 			     XrmValue *args,
@@ -1963,7 +2038,7 @@ _XmCvtStringToResIndPosition(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = (Position)_XmConvertUnits(*(Screen **)args[0].addr,
-				    (int)*(XtPointer *)args[1].addr,
+				    (int)(long)*(XtPointer *)args[1].addr,
 				    *(unsigned char *)args[2].addr,
 				    atoi(from->addr),
 				    XmPIXELS);
@@ -1978,7 +2053,7 @@ _XmCvtStringToResIndPosition(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalPosition : XmRVerticalPosition);
 	    return False;
 	}
@@ -1989,6 +2064,7 @@ _XmCvtStringToResIndPosition(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToResIndDimension(Display *display,
 			      XrmValue *args,
@@ -2006,7 +2082,7 @@ _XmCvtStringToResIndDimension(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     dim = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-				     (int)*(XtPointer *)args[1].addr,
+				     (int)(long)*(XtPointer *)args[1].addr,
 				     *(unsigned char *)args[2].addr,
 				     atoi(from->addr),
 				     XmPIXELS);
@@ -2021,7 +2097,7 @@ _XmCvtStringToResIndDimension(Display *display,
 	if (to->size < sizeof dim)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalDimension : XmRVerticalDimension);
 	    return False;
 	}
@@ -2032,6 +2108,7 @@ _XmCvtStringToResIndDimension(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToResIndInt(Display *display,
 			XrmValue *args,
@@ -2049,7 +2126,7 @@ _XmCvtStringToResIndInt(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = _XmConvertUnits(*(Screen **)args[0].addr,
-			  (int)*(XtPointer *)args[1].addr,
+			  (int)(long)*(XtPointer *)args[1].addr,
 			  *(unsigned char *)args[2].addr,
 			  atoi(from->addr),
 			  XmPIXELS);
@@ -2064,7 +2141,7 @@ _XmCvtStringToResIndInt(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalInt : XmRVerticalInt);
 	    return False;
 	}
@@ -2075,6 +2152,7 @@ _XmCvtStringToResIndInt(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToWidget(	Display *display,
 			XrmValue *args,
@@ -2129,6 +2207,7 @@ _XmCvtStringToWidget(	Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToWindow(Display *display,
 		     XrmValue *args,
@@ -2155,6 +2234,7 @@ _XmCvtStringToWindow(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToBooleanDimension( Display *display,
 				XrmValue *args,
@@ -2180,7 +2260,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	if (isdigit(str[0])) {
 	    preval = atoi(from->addr);
 	    value = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-					       (int)*(XtPointer *)args[1].addr,
+					       (int)(long)*(XtPointer *)args[1].addr,
 					       *(unsigned char *)args[2].addr,
 					       preval,
 					       XmPIXELS);
@@ -2222,6 +2302,7 @@ _XmCvtStringToBooleanDimension( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToChar( Display *display,
 		    XrmValue *args,
@@ -2248,6 +2329,7 @@ _XmCvtStringToChar( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToTextPosition( Display *display,
 			    XrmValue *args,
@@ -2275,6 +2357,7 @@ _XmCvtStringToTextPosition( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToTopItemPosition( Display *display,
 			       XrmValue *args,
@@ -2302,6 +2385,7 @@ _XmCvtStringToTopItemPosition( Display *display,
     return True;
 }
 
+
 /* Converter for various tables of comma-separated strings,
  * with those strings converted each in their own way.
  */
@@ -2327,7 +2411,7 @@ _XmCvtStringToSomeTable( Display *display,
     nitems = 0;
     item = NULL;
     escaped = anyescaped = False;
-    tabtype = (int)*(XtPointer *)args[0].addr;
+    tabtype = (int)(long)*(XtPointer *)args[0].addr;
     for (p = from->addr;; p++)
     {
 	if (escaped)
@@ -2506,6 +2590,7 @@ _XmCvtStringToSomeTable( Display *display,
     return True;
 }
 
+
 static void
 destroy_font_list(XtAppContext app, XrmValue *to,
 		  XtPointer converer_data, XrmValue *args,
@@ -2514,6 +2599,7 @@ destroy_font_list(XtAppContext app, XrmValue *to,
     XmFontListFree(*(XmFontList *)to->addr);
 }
 
+
 static void
 destroy_table(XtAppContext app, XrmValue *to,
 	      XtPointer converer_data, XrmValue *args,
@@ -2522,6 +2608,7 @@ destroy_table(XtAppContext app, XrmValue *to,
     XtFree(*(char **)to->addr);
 }
 
+
 static void
 destroy_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2535,6 +2622,7 @@ destroy_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
+
 static void
 destroy_xm_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2548,6 +2636,7 @@ destroy_xm_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
+
 static void
 get_unit_type(Widget w, Cardinal *size, XrmValue *val)
 {
@@ -2565,11 +2654,12 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
  * uses the specified screen's resolution to compute the number of units for
  * the string specification.
  */
-int
+extern int
 XmConvertStringToUnits(Screen *screen, String spec, int orientation,
 	int to_type, XtEnum *parse_error)
 {
 	/* FIX ME not implemented yet */
+        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
 
 	if (screen == NULL)
 		return 0;
@@ -2595,6 +2685,7 @@ XmConvertStringToUnits(Screen *screen, String spec, int orientation,
     return 0;
 }
 
+
 static Boolean
 _XmCvtStringToTabList(Display *display,
 		       XrmValue *args,
@@ -2606,6 +2697,7 @@ _XmCvtStringToTabList(Display *display,
 	return False;
 }
 
+
 static Boolean
 _XmCvtStringToRenderTable(Display *display,
 		       XrmValue *args,
@@ -2614,6 +2706,28 @@ _XmCvtStringToRenderTable(Display *display,
 		       XrmValue *to,
 		       XtPointer *converter_data)
 {
+
 	return False;
 }
-#endif
+
+
+extern unsigned int
+XmCvtXmStringToByteStream(XmString string,
+                      unsigned char **prop_return)
+{
+        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
+	return 0;
+}
+
+
+extern int
+XmCvtXmStringTableToTextProperty (Display *display,
+                                      XmStringTable string_table,
+                                      int count,
+                                      XmICCEncodingStyle style,
+                                      XTextProperty *text_prop_return)
+{
+        _XmWarning(NULL, "XmCvtXmStringTableToTextProperty() is not implemented yet!\n");
+	return 0;
+}				      
+#endif /* XmVERSION > 1 */
