@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ResInd.c,v 1.9 1998/10/08 05:24:51 gritton Exp $
+ * $Id: ResInd.c,v 1.23 2000/11/06 09:40:17 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -28,13 +29,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResInd.c,v 1.9 1998/10/08 05:24:51 gritton Exp $";
+static const char rcsid[] = "$Id: ResInd.c,v 1.23 2000/11/06 09:40:17 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <X11/Xfuncs.h>
 #include <Xm/ManagerP.h>
 #include <Xm/PrimitiveP.h>
 #include <Xm/GadgetP.h>
@@ -43,17 +45,6 @@ static const char rcsid[] = "$Id: ResInd.c,v 1.9 1998/10/08 05:24:51 gritton Exp
 
 #include <XmI/DebugUtil.h>
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
-    extern void _XtCopyFromArg(XtArgVal, char *, int);
-
-#ifdef __cplusplus
-}
-#endif
-
 /*
  * ruthlessly stripped from Xt/Resources.c
  */
@@ -76,7 +67,7 @@ CopyToArg(char *src, XtArgVal *dst, unsigned int size)
     if (size <= sizeof(XtArgVal))
     {
 
-	bcopy((char *)src, (char *)&u, (int)size);
+	memcpy(&u, src, size);
 
 	if (size == sizeof(long))
 	{
@@ -106,12 +97,12 @@ CopyToArg(char *src, XtArgVal *dst, unsigned int size)
 	}
 	else
 	{
-	    bcopy((char *)src, (char *)dst, (int)size);
+	    memcpy(dst, src, size);
 	}
     }
     else
     {
-	bcopy((char *)src, (char *)dst, (int)size);
+	memcpy(dst, src, size);
     }
 }
 
@@ -120,7 +111,7 @@ CopyFromArg(XtArgVal src, char *dst, unsigned int size)
 {
     if (size > sizeof(XtArgVal))
     {
-	bcopy((char *)src, (char *)dst, (int)size);
+	memcpy(dst, (void *)src, size);
     }
     else
     {
@@ -169,7 +160,7 @@ CopyFromArg(XtArgVal src, char *dst, unsigned int size)
 	    p = (char *)&src;
 	}
 
-	bcopy(p, dst, (int)size);
+	memcpy(dst, p, size);
     }
 }
 
@@ -276,12 +267,12 @@ _XmBuildResources(XmSyntheticResource **wc_resources_ptr,
 
     ncmb = *wc_num_resources_ptr + sc_num_resources;
     cmb = (XmSyntheticResource *)XtMalloc(ncmb * sizeof(XmSyntheticResource));
-    bcopy((void *)sc_resources,
-	  (void *)cmb,
-	  sc_num_resources * sizeof(XmSyntheticResource));
-    bcopy((void *)*wc_resources_ptr,
-	  (void *)&cmb[sc_num_resources],
-	  *wc_num_resources_ptr * sizeof(XmSyntheticResource));
+    memcpy((void *)cmb,
+           (void *)sc_resources,
+	   sc_num_resources * sizeof(XmSyntheticResource));
+    memcpy((void *)&cmb[sc_num_resources],
+           (void *)*wc_resources_ptr,
+	   *wc_num_resources_ptr * sizeof(XmSyntheticResource));
 
     for (i = 0; i < sc_num_resources; i++)
     {
@@ -295,9 +286,9 @@ _XmBuildResources(XmSyntheticResource **wc_resources_ptr,
 		cmb[i] = cmb[wb + j];
 		if ((ncmb - (wb + j + 1) > 0))
 		{
-		    bcopy((void *)&cmb[wb + j + 1],
-			  (void *)&cmb[wb + j],
-			  (ncmb - (wb + j + 1)) * sizeof(XmSyntheticResource));
+		    memcpy((void *)&cmb[wb + j],
+		           (void *)&cmb[wb + j + 1],
+			   (ncmb - (wb + j + 1)) * sizeof(XmSyntheticResource));
 		}
 		ncmb--;
 	    }
@@ -329,7 +320,7 @@ _XmInitializeSyntheticResources(XmSyntheticResource *resources,
     for (i = 0; i < num_resources; i++)
     {
 	resources[i].resource_name =
-	    (char *)XrmStringToQuark(resources[i].resource_name);
+	    (char *)(long)XrmStringToQuark(resources[i].resource_name);
     }
 }
 
@@ -377,7 +368,7 @@ _XmPrimitiveGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &pwc->primitive_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -416,7 +407,7 @@ _XmPrimitiveGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -463,7 +454,7 @@ _XmGadgetGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &gwc->gadget_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -502,7 +493,7 @@ _XmGadgetGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -549,7 +540,7 @@ _XmManagerGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &pwc->manager_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -588,7 +579,7 @@ _XmManagerGetValuesHook(Widget w,
 	    XrmQuark rq;
 
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -634,7 +625,7 @@ _XmExtGetValuesHook(Widget w,
 	for (j = 0; j < ewc->ext_class.num_syn_resources; j++)
 	{
 	    res = &ewc->ext_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (rq == tq && res->export_proc != NULL)
 	    {
 		XtArgVal val = 0;
@@ -686,7 +677,7 @@ _XmExtImportArgs(Widget w,
 	for (j = 0; j < ewc->ext_class.num_syn_resources; j++)
 	{
 	    res = &ewc->ext_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc != NULL)
 	    {
 		/*
@@ -746,7 +737,7 @@ _XmPrimitiveImportArgs(Widget w,
 	for (j = 0; j < pwc->primitive_class.num_syn_resources; j++)
 	{
 	    res = &pwc->primitive_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 
 	    if (tq == rq && res->import_proc != NULL)
 	    {
@@ -787,7 +778,7 @@ _XmPrimitiveImportArgs(Widget w,
 	for (j = 0; j < mwc->manager_class.num_syn_constraint_resources; j++)
 	{
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc)
 	    {
 		value = args[i].value;
@@ -840,7 +831,7 @@ _XmGadgetImportArgs(Widget w,
 	for (j = 0; j < gwc->gadget_class.num_syn_resources; j++)
 	{
 	    res = &gwc->gadget_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc != NULL)
 	    {
 		/*
@@ -880,7 +871,7 @@ _XmGadgetImportArgs(Widget w,
 	for (j = 0; j < mwc->manager_class.num_syn_constraint_resources; j++)
 	{
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc)
 	    {
 		value = args[i].value;
@@ -941,7 +932,7 @@ _XmGadgetImportSecondaryArgs(Widget w,
 	for (j = 0; j < subpclass->ext_class.num_syn_resources; j++)
 	{
 	    res = &subpclass->ext_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc != NULL)
 	    {
 		/*
@@ -962,6 +953,7 @@ _XmManagerImportArgs(Widget w,
 		     ArgList args,
 		     Cardinal *num_args)
 {
+    /*XmManagerWidget mw = (XmManagerWidget)w;*/
     XmManagerWidgetClass pwc = (XmManagerWidgetClass)XtClass(w);
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)XtClass(XtParent(w));
     int i;
@@ -986,10 +978,34 @@ _XmManagerImportArgs(Widget w,
 
 	tq = XrmStringToQuark(args[i].name);
 
+#if 0
+	/* Hack
+	 * Don't assign 0 values to width/height
+	 *
+	 * Danny june 24, 1999
+	 */
+	if (tq == XrmStringToQuark(XmNwidth)) {
+		if (mw->manager.user_data == 0xdead) {
+			_XmWarning(w, "_XmManagerImportArgs (in init): set width of widget to 0\n");
+		} else {
+			_XmWarning(w, "_XmManagerImportArgs: won't set width of widget to 0\n");
+			continue;
+		}
+	}
+	if (tq == XrmStringToQuark(XmNheight)) {
+		if (mw->manager.user_data == 0xdead) {
+			_XmWarning(w, "_XmManagerImportArgs (in init): set height of widget to 0\n");
+		} else {
+			_XmWarning(w, "_XmManagerImportArgs: won't set height of widget to 0\n");
+			continue;
+		}
+	}
+#endif
+
 	for (j = 0; j < pwc->manager_class.num_syn_resources; j++)
 	{
 	    res = &pwc->manager_class.syn_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc != NULL)
 	    {
 		/*
@@ -1028,7 +1044,7 @@ _XmManagerImportArgs(Widget w,
 	for (j = 0; j < mwc->manager_class.num_syn_constraint_resources; j++)
 	{
 	    res = &mwc->manager_class.syn_constraint_resources[j];
-	    rq = (XrmQuark)res->resource_name;
+	    rq = (XrmQuark)(long)res->resource_name;
 	    if (tq == rq && res->import_proc)
 	    {
 		value = args[i].value;
@@ -1059,7 +1075,7 @@ _XmConvertUnits(Screen *screen,
 		int from_val,
 		int to_type)
 {
-    int		fu, cmmpp;
+    int		fu = 0, cmmpp = 0;
     struct conv
     {
 	int	num, denom;	/* Constant conversion factor		*/
@@ -1171,7 +1187,8 @@ _XmSortResourceList(XrmResource *list[],
     }
 
     tmp = list[i];
-    bcopy((void *)&list[0], (void *)&list[1], i * sizeof(XrmResource *));
+/*    memcpy((void *)&list[1], (void *)&list[0], i * sizeof(XrmResource *)); */
+    list[i] = list[0];
     list[0] = tmp;
 }
 
@@ -1272,6 +1289,11 @@ _XmExportXmString(Widget w, int offset, XtArgVal *value)
     }
 
     *value = (XtArgVal)str;
+
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmExportXmString(%p, %d, _) %p -> '%s'\n",
+		w, offset,
+		str,
+		XdbXmString2String(str)));
 }
 
 void
