@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Sash.c,v 1.12 1998/09/13 20:17:51 rwscott Exp $
+ * $Id: Sash.c,v 1.14 2000/09/23 15:05:25 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Sash.c,v 1.12 1998/09/13 20:17:51 rwscott Exp $";
+static const char rcsid[] = "$Id: Sash.c,v 1.14 2000/09/23 15:05:25 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/SashP.h>
 #include <Xm/DisplayP.h>
@@ -36,7 +37,7 @@ static const char rcsid[] = "$Id: Sash.c,v 1.12 1998/09/13 20:17:51 rwscott Exp
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -186,7 +187,7 @@ XmSashClassRec xmSashClassRec = {
 WidgetClass xmSashWidgetClass = (WidgetClass)&xmSashClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmSashCoreClassExtRec.record_type = XmQmotif;
 }
