@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $
+ * $Id: Scale.c,v 1.42 2000/12/12 17:09:31 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $";
+static const char rcsid[] = "$Id: Scale.c,v 1.42 2000/12/12 17:09:31 amai Exp $";
 
 #include <LTconfig.h>
-#include <stdlib.h>
-#include <XmI/XmI.h>
 
+#include <stdlib.h>
+#include <stdio.h>
+#include <limits.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ScaleP.h>
 #include <Xm/LabelGP.h>
@@ -37,9 +41,6 @@ static const char rcsid[] = "$Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $"
 #include <Xm/VendorSP.h>
 #include <Xm/VendorSEP.h>
 
-#include <stdio.h>
-#include <limits.h>
-
 #include <XmI/DebugUtil.h>
 
 /* Forward Declarations */
@@ -50,7 +51,7 @@ static const char rcsid[] = "$Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $"
 #define CHILD_SB	1
 
 /* FIX ME/BUGS
- *   - higlight
+ *   - highlight
  */
 
 /*
@@ -204,7 +205,7 @@ static XtResource resources[] =
     {
 	XmNdecimalPoints, XmCDecimalPoints, XmRShort,
 	sizeof(short), Offset(decimal_points),
-	XmRImmediate, (XtPointer)0
+	XmRImmediate, (XtPointer)(short)0
     },
     {
 	XmNscaleWidth, XmCScaleWidth, XmRHorizontalDimension,
@@ -239,7 +240,7 @@ static XtResource resources[] =
 #if XmVERSION > 1
     {
 	XmNeditable, XmCEditable, XmRBoolean,
-	sizeof(int), Offset(editable),
+	sizeof(Boolean), Offset(editable),
 	XmRImmediate, (XtPointer)True
     },
 #endif
@@ -280,7 +281,7 @@ static XtActionsRec actions[] =
     {"FocusOut", LoseFocus}
 };
 #endif
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmScaleCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -387,17 +388,19 @@ XmScaleClassRec xmScaleClassRec =
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
+
 
 
 WidgetClass xmScaleWidgetClass = (WidgetClass)&xmScaleClassRec;
 
+
 static void
 class_initialize(void)
 {
     _XmScaleCoreClassExtRec.record_type = XmQmotif;
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
@@ -428,6 +431,7 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmSCALE_BIT);
 }
 
+
 static void
 CreateForegroundGC(Widget w)
 {
@@ -595,6 +599,7 @@ initialize(Widget request, Widget new_w,
 #endif
 }
 
+
 static void
 destroy(Widget w)
 {
@@ -607,6 +612,7 @@ destroy(Widget w)
     XtDestroyGC(Scale_ForegroundGC(w));
 }
 
+
 /*
  * called when the user changes a resource
  */
@@ -801,6 +807,7 @@ set_values(Widget old, Widget request, Widget new_w,
     return refresh;
 }
 
+
 static void
 expose(Widget w,
        XEvent *event,
@@ -818,6 +825,7 @@ expose(Widget w,
     }
 }
 
+
 /*
  * called when our parent wants to find out how we would like to look.  It
  * doesn't have to honor our preference, though.
@@ -895,6 +903,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 #endif
 }
 
+
 /*
  * called when our parent is resizing us.  We have no choice but to obey.
  */
@@ -920,6 +929,7 @@ resize(Widget w)
     XtFree((char *)boxes);
 }
 
+
 /*
  * called when one of our children wants to change.  We control whether
  * the child can, or not
@@ -985,6 +995,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 #undef Wants
 }
 
+
 /*
  * called when our Window is allocated.  We may want to change our layout,
  * and we can ask our parent to allow this
@@ -1020,6 +1031,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 #endif
 }
 
+
 /*
  * one of our children has become managed or unmanaged.  We need to relayout
  */
@@ -1045,6 +1057,7 @@ change_managed(Widget w)
     _XmNavigChangeManaged(w);
 }
 
+
 #if 0
 /*
  * a child has been added
@@ -1062,7 +1075,8 @@ insert_child(Widget w)
 }
 #endif
 
-Widget
+
+extern Widget
 XmCreateScale(Widget parent,
 	      char *name,
 	      Arg *arglist,
@@ -1075,14 +1089,16 @@ XmCreateScale(Widget parent,
 			  argcount);
 }
 
-void
+
+extern void
 XmScaleGetValue(Widget widget,
 		int *value_return)
 {
     *value_return = Scale_Value(widget);
 }
 
-void
+
+extern void
 XmScaleSetValue(Widget widget,
 		int value)
 {
@@ -1109,6 +1125,7 @@ XmScaleSetValue(Widget widget,
     }
 }
 
+
 static void
 valueToString(Widget w, char *buf)
 {
@@ -1666,6 +1683,7 @@ printf("COMPUTED %d %d : %d %d\n", curw, cury, incw, inch);
     return boxes;
 }
 
+
 /*
  * if we can, change our size to match
  */
@@ -1701,6 +1719,7 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
     return result;
 }
 
+
 static void
 _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	       Widget child, XtWidgetGeometry *childgeom,
@@ -1923,6 +1942,7 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
 			 inc, p_inc, False);
 }
 
+
 static void
 computeValueSize(Widget w)
 {
@@ -1962,6 +1982,7 @@ computeValueSize(Widget w)
         Scale_FontStruct(w)->max_bounds.descent;
 }
 
+
 static void
 showValue(Widget w, int scb_value, int scale_value)
 {
@@ -2036,6 +2057,7 @@ showValue(Widget w, int scb_value, int scale_value)
     }
 }
 
+
 static void
 _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2063,6 +2085,7 @@ _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
+
 static void
 _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2071,7 +2094,7 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     int scale_value;
 
 #if XmVERSION > 1
-    if (! Scale_Editable(sb))
+    if (! Scale_Editable(XtParent(sb)))
 	return;
 #endif
 
@@ -2094,6 +2117,7 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
+
 #if 0
 static void
 GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
@@ -2108,6 +2132,7 @@ GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 		     params, *num_params);
 }
 
+
 static void
 LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
@@ -2122,6 +2147,7 @@ LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 #endif
 
+
 static int
 _XmScaleConvertWidthToSliderSize(Widget w)
 {
@@ -2193,6 +2219,7 @@ _XmScaleConvertWidthToSliderSize(Widget w)
     return ret;
 }
 
+
 static int
 _XmScaleConvertSCBValueToScaleValue(Widget w, int value)
 {
@@ -2207,6 +2234,7 @@ _XmScaleConvertSCBValueToScaleValue(Widget w, int value)
 		+ (float)Scale_Minimum(w) );
 }
 
+
 static int
 _XmScaleConvertScaleValueToSCBValue(Widget w)
 {
@@ -2216,6 +2244,7 @@ _XmScaleConvertScaleValueToSCBValue(Widget w)
 		);
 }
 
+
 static void
 _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 {
@@ -2233,4 +2262,3 @@ _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 
     val->addr = (XtPointer)&direction;
 }
-
