@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Screen.c,v 1.15 1998/10/14 21:38:26 rwscott Exp $
+ * $Id: Screen.c,v 1.19 2000/09/18 11:17:58 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,13 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Screen.c,v 1.15 1998/10/14 21:38:26 rwscott Exp $";
+static const char rcsid[] = "$Id: Screen.c,v 1.19 2000/09/18 11:17:58 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
 #include <stdio.h>
 
+#include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/MwmUtil.h>
@@ -45,6 +47,7 @@ static const char rcsid[] = "$Id: Screen.c,v 1.15 1998/10/14 21:38:26 rwscott Ex
 #define XmUNSPECIFIED (~0)
 #endif
 
+
 XrmQuark _XmInvalidCursorIconQuark;
 XrmQuark _XmValidCursorIconQuark;
 XrmQuark _XmNoneCursorIconQuark;
@@ -55,7 +58,7 @@ XrmQuark _XmLinkCursorIconQuark;
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -254,7 +257,7 @@ WidgetClass xmScreenClass = (WidgetClass)&xmScreenClassRec;
 static XContext PerScreenWidgetContext = PSWC_None;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmScreenCoreClassExtRec.record_type = XmQmotif;
 
@@ -882,6 +885,9 @@ _XmGetScreenInfo(Widget scr)
 
 	state->MU_InDragMode = False;
 	state->MU_InPMMode = False;
+	state->RC_menuFocus.oldWidget = NULL;
+	state->RC_menuFocus.oldFocus = None;
+	state->RC_menuFocus.oldRevert = RevertToNone;
 
 	info->menu_state = (XtPointer)state;
 	info->destroyCallbackAdded = False;
@@ -898,7 +904,7 @@ XmGetXmScreen(Screen *scr)
     Widget disp;
     Widget screen;
     int argc;
-    Arg args[5];
+    Arg args[3];
     char name[128];
     int screen_no, max_screens;
 
@@ -929,14 +935,9 @@ XmGetXmScreen(Screen *scr)
 	}
 	sprintf(name, "screen%d", screen_no);
 
-	screen = XtCreateManagedWidget(name, xmScreenClass, disp,
+	screen = XtCreateWidget(name, xmScreenClass, disp,
 				       args, argc);
     }
 
-    if (!XtIsRealized(screen))
-    {
-	XtRealizeWidget(screen);
-    }
-
     return screen;
 }
