@@ -1,8 +1,9 @@
 /*
  *
- * $Id: ScrolledW.c,v 1.100 1998/10/24 03:18:41 rwscott Exp $
+ * $Id: ScrolledW.c,v 1.121 2000/11/15 15:03:24 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ScrolledW.c,v 1.100 1998/10/24 03:18:41 rwscott Exp $";
+static const char rcsid[] = "$Id: ScrolledW.c,v 1.121 2000/11/15 15:03:24 amai Exp $";
 
 /*
  * Current status of changes in layout (Danny 18/4/1997) :
@@ -32,18 +33,22 @@ static const char rcsid[] = "$Id: ScrolledW.c,v 1.100 1998/10/24 03:18:41 rwscot
  */
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
 #include <stdio.h>
+#include <string.h>
 
-#include <X11/Xfuncs.h>
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ScrolledWP.h>
 #include <Xm/ScrollBarP.h>
-#include <Xm/DrawingA.h>
+#include <Xm/DrawingAP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/TransltnsP.h>
 
+#if XmVERSION >= 2
+#include <XmI/TransltnsI.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
 #ifndef XmUNSPECIFIED
@@ -62,9 +67,7 @@ static const char rcsid[] = "$Id: ScrolledW.c,v 1.100 1998/10/24 03:18:41 rwscot
 
 /* Forward Declarations */
 
-#if 1
-static void class_initialize();
-#endif
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -95,12 +98,11 @@ static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
 
+#if 0 /* T. Straumann: these are now public in XmI.h */
 static void _XmScrolledWPreferredSize(Widget w, Widget child,
 				      XtWidgetGeometry *childgeom,
 				      XmSWValues *vals);
 
-static XtGeometryResult _XmScrolledWGeomRequest(Widget w, XmSWValues *vals);
-
 static void _XmScrolledWLayout(Widget w, Widget child,
 			       XtWidgetGeometry *childgeom,
 			       XmSWValues *vals);
@@ -108,6 +110,9 @@ static void _XmScrolledWLayout(Widget w, Widget child,
 static void _XmScrolledWConfigureChildren(Widget w, Widget child,
 					  XtWidgetGeometry *childgeom,
 					  XmSWValues *vals);
+#endif
+
+static XtGeometryResult _XmScrolledWGeomRequest(Widget w, XmSWValues *vals);
 
 void _XmConfigureScrollBars(Widget w, Widget child,
 				XtWidgetGeometry *childgeom, XmSWValues *vals);
@@ -289,8 +294,10 @@ static XtActionsRec actions[] =
     {"SWNoop", SWNoop}
 };
 
+static XtTranslations comp_clip_trans;
+
 /* *INDENT-OFF* */
-#if 1
+#if 0
 static XmBaseClassExtRec _XmScrolledWCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -360,7 +367,7 @@ XmScrolledWindowClassRec xmScrolledWindowClassRec = {
 	/* tm_table              */ XtInheritTranslations,
 	/* query_geometry        */ query_geometry,
 	/* display_accelerator   */ NULL,
-	/* extension             */ (XtPointer)&_XmScrolledWCoreClassExtRec
+	/* extension             */ NULL /*(XtPointer)&_XmScrolledWCoreClassExtRec*/
     },
     /* Composite class part */
     {
@@ -388,7 +395,7 @@ XmScrolledWindowClassRec xmScrolledWindowClassRec = {
         /* syn_constraint_resources     */ NULL,
         /* num_syn_constraint_resources */ 0,
         /* parent_process               */ XmInheritParentProcess,
-        /* extension                    */ (XtPointer)&_XmScrolledWMClassExtRec
+        /* extension                    */ NULL /*(XtPointer)&_XmScrolledWMClassExtRec*/
     },
     /* XmScrolledWindow part */
     {
@@ -399,13 +406,17 @@ XmScrolledWindowClassRec xmScrolledWindowClassRec = {
 
 WidgetClass xmScrolledWindowWidgetClass = (WidgetClass)&xmScrolledWindowClassRec;
 
-#if 1
+/* T. Straumann: they don't have this method
+ *				 we use it however to compile the translation table
+ */
 static void
-class_initialize()
+class_initialize(void)
 {
+#if 0
     _XmScrolledWCoreClassExtRec.record_type = XmQmotif;
-}
 #endif
+	comp_clip_trans = XtParseTranslationTable(_XmScrolledW_ClipWindowTranslationTable);
+}
 
 static void
 class_part_initialize(WidgetClass widget_class)
@@ -436,6 +447,7 @@ class_part_initialize(WidgetClass widget_class)
 	}
     }
     _XmFastSubclassInit(widget_class, XmSCROLLED_WINDOW_BIT);
+
 }
 
 /*
@@ -501,14 +513,28 @@ initialize(Widget request, Widget new_w,
 
     if (SW_VisualPolicy(new_w) == XmCONSTANT)
     {
-	XtTranslations tr;
 
-	SW_ClipWindow(new_w) =
-	    (XmDrawingAreaWidget)XtCreateManagedWidget("clipWindow",
-				     xmDrawingAreaWidgetClass, new_w, NULL, 0);
+	/* T. Straumann: M*TIF enforces 0 borderWidth */
+	SW_ClipWindow(new_w) = (XmDrawingAreaWidget)XtVaCreateManagedWidget(
+						"ScrolledWindowClipWindow",
+						xmDrawingAreaWidgetClass, new_w, 
+						XmNborderWidth,0,
+						NULL);
 
-	tr = XtParseTranslationTable(_XmScrolledW_ClipWindowTranslationTable);
-	XtOverrideTranslations((Widget)SW_ClipWindow(new_w), tr);
+	{
+	/* rws 7 Nov 1998
+	   This is for xdir Prefs.
+	 */
+	DA_ResizePolicy(SW_ClipWindow(new_w)) = XmRESIZE_SWINDOW;
+	}
+
+	/* T. Straumann: The compiled translation table is dynamically allocated by Xt
+	 *				 Unless you intend to free it in destroy, don't compile it here.
+	 *				 Since it's constant anyway we do that in class_initialize().
+	 *
+	 * comp_clip_trans = XtParseTranslationTable(_XmScrolledW_ClipWindowTranslationTable);
+	 */
+	XtOverrideTranslations((Widget)SW_ClipWindow(new_w), comp_clip_trans);
     }
     else if (SW_VisualPolicy(new_w) != XmVARIABLE)
     {
@@ -517,23 +543,20 @@ initialize(Widget request, Widget new_w,
 
     if (SW_ScrollPolicy(new_w) == XmAUTOMATIC)
     {
+	/* till 27.5.1999: Note that we don't copy our colors to the
+	 *				   scrollbars anymore. ScrollBar has got a new
+	 *				   ResourceDefaultProc to copy our value as a
+	 *				   default.
+	 *				   This yields correct results also if the
+	 *				   scrollbars are added later.
+	 */
 	SW_VSB(new_w) =
 	    (XmScrollBarWidget)XtVaCreateManagedWidget("VertScrollBar",
 						xmScrollBarWidgetClass, new_w,
 						XmNorientation, XmVERTICAL,
 						XmNsliderSize, 100,
-						XmNforeground,
-						 MGR_Foreground(new_w),
-						XmNbackground,
-						 XtBackground(new_w),
-						XmNtopShadowColor,
-						 MGR_TopShadowColor(new_w),
-						XmNtopShadowPixmap,
-						 MGR_TopShadowPixmap(new_w),
-						XmNbottomShadowColor,
-						 MGR_BottomShadowColor(new_w),
-						XmNbottomShadowPixmap,
-						 MGR_BottomShadowPixmap(new_w),
+	/* T. Straumann: M*TIF enforces 0 borderWidth */
+						XmNborderWidth,0,
 						NULL);
 	SW_HasVSB(new_w) = True;
 
@@ -567,18 +590,8 @@ initialize(Widget request, Widget new_w,
 						xmScrollBarWidgetClass, new_w,
 						XmNorientation, XmHORIZONTAL,
 						XmNsliderSize, 100,
-						XmNforeground,
-						 MGR_Foreground(new_w),
-						XmNbackground,
-						 XtBackground(new_w),
-						XmNtopShadowColor,
-						 MGR_TopShadowColor(new_w),
-						XmNtopShadowPixmap,
-						 MGR_TopShadowPixmap(new_w),
-						XmNbottomShadowColor,
-						 MGR_BottomShadowColor(new_w),
-						XmNbottomShadowPixmap,
-						 MGR_BottomShadowPixmap(new_w),
+	/* T. Straumann: M*TIF enforces 0 borderWidth */
+						XmNborderWidth,0,
 						NULL);
 	SW_HasHSB(new_w) = True;
 
@@ -907,8 +920,10 @@ resize(Widget w)
     /* resize not chained */
     _XmScrolledWPreferredSize(w, NULL, NULL, &vals);
 
+    /*
     vals.SwW = XtWidth(w);
     vals.SwH = XtHeight(w);
+    */
 
     _XmScrolledWLayout(w, NULL, NULL, &vals);
 
@@ -916,10 +931,44 @@ resize(Widget w)
 
     SW_FromResize(w) = False;
 }
+static void _XClearArea(Display *di, Window wi, Position x, Position y, Dimension w, Dimension h, Boolean b)
+{
+	XClearArea(di,wi,x,y,w,h,b);
+}
 
 static void
 expose(Widget w, XEvent *event, Region region)
 {
+	/* T. Straumann:  need to clear the margin areas */
+	/* clear area on top of the clip */
+	_XClearArea(XtDisplay(w),XtWindow(w),
+		(Position)0,
+		(Position)0,
+		(Dimension)(XtWidth(w)),
+		(Dimension)(SW_CWY(w) - MGR_ShadowThickness(w)),
+		False);
+	/* clear area below clip */
+	_XClearArea(XtDisplay(w),XtWindow(w),
+		(Position)0,
+		(Position)(SW_CWY(w) + SW_CWHeight(w) + MGR_ShadowThickness(w)),
+		(Dimension)XtWidth(w),
+		(Dimension) 0, /* clear all below y */
+		False);
+	/* clear to the left of clip */
+	_XClearArea(XtDisplay(w),XtWindow(w),
+		(Position)0,
+		(Position)0,
+		(Dimension)(SW_CWX(w) - MGR_ShadowThickness(w)),
+		(Dimension)(XtHeight(w)),
+		False);
+	/* clear to the right of clip */
+	_XClearArea(XtDisplay(w),XtWindow(w),
+		(Position)(SW_CWX(w) + SW_CWWidth(w) + MGR_ShadowThickness(w)),
+		(Position)0,
+		(Dimension)0, /* all from x to the window width */
+		(Dimension)XtHeight(w),
+		False);
+
     _XmRedisplayGadgets(w, event, region);
 
     _XmDrawShadows(XtDisplay(w), XtWindow(w),
@@ -934,11 +983,15 @@ expose(Widget w, XEvent *event, Region region)
 static void
 realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
 {
+    /*
     XmSWValues vals;
+    */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    	__FILE__, __LINE__,
+    	XtWidth(w), XtHeight(w)));
 
-#if 1
+#if 0
     /* rws 23 Oct 1998
        This stuff should not be here.  It is handled in change_managed, which
        is call just before realize
@@ -960,6 +1013,18 @@ realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
     _XmScrolledWLayout(w, NULL, NULL, &vals);
 
     _XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
+#else
+    if (XtWidth(w) == 0 || XtHeight(w) == 0)
+    {
+    XtWidgetGeometry request;
+
+    	request.request_mode = 0;
+    	request.request_mode |= XtWidth(w) == 0 ? CWWidth : 0;
+    	request.request_mode |= XtHeight(w) == 0 ? CWHeight : 0;
+    	request.width = 100;
+    	request.height = 100;
+    	_XmMakeGeometryRequest(w, &request);
+    }
 #endif
 
 #define superclass (&xmManagerClassRec)
@@ -1059,6 +1124,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     XtWidgetGeometry wants;
     Widget sw = XtParent(w);
     XmSWValues vals;
+	XtGeometryResult rval;
 
     DEBUGOUT(XdbDebug2(__FILE__, sw, w, "geometry_manager (request %s)\n",
 		       XdbWidgetGeometry2String(desired)));
@@ -1074,7 +1140,8 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     wants = *desired;
 
     /* We control the XY of all children. Width/Height is all we care about */
-    wants.request_mode &= CWWidth | CWHeight;
+	/* T. Straumann: we also care about borderWidth */
+    wants.request_mode &= CWWidth | CWHeight | CWBorderWidth;
 
     /*
      * Special case : Work Window trying to resize itself in XmAUTOMATIC
@@ -1131,30 +1198,29 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     /* not chained */
     _XmScrolledWPreferredSize(sw, w, &wants, &vals);
 
-    if (_XmScrolledWGeomRequest(sw, &vals) == XtGeometryYes)
-    {
-#if 1
-	/* rws 25 Mar 1998
-	 * This makes the mgv page list size correctly
-	 *
-	 * jonf 08 Apr 1998
-	 * I think I've fixed that problem, so I put this back in.
+	/* T. Straumann: we only should ask the parent for a size change
+	 *               if we are willing to reconfigure our children.
+	 *               Otherwise we may end up with more space, then do the
+	 *               layout, which possibly modifies `wants' leading to
+	 *               rejection of the child request (--> old configuration
+	 *               with new ScrolledW window size)
 	 */
-	_XmScrolledWLayout(sw, w, &wants, &vals);
-#else
-	_XmScrolledWLayout(sw, NULL, NULL, &vals);
-#endif
-    }
-    else
-    {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
-	return XtGeometryNo;
-    }
+	_XmScrolledWLayout(sw,w,&wants,&vals);
 
-    wants.request_mode &= desired->request_mode & (CWWidth|CWHeight);
+	rval = (	(Wants(CWWidth)		 &&	(wants.width != desired->width))
+			||	(Wants(CWHeight)		 &&	(wants.height != desired->height))
+			||	(Wants(CWBorderWidth) && (wants.border_width != desired->border_width)) )
+			? XtGeometryAlmost : XtGeometryYes;
+
+	/* T. Straumann: we also are able to manage the border width */
+    wants.request_mode &= desired->request_mode & (CWWidth|CWHeight|CWBorderWidth);
 
     *allowed = wants;
 
+    /* Strip off unwanted bits */
+    allowed->request_mode &= wants.request_mode;
+
+
     if (Wants(XtCWQueryOnly))
     {
 	_XmWarning(sw, "XmScrolledWindow: geometry_manager QueryOnly"
@@ -1167,7 +1233,11 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 	return XtGeometryYes;
     }
 
-    if (Wants(CWX) && Wants(CWY) && !(Wants(CWWidth) && Wants(CWHeight)))
+	/* T. Straumann: if (wants(x) && wants(y) && !(wants(w) && wants(h)) )
+	 * didn't make sense to me. Should never pass this test
+	 * anyway if you look at the Layout code.
+	 */
+    if ( (Wants(CWX) || Wants(CWY)) && !(Wants(CWWidth) || Wants(CWHeight) || Wants(CWBorderWidth)))
     {
 	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => No 2\n"));
 	return XtGeometryNo;
@@ -1176,41 +1246,59 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     if (Wants((CWWidth|CWHeight)) == (CWWidth|CWHeight) &&
 	wants.width == desired->width && wants.height == desired->height)
     {
-	_XmScrolledWConfigureChildren(sw, w, &wants, &vals);
-
 	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-1 %s\n",
-	    XdbWidgetGeometry2String(allowed)));
-
-	return XtGeometryYes;
+		XdbWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWWidth &&
 	wants.width == desired->width)
     {
-	_XmScrolledWConfigureChildren(sw, w, &wants, &vals);
-
 	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-2 %s\n",
-	    XdbWidgetGeometry2String(allowed)));
-
-	return XtGeometryYes;
+		XdbWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWHeight &&
 	wants.height == desired->height)
     {
-	_XmScrolledWConfigureChildren(sw, w, &wants, &vals);
-
 	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-3 %s\n",
-	    XdbWidgetGeometry2String(allowed)));
-
-	return XtGeometryYes;
+		XdbWidgetGeometry2String(allowed)));
     }
-
-    /* Strip off unwanted bits */
-    allowed->request_mode &= wants.request_mode;
-
+	else if (rval == XtGeometryYes)
+	{
+	/* T. Straumann: change in border width only */
+	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-4 %s\n",
+		XdbWidgetGeometry2String(allowed)));
+	}
+	else
+	{
     DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager -> Almost %s\n",
-	XdbWidgetGeometry2String(allowed)));
+		XdbWidgetGeometry2String(allowed)));
+	}
 
-    return XtGeometryAlmost;
+
+	if ( rval == XtGeometryYes)
+	{
+    if ( _XmScrolledWGeomRequest(sw, &vals) == XtGeometryYes)
+    {
+#if 1
+	/* rws 25 Mar 1998
+	 * This makes the mgv page list size correctly
+	 *
+	 * jonf 08 Apr 1998
+	 * I think I've fixed that problem, so I put this back in.
+	 */
+	/* T. Straumann: should do layout before asking parent for new geometry */
+	_XmScrolledWConfigureChildren(sw, w, &wants, &vals);
+#else
+	_XmScrolledWLayout(sw, NULL, NULL, &vals);
+#endif
+    }
+    else
+    {
+	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
+	return XtGeometryNo;
+    }
+	}
+
+    return rval;
 }
 
 static void
@@ -1224,11 +1312,13 @@ change_managed(Widget w)
     {
 	_XmScrolledWPreferredSize(w, NULL, NULL, &vals);
 
-	_XmScrolledWGeomRequest(w, &vals);
+	if (_XmScrolledWGeomRequest(w, &vals) == XtGeometryYes)
+	{
 
-	_XmScrolledWLayout(w, NULL, NULL, &vals);
+	    _XmScrolledWLayout(w, NULL, NULL, &vals);
 
-	_XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
+	    _XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
+	}
 
 	DEBUGOUT(XdbDebug(__FILE__, w, "change_managed: size %d %d\n",
 			  XtWidth(w), XtHeight(w)));
@@ -1288,6 +1378,13 @@ insert_child(Widget w)
     }
     else if (XmIsScrollBar(w))
     {
+	/* T. Straumann: M*TIF enforces 0 borderWidth on SW children
+	 *				 (except the work window)
+	 */
+	if ( 0 != XtBorderWidth(w) )
+	{
+		XtVaSetValues(w,XmNborderWidth,0,NULL);
+	}
 	(*superclass->composite_class.insert_child) (w);
 
 	switch (SCB_Orientation(w))
@@ -1415,7 +1512,13 @@ _XmRepositionScrolledWindow(Widget w, XtPointer client, XtPointer call)
 
     if (SW_VSB(sw))
     {
-	XtVaGetValues((Widget)SW_VSB(sw), XmNvalue, &v, NULL);
+	if ((call != NULL) && ((Widget)SW_VSB(sw) == w))
+	{
+	    v = ((XmScrollBarCallbackStruct *)call)->value;
+	}
+	else {
+	    XtVaGetValues((Widget)SW_VSB(sw), XmNvalue, &v, NULL);
+	}
 
 	SW_VSBValue(sw) = v;
     }
@@ -1426,7 +1529,13 @@ _XmRepositionScrolledWindow(Widget w, XtPointer client, XtPointer call)
 
     if (SW_HSB(sw))
     {
-	XtVaGetValues((Widget)SW_HSB(sw), XmNvalue, &h, NULL);
+	if ((call != NULL) && ((Widget)SW_HSB(sw) == w))
+	{
+	    h = ((XmScrollBarCallbackStruct *)call)->value;
+	}
+	else {
+	    XtVaGetValues((Widget)SW_HSB(sw), XmNvalue, &h, NULL);
+	}
 
 	SW_HSBValue(sw) = h;
     }
@@ -1723,11 +1832,19 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 
     if (childgeom)
     {
-	childgeom->request_mode &= (CWWidth | CWHeight | XtCWQueryOnly);
+	/* T. Straumann: allow changes of border width of the work window */
+	if (child == SW_WorkWindow(w))
+	{
+		childgeom->request_mode &= (CWWidth | CWHeight | CWBorderWidth | XtCWQueryOnly);
+	}
+	else
+	{
+		childgeom->request_mode &= (CWWidth | CWHeight | XtCWQueryOnly);
+	}
     }
 
     /* Initialize all local variables to reflect their widgets */
-    bzero(vals, sizeof(XmSWValues));
+    memset(vals, 0, sizeof(XmSWValues));
 
     if (SW_VSB(w))
     {
@@ -1766,7 +1883,9 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    XtWidgetGeometry workgeo;
 
-	    XtQueryGeometry(SW_WorkWindow(w), NULL, &workgeo);
+	    XtQueryGeometry(SW_WorkWindow(w),
+						child == SW_WorkWindow(w) ? childgeom : NULL,
+						&workgeo);
 	    vals->WorkW = workgeo.width + 2 * workgeo.border_width;
 	    vals->WorkH = workgeo.height + 2 * workgeo.border_width;
 	}
@@ -1806,23 +1925,41 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
     }
     else
     {
-	vals->SwW = 0;
-	vals->SwH = 0;
+	/* T. Straumann: at creation time, their scrolledw isn't really
+	 *				 variable but it sets the size (scrolledwindow/test19).
+	 */
+		if (XtIsRealized(w) && !SW_FromResize(w))
+		{
+		vals->SwW = 0;
+		vals->SwH = 0;
+		}
+		else
+		{
+		vals->SwW = XtWidth(w);
+		vals->SwH = XtHeight(w);
+		}
     }
 
     if (childgeom)
     {
 	/* only happens for APPLICATION_DEFINED */
+	/* T. Straumann: NOT TRUE;
+	 * if the work window asks for a size change, we get here
+	 * anyway.
+	 */
 	if (child == (Widget)SW_WorkWindow(w))
 	{
-	    if (childgeom->request_mode & CWWidth)
-	    {
-		vals->WorkW = childgeom->width;
-	    }
-	    if (childgeom->request_mode & CWHeight)
-	    {
-		vals->WorkH = childgeom->height;
-	    }
+		/* T. Straumann: added support for borderWidth
+		 * (border width of scrollbars and clip are 0)
+		 */
+		Dimension bw = 2 * (childgeom->request_mode & CWBorderWidth	? childgeom->border_width
+																	: XtBorderWidth(child) );
+		Dimension ww = childgeom->request_mode & CWWidth ? childgeom->width
+											             : XtWidth(child);
+		Dimension hh = childgeom->request_mode & CWHeight ? childgeom->height
+											              : XtHeight(child);
+		vals->WorkW = ww + bw;
+		vals->WorkH = hh + bw;
 	}
 	/* only happens for AUTOMATIC */
 	if (child == (Widget)SW_ClipWindow(w))
@@ -1881,8 +2018,16 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    vals->ShowVSB = True;
 	}
 #else
+	if (SW_WorkWindow(w) && XtIsManaged(SW_WorkWindow(w)))
+	{
 	vals->ShowHSB = SW_HSB(w) ? XtIsManaged(SW_HSB(w)) : False;
 	vals->ShowVSB = SW_VSB(w) ? XtIsManaged(SW_VSB(w)) : False;
+	}
+	else
+	{
+	vals->ShowHSB = False;
+	vals->ShowVSB = False;
+	}
 #endif
 
 	/* If we're being resized (grown), make sure child follows */
@@ -1918,7 +2063,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	}
 
 	/* If child is bigger than we are, grow (if we can) */
-	if (!SW_FromResize(w) && SW_VisualPolicy(w) == XmVARIABLE)
+	if (!SW_FromResize(w) && SW_VisualPolicy(w) == XmVARIABLE )
 	{
 	    /* rws 25 Mar 1998
 	     * Where does this 3 come from??? Just like FileSB:ListPreferredWidth
@@ -1929,7 +2074,12 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	     * The 3 is no longer needed, since the mgv page list problem is now
 	     * fixed.
 	     */
-	    if (/*3 +*/ vals->WorkW + 2 * (SW_MarginWidth(w) +
+
+		/* T. Straumann: their scrolledW doesn't allow the child to
+	 	 *				 grow at creation time (scrolledwindow/test19).
+	 	 */
+	    if ( (XtIsRealized(w) || vals->SwW == 0 ) &&
+			   /*3 +*/ vals->WorkW + 2 * (SW_MarginWidth(w) +
 		       MGR_ShadowThickness(w)) + 
 		       (vals->ShowVSB ? (SW_Spacing(w) + vals->VsbW) : 0) > vals->SwW)
 	    {
@@ -1943,7 +2093,12 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 				   "Grow SwW %d -> %d\n",
 				   xx, vals->SwW));
 	    }
-	    if (vals->WorkH + 2 * (SW_MarginHeight(w) +
+
+		/* T. Straumann: their scrolledW doesn't allow the child to
+	 	 *				 grow at creation time (scrolledwindow/test19).
+	 	 */
+	    if ( (XtIsRealized(w) || vals->SwH == 0 ) &&
+	    	 vals->WorkH + 2 * (SW_MarginHeight(w) +
 				   MGR_ShadowThickness(w)) +
 			(vals->ShowHSB ? (SW_Spacing(w) + vals->HsbH) : 0) > vals->SwH)
 	    {
@@ -1972,10 +2127,36 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	else
 	{
 	    /* do we need to display scrollbars ? */
-	    vals->ShowHSB = (vals->WorkW + 2 * SW_MarginWidth(w) +
-			     2 * MGR_ShadowThickness(w)) > vals->SwW;
-	    vals->ShowVSB = (vals->WorkH + 2 * SW_MarginHeight(w) +
-			     2 * MGR_ShadowThickness(w)) > vals->SwH;
+		/* T. Straumann: the need for one bar might urge for the
+		 * second as well.
+		 * Note that the state 'need scrollbars'
+		 * is bi-stable for certain window sizes. I.e. `scrollbars
+		 * are needed if they're there and not needed if they are not
+		 * there' - almost philosophical isn't it :-). This obviously is due
+		 * to the space requirement of the scrollbars themselves.
+		 *
+		 * This algorithm makes sure scrollbars are only shown if
+		 * they are _really_ needed.
+		 */
+		int wtot = vals->WorkW + 2 * (SW_MarginWidth(w) + MGR_ShadowThickness(w));
+		int htot = vals->WorkH + 2 * (SW_MarginHeight(w) + MGR_ShadowThickness(w));
+#ifdef I_WANT_THEIR_SUCKING_EXTRA_SEP
+    	int bw   = vals->HasHSB ? Prim_HighlightThickness(SW_HSB(w)) : 2;
+    	int bh   = vals->HasVSB ? Prim_HighlightThickness(SW_VSB(w)) : 2;
+#else
+#define bw 0
+#define bh 0
+#endif
+		vals->ShowHSB = 	(wtot > vals->SwW)
+						||	((htot > vals->SwH) && (wtot + bw + SW_Spacing(w) + vals->VsbW > vals->SwW));
+		vals->ShowVSB = 	(htot > vals->SwH)
+						||	((wtot > vals->SwW) && (htot + bh + SW_Spacing(w) + vals->HsbH > vals->SwH));
+#ifdef bw
+#undef bw
+#endif
+#ifdef bh
+#undef bh
+#endif
 	}
     }
 
@@ -1987,23 +2168,15 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
     if (SW_VisualPolicy(w) != XmCONSTANT && !SW_FromResize(w) &&
         (vals->SwW == 0 || vals->SwH == 0))
     {
-	if (SW_GivenWidth(w) == 0)
+	if ( vals->SwW==0 )
 	{
-	    vals->SwW = vals->WorkW + 2 * SW_MarginWidth(w) +
-			2 * MGR_ShadowThickness(w);
+	    vals->SwW = SW_GivenWidth(w) ? SW_GivenWidth(w) : vals->WorkW + 2 * SW_MarginWidth(w) +
+														  2 * MGR_ShadowThickness(w);
 	}
-	else
+	if ( vals->SwH==0 )
 	{
-	    vals->SwW = SW_GivenWidth(w);
-	}
-	if (SW_GivenHeight(w) == 0)
-	{
-	    vals->SwH = vals->WorkH + 2 * SW_MarginHeight(w) +
-			2 * MGR_ShadowThickness(w);
-	}
-	else
-	{
-	    vals->SwH = SW_GivenHeight(w);
+	    vals->SwH = SW_GivenHeight(w) ? SW_GivenHeight(w) : vals->WorkH + 2 * SW_MarginHeight(w) +
+															2 * MGR_ShadowThickness(w);
 	}
     }
 }
@@ -2099,6 +2272,7 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 		   XmSWValues *vals)
 {
     Dimension bw, bh;
+	int		  SWY = vals->SwY + SW_MarginHeight(w);
 
     /*
      * Motif has certain layout details that don't seem to be documented other
@@ -2113,7 +2287,34 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
      * jonf  08 Apr 1998
      *	Is there a test in test/Xm that will show the need for 
      *	these adjustments?
+	 *
+	 * T. Straumann 3/1/99
+	 *  Believe the actual size of 'those borders' is just
+	 *  just the highlightThickness ???
+	 *  In case there is only ONE scrollbar managed,
+	 *  their layout sometimes just goes haywire.
+	 *  Well, create one of their ScrolledWindows and
+	 *  play around with different VertScrollBar.highlightThickness
+	 *  / HorScrollBar.highlightThickness settings. Sit back
+	 *  and enjoy their layouting magic.
+	 *  Take, e.g. scrolledwindow/test10, and set
+	 *
+	 *    VertScrollBar.highlightThickness: 0
+	 *    HorScrollBar.highlightThickness: 10
+	 *
+	 *  Note that the vertical scrollbar is neither needed nor 
+	 *  shown. Then monotonically increase the hT of the VSB 
+	 *  the `extra' space between clipWindow and scrollBar
+	 *  will first be negative then it will increase and then
+	 *  shrink again.
+	 *  I don't feel like spending a lot of time trying to imitate
+	 *  this sucking behavior. We should just do it better :-)
+	 *  Still, if I_WANT_THEIR_SUCKING_EXTRA_SEP is defined, the extra
+	 *  space will be there; however, don't expect behavior to be
+	 *  the same as theirs for unequal highlightThicknes settings
+	 *  of VSB and HSB.
      */
+
     bw = vals->HasHSB ? Prim_HighlightThickness(SW_HSB(w)) : 2;
     bh = vals->HasVSB ? Prim_HighlightThickness(SW_VSB(w)) : 2;
 
@@ -2121,28 +2322,32 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
     {
     case XmTOP_RIGHT:
 	/* Independent of scrollbars actually being there */
-	vals->HsbY = SW_MarginHeight(w);
+	vals->HsbY = SWY;
 	vals->VsbX = vals->SwW - vals->VsbW - SW_MarginWidth(w);
-	vals->VsbY = vals->HsbY + vals->HsbH + SW_Spacing(w) - bh;
+	/* T. Straumann: no need for bh */
+	vals->VsbY = vals->HsbY + vals->HsbH + SW_Spacing(w);
 	vals->HsbX = SW_MarginWidth(w);
 
 	break;
 
     case XmBOTTOM_LEFT:
 	/* Independent of scrollbars actually being there */
-	vals->HsbY = vals->SwH - vals->HsbH;
+	/* T. Straumann: respect margin height */
+	vals->HsbY = vals->SwH - vals->HsbH - SW_MarginHeight(w);
 	vals->VsbX = SW_MarginWidth(w);
-	vals->VsbY = SW_MarginHeight(w);
-	vals->HsbX = vals->VsbX + vals->VsbW + SW_Spacing(w) - bw;
+	vals->VsbY = SWY;
+	/* T. Straumann: no need for bw */
+	vals->HsbX = vals->VsbX + vals->VsbW + SW_Spacing(w);
 
 	break;
 
     case XmTOP_LEFT:
 	/* Independent of scrollbars actually being there */
-	vals->HsbY = SW_MarginHeight(w);
+	vals->HsbY = SWY;
 	vals->VsbX = SW_MarginWidth(w);
-	vals->VsbY = vals->HsbY + vals->HsbH + bh;
-	vals->HsbX = vals->VsbX + vals->VsbW + bw;
+	/* T. Straumann: added spacing, no need for bw/bh */
+	vals->VsbY = vals->HsbY + vals->HsbH + SW_Spacing(w);
+	vals->HsbX = vals->VsbX + vals->VsbW + SW_Spacing(w);
 
 	break;
 
@@ -2151,7 +2356,7 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	/* Independent of scrollbars actually being there */
 	vals->HsbX = SW_MarginWidth(w);
 	vals->HsbY = vals->SwH - vals->HsbH - SW_MarginHeight(w);
-	vals->VsbY = SW_MarginHeight(w);
+	vals->VsbY = SWY;
 	vals->VsbX = vals->SwW - vals->VsbW - SW_MarginWidth(w);
 
 	break;
@@ -2171,7 +2376,7 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    vals->ClipW = vals->SwW - 2 * bw - 2 * MGR_ShadowThickness(w)
 		    - SW_Spacing(w) - vals->VsbW - 2 * SW_MarginWidth(w);
 	    vals->ClipH = vals->SwH - 2 * bh - 2 * MGR_ShadowThickness(w)
-		    - SW_Spacing(w) - vals->HsbH - 2 * SW_MarginHeight(w);
+		    - SW_Spacing(w) - vals->HsbH - SW_MarginHeight(w) - SWY;
 
 	    vals->VsbH = vals->ClipH + 2 * bh + 2 * MGR_ShadowThickness(w);
 	    vals->HsbW = vals->ClipW + 2 * bw + 2 * MGR_ShadowThickness(w);
@@ -2179,9 +2384,21 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	else
 	{
 	    vals->ClipY -= bh;
-	    vals->ClipW = vals->SwW - 2 * bw - 2 * MGR_ShadowThickness(w);
+		/* T. Straumann: new clipX, HsbX if vertical bar not visible */
+		vals->ClipX = (vals->HsbX = SW_MarginWidth(w)) + MGR_ShadowThickness(w) + bw;
+		/* T. Straumann: added margin width */
+	    vals->ClipW = vals->SwW - 2 * bw 
+			- 2 * (MGR_ShadowThickness(w) + SW_MarginWidth(w));
+#ifdef I_WANT_THEIR_SUCKING_EXTRA_SEP
+		/* T. Straumann: well, the - 1 * bh isn't really necessary, but
+		 * it seems we are behaving strictly M*TIF here
+		 */
 	    vals->ClipH = vals->SwH - 1 * bh - 2 * MGR_ShadowThickness(w)
-		    - SW_Spacing(w) - vals->HsbH - 2 * SW_MarginHeight(w);
+		    - SW_Spacing(w) - vals->HsbH - SW_MarginHeight(w) - SWY;
+#else
+	    vals->ClipH = vals->SwH - 2 * MGR_ShadowThickness(w)
+		    - SW_Spacing(w) - vals->HsbH - SW_MarginHeight(w) - SWY;
+#endif
 
 	    vals->VsbH = vals->ClipH + 2 * MGR_ShadowThickness(w) + 2 * bh;
 	    vals->HsbW = vals->ClipW + 2 * MGR_ShadowThickness(w) + 2 * bw;
@@ -2189,10 +2406,19 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
     }
     else if (vals->ShowVSB && vals->HasVSB)
     {
-	vals->ClipW = vals->SwW - 2 * bw - 2 * MGR_ShadowThickness(w)
+	/* T. Straumann: horizontal bar not visible -> new clipY, VsbY, ClipX */
+	vals->ClipX -= bw;
+	vals->ClipY = (vals->VsbY = SWY ) + MGR_ShadowThickness(w) + bh;
+#ifdef I_WANT_THEIR_SUCKING_EXTRA_SEP
+	/* T. Straumann: see comment above on 1 * bh */
+	vals->ClipW = vals->SwW - 1 * bw - 2 * MGR_ShadowThickness(w)
 		- SW_Spacing(w) - vals->VsbW - 2 * SW_MarginWidth(w);
+#else
+	vals->ClipW = vals->SwW - 2 * MGR_ShadowThickness(w)
+		- SW_Spacing(w) - vals->VsbW - 2 * SW_MarginWidth(w);
+#endif
 	vals->ClipH = vals->SwH - 2 * bh - 2 * MGR_ShadowThickness(w)
-	    - 2 * SW_MarginHeight(w);
+	    - SW_MarginHeight(w) - SWY;
 
 	vals->VsbH = vals->ClipH + 2 * MGR_ShadowThickness(w) + 2 * bh;
 	vals->HsbW = vals->ClipW + 2 * MGR_ShadowThickness(w) + 2 * bw;
@@ -2201,7 +2427,7 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
     {
 	/* No scrollbars -> no borders anywhere */
 	vals->ClipX = SW_MarginWidth(w) + MGR_ShadowThickness(w);
-	vals->ClipY = SW_MarginHeight(w) + MGR_ShadowThickness(w);
+	vals->ClipY = SWY + MGR_ShadowThickness(w);
 	vals->ClipW = vals->SwW - vals->ClipX - SW_MarginWidth(w)
 		    - MGR_ShadowThickness(w);
 	vals->ClipH = vals->SwH - vals->ClipY - SW_MarginHeight(w)
@@ -2296,7 +2522,14 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
     {
 	if (child == (Widget)SW_WorkWindow(w))
 	{
-	    childgeom->request_mode = CWX | CWY | CWHeight | CWWidth;
+		/* T. Straumann: we only get here if called by geometry_manager and if
+		 * the workWindow instigated a change.
+		 * Since there is no field in vals for
+		 * the workWindow's border width, we should preserve the
+		 * border width flag and value passed in childgeom.
+		 */
+		childgeom->request_mode &= CWBorderWidth;
+	    childgeom->request_mode |= CWX | CWY | CWHeight | CWWidth;
 	    childgeom->x = vals->WorkX;
 	    childgeom->y = vals->WorkY;
 	    childgeom->width = vals->WorkW;
@@ -2350,10 +2583,26 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    XtUnmanageChild((Widget)SW_HSB(w));
 	}
+#else
+	vals->VsbX = vals->SwW;
+	vals->VsbH = vals->SwH + SW_Spacing(w);
+
+	vals->HsbY = vals->SwH;
+	vals->HsbW = vals->SwW + SW_Spacing(w);
 #endif
+#if 0
 	SW_HasVSB(w) = False;
 	SW_HasHSB(w) = False;
 	return;
+#else
+	/* rws 11 Nov 1998
+	   budget
+	 */
+	vals->ShowVSB = False;
+	vals->ShowHSB = False;
+	vals->ClipW = vals->SwW - SW_Spacing(w);
+	vals->ClipH = vals->SwH - SW_Spacing(w);
+#endif
     }
 
     /*
@@ -2512,36 +2761,19 @@ _XmScrolledWConfigureChildren(Widget w, Widget child,
 			   (vals->ShowVSB && vals->HasVSB) ? "" : "not"));
     }
 
-    _XmConfigureScrollBars(w, child, childgeom, vals);
-
-    if (SW_ClipWindow(w))
-    {
-	if (child == (Widget)SW_ClipWindow(w))
-	{
-	    XtX(SW_ClipWindow(w)) = vals->ClipX;
-	    XtY(SW_ClipWindow(w)) = vals->ClipY;
-	    XtWidth(SW_ClipWindow(w)) = vals->ClipW;
-	    XtHeight(SW_ClipWindow(w)) = vals->ClipH;
-	}
-	else
-	{
-	    _XmConfigureObject((Widget)SW_ClipWindow(w),
-			       vals->ClipX, vals->ClipY,
-			       vals->ClipW, vals->ClipH,
-			       XtBorderWidth(SW_ClipWindow(w)));
-	}
-
-	SW_CWX(w) = vals->ClipX;
-	SW_CWY(w) = vals->ClipY;
-	SW_CWWidth(w) = vals->ClipW;
-	SW_CWHeight(w) = vals->ClipH;
-    }
     if (SW_WorkWindow(w) && XtIsManaged(SW_WorkWindow(w)))
     {
 	if (child == SW_WorkWindow(w))
 	{
 	    XtX(SW_WorkWindow(w)) = vals->WorkX;
 	    XtY(SW_WorkWindow(w)) = vals->WorkY;
+		/* T. Straumann: configure border width (no field in vals, we take the
+		 *				 value passed in childgeom, if valid)
+		 */
+		if ( childgeom->request_mode & CWBorderWidth )
+		{
+			XtBorderWidth(SW_WorkWindow(w)) = childgeom->border_width;
+		}
 	    XtWidth(SW_WorkWindow(w)) = vals->WorkW - 2 * XtBorderWidth(SW_WorkWindow(w));
 	    XtHeight(SW_WorkWindow(w)) = vals->WorkH - 2 * XtBorderWidth(SW_WorkWindow(w));
 	}
@@ -2553,6 +2785,31 @@ _XmScrolledWConfigureChildren(Widget w, Widget child,
 			       XtBorderWidth(SW_WorkWindow(w)));
 	}
 
+	_XmConfigureScrollBars(w, child, childgeom, vals);
+
+	if (SW_ClipWindow(w))
+	{
+	    if (child == (Widget)SW_ClipWindow(w))
+	    {
+		XtX(SW_ClipWindow(w)) = vals->ClipX;
+		XtY(SW_ClipWindow(w)) = vals->ClipY;
+		XtWidth(SW_ClipWindow(w)) = vals->ClipW;
+		XtHeight(SW_ClipWindow(w)) = vals->ClipH;
+	    }
+	    else
+	    {
+		_XmConfigureObject((Widget)SW_ClipWindow(w),
+				   vals->ClipX, vals->ClipY,
+				   vals->ClipW, vals->ClipH,
+				   XtBorderWidth(SW_ClipWindow(w)));
+	    }
+
+	    SW_CWX(w) = vals->ClipX;
+	    SW_CWY(w) = vals->ClipY;
+	    SW_CWWidth(w) = vals->ClipW;
+	    SW_CWHeight(w) = vals->ClipH;
+	}
+
 	if (SW_ScrollPolicy(w) != XmAUTOMATIC)
 	{
 	    SW_CWX(w) = vals->ClipX;
@@ -2561,6 +2818,10 @@ _XmScrolledWConfigureChildren(Widget w, Widget child,
 	    SW_CWHeight(w) = vals->ClipH;
 	}
     }
+    else
+    {
+	_XmConfigureScrollBars(w, child, childgeom, vals);
+    }
 
     /* MLM: We may not have either child.  Avoid messy exposes
      * 10/29/97
