@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.46 2000/03/05 13:12:26 rwscott Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.48 2000/09/23 15:05:25 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.46 2000/03/05 13:12:26 rwscott Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.48 2000/09/23 15:05:25 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdlib.h>
+
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
-
 #include <Xm/XmP.h>
 #include <Xm/SelectioBP.h>
 #include <Xm/CommandP.h>
@@ -45,8 +48,7 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBo
 #include <Xm/TextF.h>
 
 #include <XmI/DebugUtil.h>
-#include <stdio.h>
-#include <stdlib.h>
+
 
 /* Forward Declarations */
 
@@ -801,6 +803,7 @@ set_values(Widget old,
 	String text;
 
 	SB_TextString(sb) = XmStringCopy(SB_TextString(sb));
+	XmStringFree(SB_TextString(o));
 	if (XmStringGetLtoR(SB_TextString(sb), XmSTRING_DEFAULT_CHARSET, &text))
 	{
 	    XmTextFieldSetString(SB_Text(sb), text);
@@ -813,6 +816,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_SelectionLabelString))
     {
+	SB_SelectionLabelString(sb) = XmStringCopy(SB_SelectionLabelString(sb));
+	XmStringFree(SB_SelectionLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_SelectionLabelString(sb)); ac++;
 	r = True;
     }
@@ -825,6 +830,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_ListLabelString))
     {
+	SB_ListLabelString(sb) = XmStringCopy(SB_ListLabelString(sb));
+	XmStringFree(SB_ListLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_ListLabelString(sb)); ac++;
 	r = True;
     }
@@ -837,6 +844,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_OkLabelString))
     {
+	SB_OkLabelString(sb) = XmStringCopy(SB_OkLabelString(sb));
+	XmStringFree(SB_OkLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_OkLabelString(sb)); ac++;
 	r = True;
     }
@@ -849,6 +858,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_CancelLabelString))
     {
+	SB_CancelLabelString(sb) = XmStringCopy(SB_CancelLabelString(sb));
+	XmStringFree(SB_CancelLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_CancelLabelString(sb)); ac++;
 	r = True;
     }
@@ -861,6 +872,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_ApplyLabelString))
     {
+	SB_ApplyLabelString(sb) = XmStringCopy(SB_ApplyLabelString(sb));
+	XmStringFree(SB_ApplyLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_ApplyLabelString(sb)); ac++;
 	r = True;
     }
@@ -873,6 +886,8 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_HelpLabelString))
     {
+	SB_HelpLabelString(sb) = XmStringCopy(SB_HelpLabelString(sb));
+	XmStringFree(SB_HelpLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_HelpLabelString(sb)); ac++;
 	r = True;
     }
@@ -1091,9 +1106,13 @@ void
 _XmSelectionBoxGetTextString(Widget wid, int resource_offset,
 			     XtArgVal *value)
 {
+    char *str;
+
     DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxGetTextString\n"));
 
-    *value = (XtArgVal)XmStringCreateSimple(XmTextFieldGetString(SB_Text(wid)));
+    str = XmTextFieldGetString(SB_Text(wid));
+    *value = (XtArgVal)XmStringCreateSimple(str);
+    XtFree(str);
 }
 
 void
