@@ -1,8 +1,9 @@
 /**
  *
- * $Id: SeparatoG.c,v 1.11 1998/09/13 20:17:56 rwscott Exp $
+ * $Id: SeparatoG.c,v 1.16 2000/09/22 20:35:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,24 +23,27 @@
  *
  **/
 
-static const char rcsid[] = "$Id: SeparatoG.c,v 1.11 1998/09/13 20:17:56 rwscott Exp $";
+static const char rcsid[] = "$Id: SeparatoG.c,v 1.16 2000/09/22 20:35:13 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ManagerP.h>
 #include <Xm/SeparatoGP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/CacheP.h>
 #include <Xm/RepType.h>
-#include <X11/Xfuncs.h>
+#include <Xm/RowColumnP.h>
 
 #include <XmI/DebugUtil.h>
 
+
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -119,7 +123,7 @@ XmSeparatorGCacheObjClassRec xmSeparatorGCacheObjClassRec = {
     /* Object class part */
     {
 	/* superclass            */ (WidgetClass) &xmExtClassRec,
-        /* class_name            */ "XmSeparatorGadget",
+	/* class_name            */ "XmSeparatorGadget",
 	/* widget_size           */ sizeof(XmSeparatorGCacheObjRec),
 	/* class_initialize      */ NULL,
 	/* class_part_initialize */ NULL,
@@ -144,18 +148,18 @@ XmSeparatorGCacheObjClassRec xmSeparatorGCacheObjClassRec = {
 	/* set_values_almost     */ NULL,
 	/* get_values_hook       */ NULL,
 	/* accept_focus          */ NULL,
-	/* version               */ XtVersion,
+	/* version               */ XtVersionDontCheck,
 	/* callback offsets      */ NULL,
 	/* tm_table              */ NULL,
 	/* query_geometry        */ NULL,
-        /* display_accelerator   */ NULL,
+	/* display_accelerator   */ NULL,
 	/* extension             */ NULL
     },
     /* XmExtObject part */
     {
-        /* syn_resources      */ cache_syn_resources,
-        /* num_syn_resources  */ XtNumber(cache_syn_resources),
-        /* extension          */ NULL
+	/* syn_resources      */ cache_syn_resources,
+	/* num_syn_resources  */ XtNumber(cache_syn_resources),
+	/* extension          */ NULL
     },
     /* SeparatorGCache part */
     {
@@ -169,7 +173,7 @@ static XtResource resources[] = {
     {
 	XmNtraversalOn, XmCTraversalOn, XmRBoolean,
 	sizeof(Boolean), GOffset(traversal_on),
-	XmRImmediate, (XtPointer)0
+	XmRImmediate, (XtPointer)False
     },
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
@@ -180,7 +184,7 @@ static XtResource resources[] = {
 
 static XmBaseClassExtRec _XmSeparatoGRectClassExtRec = {
     /* next_extension            */ NULL,
-    /* record_type               */ NULLQUARK,                             
+    /* record_type               */ NULLQUARK,
     /* version                   */ XmBaseClassExtVersion,
     /* size                      */ sizeof(XmBaseClassExtRec),
     /* initialize_prehook        */ XmInheritInitializePrehook /*initialize_prehook*/,
@@ -247,7 +251,7 @@ XmSeparatorGadgetClassRec xmSeparatorGadgetClassRec = {
 	/* compress_motion       */ True /*False*/,
 	/* compress_exposure     */ XtExposeCompressSeries /*XtExposeCompressMaximal*/,
 	/* compress_enterleave   */ True /*False*/,
- 	/* visible_interest      */ False,
+	/* visible_interest      */ False,
 	/* destroy               */ destroy,
 	/* resize                */ NULL,
 	/* expose                */ expose,
@@ -256,7 +260,7 @@ XmSeparatorGadgetClassRec xmSeparatorGadgetClassRec = {
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ NULL /*get_values_hook*/,
 	/* accept_focus          */ NULL,
-	/* version               */ XtVersion,
+	/* version               */ XtVersionDontCheck,
 	/* callback offsets      */ NULL,
 	/* tm_table              */ NULL,
 	/* query_geometry        */ NULL /* query_geometry */,
@@ -265,7 +269,7 @@ XmSeparatorGadgetClassRec xmSeparatorGadgetClassRec = {
     },
     /* XmGadget part */
     {
-	/* border_highlight   */ NULL /*XmInheritBorderHighlight*/, 
+	/* border_highlight   */ NULL /*XmInheritBorderHighlight*/,
 	/* border_unhighlight */ NULL /*XmInheritBorderUnhighlight*/,
 	/* arm_and_activate   */ NULL,
 	/* input_dispatch     */ NULL, /* FIX ME */
@@ -329,7 +333,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -341,7 +345,7 @@ secondary_object_create(Widget request,
 int
 _XmSeparatorCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmSeparatorGCacheObjPart *)A),
+    return !memcmp(((XmSeparatorGCacheObjPart *)A),
 		 ((XmSeparatorGCacheObjPart *)B),
 		 sizeof(XmSeparatorGCacheObjPart));
 }
@@ -349,7 +353,7 @@ _XmSeparatorCacheCompare(XtPointer A, XtPointer B)
 /***************************** GADGET PART *******************************/
 
 static void
-class_initialize()
+class_initialize(void)
 {
     /* don't let the nulls fool you.  look at the header file -- the arg
      * isn't used. */
@@ -419,77 +423,14 @@ CreateSeparatorGC(Widget w)
     valueMask = GCBackground | GCForeground | GCLineStyle | GCJoinStyle |
 	GCCapStyle;
 
-    switch (SEPG_SeparatorType(w))
-    {
-    case XmNO_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmSINGLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmSINGLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmDOUBLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmDOUBLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_OUT:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN_DASH:
-    case XmSHADOW_ETCHED_OUT_DASH:
-    default:
-	SEPG_SeparatorType(w) = XmSHADOW_ETCHED_IN;
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = XmParentForeground(w);
-	values.background = XmParentBackground(w);
-	break;
-    }
+    values.join_style = JoinMiter;
+    values.cap_style = CapButt;
+    values.foreground = XmParentForeground(w);
+    values.background = XmParentBackground(w);
+    values.line_style = (SEPG_SeparatorType(w) == XmSINGLE_DASHED_LINE ||
+			 SEPG_SeparatorType(w) == XmDOUBLE_DASHED_LINE)
+	? LineDoubleDash
+	: LineSolid;
 
     SEPG_SeparatorGC(w) = XtGetGC(w, valueMask, &values);
 }
@@ -503,52 +444,78 @@ initialize(Widget request, Widget new_w,
 	_XmError(new_w, "parent should be manager.");
     }
 
-    /* XmSHADOW_ETCHED_IN_DASH  and XmSHADOW_ETCHED_OUT_DASH 
-     * is a version 2.0 feature
+    /* Don't rely on defaults for the proper traversalOn and highlightThickness
+     * TraversalOn is always false, and highlightThickness is zero for menus.
      */
 
-    if (SEPG_SeparatorType(new_w) == XmINVALID_SEPARATOR_TYPE ||
-	SEPG_SeparatorType(new_w) == XmSHADOW_ETCHED_IN_DASH ||
-	SEPG_SeparatorType(new_w) == XmSHADOW_ETCHED_OUT_DASH ||
-	!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
-			     SEPG_SeparatorType(new_w),
-			     new_w))
-    {
+    G_TraversalOn(new_w) = False;
+    if (XmIsRowColumn(XtParent(new_w)) &&
+	RC_Type(XtParent(new_w)) > XmWORK_AREA)
+	G_HighlightThickness(new_w) = 0;
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmROrientation),
+			     SEPG_Orientation(new_w), new_w))
+	SEPG_Orientation(new_w) = XmHORIZONTAL;
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     SEPG_SeparatorType(new_w), new_w))
 	SEPG_SeparatorType(new_w) = XmSHADOW_ETCHED_IN;
-    }
 
     if (SEPG_Orientation(new_w) == XmVERTICAL)
     {
-        switch(SEPG_SeparatorType(new_w))
-        {
-            case XmSINGLE_LINE:
-            case XmSINGLE_DASHED_LINE:
-                XtWidth(new_w) = 1;
-                break;
-            case XmDOUBLE_LINE:
-            case XmDOUBLE_DASHED_LINE:
-                XtWidth(new_w) = 3;
-                break;
-            default:
-                XtWidth(new_w) = G_ShadowThickness(new_w);
-        }
+	if (!XtHeight(request))
+	{
+	    XtHeight(new_w) = (G_HighlightThickness(new_w) + 1) << 1;
+	}
+	if (!XtWidth(request))
+	{
+	    XtWidth(new_w) = G_HighlightThickness(new_w) << 1;
+	    switch(SEPG_SeparatorType(new_w))
+	    {
+	    case XmNO_LINE:
+		break;
+	    case XmSINGLE_LINE:
+	    case XmSINGLE_DASHED_LINE:
+		XtWidth(new_w) += 3;
+		break;
+	    case XmDOUBLE_LINE:
+	    case XmDOUBLE_DASHED_LINE:
+		XtWidth(new_w) += 5;
+		break;
+	    default:
+		XtWidth(new_w) += G_ShadowThickness(new_w);
+	    }
+	    if (!XtWidth(new_w))
+		XtWidth(new_w) = 1;
+	}
     }
-
-    if (SEPG_Orientation(new_w) == XmHORIZONTAL)
+    else
     {
-        switch(SEPG_SeparatorType(new_w))
-        {
-            case XmSINGLE_LINE:
-            case XmSINGLE_DASHED_LINE:
-                XtHeight(new_w) = 1;
-                break;
-            case XmDOUBLE_LINE:
-            case XmDOUBLE_DASHED_LINE:
-                XtHeight(new_w) = 3;
-                break;
-            default:
-                XtHeight(new_w) = G_ShadowThickness(new_w);
-        }
+	if (!XtWidth(request))
+	{
+	    XtWidth(new_w) = (G_HighlightThickness(new_w)  + 1) << 1;
+	}
+	if (!XtHeight(request))
+	{
+	    XtHeight(new_w) = G_HighlightThickness(new_w) << 1;
+	    switch(SEPG_SeparatorType(new_w))
+	    {
+	    case XmNO_LINE:
+		break;
+	    case XmSINGLE_LINE:
+	    case XmSINGLE_DASHED_LINE:
+		XtHeight(new_w) += 3;
+		break;
+	    case XmDOUBLE_LINE:
+	    case XmDOUBLE_DASHED_LINE:
+		XtHeight(new_w) += 5;
+		break;
+	    default:
+		XtHeight(new_w) += G_ShadowThickness(new_w);
+	    }
+	    if (!XtHeight(new_w))
+		XtHeight(new_w) = 1;
+	}
     }
 
     CreateSeparatorGC(new_w);
@@ -590,9 +557,9 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(SEPG_Cache(new_w),
-	  &((XmSeparatorGCacheObject)nsec)->separator_cache,
-	  sizeof(XmSeparatorGCacheObjPart));
+    memcpy(&((XmSeparatorGCacheObject)nsec)->separator_cache,
+           SEPG_Cache(new_w),
+	   sizeof(XmSeparatorGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -607,7 +574,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     SEPG_Cache(new_w) = &(((XmSeparatorGCacheObject)nsec)->separator_cache);
@@ -654,24 +621,87 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    /* XmSHADOW_ETCHED_IN_DASH  and XmSHADOW_ETCHED_OUT_DASH 
-     * is a version 2.0 feature
-     */
+    G_TraversalOn(new_w) = False;
+    if (XmIsRowColumn(XtParent(new_w)) &&
+	RC_Type(XtParent(new_w)) > XmWORK_AREA)
+	G_HighlightThickness(new_w) = 0;
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmROrientation),
+			     SEPG_Orientation(new_w), new_w))
+	SEPG_Orientation(new_w) = SEPG_Orientation(old);
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     SEPG_SeparatorType(new_w), new_w))
+	SEPG_SeparatorType(new_w) = SEPG_SeparatorType(old);
+
+    if (SEPG_SeparatorType(new_w) != SEPG_SeparatorType(old) ||
+	G_HighlightThickness(new_w) != G_HighlightThickness(old))
+    {
+	if (SEPG_Orientation(new_w) == XmVERTICAL)
+	{
+	    if (XtWidth(new_w) == XtWidth(old))
+	    {
+		XtWidth(new_w) = G_HighlightThickness(new_w) << 1;
+		switch(SEPG_SeparatorType(new_w))
+		{
+		case XmNO_LINE:
+		    break;
+		case XmSINGLE_LINE:
+		case XmSINGLE_DASHED_LINE:
+		    XtWidth(new_w) += 3;
+		    break;
+		case XmDOUBLE_LINE:
+		case XmDOUBLE_DASHED_LINE:
+		    XtWidth(new_w) += 5;
+		    break;
+		default:
+		    XtWidth(new_w) += G_ShadowThickness(new_w);
+		}
+		if (!XtWidth(new_w))
+		    XtWidth(new_w) = 1;
+	    }
+	}
+	else
+	{
+	    if (XtHeight(new_w) == XtHeight(old))
+	    {
+		XtHeight(new_w) = G_HighlightThickness(new_w) << 1;
+		switch(SEPG_SeparatorType(new_w))
+		{
+		case XmNO_LINE:
+		    break;
+		case XmSINGLE_LINE:
+		case XmSINGLE_DASHED_LINE:
+		    XtHeight(new_w) += 3;
+		    break;
+		case XmDOUBLE_LINE:
+		case XmDOUBLE_DASHED_LINE:
+		    XtHeight(new_w) += 5;
+		    break;
+		default:
+		    XtHeight(new_w) += G_ShadowThickness(new_w);
+		}
+		if (!XtHeight(new_w))
+		    XtHeight(new_w) = 1;
+	    }
+	}
+	refresh_needed = True;
+    }
+
     if (XmParentForeground(new_w) != XmParentForeground(old) ||
-	(SEPG_SeparatorType(new_w) != SEPG_SeparatorType(old) &&
-	 SEPG_SeparatorType(new_w) != XmINVALID_SEPARATOR_TYPE &&
-	 SEPG_SeparatorType(new_w) != XmSHADOW_ETCHED_IN_DASH &&
-	 SEPG_SeparatorType(new_w) != XmSHADOW_ETCHED_OUT_DASH &&
-	 XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
-			     SEPG_SeparatorType(new_w),
-			     new_w)))
+	XmParentBackground(new_w) != XmParentBackground(old) ||
+	((SEPG_SeparatorType(new_w) == XmSINGLE_DASHED_LINE ||
+	  SEPG_SeparatorType(new_w) == XmDOUBLE_DASHED_LINE) ^
+	 (SEPG_SeparatorType(old) == XmSINGLE_DASHED_LINE ||
+	  SEPG_SeparatorType(old) == XmDOUBLE_DASHED_LINE)))
     {
 	XtReleaseGC(new_w, SEPG_SeparatorGC(new_w));
 	CreateSeparatorGC(new_w);
 	refresh_needed = True;
     }
 
-    if (SEPG_Orientation(new_w) != SEPG_Orientation(old))
+    if (SEPG_Margin(new_w) != SEPG_Margin(old) ||
+	SEPG_Orientation(new_w) != SEPG_Orientation(old))
 	refresh_needed = True;
 
     return refresh_needed;
@@ -701,9 +731,9 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(SEPG_Cache(new_w),
-	  &((XmSeparatorGCacheObject)nsec)->separator_cache,
-	  sizeof(XmSeparatorGCacheObjPart));
+    memcpy(&((XmSeparatorGCacheObject)nsec)->separator_cache,
+           SEPG_Cache(new_w),
+	   sizeof(XmSeparatorGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -744,7 +774,7 @@ expose(Widget w, XEvent *event, Region region)
 		     XtX(w), XtY(w),
 		     XtWidth(w), XtHeight(w),
 		     G_ShadowThickness(w),
-		     SEPG_Margin(w),
+		     G_HighlightThickness(w) + SEPG_Margin(w),
 		     SEPG_Orientation(w),
 		     SEPG_SeparatorType(w));
 }
