@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Separator.c,v 1.11 1998/09/13 20:17:56 rwscott Exp $
+ * $Id: Separator.c,v 1.13 2000/09/23 15:05:25 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,14 +23,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Separator.c,v 1.11 1998/09/13 20:17:56 rwscott Exp $";
+static const char rcsid[] = "$Id: Separator.c,v 1.13 2000/09/23 15:05:25 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/SeparatorP.h>
 #include <Xm/RepType.h>
+#include <Xm/RowColumnP.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -82,7 +84,7 @@ static XtResource resources[] = {
     {
 	XmNtraversalOn, XmCTraversalOn, XmRBoolean,
 	sizeof(Boolean), POffset(traversal_on),
-	XmRImmediate, (XtPointer)0
+	XmRImmediate, (XtPointer)False
     },
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
@@ -103,7 +105,7 @@ static XmSyntheticResource syn_resources[] = {
 static void Help(Widget w, XEvent *event,
  String *params, Cardinal *num_params);
 
-static char defaultTranslations[] = 
+static char defaultTranslations[] =
     "<Key>osfHelp:  Help() ";
 
 static XtActionsRec actions[] = {
@@ -115,7 +117,7 @@ static XtActionsRec actions[] = {
 #if 0
 static XmBaseClassExtRec _XmSeparatorCoreClassExtRec = {
     /* next_extension            */ NULL,
-    /* record_type               */ NULLQUARK,                             
+    /* record_type               */ NULLQUARK,
     /* version                   */ XmBaseClassExtVersion,
     /* size                      */ sizeof(XmBaseClassExtRec),
     /* initialize_prehook        */ NULL,
@@ -154,7 +156,7 @@ XmSeparatorClassRec xmSeparatorClassRec = {
     /* Core class part */
     {
 	/* superclass            */ (WidgetClass) &xmPrimitiveClassRec,
-        /* class_name            */ "XmSeparator",
+	/* class_name            */ "XmSeparator",
 	/* widget_size           */ sizeof(XmSeparatorRec),
 	/* class_initialize      */ NULL /*class_initialize*/,
 	/* class_part_initialize */ class_part_initialize,
@@ -179,7 +181,7 @@ XmSeparatorClassRec xmSeparatorClassRec = {
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ NULL,
 	/* accept_focus          */ NULL,
-	/* version               */ XtVersion,
+	/* version               */ XtVersionDontCheck,
 	/* callback offsets      */ NULL,
 	/* tm_table              */ NULL /*defaultTranslations*/,
 	/* query_geometry        */ NULL /* query_geometry */, /* Motif has NULL */
@@ -188,13 +190,13 @@ XmSeparatorClassRec xmSeparatorClassRec = {
     },
     /* Primitive Class part */
     {
-        /* border_highlight      */ NULL /*XmInheritBorderHighlight*/,
-        /* border_unhighlight    */ NULL /*XmInheritBorderUnhighlight*/,
-        /* translations          */ NULL /*XtInheritTranslations*/,
-        /* arm_and_activate_proc */ NULL /*XmInheritArmAndActivate*/,
-        /* Synthetic Resources   */ syn_resources, 
-        /* num syn res           */ XtNumber(syn_resources),
-        /* extension             */ (XtPointer)NULL /*&_XmSeparatorPrimClassExtRec*/
+	/* border_highlight      */ NULL /*XmInheritBorderHighlight*/,
+	/* border_unhighlight    */ NULL /*XmInheritBorderUnhighlight*/,
+	/* translations          */ NULL /*XtInheritTranslations*/,
+	/* arm_and_activate_proc */ NULL /*XmInheritArmAndActivate*/,
+	/* Synthetic Resources   */ syn_resources,
+	/* num syn res           */ XtNumber(syn_resources),
+	/* extension             */ (XtPointer)NULL /*&_XmSeparatorPrimClassExtRec*/
     },
     /* Separator Class part */
     {
@@ -228,92 +230,14 @@ CreateSeparatorGC(Widget w)
     valueMask =  GCBackground | GCLineStyle | GCForeground | GCJoinStyle |
 			GCCapStyle;
 
-    switch (SEP_SeparatorType(w)) {
-    case XmSINGLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmNO_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSINGLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmDOUBLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmDOUBLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_OUT:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN_DASH:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_OUT_DASH:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    default:
-	SEP_SeparatorType(w) = XmSHADOW_ETCHED_IN;
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-    }
+    values.join_style = JoinMiter;
+    values.cap_style = CapButt;
+    values.foreground = Prim_Foreground(w);
+    values.background = XtBackground(w);
+    values.line_style = (SEP_SeparatorType(w) == XmSINGLE_DASHED_LINE ||
+			 SEP_SeparatorType(w) == XmDOUBLE_DASHED_LINE)
+	? LineDoubleDash
+	: LineSolid;
 
     SEP_SeparatorGC(w) = XtGetGC(w, valueMask, &values);
 }
@@ -322,53 +246,78 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    /* XmSHADOW_ETCHED_IN_DASH  and XmSHADOW_ETCHED_OUT_DASH 
-     * is a version 2.0 feature
+    /* Don't rely on defaults for the proper traversalOn and highlightThickness
+     * TraversalOn is always false, and highlightThickness is zero for menus.
      */
 
-    if (SEP_SeparatorType(new_w) == XmINVALID_SEPARATOR_TYPE ||
-	SEP_SeparatorType(new_w) == XmSHADOW_ETCHED_IN_DASH ||
-	SEP_SeparatorType(new_w) == XmSHADOW_ETCHED_OUT_DASH ||
-	!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
-			     SEP_SeparatorType(new_w),
-			     new_w))
-    {
-	SEP_SeparatorType(new_w) = XmSHADOW_ETCHED_IN;
-    }
+    Prim_TraversalOn(new_w) = False;
+    if (XmIsRowColumn(XtParent(new_w)) &&
+	RC_Type(XtParent(new_w)) > XmWORK_AREA)
+	Prim_HighlightThickness(new_w) = 0;
 
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmROrientation),
+			     SEP_Orientation(new_w), new_w))
+	SEP_Orientation(new_w) = XmHORIZONTAL;
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     SEP_SeparatorType(new_w), new_w))
+	SEP_SeparatorType(new_w) = XmSHADOW_ETCHED_IN;
 
     if (SEP_Orientation(new_w) == XmVERTICAL)
     {
-        switch(SEP_SeparatorType(new_w))
-        {
-            case XmSINGLE_LINE:
-            case XmSINGLE_DASHED_LINE:
-                XtWidth(new_w) = 1;
-                break;
-            case XmDOUBLE_LINE:
-            case XmDOUBLE_DASHED_LINE:
-                XtWidth(new_w) = 3;
-                break;
-            default:
-                XtWidth(new_w) = Prim_ShadowThickness(new_w);
-        }
+	if (!XtHeight(request))
+	{
+	    XtHeight(new_w) = (Prim_HighlightThickness(new_w) + 1) << 1;
+	}
+	if (!XtWidth(request))
+	{
+	    XtWidth(new_w) = Prim_HighlightThickness(new_w) << 1;
+	    switch(SEP_SeparatorType(new_w))
+	    {
+	    case XmNO_LINE:
+		break;
+	    case XmSINGLE_LINE:
+	    case XmSINGLE_DASHED_LINE:
+		XtWidth(new_w) += 3;
+		break;
+	    case XmDOUBLE_LINE:
+	    case XmDOUBLE_DASHED_LINE:
+		XtWidth(new_w) += 5;
+		break;
+	    default:
+		XtWidth(new_w) += Prim_ShadowThickness(new_w);
+	    }
+	    if (!XtWidth(new_w))
+		XtWidth(new_w) = 1;
+	}
     }
-
-    if (SEP_Orientation(new_w) == XmHORIZONTAL)
+    else
     {
-        switch(SEP_SeparatorType(new_w))
-        {
-            case XmSINGLE_LINE:
-            case XmSINGLE_DASHED_LINE:
-                XtHeight(new_w) = 1;
-                break;
-            case XmDOUBLE_LINE:
-            case XmDOUBLE_DASHED_LINE:
-                XtHeight(new_w) = 3;
-                break;
-            default:
-                XtHeight(new_w) = Prim_ShadowThickness(new_w);
-        }
+	if (!XtWidth(request))
+	{
+	    XtWidth(new_w) = (Prim_HighlightThickness(new_w)  + 1) << 1;
+	}
+	if (!XtHeight(request))
+	{
+	    XtHeight(new_w) = Prim_HighlightThickness(new_w) << 1;
+	    switch(SEP_SeparatorType(new_w))
+	    {
+	    case XmNO_LINE:
+		break;
+	    case XmSINGLE_LINE:
+	    case XmSINGLE_DASHED_LINE:
+		XtHeight(new_w) += 3;
+		break;
+	    case XmDOUBLE_LINE:
+	    case XmDOUBLE_DASHED_LINE:
+		XtHeight(new_w) += 5;
+		break;
+	    default:
+		XtHeight(new_w) += Prim_ShadowThickness(new_w);
+	    }
+	    if (!XtHeight(new_w))
+		XtHeight(new_w) = 1;
+	}
     }
 
     CreateSeparatorGC(new_w);
@@ -385,25 +334,89 @@ set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     Boolean refresh_needed = False;
-    /* XmSHADOW_ETCHED_IN_DASH  and XmSHADOW_ETCHED_OUT_DASH 
-     * is a version 2.0 feature
-     */
+
+    Prim_TraversalOn(new_w) = False;
+    if (XmIsRowColumn(XtParent(new_w)) &&
+	RC_Type(XtParent(new_w)) > XmWORK_AREA)
+	Prim_HighlightThickness(new_w) = 0;
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmROrientation),
+			     SEP_Orientation(new_w), new_w))
+	SEP_Orientation(new_w) = SEP_Orientation(old);
+
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     SEP_SeparatorType(new_w), new_w))
+	SEP_SeparatorType(new_w) = SEP_SeparatorType(old);
+
+    if (SEP_SeparatorType(new_w) != SEP_SeparatorType(old) ||
+	Prim_HighlightThickness(new_w) != Prim_HighlightThickness(old))
+    {
+	if (SEP_Orientation(new_w) == XmVERTICAL)
+	{
+	    if (XtWidth(new_w) == XtWidth(old))
+	    {
+		XtWidth(new_w) = Prim_HighlightThickness(new_w) << 1;
+		switch(SEP_SeparatorType(new_w))
+		{
+		case XmNO_LINE:
+		    break;
+		case XmSINGLE_LINE:
+		case XmSINGLE_DASHED_LINE:
+		    XtWidth(new_w) += 3;
+		    break;
+		case XmDOUBLE_LINE:
+		case XmDOUBLE_DASHED_LINE:
+		    XtWidth(new_w) += 5;
+		    break;
+		default:
+		    XtWidth(new_w) += Prim_ShadowThickness(new_w);
+		}
+		if (!XtWidth(new_w))
+		    XtWidth(new_w) = 1;
+	    }
+	}
+	else
+	{
+	    if (XtHeight(new_w) == XtHeight(old))
+	    {
+		XtHeight(new_w) = Prim_HighlightThickness(new_w) << 1;
+		switch(SEP_SeparatorType(new_w))
+		{
+		case XmNO_LINE:
+		    break;
+		case XmSINGLE_LINE:
+		case XmSINGLE_DASHED_LINE:
+		    XtHeight(new_w) += 3;
+		    break;
+		case XmDOUBLE_LINE:
+		case XmDOUBLE_DASHED_LINE:
+		    XtHeight(new_w) += 5;
+		    break;
+		default:
+		    XtHeight(new_w) += Prim_ShadowThickness(new_w);
+		}
+		if (!XtHeight(new_w))
+		    XtHeight(new_w) = 1;
+	    }
+	}
+	refresh_needed = True;
+    }
+
     if (Prim_Foreground(new_w) != Prim_Foreground(old) ||
 	XtBackground(new_w) != XtBackground(old) ||
-	(SEP_SeparatorType(new_w) != SEP_SeparatorType(old) &&
-	 SEP_SeparatorType(new_w) != XmINVALID_SEPARATOR_TYPE &&
-	 SEP_SeparatorType(new_w) != XmSHADOW_ETCHED_IN_DASH &&
-	 SEP_SeparatorType(new_w) != XmSHADOW_ETCHED_OUT_DASH &&
-	 XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
-			     SEP_SeparatorType(new_w),
-			     new_w)))
+	((SEP_SeparatorType(new_w) == XmSINGLE_DASHED_LINE ||
+	  SEP_SeparatorType(new_w) == XmDOUBLE_DASHED_LINE) ^
+	 (SEP_SeparatorType(old) == XmSINGLE_DASHED_LINE ||
+	  SEP_SeparatorType(old) == XmDOUBLE_DASHED_LINE)))
     {
 	XtReleaseGC(new_w, SEP_SeparatorGC(new_w));
 	CreateSeparatorGC(new_w);
 	refresh_needed = True;
     }
 
-    if (SEP_Orientation(new_w) != SEP_Orientation(old)) {
+    if (SEP_Margin(new_w) != SEP_Margin(old) ||
+	SEP_Orientation(new_w) != SEP_Orientation(old))
+    {
 	refresh_needed = True;
     }
 
@@ -419,13 +432,13 @@ expose(Widget w, XEvent *event, Region region)
 		     0,0,
 		     XtWidth(w), XtHeight(w),
 		     Prim_ShadowThickness(w),
-		     SEP_Margin(w),
+		     Prim_HighlightThickness(w) + SEP_Margin(w),
 		     SEP_Orientation(w),
 		     SEP_SeparatorType(w));
 }
 
 #if 0
-static XtGeometryResult 
+static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 {
     /* Motif does not have this method */
@@ -456,7 +469,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 {
 	return XtGeometryNo;
 }
-    else 
+    else
 {
 	return XtGeometryAlmost;
 }
@@ -464,15 +477,15 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 #endif
 
 #if 0
-static void 
+static void
 Help(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XtCallActionProc(w, "PrimitiveHelp", event, params, *num_params);
 }
 #endif
 
-Widget 
-XmCreateSeparator(Widget parent, char *name, 
+Widget
+XmCreateSeparator(Widget parent, char *name,
 		  Arg *arglist, Cardinal argcount)
 {
     return XtCreateWidget(name, xmSeparatorWidgetClass, parent,
