@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Simple.c,v 1.23 2000/06/25 17:02:53 amai Exp $
+ * $Id: Simple.c,v 1.25 2000/09/22 20:35:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,13 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Simple.c,v 1.23 2000/06/25 17:02:53 amai Exp $";
+static const char rcsid[] = "$Id: Simple.c,v 1.25 2000/09/22 20:35:13 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <stdio.h>
+#include <string.h>
 
 #include <XmI/XmI.h>
-#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/CascadeBG.h>
@@ -40,6 +42,7 @@ static const char rcsid[] = "$Id: Simple.c,v 1.23 2000/06/25 17:02:53 amai Exp $
 
 #include <XmI/DebugUtil.h>
 
+
 /* For the prototype police */
 extern Widget _XmCreateSimpleGadget(char *name, Widget parent, int def_type,
 				    XmSimpleMenu data, int which,
@@ -254,7 +257,7 @@ XmCreateSimpleCheckBox(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA);
@@ -310,7 +313,7 @@ XmCreateSimpleMenuBar(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmMENU_BAR);
@@ -368,7 +371,7 @@ XmCreateSimpleOptionMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     XtGetSubresources(parent, (XtPointer)&data, name, XmCSimpleOptionMenu,
 		      simple_resources, XtNumber(simple_resources),
@@ -496,7 +499,7 @@ XmCreateSimplePopupMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePopupMenu(parent, name, arglist, argcount);
 
@@ -569,7 +572,7 @@ XmCreateSimplePulldownMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePulldownMenu(parent, name, arglist, argcount);
 
@@ -708,7 +711,7 @@ XmCreateSimpleRadioBox(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA); n++;
