@@ -1,8 +1,9 @@
 /**
  *
- * $Id: TearOffB.c,v 1.16 1998/09/13 20:17:56 rwscott Exp $
+ * $Id: TearOffB.c,v 1.20 2000/09/23 15:05:26 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TearOffB.c,v 1.16 1998/09/13 20:17:56 rwscott Exp $";
+static const char rcsid[] = "$Id: TearOffB.c,v 1.20 2000/09/23 15:05:26 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/MenuShell.h>
 #include <Xm/MenuUtilP.h>
@@ -35,12 +36,13 @@ static const char rcsid[] = "$Id: TearOffB.c,v 1.16 1998/09/13 20:17:56 rwscott
 #include <Xm/CascadeBG.h>
 #include <Xm/DisplayP.h>
 #include <Xm/TransltnsP.h>
+#include <Xm/RepType.h>
 
 #include <XmI/DebugUtil.h>
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -61,17 +63,12 @@ static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
 
-/* 
- * Resources for the tearoffbutton class 
+/*
+ * Resources for the tearoffbutton class
  */
 #define Offset(field) XtOffsetOf(XmTearOffButtonRec, tear_off_button.field)
 static XtResource resources[] =
 {
-    {
-	XmNorientation, XmCOrientation, XmROrientation,
-	sizeof(unsigned char), Offset(orientation),
-	XmRImmediate, (XtPointer)XmHORIZONTAL
-    },
     {
 	XmNseparatorType, XmCSeparatorType, XmRSeparatorType,
 	sizeof(unsigned char), Offset(separator_type),
@@ -130,7 +127,7 @@ XmTearOffButtonClassRec xmTearOffButtonClassRec = {
     /* Core class part */
     {
 	/* superclass            */ (WidgetClass) &xmPushButtonClassRec,
-        /* class_name            */ "XmTearOffButton",
+	/* class_name            */ "XmTearOffButton",
 	/* widget_size           */ sizeof(XmTearOffButtonRec),
 	/* class_initialize      */ class_initialize,
 	/* class_part_initialize */ class_part_initialize,
@@ -148,14 +145,14 @@ XmTearOffButtonClassRec xmTearOffButtonClassRec = {
 	/* compress_enterleave   */ True,
 	/* visible_interest      */ False,
 	/* destroy               */ destroy,
-	/* resize                */ XtInheritResize, 
+	/* resize                */ XtInheritResize,
 	/* expose                */ expose,
 	/* set_values            */ set_values,
 	/* set_values_hook       */ NULL,
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ NULL,
 	/* accept_focus          */ NULL,
-	/* version               */ XtVersion,
+	/* version               */ XtVersionDontCheck,
 	/* callback offsets      */ NULL,
 	/* tm_table              */ XtInheritTranslations,
 	/* query_geometry        */ XtInheritQueryGeometry /* query_geometry */,
@@ -164,24 +161,24 @@ XmTearOffButtonClassRec xmTearOffButtonClassRec = {
     },
     /* Primitive Class part */
     {
-        /* border_highlight      */ XmInheritBorderHighlight,
-        /* border_unhighlight    */ XmInheritBorderUnhighlight,
-        /* translations          */ XtInheritTranslations,
-        /* arm_and_activate_proc */ XmInheritArmAndActivate,
-        /* Synthetic Resources   */ syn_resources,
-        /* num syn res           */ XtNumber(syn_resources),
+	/* border_highlight      */ XmInheritBorderHighlight,
+	/* border_unhighlight    */ XmInheritBorderUnhighlight,
+	/* translations          */ XtInheritTranslations,
+	/* arm_and_activate_proc */ XmInheritArmAndActivate,
+	/* Synthetic Resources   */ syn_resources,
+	/* num syn res           */ XtNumber(syn_resources),
 	/* extension             */ (XtPointer)&_XmTearOffBPrimClassExtRec
     },
     /* Label Class part */
     {
-        /* setOverrideCallback */ XmInheritSetOverrideCallback,
-        /* menuProcs           */ XmInheritMenuProc,
-        /* translations        */ XtInheritTranslations,
+	/* setOverrideCallback */ XmInheritSetOverrideCallback,
+	/* menuProcs           */ XmInheritMenuProc,
+	/* translations        */ XtInheritTranslations,
 	/* extension           */ NULL
     },
     /* Push Button part */
     {
-        /* extension           */ NULL
+	/* extension           */ NULL
     },
     /* Tear Off Button part */
     {
@@ -194,8 +191,9 @@ XmTearOffButtonClassRec xmTearOffButtonClassRec = {
 WidgetClass xmTearOffButtonWidgetClass = (WidgetClass)&xmTearOffButtonClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
+    /* FIX ME */
 }
 
 static void
@@ -223,202 +221,57 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmTEAROFF_BUTTON_BIT);
 }
 
-static void
-CreateBottomShadowGC(Widget pw)
-{
-    XGCValues values;
-    unsigned long mask;
-
-    mask = GCForeground | GCBackground;
-    values.foreground = Prim_BottomShadowColor(pw);
-    values.background = XtBackground(pw);
-
-    if (Prim_BottomShadowPixmap(pw) != None
-	&& Prim_BottomShadowPixmap(pw) != XmUNSPECIFIED_PIXMAP)
-    {
-	/* we're dealing with a pixmap'ed bottom shadow */
-	mask |= GCTile | GCFillStyle;
-
-	values.tile = Prim_BottomShadowPixmap(pw);
-	values.fill_style = FillTiled;
-    }
-
-    /* these GC's get used for shadow drawing, so set 'em up */
-    mask |= GCLineWidth | GCLineStyle | GCJoinStyle | GCCapStyle;
-    values.line_width = 1;
-    values.line_style = LineDoubleDash;
-    values.join_style = JoinMiter;
-    values.cap_style = CapButt;
-
-    Prim_BottomShadowGC(pw) = XtGetGC((Widget)pw, mask, &values);
-}
-
-static void
-CreateTopShadowGC(Widget pw)
-{
-    XGCValues values;
-    unsigned long mask;
-
-    mask = GCForeground | GCBackground;
-    values.foreground = Prim_TopShadowColor(pw);
-    values.background = XtBackground(pw);
-
-    if (Prim_TopShadowPixmap(pw) != None
-	&& Prim_TopShadowPixmap(pw) != XmUNSPECIFIED_PIXMAP)
-    {
-	/* we're dealing with a pixmap'ed top shadow */
-	mask |= GCTile | GCFillStyle;
-
-	values.tile = Prim_TopShadowPixmap(pw);
-	values.fill_style = FillTiled;
-    }
-
-    /* these GC's get used for shadow drawing, so set 'em up */
-    mask |= GCLineWidth | GCLineStyle | GCCapStyle | GCJoinStyle;
-    values.line_width = 1;
-    values.line_style = LineDoubleDash;
-    values.join_style = JoinMiter;
-    values.cap_style = CapButt;
-
-    Prim_TopShadowGC(pw) = XtGetGC((Widget)pw, mask, &values);
-}
-
 static void
 CreateSeparatorGC(Widget w)
 {
     XGCValues values;
-    long value_mask;
+    XtGCMask  valueMask;
 
-    value_mask = GCBackground | GCForeground | GCLineStyle | GCCapStyle |
-	GCJoinStyle;
+    valueMask =  GCBackground | GCLineStyle | GCForeground | GCJoinStyle |
+			GCCapStyle;
 
-    switch (TOB_SeparatorType(w))
-    {
-    case XmSINGLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
+    values.join_style = JoinMiter;
+    values.cap_style = CapButt;
+    values.foreground = Prim_Foreground(w);
+    values.background = XtBackground(w);
+    values.line_style = (TOB_SeparatorType(w) == XmSINGLE_DASHED_LINE ||
+			 TOB_SeparatorType(w) == XmDOUBLE_DASHED_LINE)
+	? LineDoubleDash
+	: LineSolid;
 
-    case XmSINGLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmDOUBLE_LINE:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmDOUBLE_DASHED_LINE:
-	values.line_style = LineDoubleDash;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_OUT:
-	/* doesn't really matter */
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_IN_DASH:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    case XmSHADOW_ETCHED_OUT_DASH:
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-
-    default:
-	TOB_SeparatorType(w) = XmSINGLE_LINE;
-	values.line_style = LineSolid;
-	values.join_style = JoinMiter;
-	values.cap_style = CapButt;
-	values.foreground = Prim_Foreground(w);
-	values.background = XtBackground(w);
-	break;
-    }
-
-    TOB_SeparatorGC(w) = XtGetGC(w, value_mask, &values);
+    TOB_SeparatorGC(w) = XtGetGC(w, valueMask, &values);
 }
 
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    XmTearOffButtonWidgetClass tobc =
-    (XmTearOffButtonWidgetClass)new_w->core.widget_class;
-
-    XmString xmstr = XmStringCreateSimple("");
+    int trh;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w, "TOB_initialize\n"));
 
-    XtWidth(new_w) = 2 * (Lab_Shadow(new_w) + Lab_Highlight(new_w));
-    XtHeight(new_w) = 2 * (Lab_Shadow(new_w) + Lab_Highlight(new_w));
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     TOB_SeparatorType(new_w), new_w))
+	TOB_SeparatorType(new_w) = XmSHADOW_ETCHED_OUT_DASH;
 
-    TOB_Margin(new_w) = 5;
+    TOB_Orientation(new_w) = XmHORIZONTAL;
 
-    if (TOB_Orientation(new_w) == XmVERTICAL)
-    {
-	XtWidth(new_w) += TOB_Margin(new_w);
-    }
-    if (TOB_Orientation(new_w) == XmHORIZONTAL)
-    {
-	XtHeight(new_w) += TOB_Margin(new_w);
-    }
+    XtOverrideTranslations(new_w, (XtTranslations)
+	((XmTearOffButtonWidgetClass)new_w->core.widget_class)
+	->tearoffbutton_class.translations);
 
     CreateSeparatorGC(new_w);
-    CreateTopShadowGC(new_w);
-    CreateBottomShadowGC(new_w);
 
-    XtOverrideTranslations(new_w,
-			   (XtTranslations)tobc->tearoffbutton_class.translations);
-
-
-    _XmStringFree(Lab_Label(new_w));
-    Lab_Label(new_w) = _XmStringCreate(xmstr);
-    XmStringFree(xmstr);
-
-    if (XtWidth(request) == 0 || XtHeight(request) == 0)
-    {
-	XtWidth(new_w) = 0;
-	XtHeight(new_w) = 0;
-
-	_XmCalcLabelDimensions(new_w);
-
-	(*xmLabelClassRec.core_class.resize) (new_w);
-    }
+    /* Tweak the "text" rect so the button is slim (but not too slim) */
+    Lab_TextRect_width(new_w) = 0;
+    if (!XtWidth(request))
+	XtWidth(new_w) = 1;
+    trh = (Lab_TextRect_height(new_w) >> 1) > (Lab_Shadow(new_w) << 1)
+	? (Lab_TextRect_height(new_w) >> 1) - (Lab_Shadow(new_w) << 1)
+	: 0;
+    if (!XtHeight(request))
+	XtHeight(request) += trh - Lab_TextRect_height(new_w);
+    Lab_TextRect_height(new_w) = trh;
 }
 
 static void
@@ -431,10 +284,49 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = True;	/* FIX ME */
+    Boolean refresh_needed = False;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w, "TOB_SetValues()\n"));
 
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
+			     TOB_SeparatorType(new_w), new_w))
+	TOB_SeparatorType(new_w) = TOB_SeparatorType(old);
+
+    if (Prim_Foreground(new_w) != Prim_Foreground(old) ||
+	XtBackground(new_w) != XtBackground(old) ||
+	((TOB_SeparatorType(new_w) == XmSINGLE_DASHED_LINE ||
+	  TOB_SeparatorType(new_w) == XmDOUBLE_DASHED_LINE) ^
+	 (TOB_SeparatorType(old) == XmSINGLE_DASHED_LINE ||
+	  TOB_SeparatorType(old) == XmDOUBLE_DASHED_LINE)))
+    {
+	XtReleaseGC(new_w, TOB_SeparatorGC(new_w));
+	CreateSeparatorGC(new_w);
+	refresh_needed = True;
+    }
+
+    if (Lab_TextRect_height(new_w) != Lab_TextRect_height(old)
+	|| Lab_Shadow(new_w) != Lab_Shadow(old))
+    {
+	int trh;
+
+	Lab_TextRect_width(new_w) = 0;
+	if (!XtWidth(request) ||
+	    (Lab_RecomputeSize(new_w) && XtWidth(request) == XtWidth(old)))
+	    XtWidth(new_w) = 1;
+	trh = (Lab_TextRect_height(new_w) >> 1) > (Lab_Shadow(new_w) << 1)
+	    ? (Lab_TextRect_height(new_w) >> 1) - (Lab_Shadow(new_w) << 1)
+	    : 0;
+	if (!XtHeight(request) ||
+	    (Lab_RecomputeSize(new_w) && XtHeight(request) == XtHeight(old)))
+	    XtHeight(request) += trh - Lab_TextRect_height(new_w);
+	Lab_TextRect_height(new_w) = trh;
+    }
+
+    if (TOB_Margin(new_w) != TOB_Margin(old))
+    {
+	refresh_needed = True;
+    }
+
     return refresh_needed;
 }
 
@@ -443,24 +335,33 @@ expose(Widget w, XEvent *event, Region region)
 {
     DEBUGOUT(XdbDebug(__FILE__, w, "TearOffB expose\n"));
 
-    _XmDrawSeparator(XtDisplay(w),
-		     XtWindow(w),
-		     Prim_TopShadowGC(w),
-		     Prim_BottomShadowGC(w),
+    _XmDrawSeparator(XtDisplay(w), XtWindow(w),
+		     Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
 		     TOB_SeparatorGC(w),
 		     0, 0,
 		     XtWidth(w), XtHeight(w),
-    /*Lab_Shadow(w) * 2 */ Lab_Shadow(w),
-		     TOB_Margin(w) + Lab_Shadow(w),
+		     Lab_Shadow(w),
+		     Lab_Shadow(w) + TOB_Margin(w),
 		     TOB_Orientation(w),
 		     TOB_SeparatorType(w));
 
-/*
- * Why ??
- */
-#define superclass (&xmPushButtonClassRec)
-    (*superclass->core_class.expose) (w, event, region);
-#undef superclass
+    /* Draw the shadow like PushB does, but don't draw the label */
+
+    if (PB_Armed(w))
+    {
+	_XmDrawShadows(XtDisplay(w), XtWindow(w),
+		       Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
+		       0, 0,
+		       XtWidth(w), XtHeight(w),
+		       Lab_Shadow(w), XmSHADOW_OUT);
+    }
+    else
+    {
+	_XmClearBorder(XtDisplay(w), XtWindow(w),
+		       0, 0,
+		       XtWidth(w), XtHeight(w),
+		       Lab_Shadow(w));
+    }
 }
 
 #if 0
@@ -675,22 +576,22 @@ EventLoop(Widget w, GC gc,
 	    yt = oevent.xmotion.y_root + YOffset;
 
 	    /* Resist moving windows over the edge of the screen! */
-	    if ((xl + Width) >= WidthOfScreen(XtScreen(w)))
+	    if ((xl + Width) > WidthOfScreen(XtScreen(w)))
 	    {
 		xl = WidthOfScreen(XtScreen(w)) - Width;
 	    }
 
-	    if (xl <= 0)
+	    if (xl < 0)
 	    {
 		xl = 0;
 	    }
 
-	    if ((yt + Height) >= HeightOfScreen(XtScreen(w)))
+	    if ((yt + Height) > HeightOfScreen(XtScreen(w)))
 	    {
 		yt = HeightOfScreen(XtScreen(w)) - Height;
 	    }
 
-	    if (yt <= 0)
+	    if (yt < 0)
 	    {
 		yt = 0;
 	    }
@@ -714,22 +615,22 @@ EventLoop(Widget w, GC gc,
 	    yt += YOffset;
 
 	    /* Resist moving windows over the edge of the screen! */
-	    if ((xl + Width) >= WidthOfScreen(XtScreen(w)))
+	    if ((xl + Width) > WidthOfScreen(XtScreen(w)))
 	    {
 		xl = WidthOfScreen(XtScreen(w)) - Width;
 	    }
 
-	    if (xl <= 0)
+	    if (xl < 0)
 	    {
 		xl = 0;
 	    }
 
-	    if ((yt + Height) >= HeightOfScreen(XtScreen(w)))
+	    if ((yt + Height) > HeightOfScreen(XtScreen(w)))
 	    {
 		yt = HeightOfScreen(XtScreen(w)) - Height;
 	    }
 
-	    if (yt <= 0)
+	    if (yt < 0)
 	    {
 		yt = 0;
 	    }
@@ -756,12 +657,9 @@ EventLoop(Widget w, GC gc,
 	    break;
 	}
 
-	if (!done)
+	if (!done && !opaque_move)
 	{
-	    if (!opaque_move)
-	    {
-		DrawOutline(w, gc, 0, 0, 0, 0);
-	    }
+	    DrawOutline(w, gc, 0, 0, 0, 0);
 	}
     }
 }
@@ -791,23 +689,23 @@ BDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     gcm = GCFunction | GCLineWidth | GCForeground | GCSubwindowMode;
     gcv.function = GXxor;
     gcv.line_width = 0;
-    gcv.foreground = (((unsigned long)1) << depth) - 1;
+    gcv.foreground = (1UL << depth) - 1;
     gcv.subwindow_mode = IncludeInferiors;
 
     gc = XCreateGC(XtDisplay(shell), RootWindowOfScreen(XtScreen(shell)),
 		   gcm, &gcv);
- 
+
     dw += bw;
     dh += bw;
     xoff = dx - event->xbutton.x_root;
     yoff = dy - event->xbutton.y_root;
 
     _XmGrabPointer(shell, True, (ButtonPressMask | ButtonReleaseMask |
-                                 EnterWindowMask | LeaveWindowMask |
+				 EnterWindowMask | LeaveWindowMask |
 				 PointerMotionMask),
-                   GrabModeSync, GrabModeAsync, None,
+		   GrabModeSync, GrabModeAsync, None,
 		   ((XmDisplayInfo *)Display_DisplayInfo(disp))->TearOffCursor,
-                   CurrentTime);
+		   CurrentTime);
 
     XAllowEvents(XtDisplay(shell), SyncPointer, CurrentTime);
 
@@ -816,22 +714,15 @@ BDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     _XmUngrabPointer(shell, CurrentTime);
 
     PB_Armed(w) = False;
- 
-    _XmDrawShadows(XtDisplay(w),
-                   XtWindow(w),
-                   Prim_TopShadowGC(w),
-                   Prim_BottomShadowGC(w),
-                   Lab_Highlight(w),
-                   Lab_Highlight(w),
-                   XtWidth(w),
-                   XtHeight(w),
-                   Lab_Shadow(w),
-                   XmNO_LINE);
- 
+
+    _XmClearBorder(XtDisplay(w), XtWindow(w),
+		   0, 0, XtWidth(w), XtHeight(w),
+		   Lab_Shadow(w));
+
     XFreeGC(XtDisplay(shell), gc);
 
     _XmSetInDragMode(w, False);
- 
+
     _XmTearOffInitiate(w, event);
 }
 
@@ -858,6 +749,10 @@ BActivate(Widget w,
     {
 	RC_MenuButton(w, event, &validButton);
     }
+    else
+    {
+	validButton = False;
+    }
 
     if (!validButton)
     {
@@ -868,16 +763,9 @@ BActivate(Widget w,
 
     PB_Armed(w) = False;
 
-    _XmDrawShadows(XtDisplay(w),
-		   XtWindow(w),
-		   Prim_TopShadowGC(w),
-		   Prim_BottomShadowGC(w),
-		   Lab_Highlight(w),
-		   Lab_Highlight(w),
-		   XtWidth(w),
-		   XtHeight(w),
-		   Lab_Shadow(w),
-		   XmNO_LINE);
+    _XmClearBorder(XtDisplay(w), XtWindow(w),
+		   0, 0, XtWidth(w), XtHeight(w),
+		   Lab_Shadow(w));
 
     _XmSetInDragMode(w, False);
 
