@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/Text.c,v 1.124 2000/07/18 23:16:38 hennessy Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,32 +23,33 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.124 2000/07/18 23:16:38 hennessy Exp $";
+static const char rcsid[] = "$Id: Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $";
 
 #undef VERBOSE
 
 #include <LTconfig.h>
+
+#include <string.h>
+#include <stdlib.h>
+#include <stddef.h>    /* for  wchar_t */
+#include <limits.h>    /* for INT_MAX */
+
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
 #include <Xm/TextOutP.h>
 #include <Xm/TextF.h>
 #include <Xm/VendorSEP.h>   /* for _XmGetAudibleWarning() only */
-
 #include <Xm/CutPaste.h>
-
 #include <Xm/TransltnsP.h>
 #include <Xm/ScrolledW.h>
-#include <XmI/XmI.h>
-#include <X11/Xfuncs.h>
-
-#include <limits.h>		/* for INT_MAX */
-#ifdef HAVE_STRING_H
-#include <string.h>
-#define ANSI_STRING
-#else
-#include <strings.h>
+#if XmVERSION > 1
+#include <Xm/XmIm.h>
+#include <Xm/TraitP.h>
+#include <Xm/AccTextT.h>
 #endif
-#include <stdlib.h>
+
+#include <XmI/XmI.h>
+
 #include <XmI/DebugUtil.h>
 
 #ifndef XmUNSPECIFIED
@@ -102,9 +104,8 @@ void _XmTextExportValue(Widget w, int offset, XtArgVal *value);
 
 static void TextGetValues(Widget w, ArgList args, Cardinal *num_args);
 
+
 #if XmVERSION > 1
-#include <Xm/TraitP.h>
-#include <Xm/AccTextT.h>
 static XtPointer _XmText_TraitGetValue(Widget w, int format);
 static void _XmText_TraitSetValue(Widget w, XtPointer value, int format);
 static int _XmText_TraitPreferredFormat(Widget w);
@@ -265,7 +266,6 @@ static XmSyntheticResource syn_resources[] =
 };
 #undef Offset
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec textBaseClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -355,7 +355,6 @@ XmTextClassRec xmTextClassRec =
 	/* extension */ NULL
   }
 };
-/* *INDENT-ON* */
 
 WidgetClass xmTextWidgetClass = (WidgetClass)&xmTextClassRec;
 
@@ -420,6 +419,7 @@ InnerSetValues(Widget old, Widget request, Widget new_w,
     return refresh_needed;
 }
 
+
 XmTextInnerClassRec xmTextInnerClassRec =
 {
     /* core_class fields */
@@ -510,6 +510,7 @@ ClassInitialize(void)
 #endif
 }
 
+
 static void
 ClassPartInitialize(WidgetClass widget_class)
 {
@@ -517,6 +518,7 @@ ClassPartInitialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmTEXT_BIT);
 }
 
+
 static void
 Initialize(Widget request, Widget new,
 	   ArgList args, Cardinal *num_args)
@@ -556,8 +558,8 @@ Initialize(Widget request, Widget new,
 					  new, args, *num_args);
 
     /* initialize the inner to sane values before fetching resources */
-    bzero((char *)(w->text.inner_widget) + XtOffsetOf(XmTextInnerRec, inner),
-	  sizeof(XmTextInnerPart));
+    memset((char *)(w->text.inner_widget) + XtOffsetOf(XmTextInnerRec, inner),
+	   0, sizeof(XmTextInnerPart));
 
     Text_TableSize(w) = Text_TotalLines(w) = 0;
     Text_LineTable(w) = NULL;
@@ -648,6 +650,7 @@ Initialize(Widget request, Widget new,
 	}
 }
 
+
 static void
 Destroy(Widget w)
 {
@@ -668,11 +671,13 @@ Destroy(Widget w)
      */
     XtFree((XtPointer)Text_LineTable(w));
 #endif
+    if(Text_Line(w)) XtFree((XtPointer)Text_Line(w));
     XtFree((XtPointer)Text_Highlight(w).list);
     XtFree((XtPointer)Text_OldHighlight(w).list);
     XtFree((XtPointer)Text_Repaint(w).range);
 }
 
+
 static Boolean
 SetValues(Widget old, Widget request, Widget new,
 	  ArgList args, Cardinal *num_args)
@@ -786,6 +791,7 @@ SetValues(Widget old, Widget request, Widget new,
     return refresh_needed;
 }
 
+
 static void
 Realize(Widget aw, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
@@ -846,6 +852,7 @@ DoExpose(Widget aw, XEvent *event, Region region)
     Text_InExpose(w)= False;
 }
 
+
 static void
 Resize(Widget aw)
 {
@@ -877,6 +884,7 @@ Resize(Widget aw)
     RefigureLines(w);
 }
 
+
 static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 {
@@ -986,12 +994,14 @@ Redisplay(XmTextWidget w)
     Text_InRedisplay(w) = False;
 }
 
+
 static Cardinal
 GetSecResData(WidgetClass wc, XmSecondaryResourceData **resdata)
 {
     return 0;
 }
 
+
 /* Line Table Routines ---------------------------------------------------- */
 
 static void
@@ -1016,6 +1026,7 @@ LineIncrease(XmTextWidget w, LineNum num)
     }
 }
 
+
 /*
  * Set up the entire line table, starting with the first visible position.
  *
@@ -1186,6 +1197,7 @@ RefigureLines(XmTextWidget w)
 #endif
 }
 
+
 #if 0
 /* This is not used anywhere. Remove ? FIX ME */
 static LineNum
@@ -1234,11 +1246,12 @@ LineTableFindNum(XmTextWidget w, XmTextPosition pos)
  */
 #define LINETABLE_INCREMENT	64
 
+
 /*
  * The block and update parameters are currently unused because I don't
  * know what they should be used for.
  */
-void
+extern void
 _XmTextUpdateLineTable(Widget w,
 		       XmTextPosition start,
 		       XmTextPosition end,
@@ -1468,6 +1481,7 @@ _XmTextUpdateLineTable(Widget w,
     Text_TotalLines(w) = index;
 }
 
+
 /*
  * This function is the *initialize* variant of the one above.
  */
@@ -1495,7 +1509,8 @@ InitializeLineTable(XmTextWidget w)
 /* Not needed beyond this */
 #undef LINETABLE_INCREMENT
 
-unsigned int
+
+extern unsigned int
 _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
 {
     XmTextLineTable current = Text_LineTable(w) + Text_TotalLines(w) - 1;
@@ -1521,8 +1536,9 @@ _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
     return i;
 }
 
+
 /* Quasi-Public Functions ------------------------------------------------ */
-void
+extern void
 _XmTextLineInfo(XmTextWidget w, LineNum line,
 		XmTextPosition *startpos, LineTableExtra *extra)
 {
@@ -1530,13 +1546,15 @@ _XmTextLineInfo(XmTextWidget w, LineNum line,
     *extra = Text_Line(w)[line].extra;
 }
 
-void
+
+extern void
 _XmTextMarkRedraw(XmTextWidget w, XmTextPosition left,
 		  XmTextPosition right)
 {
 }
 
-LineNum
+
+extern LineNum
 _XmTextPosToLine(XmTextWidget w, XmTextPosition position)
 {
     if (position < 1)
@@ -1602,7 +1620,8 @@ _XmTextInsert(Widget w, XmTextPosition position, char *string, XEvent *evp)
     }
 }
 
-void
+
+extern void
 _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 {
     XmTextWidget tw = (XmTextWidget)w;
@@ -1706,13 +1725,15 @@ _XmTextSetEditable(Widget w, Boolean e)
     _XmStringSourceSetEditable(Text_Source(w), e);
 }
 
-void
+
+extern void
 _XmTextDisableRedisplay(XmTextWidget w, Boolean losesbackingstore)
 {
     Text_DisableDepth(w)++;
 }
 
-void
+
+extern void
 _XmTextEnableRedisplay(XmTextWidget w)
 {
     if (Text_DisableDepth(w) > 0)
@@ -1728,10 +1749,11 @@ _XmTextEnableRedisplay(XmTextWidget w)
     }
 }
 
+
 /*
  * What on earth does this do ???
  */
-void
+extern void
 _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 		  XmTextPosition topos, long delta)
 {
@@ -1746,21 +1768,33 @@ _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 	return;
     }
 
-    Text_Line(w)[i - 1].changed = True;
-    Text_Line(w)[i - 1].changed_position = position;
+    if (i==0)
+    {
+       /* This fixes SF [Bug #124809] */
+       Text_Line(w)[0].changed = True;
+       Text_Line(w)[0].changed_position = position;
+    }
+    else
+    {
+       Text_Line(w)[i - 1].changed = True;
+       Text_Line(w)[i - 1].changed_position = position;
+    }
 
     (*Text_Output(w)->Invalidate) (w, position, topos, delta);
     (*Text_Input(w)->Invalidate) (w, position, topos, delta);
 }
+
+
 /* Public Functions ------------------------------------------------------ */
 
-Widget
+extern Widget
 XmCreateText(Widget parent, char *name, Arg *arglist, Cardinal argCount)
 {
     return XtCreateWidget(name, xmTextWidgetClass, parent, arglist, argCount);
 }
 
-Widget
+
+extern Widget
 XmCreateScrolledText(Widget parent, char *name, Arg *arglist, Cardinal argcount)
 {
     Widget sw, w;
@@ -1806,7 +1840,8 @@ XmCreateScrolledText(Widget parent, char *name, Arg *arglist, Cardinal argcount)
     return w;
 }
 
-void
+
+extern void
 XmTextClearSelection(Widget w, Time time)
 {
     Boolean sel;
@@ -1839,7 +1874,8 @@ XmTextClearSelection(Widget w, Time time)
 
 }
 
-Boolean
+
+extern Boolean
 XmTextCopy(Widget w, Time time)
 {
     Display		*dpy;
@@ -1904,7 +1940,8 @@ XmTextCopy(Widget w, Time time)
 	return False;
 }
 
-Boolean
+
+extern Boolean
 XmTextCut(Widget w, Time time)
 {
     Boolean		sel, r = False;
@@ -1932,7 +1969,8 @@ XmTextCut(Widget w, Time time)
     return r;
 }
 
-Boolean
+
+extern Boolean
 XmTextFindString(Widget w, XmTextPosition start, char *string,
 		 XmTextDirection direction, XmTextPosition *position)
 {
@@ -1976,13 +2014,14 @@ XmTextFindString(Widget w, XmTextPosition start, char *string,
     return True;
 }
 
+
 /*
  * Returns an integer value that indicates the y position of the first baseline
  * in the Text widget. The calculation takes into account the margin height,
  * shadow thickness, highlight thickness, and font ascent of the first font in the
  * fontlist. In this calculation the x position of the top of the widget is 0. 
  */
-int
+extern int
 XmTextGetBaseline(Widget w)
 {
     /*
@@ -2011,7 +2050,7 @@ XmTextGetBaseline(Widget w)
 }
 
 
-XmTextPosition
+extern XmTextPosition
 XmTextGetCursorPosition(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2028,7 +2067,8 @@ XmTextGetCursorPosition(Widget w)
     return 0;
 }
 
-Boolean
+
+extern Boolean
 XmTextGetEditable(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2045,7 +2085,8 @@ XmTextGetEditable(Widget w)
     return 0;
 }
 
-XmTextPosition
+
+extern XmTextPosition
 XmTextGetInsertionPosition(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2062,7 +2103,8 @@ XmTextGetInsertionPosition(Widget w)
     return 0;
 }
 
-XmTextPosition
+
+extern XmTextPosition
 XmTextGetLastPosition(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2079,7 +2121,8 @@ XmTextGetLastPosition(Widget w)
     return 0;
 }
 
-int
+
+extern int
 XmTextGetMaxLength(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2096,7 +2139,8 @@ XmTextGetMaxLength(Widget w)
     return 0;
 }
 
-char *
+
+extern char *
 XmTextGetSelection(Widget w)
 {
     Boolean sel;
@@ -2125,7 +2169,8 @@ XmTextGetSelection(Widget w)
     return NULL;
 }
 
-Boolean
+
+extern Boolean
 XmTextGetSelectionPosition(Widget w, XmTextPosition *left, XmTextPosition *right)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2142,7 +2187,8 @@ XmTextGetSelectionPosition(Widget w, XmTextPosition *left, XmTextPosition *right
     return False;
 }
 
-wchar_t *
+
+extern wchar_t *
 XmTextGetSelectionWcs(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2161,7 +2207,7 @@ XmTextGetSelectionWcs(Widget w)
 }
 
 
-char *
+extern char *
 XmTextGetString(Widget w)
 {
     if (XmIsText(w))
@@ -2178,7 +2224,8 @@ XmTextGetString(Widget w)
     return NULL;
 }
 
-wchar_t *
+
+extern wchar_t *
 XmTextGetStringWcs(Widget w)
 {
     if (XmIsText(w))
@@ -2195,7 +2242,8 @@ XmTextGetStringWcs(Widget w)
     return NULL;
 }
 
-Boolean
+
+extern Boolean
 XmTextFindStringWcs(Widget w,
 		    XmTextPosition start,
 		    wchar_t *wc_string,
@@ -2206,12 +2254,13 @@ XmTextFindStringWcs(Widget w,
     return False;
 }
 
+
 /*
  * XmTextGetSubstring()
  * 
  * Gets a substring of the text 
  */
-int
+extern int
 XmTextGetSubstring(Widget w, XmTextPosition start, int num_chars,
 		   int buffer_size, char *buffer)
 {
@@ -2248,7 +2297,8 @@ XmTextGetSubstring(Widget w, XmTextPosition start, int num_chars,
     return retval;
 }
 
-int
+
+extern int
 XmTextGetSubstringWcs(Widget w, XmTextPosition start, int num_chars,
 		      int buffer_size, wchar_t *buffer)
 {
@@ -2269,7 +2319,8 @@ XmTextGetSubstringWcs(Widget w, XmTextPosition start, int num_chars,
     return XmCOPY_FAILED;
 }
 
-XmTextPosition
+
+extern XmTextPosition
 XmTextGetTopCharacter(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2278,15 +2329,13 @@ XmTextGetTopCharacter(Widget w)
     }
     else
     {
-	_XmWarning(w, "XmTextGetTopCharacter: not implemented");
+	_XmWarning(w, "XmTextGetTopCharacter: widget has invalid class");
 	return 0;
-    }
-    _XmWarning(w, "XmTextGetTopCharacter: widget has invalid class");
-
-    return 0;
+     }
 }
 
-void
+
+extern void
 XmTextInsert(Widget w, XmTextPosition position, char *string)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2304,7 +2353,7 @@ XmTextInsert(Widget w, XmTextPosition position, char *string)
 }
 
 
-void
+extern void
 XmTextInsertWcs(Widget w, XmTextPosition position, wchar_t *wcstring)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2322,7 +2371,8 @@ XmTextInsertWcs(Widget w, XmTextPosition position, wchar_t *wcstring)
     }
 }
 
-Boolean
+
+extern Boolean
 XmTextPaste(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2388,7 +2438,8 @@ XmTextPaste(Widget w)
     return False;
 }
 
-Boolean
+
+extern Boolean
 XmTextPosToXY(Widget w, XmTextPosition position, Position *x, Position *y)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2406,7 +2457,8 @@ XmTextPosToXY(Widget w, XmTextPosition position, Position *x, Position *y)
 
 }
 
-Boolean
+
+extern Boolean
 XmTextRemove(Widget w)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2437,7 +2489,8 @@ XmTextRemove(Widget w)
     }
 }
 
-void
+
+extern void
 XmTextReplace(Widget w, XmTextPosition from_pos, XmTextPosition to_pos, char *value)
 {
     XmTextStatus st;
@@ -2484,7 +2537,8 @@ XmTextReplace(Widget w, XmTextPosition from_pos, XmTextPosition to_pos, char *va
 #endif
 }
 
-void
+
+extern void
 XmTextReplaceWcs(Widget w, XmTextPosition from_pos, XmTextPosition to_pos,
 		 wchar_t *wcstring)
 {
@@ -2504,7 +2558,8 @@ XmTextReplaceWcs(Widget w, XmTextPosition from_pos, XmTextPosition to_pos,
     _XmWarning(w, "XmTextReplaceWcs is not implemented");
 }
 
-void
+
+extern void
 XmTextSetAddMode(Widget w, Boolean state)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2522,7 +2577,8 @@ XmTextSetAddMode(Widget w, Boolean state)
     }
 }
 
-void
+
+extern void
 XmTextSetCursorPosition(Widget w, XmTextPosition position)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2540,7 +2596,7 @@ XmTextSetCursorPosition(Widget w, XmTextPosition position)
 }
 
 
-void
+extern void
 XmTextSetEditable(Widget w, Boolean editable)
 {
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
@@ -2562,7 +2618,8 @@ XmTextSetEditable(Widget w, Boolean editable)
     Text_Editable(w) = editable;
 }
 
-void
+
+extern void
 XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighlightMode mode)
 {
     if (left >= right || left < 0 )
@@ -2715,7 +2772,8 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
     }
 }
 
-void
+
+extern void
 XmTextSetInsertionPosition(Widget w, XmTextPosition position)
 {
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
@@ -2733,7 +2791,8 @@ XmTextSetInsertionPosition(Widget w, XmTextPosition position)
     }
 }
 
-void
+
+extern void
 XmTextSetMaxLength(Widget w, int max_length)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2750,7 +2809,8 @@ XmTextSetMaxLength(Widget w, int max_length)
     }
 }
 
-void
+
+extern void
 XmTextSetSelection(Widget w, XmTextPosition first, XmTextPosition last,
 		   Time time)
 {
@@ -2770,7 +2830,8 @@ XmTextSetSelection(Widget w, XmTextPosition first, XmTextPosition last,
     }
 }
 
-void
+
+extern void
 XmTextSetString(Widget w, char *value)
 {
     XmTextWidget tw = (XmTextWidget)w;
@@ -2820,7 +2881,8 @@ XmTextSetString(Widget w, char *value)
     }
 }
 
-void
+
+extern void
 XmTextSetStringWcs(Widget w, wchar_t *wcstring)
 {
     if (XtIsSubclass(w, xmTextWidgetClass))
@@ -2838,26 +2900,29 @@ XmTextSetStringWcs(Widget w, wchar_t *wcstring)
     }
 }
 
-void
+
+extern void
 XmTextDisableRedisplay(Widget w)
 {
     Text_DisableDepth(w)++;
 }
 
-void
+
+extern void
 XmTextEnableRedisplay(Widget w)
 {
     _XmTextEnableRedisplay((XmTextWidget)w);
 }
 
 
-XmTextSource
+extern XmTextSource
 XmTextGetSource(Widget w)
 {
     return Text_Source(w);
 }
 
-void
+
+extern void
 XmTextSetSource(Widget w, XmTextSource s,
 		XmTextPosition top, XmTextPosition curs)
 {
@@ -2887,7 +2952,8 @@ XmTextSetSource(Widget w, XmTextSource s,
     }
 }
 
-void
+
+extern void
 XmTextScroll(Widget aw, int n)
 {
     XmTextWidget w = (XmTextWidget)aw;
@@ -2918,7 +2984,8 @@ XmTextScroll(Widget aw, int n)
     XmTextSetTopCharacter(aw, Text_LineTable(w)[index].start_pos);
 }
 
-void
+
+extern void
 XmTextSetTopCharacter(Widget w, XmTextPosition top_character)
 {
     if (!XtIsSubclass(w, xmTextWidgetClass))
@@ -2957,7 +3024,8 @@ XmTextSetTopCharacter(Widget w, XmTextPosition top_character)
     }
 }
 
-void
+
+extern void
 XmTextShowPosition(Widget aw, XmTextPosition position)
 {
     XmTextWidget w = (XmTextWidget)aw;
@@ -3009,7 +3077,8 @@ XmTextShowPosition(Widget aw, XmTextPosition position)
     }
 }
 
-XmTextPosition
+
+extern XmTextPosition
 XmTextXYToPos(Widget w, Position x, Position y)
 {
     DEBUGOUT(XdbDebug(__FILE__, w, "XmTextXYToPos x=%d y=%d\n", x, y));
@@ -3029,7 +3098,7 @@ XmTextXYToPos(Widget w, Position x, Position y)
 }
 
 
-void
+extern void
 _XmTextExportValue(Widget w, int offset, XtArgVal *value)
 {
     *value = (XtArgVal)XmTextGetString(w);
@@ -3039,6 +3108,7 @@ _XmTextExportValue(Widget w, int offset, XtArgVal *value)
 		      (char *)*value));
 }
 
+
 /*
  * GetValues works through a whole bunch of stuff here :
  * - the "normal" mechanism : Xt will copy stuff specified in resources
@@ -3072,13 +3142,15 @@ TextGetValues(Widget w, ArgList args, Cardinal *num_args)
     DEBUGOUT(XdbPrintArgList(__FILE__, w, args, *num_args, True));
 }
 
-int
+
+extern int
 _XmTextGetTotalLines(Widget w)
 {
 	return Text_TotalLines(w);
 }
 
-void
+
+extern void
 _XmTextSetTopCharacter (  Widget w,
                       XmTextPosition top_character)
 {
@@ -3107,12 +3179,13 @@ _XmTextSetTopCharacter (  Widget w,
 }
 
 
-LineNum _XmTextNumLines(
-                        XmTextWidget widget)
+extern LineNum
+_XmTextNumLines(XmTextWidget widget)
 {
 	return Text_LineCount(widget);
 }
 
+
 #if XmVERSION > 1
 /*
  * Not sure whether I need to do all this copying.
@@ -3138,6 +3211,7 @@ _XmText_TraitGetValue(Widget w, int format)
 	}  
 }
 
+
 static void
 _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 {
@@ -3167,6 +3241,7 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 	}
 }
 
+
 static int
 _XmText_TraitPreferredFormat(Widget w)
 {
@@ -3174,4 +3249,14 @@ _XmText_TraitPreferredFormat(Widget w)
 
 	return XmFORMAT_WCS;
 }
-#endif
+
+
+extern Boolean
+XmTextCopyLink(Widget widget,
+               Time time)
+{
+   _XmWarning(NULL, "XmTextCopyLink(): not yet implemented!");
+   return False;
+}
+
+#endif /* XmVERSION > 1 */
