@@ -1,9 +1,9 @@
-/*                   -*-Mode: c; c-file-style: "GNU"-*-              */
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextIn.c,v 1.57 2000/04/18 19:35:40 hennessy Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.61 2000/11/05 17:25:35 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,24 +23,24 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/TextIn.c,v 1.57 2000/04/18 19:35:40 hennessy Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.61 2000/11/05 17:25:35 amai Exp $";
 
 #include <LTconfig.h>
-#include <Xm/XmP.h>
-#include <XmI/XmI.h>
-#include <Xm/TextP.h>
-#include <X11/Xfuncs.h>
+
 #include <stdio.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#define ANSI_STRING
-#else
-#include <strings.h>
-#endif
 #include <stdlib.h>
 
+#include <Xm/XmP.h>
+#include <Xm/TextP.h>
+#if XmVERSION > 1
+#include <Xm/XmIm.h>
+#endif
+
+#include <XmI/XmI.h>
 #include <XmI/DebugUtil.h>
 
+
 static void Activate(Widget w, XEvent *ev, String *params,
 		     Cardinal *num_params);
 static void MoveBackwardChar(Widget w, XEvent *ev, String *params,
@@ -417,7 +417,7 @@ GetSecResData(XmSecondaryResourceData *secres)
 {
 }
 
-InputRec inputRec =
+static InputRec inputRec =
 {
     /* _InputDataRec             */ NULL,
     /* InputInvalidateProc       */ Invalidate,
@@ -435,7 +435,7 @@ _XmTextInputCreate(Widget aw, ArgList args, Cardinal num_args)
     InputData i;
 
     Text_Input(w) = (Input)XtMalloc(sizeof(InputRec));
-    bcopy(&inputRec, Text_Input(w), sizeof(InputRec));
+    memcpy(Text_Input(w), &inputRec, sizeof(InputRec));
 
     i = Text_Input(w)->data = &iw->inner.in;
 
