@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.85 2000/08/03 21:29:46 rwscott Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.89 2000/11/07 23:22:05 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.85 2000/08/03 21:29:46 rwscott Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.89 2000/11/07 23:22:05 dannybackx Exp $";
 
 #include <LTconfig.h>
+
+#include <limits.h>		/* for INT_MAX */
+#include <string.h>
+#include <stdlib.h>
+
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
 #include <Xm/TextOutP.h>
@@ -33,15 +39,6 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v
 #include <Xm/AtomMgr.h>
 #include <XmI/XmI.h>
 #include <XmI/AtomMgrI.h>
-#include <X11/Xfuncs.h>
-#include <limits.h>		/* for INT_MAX */
-#ifdef HAVE_STRING_H
-#include <string.h>
-#define ANSI_STRING
-#else
-#include <strings.h>
-#endif
-#include <stdlib.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -744,9 +741,12 @@ _XmTextNextX(XmTextWidget w, int x, char *ptr, int len)
 	    if (c < fs->min_char_or_byte2 || c > fs->max_char_or_byte2)
 	    {
 		c = fs->default_char;
-		/* FIX ME
-		 * Hack by vogt@kvi.nl */
-		if (c < 32) {
+
+		/*
+		 * Hack by vogt@kvi.nl
+		 * Updated 8 nov 2000 by Tom Pollard pollard@schrodinger.com
+		 */
+		if (c < fs->min_char_or_byte2 || c > fs->max_char_or_byte2) {
 			DEBUGOUT(XdbDebug(__FILE__, (Widget)w, 
 				"_XmTextNextX: fs->default_char %d -> 32\n",
 				c));
@@ -2426,7 +2426,7 @@ resize(Widget aw, Boolean state)
 }
 
 
-OutputRec outputRec =
+static OutputRec outputRec =
 {
     /* _OutputDataRec            */ NULL,
     /* XYToPosProc               */ XYToPos,
@@ -2461,7 +2461,7 @@ _XmTextOutputCreate(Widget aw, ArgList args, Cardinal num_args)
 #endif
 
     Text_Output(w) = (Output)XtMalloc(sizeof(OutputRec));
-    bcopy(&outputRec, Text_Output(w), sizeof(OutputRec));
+    memcpy(Text_Output(w), &outputRec, sizeof(OutputRec));
 
     Text_OutputData(w) = o = &iw->inner.out;
     XtGetSubresources(aw, iw,
