@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextStrSo.c,v 1.46 2000/04/02 14:08:23 rwscott Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TextStrSo.c,v 1.46 2000/04/02 14:08:23 rwscott Exp $";
+static const char rcsid[] = "$Id: TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Exp $";
 
 /*
  * Empirical evidence (fooling around with the structures found in Motif
@@ -42,24 +43,18 @@ static const char rcsid[] = "$Id: TextStrSo.c,v 1.46 2000/04/02 14:08:23 rwscott
 #undef VERBOSE_XdbDebug
 
 #include <LTconfig.h>
+
+#include <string.h>
+#include <stdlib.h>
+
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
 #include <Xm/VendorSEP.h>
-#include <X11/Xfuncs.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
-#define ANSI_STRING
-#else
-#include <strings.h>
-#endif
-#include <stdlib.h>
 
 #include <XmI/DebugUtil.h>
 
 #define SOURCE_ALLOC_SIZE 256
 
-void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
-		       XmTextPosition topos, long delta);
 
 static char *
 StrPtr(XmSourceData d, XmTextPosition pos)
@@ -70,6 +65,7 @@ StrPtr(XmSourceData d, XmTextPosition pos)
     return ptr;
 }
 
+
 #if 0
 static char *
 StrNext(XmSourceData d, XmTextPosition pos)
@@ -77,6 +73,7 @@ StrNext(XmSourceData d, XmTextPosition pos)
     return d->ptr + pos + 1;
 }
 
+
 static char *
 StrPrev(XmSourceData d, XmTextPosition pos)
 {
@@ -707,6 +704,7 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
     return pos;
 }
 
+
 static Boolean
 GetSelection(XmTextSource source, XmTextPosition *left,
 	     XmTextPosition *right)
@@ -797,7 +795,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(???)\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
 	/* ??? */
     }
 }
@@ -887,7 +885,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     }
 }
 
-XmTextSourceRec sourceRec =
+static XmTextSourceRec sourceRec =
 {
     /* _XmSourceDataRec      */ NULL,
     /* AddWidgetProc         */ AddWidget,
@@ -900,7 +898,8 @@ XmTextSourceRec sourceRec =
     /* SetSelectionProc      */ SetSelection
 };
 
-XmTextSource
+
+extern XmTextSource
 _XmStringSourceCreate(char *value, Boolean is_wchar)
 {
     XmTextSource source;
@@ -908,7 +907,7 @@ _XmStringSourceCreate(char *value, Boolean is_wchar)
 
 
     source = (XmTextSource)XtMalloc(sizeof(XmTextSourceRec));
-    bcopy(&sourceRec, source, sizeof(XmTextSourceRec));
+    memcpy(source, &sourceRec, sizeof(XmTextSourceRec));
 
     d = (XmSourceData)XtMalloc(sizeof(XmSourceDataRec));
     d->source = source;
@@ -935,7 +934,7 @@ _XmStringSourceCreate(char *value, Boolean is_wchar)
  */
 
 
-void
+extern void
 _XmStringSourceDestroy(XmTextSource source)
 {
     XmSourceData d = source->data;
@@ -963,7 +962,8 @@ _XmStringSourceDestroy(XmTextSource source)
     XtFree((char *)source);
 }
 
-char *
+
+extern char *
 _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
 {
     XmSourceData d = source->data;
@@ -991,7 +991,8 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
     return txt;
 }
 
-void
+
+extern void
 _XmStringSourceSetValue(XmTextWidget w, char *value)
 {
     XmTextVerifyCallbackStruct cbs;
@@ -1070,19 +1071,22 @@ _XmStringSourceSetValue(XmTextWidget w, char *value)
     }
 }
 
-Boolean
+
+extern Boolean
 _XmStringSourceHasSelection(XmTextSource source)
 {
     return source->data->hasselection;
 }
 
-Boolean
+
+extern Boolean
 _XmStringSourceGetEditable(XmTextSource source)
 {
     return source->data->editable;
 }
 
-void
+
+extern void
 _XmStringSourceSetEditable(XmTextSource source, Boolean editable)
 {
     XmSourceData d;
@@ -1091,13 +1095,15 @@ _XmStringSourceSetEditable(XmTextSource source, Boolean editable)
     d->editable = editable;
 }
 
-int
+
+extern int
 _XmStringSourceGetMaxLength(XmTextSource source)
 {
     return source->data->maxlength;
 }
 
-void
+
+extern void
 _XmStringSourceSetMaxLength(XmTextSource source, int max)
 {
     XmSourceData d;
@@ -1118,7 +1124,8 @@ _XmStringSourceSetMaxLength(XmTextSource source, int max)
     d->maxallowed = max;
 }
 
-char *
+
+extern char *
 _XmStringSourceGetString(XmTextWidget w,
 			 XmTextPosition from,
 			 XmTextPosition to,
@@ -1141,7 +1148,7 @@ _XmStringSourceGetString(XmTextWidget w,
 }
 
 
-Boolean
+extern Boolean
 _XmTextFindStringBackwards(Widget w,
 			   XmTextPosition start,
 			   char *search_string,
@@ -1152,7 +1159,8 @@ _XmTextFindStringBackwards(Widget w,
     return False;		/* FIX ME */
 }
 
-Boolean
+
+extern Boolean
 _XmTextFindStringForwards(Widget w,
 			  XmTextPosition start,
 			  char *search_string,
@@ -1161,7 +1169,8 @@ _XmTextFindStringForwards(Widget w,
     return False;		/* FIX ME */
 }
 
-Boolean
+
+extern Boolean
 _XmStringSourceFindString(Widget w,
 			  XmTextPosition start,
 			  char *string,
@@ -1172,7 +1181,8 @@ _XmStringSourceFindString(Widget w,
     return False;		/* FIX ME */
 }
 
-void
+
+extern void
 _XmStringSourceSetGappedBuffer(XmSourceData data, XmTextPosition position)
 {
     _XmWarning(NULL, "_XmStringSourceSetGappedBuffer is not implemented yet.");
