@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ToggleB.c,v 1.71 2000/01/16 17:12:20 amai Exp $
+ * $Id: ToggleB.c,v 1.74 2000/09/29 22:51:55 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleB.c,v 1.71 2000/01/16 17:12:20 amai Exp $";
+static const char rcsid[] = "$Id: ToggleB.c,v 1.74 2000/09/29 22:51:55 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdarg.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ToggleBP.h>
 #include <Xm/RowColumnP.h>
@@ -38,8 +41,6 @@ static const char rcsid[] = "$Id: ToggleB.c,v 1.71 2000/01/16 17:12:20 amai Exp
 #include <Xm/TransltnsP.h>
 #include <X11/ShellP.h>
 
-#include <stdarg.h>
-
 #include <XmI/DebugUtil.h>
 
 #include <Xm/ToggleBGP.h>
@@ -137,7 +138,7 @@ static XtResource resources[] =
 	sizeof(Boolean), Offset(set),
 	XmRImmediate, (XtPointer)False
     },
-#if XmVERSION == 1 || LESSTIF_BACK_COMPAT
+#if XmVERSION == 1
     {
 	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
 	sizeof(Boolean), Offset(ind_on),
@@ -611,7 +612,8 @@ initialize(Widget request, Widget new_w,
 	    {
 		Lab_MarginLeft(new_w) += margin;
 		Lab_TextRect_x(new_w) += margin;
-		Lab_AccTextRect(new_w).x += margin;
+		if (Lab_AcceleratorText(new_w) != NULL)
+		    Lab_AccTextRect(new_w).x += margin;
 	    }
 	    else
 		Lab_MarginRight(new_w) += margin;
@@ -638,7 +640,8 @@ initialize(Widget request, Widget new_w,
 	    if (!XtHeight(request))
 	    {
 		Lab_TextRect_y(new_w) += margin >> 1;
-		Lab_AccTextRect(new_w).y += margin >> 1;
+		if (Lab_AcceleratorText(new_w) != NULL)
+		    Lab_AccTextRect(new_w).y += margin >> 1;
 		XtHeight(new_w) += margin;
 	    }
 	}
