@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ToggleBG.c,v 1.70 2000/01/16 17:12:21 amai Exp $
+ * $Id: ToggleBG.c,v 1.74 2000/09/29 22:51:55 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleBG.c,v 1.70 2000/01/16 17:12:21 amai Exp $";
+static const char rcsid[] = "$Id: ToggleBG.c,v 1.74 2000/09/29 22:51:55 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdarg.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -36,14 +41,12 @@ static const char rcsid[] = "$Id: ToggleBG.c,v 1.70 2000/01/16 17:12:21 amai Exp
 #include <Xm/MenuShell.h>
 #include <Xm/MenuUtilP.h>
 #include <Xm/CacheP.h>
-#include <X11/Xfuncs.h>
 #include <X11/ShellP.h>
 #include <Xm/ToggleBP.h>
 
-#include <stdarg.h>
-
 #include <XmI/DebugUtil.h>
 
+
 /* Some M*tif versions (e.g. 1.2.6 on Solaris 2.6) leave less room above and
  * below the indicator than others (e.g. 1.2.5 on HP-UX 10, my reference).
  */
@@ -175,7 +178,7 @@ static XtResource cache_resources[] =
 	sizeof(Pixmap), Offset(insen_pixmap),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
-#if XmVERSION == 1 || LESSTIF_BACK_COMPAT
+#if XmVERSION == 1
     {
 	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
 	sizeof(Boolean), Offset(ind_on),
@@ -499,7 +502,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -514,7 +517,7 @@ secondary_object_create(Widget request,
 int
 _XmToggleBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmToggleButtonGCacheObjPart *)A),
+    return !memcmp(((XmToggleButtonGCacheObjPart *)A),
 		 ((XmToggleButtonGCacheObjPart *)B),
 		 sizeof(XmToggleButtonGCacheObjPart));
 }
@@ -552,10 +555,10 @@ class_initialize(void)
 			     &labels, &nlabels);
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
-    bcopy(labels, combined, nlabels * sizeof(XtResource));
-    bcopy(cache_resources,
-	  &combined[nlabels],
-	  XtNumber(cache_resources) * sizeof(XtResource));
+    memcpy(combined, labels, nlabels * sizeof(XtResource));
+    memcpy(&combined[nlabels],
+           cache_resources,
+	   XtNumber(cache_resources) * sizeof(XtResource));
     XtFree((char *)labels);
 
     xmToggleButtonGCacheObjClassRec.object_class.resources = combined;
@@ -851,12 +854,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(TBG_Cache(new_w),
-	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-	  sizeof(XmToggleButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+           TBG_Cache(new_w),
+	   sizeof(XmToggleButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -871,7 +874,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
     LabG_Cache(new_w) = &(((XmToggleButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmToggleButtonGCacheObject)rsec)->label_cache);
@@ -1186,12 +1189,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(TBG_Cache(new_w),
-	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-	  sizeof(XmToggleButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+           TBG_Cache(new_w),
+	   sizeof(XmToggleButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
