@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Traversal.c,v 1.35 2000/04/30 22:38:24 amai Exp $
+ * $Id: Traversal.c,v 1.37 2000/09/22 20:35:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,17 +23,17 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Traversal.c,v 1.35 2000/04/30 22:38:24 amai Exp $";
+static const char rcsid[] = "$Id: Traversal.c,v 1.37 2000/09/22 20:35:13 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <XmI/XmI.h>
 #include <XmI/TraversalI.h>
 
-#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/VendorS.h>
 #include <Xm/VendorSEP.h>
@@ -45,6 +46,7 @@ static const char rcsid[] = "$Id: Traversal.c,v 1.35 2000/04/30 22:38:24 amai Ex
 
 #include <XmI/DebugUtil.h>
 
+
 #define ALLOC_INCR		8
 
 /*
@@ -1355,7 +1357,7 @@ DeleteFromTabList(XmTravTree tree, int node)
 	return;
     }
 
-    bcopy(&tree->excl_tabs[node + 1], &tree->excl_tabs[node],
+    memcpy(&tree->excl_tabs[node], &tree->excl_tabs[node + 1],
 	  (tree->num_tab_entries - node - 1) * sizeof(Widget));
 
     tree->num_tab_entries--;
