@@ -1,8 +1,9 @@
 /**
  *
- * $Id: VaSimple.c,v 1.8 2000/04/19 22:27:27 amai Exp $
+ * $Id: VaSimple.c,v 1.10 2000/09/22 20:35:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -49,11 +50,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: VaSimple.c,v 1.8 2000/04/19 22:27:27 amai Exp $";
+static const char rcsid[] = "$Id: VaSimple.c,v 1.10 2000/09/22 20:35:13 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ToggleBGP.h>
 #include <Xm/PushBGP.h>
@@ -61,10 +64,10 @@ static const char rcsid[] = "$Id: VaSimple.c,v 1.8 2000/04/19 22:27:27 amai Exp
 #include <Xm/SeparatoGP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/VaSimpleP.h>
-#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
+
 /* this seems realistic to me */
 #define MAX_EMBEDDED_BUTTONS	512
 static XmButtonType button_types[MAX_EMBEDDED_BUTTONS];
@@ -122,11 +125,11 @@ _XmCountVaList(va_list var, int *button_count, int *args_count,
     *typed_count = 0;
     *button_count = 0;
     *args_count = 0;
-    bzero((void *)button_types, MAX_EMBEDDED_BUTTONS * sizeof(unsigned char));
-    bzero((void *)button_strings, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
-    bzero((void *)button_mnemonics, MAX_EMBEDDED_BUTTONS * sizeof(KeySym));
-    bzero((void *)button_accel, MAX_EMBEDDED_BUTTONS * sizeof(String));
-    bzero((void *)button_acc_text, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
+    memset((void *)button_types, 0, MAX_EMBEDDED_BUTTONS * sizeof(unsigned char));
+    memset((void *)button_strings, 0, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
+    memset((void *)button_mnemonics, 0, MAX_EMBEDDED_BUTTONS * sizeof(KeySym));
+    memset((void *)button_accel, 0, MAX_EMBEDDED_BUTTONS * sizeof(String));
+    memset((void *)button_acc_text, 0, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
 
     for (attr = va_arg(var, String); attr != NULL;
 	 attr = va_arg(var, String))
@@ -314,7 +317,7 @@ _XmTypedArgToArg(Widget widget, XtTypedArgList typed_arg, ArgList arg_return,
 	{
 	    arg_return->value = (XtArgVal)XtMalloc(to_val.size);
 	    memory_return->value = (XtArgVal)arg_return->value;
-	    bcopy(to_val.addr, (void *)arg_return->value, to_val.size);
+	    memcpy((void *)arg_return->value, to_val.addr, to_val.size);
 	}
     }
 
