@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $
+ * $Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,14 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
-
-#include <XmI/XmI.h>
+#include <string.h>
 
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
@@ -37,7 +37,7 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $
 #include <X11/ShellP.h>
 #include <X11/Vendor.h>
 #include <X11/VendorP.h>
-#include <X11/Xfuncs.h>
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/BulletinBP.h>
@@ -57,6 +57,7 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $
 
 #include <XmI/DebugUtil.h>
 
+
 #if XmVERSION > 1
 #include <Xm/TraitP.h>
 #endif
@@ -65,6 +66,19 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $
 #define XmUNSPECIFIED (~0)
 #endif
 
+
+/* We use a 'private', i.e. non-declared but actually
+   exported call from OpenGroup's Intrinsic sources
+   (lib/Xt/Callback.c) in this file.
+   Note that we don't give the precise type here ...
+ */
+extern void 
+_XtRemoveCallback (
+    /* InternalCallbackList   *callbacks, */
+    void               *callbacks,
+    XtCallbackProc	callback,
+    XtPointer		closure);
+
 /***************************************************************************
  *
  * Vendor shell class record
@@ -650,8 +664,8 @@ class_initialize(void)
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
 
-    bcopy(shells, combined, nshells * sizeof(XtResource));
-    bcopy(ext_resources, &combined[nshells],
+    memcpy(combined, shells, nshells * sizeof(XtResource));
+    memcpy(&combined[nshells], ext_resources,
 	  XtNumber(ext_resources) * sizeof(XtResource));
 
     xmVendorShellExtClassRec.object_class.resources = combined;
@@ -939,7 +953,7 @@ secondary_object_create(Widget req, Widget new_w,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmSHELL_EXTENSION);
@@ -1113,12 +1127,14 @@ _XmVendorExtDestroy(Widget w)
 	  XtFree((char*)VSEP_MwmMenu(ve));
     }
 
-    XtFree((char*)VSEP_FocusData(ve));
+    _XmDestroyFocusData(VSEP_FocusData(ve));
 
     wm_delete_window = XmInternAtom(XtDisplay(shell), _XA_WM_DELETE_WINDOW, False);
 
-	/* This removes all protocols and destroys the associated extension object */
-	_XmDestroyProtocols(shell);
+    /* This removes all protocols and destroys the associated extension object */
+    _XmDestroyProtocols(shell);
+    _XtRemoveCallback(&VSEP_RealizeCallback(w), _XmVendorExtRealize, NULL);
+    XtFree((char *)w);
 }
 
 
@@ -1249,8 +1265,8 @@ set_values_prehook(Widget old, Widget req, Widget new_w,
 
     data = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
 
-    bcopy(ve, rsec, size);
-    bcopy(ve, nsec, size);
+    memcpy(rsec, ve, size);
+    memcpy(nsec, ve, size);
 
     data->widget = (Widget)ve;
     data->oldWidget = (Widget)nsec;
@@ -1334,7 +1350,7 @@ get_values_prehook(Widget widget,
 
     ve = _LtFindVendorExt(widget);
 
-    bcopy(ve, nsec, size);
+    memcpy(nsec, ve, size);
 
     data = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     data->widget = (Widget)nsec;
@@ -2066,6 +2082,10 @@ typedef struct
 }
 QueryStruct;
 
+/* A prototype for a private libXt function ... */
+/* rws 17 Dec 2000
+   The lower case w may look wrong here, BUT IT IS NOT
+ */
 extern int _XtwaitForSomething(_XtBoolean ignoreTimers, _XtBoolean ignoreInputs,
 			       _XtBoolean ignoreEvents, _XtBoolean block,
 			       unsigned long *howlong, XtAppContext app);
@@ -2169,6 +2189,9 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 	    }
 	}
 
+/* rws 17 Dec 2000
+   The lower case w may look wrong here, BUT IT IS NOT
+ */
 	if (_XtwaitForSomething(TRUE, TRUE, FALSE, TRUE, &timeout, app) != -1)
 	{
 	    continue;
@@ -2466,6 +2489,7 @@ typedef struct
 }
 QueryStruct;
 
+/* A prototype for a private libXt function ... */
 extern int _XtWaitForSomething(XtAppContext app,
 			       _XtBoolean ignoreEvents, _XtBoolean ignoreTimers,
 			       _XtBoolean ignoreInputs,
@@ -3090,7 +3114,7 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
     }
 
     if (XtIsRealized(ExtObj_LogicalParent(nw)) &&
-	bcmp(&VSEP_MwmHints(nw), &VSEP_MwmHints(cw), sizeof(MwmHints)) != 0)
+	memcmp(&VSEP_MwmHints(nw), &VSEP_MwmHints(cw), sizeof(MwmHints)) != 0)
     {
 	at = XmInternAtom(XtDisplay(nw), _XA_MWM_HINTS, False);
 	/* note the 32 format = long on client side */
@@ -3105,7 +3129,13 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 			PROP_MOTIF_WM_HINTS_ELEMENTS);
     }
 
-    if (XtIsRealized(ExtObj_LogicalParent(nw)) &&
+/* rws 13 Sep 2000
+   We have to do this whether we are realized or not.
+   test/Xm/mwm/test5 -xrm "*autoExit: True" show this.
+   It does a SetValues on mwmMenu with a static string, if we do not
+   copy this string we end up segfaulting when things get destroyed!!!
+ */
+    if (/*XtIsRealized(ExtObj_LogicalParent(nw)) &&*/
 	((!VSEP_MwmMenu(nw) && VSEP_MwmMenu(cw)) ||
 	 (VSEP_MwmMenu(nw) && !VSEP_MwmMenu(cw)) ||
 	 (VSEP_MwmMenu(nw) && VSEP_MwmMenu(cw) &&
@@ -3121,7 +3151,8 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 	    VSEP_MwmMenu(nw) = XtNewString(VSEP_MwmMenu(nw));
 	}
 
-	if (VSEP_MwmMenu(nw) != NULL) {
+	if (XtIsRealized(ExtObj_LogicalParent(nw)) && VSEP_MwmMenu(nw) != NULL)
+	{
 	    /* Only do this if we have a reason for it.
 	     * The Motif 2.1 mwm seems to crash without this. */
 	    at = XmInternAtom(XtDisplay(nw), _XA_MWM_MENU, False);
