@@ -1,8 +1,9 @@
 /**
  *
- * $Id: VirtKeys.c,v 1.12 1999/11/13 14:10:34 rwscott Exp $
+ * $Id: VirtKeys.c,v 1.15 2000/11/15 15:03:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,19 +23,16 @@
  *
  **/
 
-static const char rcsid[] = "$Id: VirtKeys.c,v 1.12 1999/11/13 14:10:34 rwscott Exp $";
+static const char rcsid[] = "$Id: VirtKeys.c,v 1.15 2000/11/15 15:03:24 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#define ANSI_STRINGS
-#endif
 #include <stdlib.h>
 
+#include <X11/keysym.h>
+
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
@@ -42,12 +40,12 @@ static const char rcsid[] = "$Id: VirtKeys.c,v 1.12 1999/11/13 14:10:34 rwscott
 #include <Xm/MwmUtil.h>
 #include <Xm/VirtKeysP.h>
 #include <Xm/TransltnsP.h>
-#include <X11/keysym.h>
-#include <X11/Xfuncs.h>
+
 #include <Xm/XmosP.h>
 
 #include <XmI/DebugUtil.h>
 
+
 /*
  * Order of binding precedences:
  *  1) defaultVirtualBindings resource
@@ -69,7 +67,8 @@ static const char rcsid[] = "$Id: VirtKeys.c,v 1.12 1999/11/13 14:10:34 rwscott
 #define DEFAULT_BINDINGS_PROPERTY_NAME _XA_MOTIF_DEFAULT_BINDINGS
 #define BINDINGS_PROPERTY_NAME         _XA_MOTIF_BINDINGS
 
-char _XmVirtKeys_hpFallbackBindingString[] = "\
+
+XmConst char _XmVirtKeys_hpFallbackBindingString[] = "\
 osfAddMode    : Shift<Key>F8   \n\
 osfBackSpace  : <Key>BackSpace \n\
 osfBeginLine  : <Key>Home      \n\
@@ -92,7 +91,8 @@ osfUndo       : <Key>Undo      \n\
 osfUp         : <Key>Up        \n\
 osfDown       : <Key>Down      ";
 
-char _XmVirtKeys_ibmFallbackBindingString[] = "\
+
+XmConst char _XmVirtKeys_ibmFallbackBindingString[] = "\
 osfAddMode    : Shift<Key>F8   \n\
 osfBackSpace  : <Key>BackSpace \n\
 osfBeginLine  : <Key>Home      \n\
@@ -110,7 +110,8 @@ osfRight      : <Key>Right     \n\
 osfUp         : <Key>Up        \n\
 osfDown       : <Key>Down      ";
 
-char _XmVirtKeys_pcFallbackBindingString[] = "\
+
+XmConst char _XmVirtKeys_pcFallbackBindingString[] = "\
 osfActivate   : <Key>KP_Enter  \n\
 osfAddMode    : Shift<Key>F8   \n\
 osfBackSpace  : <Key>BackSpace \n\
@@ -138,7 +139,8 @@ osfUndo       : <Key>Undo      \n\
 osfUp         : <Key>Up        \n\
 osfDown       : <Key>Down      ";
 
-char _XmVirtKeys_sgiFallbackBindingString[] = "\
+
+XmConst char _XmVirtKeys_sgiFallbackBindingString[] = "\
 osfActivate   : <Key>KP_Enter  \n\
 osfAddMode    : Shift<Key>F8   \n\
 osfBackSpace  : <Key>BackSpace \n\
@@ -157,7 +159,8 @@ osfRight      : <Key>Right     \n\
 osfUp         : <Key>Up        \n\
 osfDown       : <Key>Down      ";
 
-char _XmVirtKeys_sunFallbackBindingString[] = "\
+
+XmConst char _XmVirtKeys_sunFallbackBindingString[] = "\
 osfActivate   : <Key>KP_Enter  \n\
 osfAddMode    : Shift<Key>F8   \n\
 osfBackSpace  : <Key>BackSpace \n\
@@ -255,11 +258,12 @@ static XmVirtualKeysymRec VirtualKeysyms[] =
     {"osfUp", osfXK_Up}
 };				/* VirtualKeysyms */
 
+
 /*
  * Armed with a virtual keysym (one of the osfXK_xxxx keysyms) return the
  * keysym and modifiers, which trigger this virtual keysym.
  */
-void
+extern void
 _XmVirtualToActualKeysym(Display *Dsp,
 			 KeySym VirtualKeysym,
 			 KeySym *RealKeysymReturn,
@@ -403,7 +407,7 @@ static XContext ModifierCacheContext = MCC_None;
  * on the wire. So a XmDisplay widget must trigger the invalidation
  * whenever it sees the notification coming along the wire.
  */
-XmModifierMaskSetReference
+extern XmModifierMaskSetReference
 _XmGetModifierMappingsForDisplay(Display *Dsp)
 {
     XmModifierMaskSetReference ModifierMasks;
@@ -436,6 +440,7 @@ _XmGetModifierMappingsForDisplay(Display *Dsp)
     return ModifierMasks;
 }				/* _XmGetModifierMappingsForDisplay */
 
+
 /*
  * Invalidate any cached modifier mappings for a specific display. The
  * next lookup with _XmGetModifierMappingsForDisplay() will then ask
@@ -444,7 +449,7 @@ _XmGetModifierMappingsForDisplay(Display *Dsp)
  * and a broadcast was send to us. This function is intented for
  * internal use only.
  */
-void
+extern void
 _XmInvalidateModifierMappingsForDisplay(Display *Dsp)
 {
     XmModifierMaskSetReference ModifierMasks;
@@ -472,6 +477,7 @@ _XmInvalidateModifierMappingsForDisplay(Display *Dsp)
     }
 }				/* _XmInvalidateModifierMappingsForDisplay */
 
+
 /*
  * Spit out a warning during conversion of virtual bindings.
  */
@@ -530,6 +536,7 @@ DecomposeWarning(Display *Dsp, String str)
     Identifier[len] = '\0';                                             \
 }
 
+
 /*
  * This proc gets a string specifying a binding and decomposes it into
  * the vendor keysym to be translated and the destination osfkeysym. The
@@ -698,6 +705,7 @@ DecomposeBindingString(Display *Dsp,
     EAT_LINE_AND_RETURN(p);
 }
 
+
 /*
  * Armed with a string full of bindings, this proc creates the binding table
  * for use with a display. The memory for storing the bindings must have
@@ -746,12 +754,13 @@ ParseBindings(Display *Dsp, String Bindings)
     }
 }
 
+
 /*
  * If all fails, install the default bindings... But try to install vendor
  * specific default bindings, if possible. I don't know that the return
  * value is good for -- seems to be zero all the time.
  */
-int
+extern int
 _XmVirtKeysLoadFallbackBindings(Display *Dsp, String *Bindings)
 {
     String VendorString, BindingString;
@@ -776,6 +785,7 @@ _XmVirtKeysLoadFallbackBindings(Display *Dsp, String *Bindings)
     return 0;
 }
 
+
 /*
  * Read in a file containing (hopefuly) bindings for our ******* virtual
  * keysyms. The file is read in chunks of 1k to speed the reading while
@@ -783,7 +793,7 @@ _XmVirtKeysLoadFallbackBindings(Display *Dsp, String *Bindings)
  * (in principle) even read the bindings from a pipe...
  */
 #define QUANTUMLEAPS 1024
-Boolean
+extern Boolean
 _XmVirtKeysLoadFileBindings(String filename, String *binding)
 {
     FILE *fp;
@@ -821,6 +831,7 @@ _XmVirtKeysLoadFileBindings(String filename, String *binding)
     return False;
 }
 
+
 /*
  * This is a helper proc for FindXmBindAliasBinding(). It tries to locate
  * the binding file name and then to load that file.
@@ -1017,6 +1028,7 @@ FindXmBindAliasBindings(Display *Dsp, String *bindingSpec,
     return False;
 }
 
+
 /*
  * Initialize the virtual key bindings for a XmDisplay widget. We will
  * look in a couple of places for binding specifications. If all else fails,
@@ -1179,11 +1191,12 @@ VirtKeysInitialize(Widget w)
     XtFree(bindingSpec);
 }
 
+
 /*
  * This is completely new: refresh the virtual binding stuff on the fly
  * during run-time.
  */
-void
+extern void
 _XmRefreshVirtKeys(Widget w)
 {
     if (!XmIsDisplay(w))
@@ -1197,12 +1210,13 @@ _XmRefreshVirtKeys(Widget w)
     VirtKeysInitialize(w);
 }
 
+
 /*
  * Initialize the virtual key mechanism of a display widget. Although
  * the interface says, that w is any widget, we will handle only display
  * widgets here. Otherwise it would make no sense.
  */
-void
+extern void
 _XmVirtKeysInitialize(Widget w)
 {
     /*
@@ -1221,17 +1235,18 @@ _XmVirtKeysInitialize(Widget w)
     /*
      * Initialize some fields for compatibility reasons...
      */
-    bzero(((XmDisplayRec *)w)->display.keycode_tag, XmKEYCODE_TAG_SIZE);
+    memset(((XmDisplayRec *)w)->display.keycode_tag, 0, XmKEYCODE_TAG_SIZE);
 
     ((XmDisplayRec *)w)->display.lastKeyEvent =
 	(XKeyEvent *)XtMalloc(sizeof(XKeyEvent));
 }
 
+
 /*
  * Cleanup any leftovers from the binding horror when a XmDisplay is
  * getting destroyed.
  */
-void
+extern void
 _XmVirtKeysDestroy(Widget w)
 {
     if (!XmIsDisplay(w))
@@ -1252,6 +1267,7 @@ _XmVirtKeysDestroy(Widget w)
     }
 }
 
+
 /*
  * If we get our hands on some of the dreaded vendor keysyms, we have to
  * convert them to the even more dreaded csf keysyms.
@@ -1324,6 +1340,7 @@ CheckForVirtualKey(Display *Dsp, KeyCode Keycode,
 	Key, CurrentModifiers, *KeysymReturn, BestMods));
 }
 
+
 /*
  * Fortunatly, we can rely on XtTranslateKey() doing most of the work for
  * ordinary key presses: shift (lock) state, upper and lower case, worrying
@@ -1331,7 +1348,7 @@ CheckForVirtualKey(Display *Dsp, KeyCode Keycode,
  * check for an outstanding conversion from a vendor keysym (ordinary
  * keysym) to a virtual keysym.
  */
-void
+extern void
 XmTranslateKey(Display *Dsp, KeyCode Keycode,
 	       Modifiers modifiers, Modifiers *modifiers_return,
 	       KeySym *Keysym_return)
@@ -1369,7 +1386,8 @@ XmTranslateKey(Display *Dsp, KeyCode Keycode,
 #endif
 }
 
-void
+
+extern void
 _XmVirtKeysStoreBindings(Widget shell, String binding)
 {
 }
@@ -1383,7 +1401,7 @@ _XmVirtKeysStoreBindings(Widget shell, String binding)
  * Yes we do. This appears to be the only way to get hold of which
  * modifiers are valid right now (i.e. when the user presses this key).
  */
-void
+extern void
 _XmVirtKeysHandler(Widget w, XtPointer Data, XEvent *Event,
 		   Boolean *ContDispatch)
 {
