@@ -1,8 +1,9 @@
 /**
  *
- * $Id: XmIm.c,v 1.8 1998/09/12 15:05:52 rwscott Exp $
+ * $Id: XmIm.c,v 1.15 2000/11/05 17:25:36 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,21 +23,28 @@
  *
  **/
 
-static const char rcsid[] = "$Id: XmIm.c,v 1.8 1998/09/12 15:05:52 rwscott Exp $";
+static const char rcsid[] = "$Id: XmIm.c,v 1.15 2000/11/05 17:25:36 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
-#include <Xm/XmP.h>
-#include <Xm/VendorSEP.h>
+#include <stdarg.h>
+
 #include <X11/Intrinsic.h>
 #include <X11/Xos.h>
-#include <stdarg.h>
+
+#include <XmI/XmI.h>
+#include <Xm/XmP.h>
+#include <Xm/VendorSEP.h>
+#if XmVERSION > 1
+#include <Xm/XmIm.h>
+#endif
+
 
 #include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
 
+
 /*
  * This file contains I18N (Internationalisation) Input Method handling.
  *
@@ -92,6 +100,8 @@ _XmFindICStuff(Widget w)
     return NULL;
 }
 
+
+
 /*
  * XmImGetXIC creates and registers an XIC with the specified arguments for the
  * widget. If XmINHERIT_POLICY is specified for input_policy, then a new XIC
@@ -107,8 +117,16 @@ _XmFindICStuff(Widget w)
  *
  * Reusing the XIM is possible though.
  */
-XIC
-XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_args)
+
+#if XmVERSION > 1
+#define XmIMInputPolicy XmInputPolicy
+#endif
+
+extern XIC
+XmImGetXIC(Widget w,
+           XmIMInputPolicy input_policy,
+           ArgList args,
+           Cardinal num_args)
 {
     XmVendorShellExtObject v = (XmVendorShellExtObject)_LtFindVendorExt(w);
 
@@ -196,6 +214,12 @@ XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_ar
 		if ((p = XSetLocaleModifiers(buf)) != NULL)
 		{
 		    xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
+
+		    if (xim) {
+			DEBUGOUT(XdbDebug(__FILE__, w,
+			    "XOpenIM succeeded with XSetLocaleModifiers(%s)\n",
+			    buf));
+		    }
 		}
 		XtFree(buf);
 		if (k)
@@ -216,13 +240,23 @@ XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_ar
 	}
 	else
 	{
-	    if ((p = XSetLocaleModifiers("@im=none")) != NULL)
+	    if ((p = XSetLocaleModifiers("@im=none")) != NULL) {
 		xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
+		if (xim) {
+		    DEBUGOUT(XdbDebug(__FILE__, w,
+			"XOpenIM succeeded with XSetLocaleModifiers(%s)\n",
+			"@im=none"));
+		}
+	    }
 	}
 
 	if (xim == NULL && (p = XSetLocaleModifiers("")) != NULL)
 	{
 	    xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
+	    if (xim) {
+		DEBUGOUT(XdbDebug(__FILE__, w,
+			"XOpenIM succeeded with XSetLocaleModifiers('')\n"));
+	    }
 	}
     }
 
@@ -315,17 +349,6 @@ XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_ar
 	return 0;
     }
 
-#if 0
-    if (input_style != (XIMPreeditNothing | XIMStatusNothing)
-	|| input_style != (XIMPreeditNone | XIMStatusNone))
-    {
-	DEBUGOUT(XdbDebug(__FILE__, w,
-		       "XmImRegister: only Root preedit type is supported\n"));
-	XCloseIM(xim);
-	return;
-    }
-#endif
-
     stuff->xim = xim;
 
     if (!XtIsRealized(XtParent(v)))
@@ -365,25 +388,28 @@ XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_ar
  * input processing. The application is responsible for unregistering a widget by
  * calling XmImUnregister.
  */
-void
-XmImRegister(Widget w, unsigned int reserved)
+extern void
+XmImRegister(Widget w,
+             unsigned int reserved)
 {
     XIC xic;
 
     xic = XmImGetXIC(w, IP_PER_SHELL, NULL, 0);
 }
 
+
 /*
  * XmImUnregister removes the specified widget from the list of widgets
  * registered for input by the input manager.
  */
-void
+extern void
 XmImUnregister(Widget w)
 {
     DEBUGOUT(XdbDebug(__FILE__, w,
 		      "XmImUnregister is not implemented yet.\n"));
 }
 
+
 /*
  * XmImSetFocusValues notifies the input manager that the specified widget
  * has received input focus. This function also updates the attributes of
@@ -392,7 +418,7 @@ XmImUnregister(Widget w)
  * registered IC to be reused, that IC will be unregistered, and a new one will
  * be created and registered with the widget.
  */
-void
+extern void
 XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
@@ -406,15 +432,20 @@ XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args)
 
     DEBUGOUT(XdbDebug(__FILE__, w, "XmImSetFocusValues\n"));
 
-    if (stuff->xic)
-    {
+    if (stuff->xic) {
 	XSetICFocus(stuff->xic);
+    } else {
+	XmImRegister(w, 0);
+
+	if (stuff->xic)
+	    XSetICFocus(stuff->xic);
     }
 }
 
+
 /* Varargs interface to the above. */
-void
-XmImVaSetFocusValues(Widget w,...)
+extern void
+XmImVaSetFocusValues(Widget w, ...)
 {
     va_list ap;
     Arg *a;
@@ -445,6 +476,7 @@ XmImVaSetFocusValues(Widget w,...)
     XtFree((XtPointer)a);
 }
 
+
 /*
  * XmImSetValues updates attributes of the input context associated with the
  * specified widget.
@@ -452,8 +484,10 @@ XmImVaSetFocusValues(Widget w,...)
  * registered IC to be reused, that IC will be unregistered, and a new one will
  * be created and registered with the widget.
  */
-void
-XmImSetValues(Widget w, ArgList args, Cardinal num_args)
+extern void
+XmImSetValues(Widget w,
+              ArgList args,
+              Cardinal num_args)
 {
     DEBUGOUT(XdbDebug(__FILE__, w, "XmImSetValues is not implemented yet\n"));
 
@@ -508,9 +542,10 @@ XmImSetValues(Widget w, ArgList args, Cardinal num_args)
 #endif
 }
 
+
 /* Varargs interface to the above. */
-void
-XmImVaSetValues(Widget w,...)
+extern void
+XmImVaSetValues(Widget w, ...)
 {
     va_list ap;
     Arg *a;
@@ -538,14 +573,30 @@ XmImVaSetValues(Widget w,...)
     XtFree((XtPointer)a);
 }
 
+
 /*
  * XmImUnsetFocus unsets a specified widget's focus, then notifies the input
  * manager that the specified widget has lost its input focus.
  */
-void
+extern void
 XmImUnsetFocus(Widget w)
 {
-    XmICStuff *stuff = _XmFindICStuff(w);
+    XmICStuff *stuff;
+
+    if (w == NULL) {
+#ifdef	LESSTIF_VERBOSE
+	_XmWarning(w, "XmImUnsetFocus(NULL)\n");
+#endif
+	return;
+    }
+
+    stuff = _XmFindICStuff(w);
+    if (stuff == NULL) {
+#ifdef	LESSTIF_VERBOSE
+	_XmWarning(w, "XmImUnsetFocus: _XmFindICStuff returned NULL\n");
+#endif
+	return;
+    }
 
     DEBUGOUT(XdbDebug(__FILE__, w, "XmImUnsetFocus\n"));
 
@@ -555,6 +606,7 @@ XmImUnsetFocus(Widget w)
     }
 }
 
+
 /*
  * XmImGetXIM retrieves the XIM data structure representing the input method
  * that the input manager has opened for the specified widget.
@@ -562,7 +614,7 @@ XmImUnsetFocus(Widget w)
  * the first time this routine is called it opens an input method using the
  * XmNinputMethod resource for the VendorShell.
  */
-XIM
+extern XIM
 XmImGetXIM(Widget w)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
@@ -576,14 +628,19 @@ XmImGetXIM(Widget w)
     return NULL;
 }
 
+
 /*
  * XmImMbLookupString returns a string composed in the locale associated with
  * the widget's input method and a KeySym that is currently mapped to the
  * keycode in the KeyPressedEvent.
  */
-int
-XmImMbLookupString(Widget w, XKeyPressedEvent *evp,
-		   char *buf, int nbytes, KeySym *keysym, int *status)
+extern int
+XmImMbLookupString(Widget w,
+                   XKeyPressedEvent *evp,
+                   char *buf,
+                   int nbytes,
+                   KeySym *keysym,
+                   int *status)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
     XIC xic = NULL;
@@ -606,13 +663,15 @@ XmImMbLookupString(Widget w, XKeyPressedEvent *evp,
     return XLookupString(evp, buf, nbytes, keysym, NULL);
 }
 
+
 /*
  * XmImSetXIC registers the X Input Context (XIC) with the specified widget.
  * Any existing XIC registered for the widget is unregistered. The new XIC
  * registered for the widget is returned.
  */
-XIC
-XmImSetXIC(Widget w, XIC xic)
+extern XIC
+XmImSetXIC(Widget w,
+           XIC xic)
 {
     XmVendorShellExtObject v = (XmVendorShellExtObject)_LtFindVendorExt(w);
     XmICStuff *stuff;
@@ -647,6 +706,7 @@ XmImSetXIC(Widget w, XIC xic)
  * Display is closed.
  */
 
+
 /* FIX ME
  * Currently we only tackle stuff under our own shell widget.
  * This is not enough, as the above text (which reflects the Motif 2.0 spec) indicates
@@ -655,7 +715,7 @@ XmImSetXIC(Widget w, XIC xic)
  * This requires the XmDisplay to keep track of top level widgets, or of (Vendor)Shells.
  * FIX ME
  */
-void
+extern void
 XmImCloseXIM(Widget w)
 {
     XmICStuff *stuff;
@@ -678,31 +738,59 @@ XmImCloseXIM(Widget w)
     }
 }
 
+
 /*
  * XmImFreeXIC unregisters all widgets associated with the specified XIC. The
  * specified widget must be specified with the specified XIC.
  */
-void
+extern void
 XmImFreeXIC(Widget w, XIC xic)
 {
 }
 
-void
+
+extern void
 _XmImChangeManaged(Widget w)
 {
 }
 
-void
+
+extern void
 _XmImRealize(Widget w)
 {
 }
 
-void
+
+extern void
 _XmImResize(Widget w)
 {
 }
 
-void
+
+extern void
 _XmImRedisplay(Widget w)
 {
 }
+
+
+extern void
+XmImMbResetIC(Widget widget,
+              char **mb)
+{
+/*
+    XmICStuff *stuff;
+    XIM xim;
+
+    if (!widget)
+    {
+	return;
+    }
+    if ((stuff = _XmFindICStuff(widget)) == NULL)
+    {
+	return;
+    }
+
+    xim = stuff->xim;
+*/
+  _XmWarning(NULL, "XmImMbResetIC() is not yet implemented!");
+}
