@@ -1,8 +1,9 @@
 /**
  *
- * $Id: XmStrDefs.c,v 1.2 1997/07/03 00:53:49 miers Exp $
+ * $Id: XmStrDefs.c,v 1.7 2000/11/09 15:16:42 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,19 +23,24 @@
  *
  **/
 
-#include <LTconfig.h>
-#include <XmI/XmI.h>
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmStrDefs.c,v 1.7 2000/11/09 15:16:42 amai Exp $";
 
-#include <Xm/XmP.h>
-#if XtSpecificationRelease < 6
-#include <X11/IntrinsicP.h>
-#endif
+/*
+ * This file contains the _XmStrings array for Motif 1.2 libXm
+ */
+
+
+#include <LTconfig.h>
+
+/*
+#include <XmI/XmI.h>
+*/
 
 /*
  * The missing commas are intentional.  Let the compiler
  * concatenate the strings
  */
-_XmConst char _XmStrings[] =
+const char _XmStrings[] =
 /* 0     */ "\0"
 /* 1     */ "Accelerator\0"
 /* 13    */ "AcceleratorText\0"
@@ -897,7 +903,5 @@ _XmConst char _XmStrings[] =
 /* 12538 */ "osfUp\0"
 /* 12544 */ "FONTLIST_DEFAULT_TAG_STRING\0"
 /* 12572 */ "XmFONTLIST_DEFAULT_TAG_STRING\0"
-/* 12602 */ "TopItemPosition\0"
-/* 12618 */ "operatingCursorIcon\0"
-/* ????? */ 
-"\0";
+/* 12602 */ "TopItemPosition";
+/* Binary compatibility (or the possibility thereof) demands that nothing else go here */
