@@ -1,8 +1,9 @@
 /*
-
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.50 2000/08/16 10:12:58 amai Exp $
+ *
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.60 2000/11/10 12:40:51 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.50 2000/08/16 10:12:58 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.60 2000/11/10 12:40:51 amai Exp $";
 
 /*
  * ** Danny had added a flag here, but I think the behavior he added is always
@@ -45,22 +46,15 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,
 #include <LTconfig.h>
 
 #include <limits.h>
-#include <XmI/XmI.h>
-#include <XmI/MacrosI.h>
-
-#include <Xm/XmP.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Xfuncs.h>
-
 #include <stdio.h>
 #include <locale.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
+#include <XmI/XmI.h>
+#include <XmI/MacrosI.h>
+#include <Xm/XmP.h>
+#include <X11/IntrinsicP.h>
 #include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
@@ -81,15 +75,12 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,
 #define XmUNSPECIFIED (~0)
 #endif
 
-#define DEBUG	1
 
-/* For the prototype police */
-extern XmFontList XmStringCreateFontList( XFontStruct *font,
-					  XmStringCharSet charset);
-extern XmString XmStringConcatAndFree(XmString str1, XmString str2);
+#undef XMSTRING_DEBUG
 
 /**************************** PRIVATE FUNCTIONS ****************************/
-#ifdef DEBUG
+
+#ifdef XMSTRING_DEBUG
 static int
 asn1_dump(unsigned char *string)
 {
@@ -261,7 +252,8 @@ asn1_dump(unsigned char *string)
     }
 }
 
-extern void
+
+static void
 _Xm_dump_fontlist(XmFontList fontlist)
 {
     int i;
@@ -277,19 +269,22 @@ _Xm_dump_fontlist(XmFontList fontlist)
     printf("\n");
 }
 
-extern void
+
+static void
 _Xm_dump_fontlist_cache(void)
 {
 }
 
-extern void
+
+static void
 _Xm_dump_external(XmString str)
 {
     asn1_dump(str);
     printf("\n");
 }
 
-extern void
+
+static void
 _Xm_dump_internal(_XmString str)
 {
     int i;
@@ -337,7 +332,7 @@ _Xm_dump_internal(_XmString str)
     printf("\n");
 }
 
-#endif
+#endif /* XMSTRING_DEBUG */
 
 static _XmString
 __XmAllocNewXmString(int number_of_components)
@@ -533,7 +528,7 @@ __XmStringFromASN1(XmString string)
 		XmSTRING_COMPONENT_CHARSET;
 
 	    charset = XtMalloc(nlen + 1);
-	    bcopy(&str->data[i], charset, nlen);
+	    memcpy(charset, &str->data[i], nlen);
 	    charset[nlen] = 0;
 	    if (_XmStringIsCurrentCharset(charset))
 	    {
@@ -563,8 +558,8 @@ __XmStringFromASN1(XmString string)
 		nlen;
 	    intern->components[intern->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(&str->data[i],
-		  intern->components[intern->number_of_components - 1]->data,
+	    memcpy(intern->components[intern->number_of_components - 1]->data,
+   	           &str->data[i],
 		  nlen);
 	    intern->components[intern->number_of_components - 1]->data[nlen] = 0;
 
@@ -607,8 +602,8 @@ __XmStringFromASN1(XmString string)
 		nlen;
 	    intern->components[intern->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(&str->data[i],
-		  intern->components[intern->number_of_components - 1]->data,
+	    memcpy(intern->components[intern->number_of_components - 1]->data,
+ 	          &str->data[i],
 		  nlen);
 	    intern->components[intern->number_of_components - 1]->data[nlen] = 0;
 
@@ -807,15 +802,14 @@ __XmStringToASN1(_XmString string)
 		    str->data[j] = tlen & 0x00FFU;
 		    tlen >>= 8;
 		}
-		bcopy(tmp,
-		      &str->data[totlen],
+		memcpy(&str->data[totlen], tmp,
 		      nlen);
 		str = (struct __XmStringExtRec *)&str->data[totlen + nlen];
 	    }
 	    else
 	    {
 		str->len = nlen;
-		bcopy(tmp, str->data, nlen);
+		memcpy(str->data, tmp, nlen);
 		str = (struct __XmStringExtRec *)&str->data[nlen];
 	    }
 	    break;
@@ -838,8 +832,8 @@ __XmStringToASN1(_XmString string)
 		    str->data[j] = nlen & 0x00FFU;
 		    nlen >>= 8;
 		}
-		bcopy(string->components[i]->data,
-		      &str->data[totlen],
+		memcpy(&str->data[totlen],
+ 		      string->components[i]->data,
 		      string->components[i]->length);
 		str = (struct __XmStringExtRec *)&str->data[totlen +
 						string->components[i]->length];
@@ -847,9 +841,9 @@ __XmStringToASN1(_XmString string)
 	    else
 	    {
 		str->len = string->components[i]->length;
-		bcopy(string->components[i]->data,
-		      str->data,
-		      string->components[i]->length);
+		memcpy(str->data,
+ 		       string->components[i]->data,
+		       string->components[i]->length);
 		str = (struct __XmStringExtRec *)&str->data[string->components[i]->length];
 	    }
 	    break;
@@ -873,18 +867,18 @@ __XmStringToASN1(_XmString string)
 		    str->data[j] = nlen & 0x00FFU;
 		    nlen >>= 8;
 		}
-		bcopy(string->components[i]->data,
-		      &str->data[totlen],
-		      string->components[i]->length);
+		memcpy(&str->data[totlen],
+ 		       string->components[i]->data,
+		       string->components[i]->length);
 		str = (struct __XmStringExtRec *)&str->data[totlen +
 						string->components[i]->length];
 	    }
 	    else
 	    {
 		str->len = string->components[i]->length;
-		bcopy(string->components[i]->data,
-		      str->data,
-		      string->components[i]->length);
+		memcpy(str->data,
+		       string->components[i]->data,
+		       string->components[i]->length);
 		str = (struct __XmStringExtRec *)&str->data[string->components[i]->length];
 	    }
 	    break;
@@ -999,7 +993,8 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
 }
 
 /**************************** INTERNAL FUNCTIONS ***************************/
-XFontStruct *
+
+extern XFontStruct *
 _XmGetFirstFont(XmFontListEntry entry)
 {
     XFontStruct **flist;
@@ -1027,7 +1022,8 @@ _XmGetFirstFont(XmFontListEntry entry)
     return NULL;
 }
 
-Boolean
+
+extern Boolean
 _XmFontListGetDefaultFont(XmFontList fontlist,
 			  XFontStruct **font_struct)
 {
@@ -1070,7 +1066,8 @@ _XmFontListGetDefaultFont(XmFontList fontlist,
     return False;
 }
 
-Boolean
+
+extern Boolean
 _XmFontListSearch(XmFontList fontlist,
 		  XmStringCharSet charset,
 		  short *indx,
@@ -1138,7 +1135,7 @@ _XmFontListSearch(XmFontList fontlist,
  *
  * Returns True if the argument is external representation.
  */
-Boolean
+extern Boolean
 _XmStringIsXmString(XmString string)
 {
     struct __XmStringExtRec *str = (struct __XmStringExtRec *)string;
@@ -1169,7 +1166,8 @@ _XmStringIsXmString(XmString string)
     return True;
 }
 
-Boolean
+
+extern Boolean
 _XmStringEmpty(_XmString string)
 {
     int i;
@@ -1192,7 +1190,40 @@ _XmStringEmpty(_XmString string)
     return True;
 }
 
-_XmString
+
+#if XmVERSION >= 2
+
+/*   Helper function for XmStringIsVoid().
+ *   CheckMe !!
+ */
+static Boolean
+_XmStringIsVoid(_XmString string)
+{
+    int i;
+
+    if (string == NULL || string->number_of_components == 0)
+    {
+	return True;
+    }
+
+    for (i = 0; i < string->number_of_components; i++)
+    {
+	if ( (string->components[i]->type == XmSTRING_COMPONENT_TEXT ||
+	      string->components[i]->type == XmSTRING_COMPONENT_LOCALE_TEXT ||
+	      string->components[i]->type == XmSTRING_COMPONENT_SEPARATOR ||
+	      string->components[i]->type == XmSTRING_COMPONENT_TAB) &&
+	    string->components[i]->length != 0)
+	{
+	    return False;
+	}
+    }
+
+    return True;
+}
+#endif /* XmVERSION >= 2 */
+
+
+extern _XmString
 _XmStringCreate(XmString cs)
 {
     if (!cs)
@@ -1203,7 +1234,8 @@ _XmStringCreate(XmString cs)
     return __XmStringFromASN1(cs);
 }
 
-void
+
+extern void
 _XmStringFree(_XmString string)
 {
     int i;
@@ -1240,7 +1272,8 @@ _XmStringFree(_XmString string)
     XtFree((char *)string);
 }
 
-char *
+
+extern char *
 _XmStringGetCurrentCharset(void)
 {
     char *lang, *p;
@@ -1265,13 +1298,15 @@ _XmStringGetCurrentCharset(void)
     return XmFALLBACK_CHARSET;
 }
 
-char *
+
+extern char *
 _XmCharsetCanonicalize(String charset)
 {
     return NULL;
 }
 
-void
+
+extern void
 _XmStringUpdate(XmFontList fontlist, _XmString string)
 {
     short i, where, def, tf;
@@ -1322,7 +1357,8 @@ _XmStringUpdate(XmFontList fontlist, _XmString string)
     }
 }
 
-_XmString
+
+extern _XmString
 _XmStringCopy(_XmString s)
 {
     _XmString newString;
@@ -1343,7 +1379,8 @@ _XmStringCopy(_XmString s)
     return newString;
 }
 
-Boolean
+
+extern Boolean
 _XmStringByteCompare(_XmString a, _XmString b)
 {
     _XmStringContext context1 = NULL;
@@ -1405,7 +1442,8 @@ _XmStringByteCompare(_XmString a, _XmString b)
     return True;
 }
 
-Boolean
+
+extern Boolean
 _XmStringHasSubstring(_XmString string, _XmString substring)
 {
     int i, j, k;
@@ -1474,7 +1512,8 @@ _XmStringHasSubstring(_XmString string, _XmString substring)
     return False;
 }
 
-XmString
+
+extern XmString
 _XmStringCreateExternal(XmFontList fontlist, _XmString cs)
 {
     /* need to change the string maybe, so that if a font doesn't exist
@@ -1487,7 +1526,8 @@ _XmStringCreateExternal(XmFontList fontlist, _XmString cs)
     return __XmStringToASN1(cs);
 }
 
-char *
+
+extern char *
 _XmStringGetTextConcat(XmString string)
 {
     int ilen = 0, len = 0;
@@ -1515,7 +1555,7 @@ _XmStringGetTextConcat(XmString string)
 		len = comp->length;
 		ret = XtRealloc(ret, ilen + len + 1);
 	    }
-	    bcopy(comp->data, &ret[ilen], len);
+	    memcpy(&ret[ilen], comp->data, len);
 	    ret[ilen + len] = 0;
 	    ilen += len;
 	}
@@ -1528,7 +1568,8 @@ _XmStringGetTextConcat(XmString string)
     return ret;
 }
 
-Boolean
+
+extern Boolean
 _XmStringIsCurrentCharset(XmStringCharSet c)
 {
     if (!c)
@@ -1540,7 +1581,8 @@ _XmStringIsCurrentCharset(XmStringCharSet c)
     return strcmp(c, _XmStringGetCurrentCharset()) == 0;
 }
 
-Boolean
+
+extern Boolean
 _XmStringSingleSegment(XmString str, char **pTextOut,
 		       XmStringCharSet *pCharsetOut)
 {
@@ -1575,7 +1617,8 @@ _XmStringSingleSegment(XmString str, char **pTextOut,
  *
  * FIX ME - deal with the font tags as per the above spec.
  */
-void
+
+extern void
 _XmStringUpdateWMShellTitle(XmString xmstr, Widget shell)
 {
     String title = NULL;
@@ -1610,7 +1653,8 @@ _XmStringUpdateWMShellTitle(XmString xmstr, Widget shell)
     }
 }
 
-Boolean
+
+extern Boolean
 _XmStringInitContext(_XmStringContext *context, _XmString string)
 {
     _XmStringContext p;
@@ -1631,7 +1675,8 @@ _XmStringInitContext(_XmStringContext *context, _XmString string)
     }
 }
 
-Boolean
+
+extern Boolean
 _XmStringGetNextSegment(_XmStringContext context,
 			XmStringCharSet *tag,
 			XmStringDirection *direction,
@@ -1749,13 +1794,15 @@ _XmStringGetNextSegment(_XmStringContext context,
     return valid;
 }
 
-void
+
+extern void
 _XmStringFreeContext(_XmStringContext context)
 {
     XtFree((char *)context);
 }
 
-void
+
+extern void
 _XmStringExtent(XmFontList fontlist, _XmString string,
 		Dimension *width, Dimension *height)
 {
@@ -1898,7 +1945,8 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
     _XmStringFreeContext(context);
 }
 
-Dimension
+
+extern Dimension
 _XmStringWidth(XmFontList fontlist, _XmString string)
 {
     Dimension width = 0, dontcare;
@@ -1908,7 +1956,8 @@ _XmStringWidth(XmFontList fontlist, _XmString string)
     return width;
 }
 
-Dimension
+
+extern Dimension
 _XmStringHeight(XmFontList fontlist, _XmString string)
 {
     Dimension height = 0, dontcare;
@@ -1918,7 +1967,8 @@ _XmStringHeight(XmFontList fontlist, _XmString string)
     return height;
 }
 
-Dimension
+
+extern Dimension
 _XmStringBaseline(XmFontList fontlist, _XmString string)
 {
     _XmStringContext context = NULL;
@@ -1956,7 +2006,8 @@ _XmStringBaseline(XmFontList fontlist, _XmString string)
     return current_baseline;
 }
 
-int
+
+extern int
 _XmStringLineCount(_XmString string)
 {
     _XmStringContext context = NULL;
@@ -1988,7 +2039,8 @@ _XmStringLineCount(_XmString string)
     return lc;
 }
 
-void
+
+extern void
 _XmStringDraw(Display *d, Window w, XmFontList fontlist, _XmString string,
 	      GC gc, Position x, Position y, Dimension width,
 	      unsigned char align, unsigned char lay_dir,
@@ -2225,7 +2277,8 @@ _XmStringDraw(Display *d, Window w, XmFontList fontlist, _XmString string,
     }
 }
 
-void
+
+extern void
 _XmStringDrawImage(Display *d, Window w,
 		   XmFontList fontlist, _XmString string,
 		   GC gc, Position x, Position y, Dimension width,
@@ -2452,7 +2505,8 @@ _XmStringDrawImage(Display *d, Window w,
     }
 }
 
-void
+
+extern void
 _XmStringDrawUnderline(Display *d, Window w, XmFontList fontlist,
 		       _XmString string, GC gc,
 		       Position x, Position y, Dimension width,
@@ -2802,7 +2856,8 @@ _XmStringDrawUnderline(Display *d, Window w, XmFontList fontlist,
     }
 }
 
-void
+
+extern void
 _XmStringDrawMnemonic(Display *d,
 		      Window w,
 		      XmFontList fontlist,
@@ -2842,10 +2897,11 @@ _XmStringDrawMnemonic(Display *d,
     _XmStringFree(_und);
 }
 
+
 /* This is essentially _XmStringDraw without the drawing part.
  * It expects baselines to point to memory already allocated.
  */
-void
+extern void
 _XmStringBaselines(XmFontList fontlist, _XmString string, Position y,
 		   Dimension *baselines)
 {
@@ -2955,7 +3011,8 @@ _XmStringBaselines(XmFontList fontlist, _XmString string, Position y,
 }
 
 /************************* PUBLIC FUNCTIONS *****************************/
-Dimension
+
+extern Dimension
 XmStringBaseline(XmFontList fontlist,
 		 XmString string)
 {
@@ -2974,7 +3031,8 @@ XmStringBaseline(XmFontList fontlist,
     return baseline;
 }
 
-Boolean
+
+extern Boolean
 XmStringByteCompare(XmString s1,
 		    XmString s2)
 {
@@ -2997,7 +3055,8 @@ XmStringByteCompare(XmString s1,
     return ret;
 }
 
-Boolean
+
+extern Boolean
 XmStringCompare(XmString s1, XmString s2)
 {
  XmStringContext context1 = NULL, context2 = NULL;
@@ -3062,7 +3121,8 @@ XmStringCompare(XmString s1, XmString s2)
  return True;
 }
 
-XmString
+
+extern XmString
 XmStringConcat(XmString str1, XmString str2)
 {
     _XmString s1, s2;
@@ -3128,7 +3188,8 @@ XmStringConcat(XmString str1, XmString str2)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringCopy(XmString s)
 {
     _XmString s1;
@@ -3147,7 +3208,8 @@ XmStringCopy(XmString s)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringNConcat(XmString s1, XmString s2, int num_bytes)
 {
     _XmString str1, str2;
@@ -3221,9 +3283,9 @@ XmStringNConcat(XmString s1, XmString s2, int num_bytes)
 	    str1->components[str1->number_of_components - 1]->length = nlen;
 	    str1->components[str1->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(str2->components[i]->data,
-		  str1->components[str1->number_of_components - 1]->data,
-		  nlen);
+	    memcpy(str1->components[str1->number_of_components - 1]->data,
+	           str2->components[i]->data,
+		   nlen);
 	    str1->components[str1->number_of_components - 1]->data[nlen] = 0;
 	}
 	else
@@ -3249,9 +3311,9 @@ XmStringNConcat(XmString s1, XmString s2, int num_bytes)
 	    str1->components[str1->number_of_components - 1]->length = nlen;
 	    str1->components[str1->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(str2->components[i]->data,
-		  str1->components[str1->number_of_components - 1]->data,
-		  nlen);
+	    memcpy(str1->components[str1->number_of_components - 1]->data,
+ 	           str2->components[i]->data,
+		   nlen);
 	    str1->components[str1->number_of_components - 1]->data[nlen] = 0;
 	}
 
@@ -3266,7 +3328,8 @@ XmStringNConcat(XmString s1, XmString s2, int num_bytes)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringNCopy(XmString s1, int num_bytes)
 {
     _XmString str1, str2;
@@ -3340,9 +3403,9 @@ XmStringNCopy(XmString s1, int num_bytes)
 	    str1->components[str1->number_of_components - 1]->length = nlen;
 	    str1->components[str1->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(str2->components[i]->data,
-		  str1->components[str1->number_of_components - 1]->data,
-		  nlen);
+	    memcpy(str1->components[str1->number_of_components - 1]->data,
+	           str2->components[i]->data,
+		   nlen);
 	    str1->components[str1->number_of_components - 1]->data[nlen] = 0;
 	}
 	else
@@ -3370,9 +3433,9 @@ XmStringNCopy(XmString s1, int num_bytes)
 	    str1->components[str1->number_of_components - 1]->length = nlen;
 	    str1->components[str1->number_of_components - 1]->data =
 		XtMalloc(nlen + 1);
-	    bcopy(str2->components[i]->data,
-		  str1->components[str1->number_of_components - 1]->data,
-		  nlen);
+	    memcpy(str1->components[str1->number_of_components - 1]->data,
+	           str2->components[i]->data,
+		   nlen);
 	    str1->components[str1->number_of_components - 1]->data[nlen] = 0;
 	}
 
@@ -3387,7 +3450,8 @@ XmStringNCopy(XmString s1, int num_bytes)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringSegmentCreate(char *text,
 		      char *tag,
 		      XmStringDirection direction,
@@ -3468,7 +3532,8 @@ XmStringSegmentCreate(char *text,
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringSeparatorCreate(void)
 {
     _XmString newString = __XmAllocNewXmString(1);
@@ -3484,7 +3549,8 @@ XmStringSeparatorCreate(void)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringDirectionCreate(XmStringDirection direction)
 {
     _XmString newString = __XmAllocNewXmString(1);
@@ -3501,7 +3567,8 @@ XmStringDirectionCreate(XmStringDirection direction)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringCreate(char *text, char *tag)
 {
     _XmString str;
@@ -3538,7 +3605,8 @@ XmStringCreate(char *text, char *tag)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringCreateLtoR(char *text, char *tag)
 {
     XmString ret;
@@ -3657,19 +3725,22 @@ XmStringCreateLtoR(char *text, char *tag)
     return ret;
 }
 
-XmString
+
+extern XmString
 XmStringLtoRCreate(char *text, char *tag)
 {
     return XmStringCreateLtoR(text, tag);
 }
 
-XmString
+
+extern XmString
 XmStringCreateLocalized(char *text)
 {
     return XmStringCreate(text, XmFONTLIST_DEFAULT_TAG);
 }
 
-XmString
+
+extern XmString
 XmStringCreateSimple(char *text)
 {
     _XmString str;
@@ -3697,7 +3768,8 @@ XmStringCreateSimple(char *text)
     return ret;
 }
 
-void
+
+extern void
 XmStringDraw(Display *d,
 	     Window w,
 	     XmFontList fontlist,
@@ -3725,7 +3797,8 @@ XmStringDraw(Display *d,
     _XmStringFree(str);
 }
 
-void
+
+extern void
 XmStringDrawImage(Display *d,
 		  Window w,
 		  XmFontList fontlist,
@@ -3753,13 +3826,14 @@ XmStringDrawImage(Display *d,
     _XmStringFree(str);
 }
 
+
 /*
  * Similar to XmStringDraw, but with an additional parameter
  *
  * If the underline string is contained in string, then that part
  * of string is underlined.
  */
-void
+extern void
 XmStringDrawUnderline(Display *d,
 		      Window w,
 		      XmFontList fontlist,
@@ -3801,7 +3875,8 @@ XmStringDrawUnderline(Display *d,
     _XmStringFree(str);
 }
 
-Boolean
+
+extern Boolean
 XmStringEmpty(XmString s1)
 {
     _XmString str;
@@ -3821,7 +3896,8 @@ XmStringEmpty(XmString s1)
     return ret;
 }
 
-void
+
+extern void
 XmStringExtent(XmFontList fontlist,
 	       XmString string,
 	       Dimension *width,
@@ -3852,11 +3928,12 @@ XmStringExtent(XmFontList fontlist,
 
 }
 
+
 /*
  * according to Motif, this does only return the first segment in a
  * multi-segment string
  */
-Boolean
+extern Boolean
 XmStringGetLtoR(XmString string,
 		XmStringCharSet tag,
 		char **text)
@@ -3909,7 +3986,8 @@ XmStringGetLtoR(XmString string,
     return Found;
 }
 
-void
+
+extern void
 XmStringFree(XmString string)
 {
     if (!_XmStringIsSpecified(string))
@@ -3925,7 +4003,8 @@ XmStringFree(XmString string)
     XtFree((char *)string);
 }
 
-Boolean
+
+extern Boolean
 XmStringInitContext(XmStringContext *context,
 		    XmString string)
 {
@@ -3941,7 +4020,8 @@ XmStringInitContext(XmStringContext *context,
     return True;
 }
 
-XmStringComponentType
+
+extern XmStringComponentType
 XmStringGetNextComponent(XmStringContext context,
 			 char **text,
 			 XmStringCharSet *tag,
@@ -3991,7 +4071,7 @@ XmStringGetNextComponent(XmStringContext context,
 	    *unknown_tag = r->type;
 	    *unknown_length = r->length;
 	    *unknown_value = (unsigned char *)XtMalloc(r->length);
-	    bcopy(r->data, *unknown_value, r->length);
+	    memcpy(*unknown_value, r->data, r->length);
 	    break;
 
 	default:
@@ -4006,7 +4086,8 @@ XmStringGetNextComponent(XmStringContext context,
     }
 }
 
-XmStringComponentType
+
+extern XmStringComponentType
 XmStringPeekNextComponent(XmStringContext context)
 {
     if (context == NULL)
@@ -4024,12 +4105,13 @@ XmStringPeekNextComponent(XmStringContext context)
     }
 }
 
+
 /*
  * Assumption: if you change charsets or directions before a separator,
  * then that is another segment.  I don't know if this is right, but it
  * makes sense? MLM
  */
-Boolean
+extern Boolean
 XmStringGetNextSegment(XmStringContext context,
 		       char **text,
 		       XmStringCharSet *tag,
@@ -4071,7 +4153,8 @@ XmStringGetNextSegment(XmStringContext context,
     return True;
 }
 
-void
+
+extern void
 XmStringFreeContext(XmStringContext context)
 {
     _XmStringFree(context->string);
@@ -4079,7 +4162,8 @@ XmStringFreeContext(XmStringContext context)
     XtFree((char *)context);
 }
 
-Boolean
+
+extern Boolean
 XmStringHasSubstring(XmString string,
 		     XmString substring)
 {
@@ -4102,7 +4186,8 @@ XmStringHasSubstring(XmString string,
     return ret;
 }
 
-Dimension
+
+extern Dimension
 XmStringWidth(XmFontList fontlist,
 	      XmString string)
 {
@@ -4113,7 +4198,8 @@ XmStringWidth(XmFontList fontlist,
     return width;
 }
 
-Dimension
+
+extern Dimension
 XmStringHeight(XmFontList fontlist, XmString string)
 {
     Dimension width, height;
@@ -4123,7 +4209,8 @@ XmStringHeight(XmFontList fontlist, XmString string)
     return height;
 }
 
-int
+
+extern int
 XmStringLength(XmString s1)
 {
     unsigned length, i;
@@ -4161,7 +4248,8 @@ XmStringLength(XmString s1)
     return length + XmSTRING_HEADER_SIZE;
 }
 
-int
+
+extern int
 XmStringLineCount(XmString string)
 {
     _XmString str;
@@ -4181,16 +4269,20 @@ XmStringLineCount(XmString string)
     return lc;
 }
 
+
 /*
- * This sucker appears to be undocumented
+ * This sucker appears to be undocumented.
+ * Literal search in OM docs brings up a thread-safe variant
+ * only 'XmStringCreateFontList_r' !?!
  */
-XmFontList
+extern XmFontList
 XmStringCreateFontList( XFontStruct *font, XmStringCharSet charset)
 {
 	return XmFontListCreate(font, charset);
 }
 
-XmString
+
+extern XmString
 XmStringConcatAndFree(XmString str1, XmString str2)
 {
   XmString tmp;
@@ -4200,13 +4292,14 @@ XmStringConcatAndFree(XmString str1, XmString str2)
   return tmp;
 }
 
-#if XmVERSION > 1
+#if XmVERSION >= 2
+
 /*
  * MxFTP uses this as
  *	item = (char *)XmStringUnparse(tempstr,NULL,XmCHARSET_TEXT,
  *		XmCHARSET_TEXT,NULL,0,XmOUTPUT_ALL);
  */
-XtPointer
+extern XtPointer
 XmStringUnparse(XmString string, XmStringTag tag, XmTextType tag_type,
 	XmTextType output_type, XmParseTable parse_table,
 	Cardinal parse_count, XmParseModel parse_model)
@@ -4262,7 +4355,8 @@ XmStringUnparse(XmString string, XmStringTag tag, XmTextType tag_type,
 				res = realloc(res, strlen(res) + 1 + strlen(comp->data));
 				strcat(res, comp->data);
 			} else {
-				res = strdup(comp->data);
+				res = (char *)malloc(strlen(comp->data)+1);
+				strcpy(res, comp->data);
 			}
 		}
 			
@@ -4279,7 +4373,8 @@ XmStringUnparse(XmString string, XmStringTag tag, XmTextType tag_type,
     return res;
 }
 
-XmString
+
+extern XmString
 XmStringParseText(XtPointer text, XtPointer *text_end, XmStringTag tag,
 	XmTextType type, XmParseTable parse_table, Cardinal parse_count,
 	XtPointer call_data)
@@ -4288,11 +4383,7 @@ XmStringParseText(XtPointer text, XtPointer *text_end, XmStringTag tag,
 }
 
 
-/* the following calls are somehow described on
-   http://www.cs.stedwards.edu/usr/man/info/C/a_doc_lib/motif/motifpg/motifpg70.htm
-*/
-		
-Cardinal
+extern Cardinal
 XmStringToXmStringTable(XmString string, XmString break_comp, XmStringTable *table)
 {
 	
@@ -4300,14 +4391,16 @@ XmStringToXmStringTable(XmString string, XmString break_comp, XmStringTable *tab
 	return (Cardinal)0;
 }
 
-XmString
+
+extern XmString
 XmStringTableToXmString(XmStringTable table, Cardinal count, XmString break_component)
 {
 	_XmWarning(NULL, "XmStringTableToXmString() is not implemented yet!\n");
 	return (XmString)NULL;
 }
 
-XtPointer *
+
+extern XtPointer *
 XmStringTableUnparse(XmStringTable table, Cardinal count, XmStringTag tag,
 	XmTextType tag_type, XmTextType output_type, XmParseTable parse,
 	Cardinal parse_count, XmParseModel parse_model)
@@ -4316,7 +4409,8 @@ XmStringTableUnparse(XmStringTable table, Cardinal count, XmStringTag tag,
 	return (XtPointer *)NULL;
 }
 
-XmStringTable
+
+extern XmStringTable
 XmStringTableParseStringArray(XtPointer *strings, Cardinal count,
 	XmStringTag tag, XmTextType type, XmParseTable parse,
 	Cardinal parse_count, XtPointer call_data)
@@ -4325,49 +4419,53 @@ XmStringTableParseStringArray(XtPointer *strings, Cardinal count,
 	return (XmStringTable)NULL;
 }
 
-XmString
+
+extern XmString
 XmStringPutRendition(XmString string, XmStringTag rendition)
 {
 	_XmWarning(NULL, "XmStringPutRendition() is not implemented yet!\n");
 	return (XmString)NULL;
 }
 
-XmParseMapping
+
+extern XmParseMapping
 XmParseMappingCreate(ArgList  arg_list, Cardinal arg_count)
 {
 	_XmWarning(NULL, "XmParseMappingCreate() is not implemented yet!\n");
 	return (XmParseMapping)NULL;
 }
 
-void
+
+extern void
 XmParseMappingSetValues(XmParseMapping parse_mapping, ArgList arg_list, Cardinal arg_count)
 {
 	_XmWarning(NULL, "XmParseMappingSetValues() is not implemented yet!\n");
 }
 
-void
+
+extern void
 XmParseMappingGetValues(XmParseMapping parse_mapping, ArgList arg_list, Cardinal arg_count)
 {
 	_XmWarning(NULL, "XmParseMappingGetValues() is not implemented yet!\n");
 }
 
-void
+
+extern void
 XmParseMappingFree(XmParseMapping parse_mapping)
 {
 	_XmWarning(NULL, "XmParseMappingFree() is not implemented yet!\n");
 }
 
-void
+
+extern void
 XmParseTableFree(XmParseTable parse_table, Cardinal parse_count)
 {
 	_XmWarning(NULL, "XmParseTableFree() is not implemented yet!\n");
 }
 
-/*  see
-   http://www.cs.stedwards.edu/a_doc_lib/libs/motiftr/XmStringGetNextTriple.htm
-*/
 
-XmStringComponentType XmStringGetNextTriple(XmStringContext context,
+extern XmStringComponentType
+XmStringGetNextTriple(XmStringContext context,
            unsigned int *length,
 	   XtPointer *value)
 {
@@ -4376,4 +4474,73 @@ XmStringComponentType XmStringGetNextTriple(XmStringContext context,
 }
 
 
-#endif
+extern XmString
+XmStringComponentCreate(XmStringComponentType ctype,
+                                 unsigned int length,
+                                 XtPointer value)
+{
+	_XmWarning(NULL, "XmStringComponentCreate() is not implemented yet!\n");
+	return (XmString)NULL;
+}
+
+
+extern XmIncludeStatus
+XmeGetNextCharacter(XtPointer *text_in_out,
+                    XtPointer text_end,
+                    XmTextType type,
+                    XmStringTag tag,
+                    XmParseMapping entry,
+                    int pattern_length,
+                    XmString *str_include,
+                    XtPointer call_data)
+{
+       _XmWarning(NULL, "XmeGetNextCharacter() is not implemented yet!\n");
+       return XmINSERT; /* this is not sufficient to indicate a failure ... */
+}
+
+
+extern XmIncludeStatus
+XmeGetDirection(XtPointer *text_in_out,
+                XtPointer text_end,
+                XmTextType type,
+                XmStringTag tag,
+                XmParseMapping entry,
+                int pattern_length,
+                XmString *str_include,
+                XtPointer call_data)
+{
+       _XmWarning(NULL, "XmeGetDirection() is not implemented yet!\n");
+       return XmINSERT; /* this is not sufficient to indicate a failure ... */
+}
+
+
+extern XmStringComponentType
+XmStringPeekNextTriple(XmStringContext context)
+{
+       _XmWarning(NULL, "XmStringPeekNextTriple() is not implemented yet!\n");
+       return XmSTRING_COMPONENT_UNKNOWN;
+}
+
+
+/* similar structure to XmStringEmpty() */
+extern Boolean
+XmStringIsVoid(XmString s1)
+{
+    _XmString str;
+    Boolean ret;
+
+    if (!_XmStringIsXmString(s1))
+    {
+	return True;
+    }
+
+    str = _XmStringCreate(s1);
+
+    ret = _XmStringIsVoid(str);
+
+    _XmStringFree(str);
+
+    return ret;
+}
+
+#endif /* #if XmVERSION >= 2 */
