@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Xmos.c,v 1.29 2000/08/04 12:02:47 amai Exp $
+ * $Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,81 +23,108 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Xmos.c,v 1.29 2000/08/04 12:02:47 amai Exp $";
+static const char rcsid[] = "$Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $";
 
 #include <LTconfig.h>
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <ctype.h>
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #ifdef TIME_WITH_SYS_TIME
 #include <time.h>
 #endif
 #endif
+#if !defined(HAVE_SLEEP) || !defined(HAVE_USLEEP)
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
+#endif
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
-#include <stdio.h>
-#include <stdlib.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-#include <ctype.h>
-#include <X11/Xfuncproto.h>
 #include <XmI/XmI.h>
-
 #include <Xm/XmP.h>
-#include <X11/Xfuncs.h>
-
-#include <LTglob.h>
 #include <Xm/XmosP.h>
+#include <LTglob.h>
 
 #include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
 
+
+#ifdef __EMX__   /* -> OS/2 drive letters support */
+#define  INCL_DOS
+#define  INCL_DOSMISC
+#define  INCL_ERRORS
+#include <os2.h>
+static const char *GetDriveMap(void); /* local prototype */
+#endif
+
 /*
  * this is OS dependent, but this should catch most OS's.
  */
 #define MAX_PATH_LEN   2048
 
+
+/* some default settings */
+char _XmSDEFAULT_FONT[] = "fixed";
+char _XmSDEFAULT_BACKGROUND[] = "Blue";
+
+
 /*
- * Pauses program execution for a given number of seconds. Although
- * the sillable `Micro' suggest otherwise, the granularity is really
- * only seconds.
- *
- * BTW - Does anyone knows whether we continue sleeping after a
- * signal was raised? I think so, but I'm not sure... --aldi
- *
- * Not so.  There are actually two functions, one for seconds and one
+ * There are actually two functions, one for seconds and one
  * for microseconds.  The semantics are identical to the well-known
  * sleep() and usleep().  Neither continues after a signal.  - Jamie
+ *
+ * amai: Funny, but the often problematic select() call 
+ *       is meanwhile the fallback ...
  */
 
-int
+extern void
 _XmSleep(unsigned int secs)
 {
-    return sleep(secs);
-}
 
-int
-_XmMicroSleep(long secs)
-{
+#ifdef HAVE_SLEEP
+    sleep(secs);
+#else
     struct timeval tv;
 
-    /* usleep() isn't as common as it could be,
-     * so this isn't quite as pointless as _XmSleep.
-     */
-
-    tv.tv_sec = 0;
-    tv.tv_usec = secs;
-    return select(0, NULL, NULL, NULL, &tv);
+    tv.tv_sec  = secs;
+    tv.tv_usec = 0;
+    select(0, NULL, NULL, NULL, &tv);
+#endif
+    return;
 }
 
-XmString
+
+extern int
+_XmMicroSleep(long usecs)
+{
+
+#ifdef HAVE_USLEEP
+    usleep(usecs);
+    return 0;
+#else
+    struct timeval tv;
+
+    tv.tv_sec  = 0;
+    tv.tv_usec = usecs;
+    return select(0, NULL, NULL, NULL, &tv);
+#endif
+}
+
+
+extern XmString
 _XmOSGetLocalizedString(char *reserved,
 			Widget w,
 			String resourceName,
@@ -106,6 +134,18 @@ _XmOSGetLocalizedString(char *reserved,
     return XmStringCreateSimple(value);
 }
 
+
+#if XmVERSION >= 2
+extern XmString
+XmeGetLocalizedString(char *reserved, Widget widget,                                                                                  
+                               char *resource, String string)
+{
+    return _XmOSGetLocalizedString(reserved, widget,
+                                   resource, string);
+}
+#endif
+
+
 /*
  * find the pattern part in a fileSpec
  * Rules I've been able to get out of M*tif
@@ -114,10 +154,10 @@ _XmOSGetLocalizedString(char *reserved,
  * an escaped wildcard, or b) the last component that doesn't end in '/'.
  * 3) Escaped wildcards ('\') will be ignored.
  */
-String
+extern String
 _XmOSFindPatternPart(String fileSpec)
 {
-    static char *wildcards = "*?[]+/";
+    static const char wildcards[] = "*?[]+/";
     String ret, tmp;
 
     /*
@@ -171,10 +211,11 @@ retry:
 
 }
 
-String
+
+extern String
 _XmOSGetHomeDirName(void)
 {
-    static char *home;
+    static char *home=NULL;
 
     /* Only actually check for the directory the first time.
      * We just keep it around for future calls.
@@ -183,23 +224,46 @@ _XmOSGetHomeDirName(void)
     if (!home)
     {
 	char *estr;
-	struct passwd *pw;
 
 	/* First, try the environment.
 	 * If that fails, look in the passwd file.
 	 * If nothing there, return NULL - the caller must handle this.
 	 */
 
-	home = (estr = getenv("HOME"))
-	    ? XtNewString(estr)
-	    : ((estr = getenv("LOGNAME")) && (pw = getpwuid(getuid()))) ||
-	      ((estr = getenv("USER")) && (pw = getpwuid(getuid()))) ||
-	      (pw = getpwuid(getuid()))
-	    ? XtNewString(pw->pw_dir) : "";
+	estr = getenv("HOME");
+	if (estr)
+	   home = XtNewString(estr);
+#if defined(HAVE_GETPWUID) && defined(HAVE_GETUID)
+	else
+	{
+           struct passwd *pw;
+
+           if ((estr = getenv("LOGNAME")) && (pw = getpwuid(getuid())))
+              home = XtNewString(estr);
+           else if ((estr = getenv("USER")) && (pw = getpwuid(getuid())))
+              home = XtNewString(estr);
+           else if ((pw = getpwuid(getuid())))
+              home = XtNewString(pw->pw_dir);
+        }
+#endif
+
+        if (!home)
+           home = XtNewString("");
     }
+
     return home;
 }
 
+
+#if XmVERSION >= 2
+String
+XmeGetHomeDirName(void)
+{
+    return _XmOSGetHomeDirName();
+}
+#endif
+
+
 static Boolean
 startsWithTwiddle(String dir)
 {
@@ -212,6 +276,7 @@ startsWithTwiddle(String dir)
     return *ptr == '~';
 }
 
+
 static String
 convertTwiddle(char *dir)
 {
@@ -234,14 +299,16 @@ convertTwiddle(char *dir)
 	struct passwd *pw;
 
     	name = XtNewString(ptr);
-    	ptr2 = strchr(name, '/');
-    	*ptr2 = '\0';
+      ptr2=strchr(name, '/');
+      if (ptr2) *ptr2='\0';
+#if defined(HAVE_GETPWNAM)
     	pw = getpwnam(name);
     	if (pw)
     	{
 	    home = XtNewString(pw->pw_dir);
     	}
     	else
+#endif
     	{
 	    home = XtNewString("/");
     	}
@@ -262,11 +329,11 @@ convertTwiddle(char *dir)
  * 2) If the dirSpec is all dots, or combinations of dots, the routine will
  * resolve the dots relative to the current directory and return that.
  */
-void
+extern void
 _XmOSQualifyFileSpec(String dirSpec,
-		     String filterSpec,
-		     String *pQualifiedDir,
-		     String *pQualifiedPattern)
+                     String filterSpec,
+                     String *pQualifiedDir,
+                     String *pQualifiedPattern)
 {
     String dir, filt;
     char *tmp, *tmp2;
@@ -276,7 +343,9 @@ _XmOSQualifyFileSpec(String dirSpec,
     if (strlen(dirSpec) == 0 ||
 	strncmp(dirSpec, ".", 1) == 0 || strncmp(dirSpec, "..", 2) == 0)
     {
+#if HAVE_GETCWD
 	if ((tmp = (char *)getcwd(NULL, MAX_PATH_LEN)) == NULL)
+#endif
 	    tmp = XtNewString(_XmOSGetHomeDirName());
 
 	dir = (String)XtMalloc(strlen(tmp) + 1);
@@ -458,6 +527,7 @@ _XmOSQualifyFileSpec(String dirSpec,
     *pQualifiedPattern = filt;
 }
 
+
 /*
  * Takes a string and converts /this/dir/. into /this/dir/
  * also converts /this/dir/.. into /this/
@@ -509,6 +579,7 @@ _XmOSGetDotDot(String s)
     /* else no action */
 }
 
+
 /*
  * does this operate on one dir, or many ? (later) One.
  * Motif apparently does it this way.  If someone can prove otherwise,
@@ -516,7 +587,7 @@ _XmOSGetDotDot(String s)
  * description of the problem.
  * FIX ME -- This is a hack.  It should understand locale (for * mapping).
  */
-void
+extern void
 _XmOSGetDirEntries(String qualifiedDir,
 		   String matchPattern,
 		   unsigned char fileType,
@@ -547,7 +618,7 @@ _XmOSGetDirEntries(String qualifiedDir,
 	if (slash > matchPattern && slash[-1] != '\\')
 	{
 	    tmp = XtMalloc(slash - qualifiedDir + 1);
-	    bcopy(qualifiedDir, tmp, slash - qualifiedDir);
+	    memcpy(tmp, qualifiedDir, slash - qualifiedDir);
 	    tmp[slash - qualifiedDir] = 0;
 	    matchPattern = tmp;
 	}
@@ -578,7 +649,7 @@ _XmOSGetDirEntries(String qualifiedDir,
     DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "_XmOSGetDirEntries -> work on '%s'\n", buf));
 
-    bzero((void *)&result, sizeof(result));
+    memset((void *)&result, 0, sizeof(result));
 
     i = _Lesstif_glob(buf, flags, NULL, &result);
     if (i)
@@ -714,7 +785,8 @@ _XmOSGetDirEntries(String qualifiedDir,
     }
 }
 
-void
+
+extern void
 _XmOSBuildFileList(String dirPath,
 		   String pattern,
 		   unsigned char typeMask,
@@ -847,36 +919,94 @@ _XmOSBuildFileList(String dirPath,
    qsort.
  */
 
-int
+extern int
 _XmOSFileCompare(XmConst void *sp1, XmConst void *sp2)
 {
     return strcmp(*((char **)sp1), *((char **)sp2));
 }
 
 
-char _XmSDEFAULT_FONT[] = "fixed";
-char _XmSDEFAULT_BACKGROUND[] = "Blue";
-
-
-/*
- * ?: Not sure what this thing does but it's rumoured to exist
-   amai: based on a look at some Motif libs I guess it's
-         a 'ghost' induced by typo only ... See below!
-
-void
-XmOSInitPath()
-{
- _XmWarning(NULL, "XmOSInitPath() is not implemented! Please report!");
-}
-*/
-
 /*
  * This one exists in Motif 1.2 (and above?)
-   Probably contrary to XmOSInitPath() ...
  */
-String
+extern String
 _XmOSInitPath(String file_name, String env_pathname, Boolean *user_path)
 {
- _XmWarning(NULL, "_XmOSInitPath() is not yet implemented!");
- return (String)NULL; /* we need a return to keep compiler happy */
+   _XmWarning(NULL, "_XmOSInitPath() is not yet implemented!");
+   return (String)NULL;
 }
+
+
+#if XmVERSION == 1
+
+extern int 
+_XmOSPutenv(String env_string)
+/* amai: "obviously" just a wrapper around a libc's putenv(3) call?! */
+{
+#ifdef HAVE_PUTENV
+   return putenv(env_string);
+#else
+   /* amai: I have no idea how to fake a putenv() call on this
+            level (outside libc or so ...) */
+   _XmWarning(NULL, "_XmOSPutenv() is not implemented on this system!");
+   return -1;
+#endif
+}
+
+
+extern String 
+_XmOSBuildFileName(String a, String b)
+{
+  _XmWarning(NULL, "_XmOSBuildFileName() is not yet implemented!");
+  return (String)NULL;
+}
+
+#endif
+
+
+#ifdef __EMX__
+/*
+   On OS/2 we may need to deal with drive letters.
+   Question is whether this "manual" implementation or
+   libcExt/POSIX2 will be faster in providing this feature ...
+*/
+
+static const char 
+*GetDriveMap(void)
+{
+  /* returns a string containing a list of all drives: e.g. "C: D: E:" */
+
+#define MAXDRIVELETTERS 26
+  static char drivelist[3*MAXDRIVELETTERS +1] = "";
+  static char tmpstr[4] = " : ";
+  ULONG  CurDrive;
+  ULONG  DriveMap;
+  int    dnum;
+  int    start = 3;  /* this should correspond to a hard coded limit
+                        to 'C', i.e. no check for floppy disk ?! */
+  static const char offset = 'A' -1;
+  char *retstr;
+
+  /* DosError(0); */
+
+  DosQueryCurrentDisk(&CurDrive, &DriveMap);
+  DriveMap>>=start-1;
+  for (dnum = start; dnum <= MAXDRIVELETTERS; dnum++) {
+     if ((DriveMap & (ULONG)1)) {
+        tmpstr[0] = (char)dnum + offset;
+        strcat(drivelist, tmpstr);
+     }
+      DriveMap>>=1; 
+  } /* for dnum */
+
+  /* cosmetics: strip trailing blank: */ 
+  if (drivelist[strlen(drivelist)-1]== ' ')
+    drivelist[strlen(drivelist)-1] = '\0';
+
+  /* DosError(1); */
+
+  retstr=(char *)malloc(strlen(drivelist)+1);
+  strcpy(retstr, drivelist);
+  return retstr;
+}
+#endif /* __EMX__ */
