@@ -49,6 +49,11 @@ patch.
 Widget GXCreateFileBox(Widget parent);
 Widget menubar,button;
 
+static char *FallBack[] = {
+		"*.geometrySlop: 0",
+		NULL
+};
+
 Widget GXTopWidget, GXClipBox;
 int main(int argc, char **argv)
 {
@@ -57,13 +62,14 @@ int main(int argc, char **argv)
   make_tmp_dir_tree();
 
   GXTopWidget= XtVaAppInitialize(&theApp, "test1", NULL, 0, &argc, argv,
-				 NULL, NULL); 
+				 FallBack, NULL); 
   label = XmCreateLabel(GXTopWidget, "Label", NULL, 0);
   XtManageChild(label);
   XtManageChild(GXCreateFileBox(GXTopWidget));
   XtRealizeWidget(GXTopWidget);
 
   
+    
 {
     static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,   57,   73,   34,   17, 0,0,0, /* Label */ 
@@ -98,7 +104,7 @@ GXCreateFileBox(Widget parent)
     n = 0;
     /* XtSetArg(args[n], XmNdialogStyle, XmDIALOG_APPLICATION_MODAL);  n++; */
     filew = XmCreateFileSelectionDialog(parent, "FileBox", args, n);
-    XtAddCallback(filew,XmNcancelCallback, CancelCB, NULL);
+    XtAddCallback(filew,XmNcancelCallback, (XtCallbackProc)CancelCB, NULL);
     set_path(filew);
     /* these calls are here to force the menu bar to the top, but it fails
        under lesstif */
