@@ -4,6 +4,7 @@
 #include <Xm/TextF.h>
 #include <Xm/Form.h>
 #include <Xm/RowColumn.h>
+#include <Xm/FileSBP.h>
 #include <Xm/FileSB.h>
 #include <Xm/PushB.h>
 #include <Xm/Frame.h>
@@ -14,6 +15,11 @@ XmQualifyProc (*defaultQualifyProc)();
 Widget In;
 Widget Out;
 
+static char *FallBack[] = {
+		"*.geometrySlop: 0",
+		NULL
+};
+
 static void
 StuffInt(Widget w, int value)
 {
@@ -76,7 +82,7 @@ StuffValues(Widget w, Widget In, XmFileSelectionBoxCallbackStruct *in)
 	StuffXmString(XtNameToWidget(In, "*pattern_Text"), in->pattern);
 }
 
-static XmQualifyProc 
+static void
 myQualifyProc(Widget w, XmFileSelectionBoxCallbackStruct *in, XmFileSelectionBoxCallbackStruct *out)
 {
 	printf("------ IN -----\n");
@@ -257,7 +263,7 @@ main(int argc, char **argv)
 
   make_tmp_dir_tree();
   toplevel = XtVaAppInitialize(&app, "FSBQualifyTest", NULL, 0,
- 		               &argc, argv, NULL, NULL);
+ 		               &argc, argv, FallBack, NULL);
   XtVaSetValues(toplevel,
   	XmNallowShellResize, True,
   	NULL);
@@ -274,7 +280,7 @@ main(int argc, char **argv)
   XtSetArg(args[n], XmNeditable, False); n++;
   Out = CreateFSBcallbackStruct(Form, "Out", args, n);
   Qualify = XmCreatePushButton(Form, "Qualify", NULL, 0);
-  XtAddCallback(Qualify, XmNactivateCallback, (void *)QualifyCallback, NULL);
+  XtAddCallback(Qualify, XmNactivateCallback, (XtCallbackProc)QualifyCallback, NULL);
 
   XtVaSetValues(Qualify,
   	XmNleftAttachment, XmATTACH_FORM,
@@ -329,7 +335,6 @@ main(int argc, char **argv)
   	NULL);
   }
 
-
   {
     static XtWidgetGeometry Expected[] = {
       CWWidth | CWHeight            ,    6,   22,  808,  420, 0,0,0, /* MainForm */
@@ -367,11 +372,11 @@ main(int argc, char **argv)
       CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern_length */
       CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_length_Text */
       CWWidth | CWHeight | CWX | CWY,  262,   10,  284,  400, 0,0,0, /* FSB */
-      CWWidth | CWHeight | CWX | CWY,  136,   68,  137,   17, 0,0,0, /* Items */
-      CWWidth | CWHeight | CWX | CWY,  136,   85,  137,  182, 0,0,0, /* ItemsListSW */
-      CWWidth | CWHeight | CWX | CWY,  122,    0,   15,  163, 0,0,0, /* VertScrollBar */
-      CWWidth | CWHeight | CWX | CWY,    0,  167,  118,   15, 0,0,0, /* HorScrollBar */
-      CWWidth | CWHeight | CWX | CWY,    0,    0,  118,  163, 0,0,0, /* ItemsList */
+      CWWidth | CWHeight | CWX | CWY,  190,   68,   83,   17, 0,0,0, /* Items */
+      CWWidth | CWHeight | CWX | CWY,  190,   85,   83,  182, 0,0,0, /* ItemsListSW */
+      CWWidth | CWHeight | CWX | CWY,   68,    0,   15,  163, 0,0,0, /* VertScrollBar */
+      CWWidth | CWHeight | CWX | CWY,    0,  167,   64,   15, 0,0,0, /* HorScrollBar */
+      CWWidth | CWHeight | CWX | CWY,    0,    0,   64,  163, 0,0,0, /* ItemsList */
       CWWidth | CWHeight | CWX | CWY,   10,  277,  264,   17, 0,0,0, /* Selection */
       CWWidth | CWHeight | CWX | CWY,   10,  294,  264,   31, 0,0,0, /* Text */
       CWWidth | CWHeight | CWX | CWY,    0,  335,  284,    2, 0,0,0, /* Separator */
@@ -380,12 +385,12 @@ main(int argc, char **argv)
       CWWidth | CWHeight | CWX | CWY,  142,  347,   66,   43, 0,0,0, /* Cancel */
       CWWidth | CWHeight | CWX | CWY,  208,  347,   66,   43, 0,0,0, /* Help */
       CWWidth | CWHeight | CWX | CWY,   10,   10,  264,   17, 0,0,0, /* FilterLabel */
-      CWWidth | CWHeight | CWX | CWY,   10,   68,  116,   17, 0,0,0, /* Dir */
+      CWWidth | CWHeight | CWX | CWY,   10,   68,  170,   17, 0,0,0, /* Dir */
       CWWidth | CWHeight | CWX | CWY,   10,   27,  264,   31, 0,0,0, /* FilterText */
-      CWWidth | CWHeight | CWX | CWY,   10,   85,  116,  182, 0,0,0, /* DirListSW */
-      CWWidth | CWHeight | CWX | CWY,  101,    0,   15,  163, 0,0,0, /* VertScrollBar */
-      CWWidth | CWHeight | CWX | CWY,    0,  167,   97,   15, 0,0,0, /* HorScrollBar */
-      CWWidth | CWHeight | CWX | CWY,    0,    0,   97,  163, 0,0,0, /* DirList */
+      CWWidth | CWHeight | CWX | CWY,   10,   85,  170,  182, 0,0,0, /* DirListSW */
+      CWWidth | CWHeight | CWX | CWY,  155,    0,   15,  163, 0,0,0, /* VertScrollBar */
+      CWWidth | CWHeight | CWX | CWY,    0,  167,  151,   15, 0,0,0, /* HorScrollBar */
+      CWWidth | CWHeight | CWX | CWY,    0,    0,  151,  163, 0,0,0, /* DirList */
       CWWidth | CWHeight | CWX | CWY,  556,   10,  242,  365, 0,0,0, /* Out */
       CWWidth | CWHeight | CWX | CWY,   56,    0,  130,   17, 0,0,0, /* Output CallbackStruct */
       CWWidth | CWHeight | CWX | CWY,    5,   17,  232,  343, 0,0,0, /* Out */
@@ -424,7 +429,6 @@ main(int argc, char **argv)
     /* toplevel should be replaced with to correct applicationShell */
     PrintDetails(toplevel, Expected);
   }
-  LessTifTestMainLoop(toplevel);
-
+LessTifTestMainLoop(toplevel);
   exit(0);
 }
