@@ -7,7 +7,9 @@
 #include <Xm/Text.h>
 #include <Xm/RowColumn.h>
 
-#include "DumpLayout.h"
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 
 Widget	form, toplevel, deleteButton, dbDescFileTf, dbFileTf, DBOptionMenu, dbNameTf, dbList;
 
@@ -736,28 +738,28 @@ int main(int argc, char **argv)
 
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,              0,  	0,	500,	504, 0,0,0,	/* ConfigureWindow */
-  	CWWidth | CWHeight | CWX | CWY,383,	160,	99,	30, 0,0,0,	/* moveDownButton */
-  	CWWidth | CWHeight | CWX | CWY,259,	160,	99,	30, 0,0,0,	/* moveUpButton */
-  	CWWidth | CWHeight | CWX | CWY, 10,	160,	99,	30, 0,0,0,	/* addDBButton */
-  	CWWidth | CWHeight | CWX | CWY,	10,	200,	482,	20, 0,0,0,	/* separator2 */
-  	CWWidth | CWHeight | CWX | CWY,	134,	160,	100,	30, 0,0,0,	/* deleteButton */
-  	CWWidth | CWHeight | CWX | CWY,	10,	426,	480,	20,0,0,0,	/* separator1 */
-  	CWWidth | CWHeight | CWX | CWY,	222,	380,	268,	36,0,0,0,	/* dbDescFileTf */
-  	CWWidth | CWHeight | CWX | CWY,	222,	332,	268,	36,0,0,0,	/* dbFileTf */
-  	CWWidth | CWHeight | CWX | CWY,	10,	383,	200,	43,0,0,0,	/* label5 */
-  	CWWidth | CWHeight | CWX | CWY,	10,	331,	202,	42,0,0,0,	/* label4 */
-  	CWWidth | CWHeight | CWX | CWY,	10,	280,	202,	41,0,0,0,	/* label3 */
-  	CWWidth | CWHeight | CWX | CWY,	222,	280,	268,	31,0,0,0,	/* optionMenu1 */
-  	CWWidth | CWHeight | CWX | CWY,	3,	3,	10,	25,0,0,0,	/* OptionLabel */
-  	CWWidth | CWHeight | CWX | CWY,	16,	3,	103,	25,0,0,0,	/* OptionButton */
-  	CWWidth | CWHeight | CWX | CWY,	222,	230,	268,	36,0,0,0,	/* dbNameTf */
-  	CWWidth | CWHeight | CWX | CWY,	10,	230,	202,	40,0,0,0,	/* label2 */
-  	CWWidth | CWHeight | CWX | CWY,	10,	50,	481,	100,0,0,0,	/* scrolledWindow1 */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	481,	100,0,0,0,	/* dbList */
-  	CWWidth | CWHeight | CWX | CWY,	10,	10,	101,	30,0,0,0,	/* label1 */
-  	CWWidth | CWHeight | CWX | CWY,	230,	456,	115,	31,0,0,0,	/* cancelButton */
-  	CWWidth | CWHeight | CWX | CWY,	20,	456,	115,	31,0,0,0,	/* applyButton */
+  	{CWWidth | CWHeight,              0,  	0,	500,	504, 0,0,0,	/* ConfigureWindow */},
+  	{CWWidth | CWHeight | CWX | CWY,383,	160,	99,	30, 0,0,0,	/* moveDownButton */},
+  	{CWWidth | CWHeight | CWX | CWY,259,	160,	99,	30, 0,0,0,	/* moveUpButton */},
+  	{CWWidth | CWHeight | CWX | CWY, 10,	160,	99,	30, 0,0,0,	/* addDBButton */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	200,	482,	20, 0,0,0,	/* separator2 */},
+  	{CWWidth | CWHeight | CWX | CWY,	134,	160,	100,	30, 0,0,0,	/* deleteButton */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	426,	480,	20,0,0,0,	/* separator1 */},
+  	{CWWidth | CWHeight | CWX | CWY,	222,	380,	268,	36,0,0,0,	/* dbDescFileTf */},
+  	{CWWidth | CWHeight | CWX | CWY,	222,	332,	268,	36,0,0,0,	/* dbFileTf */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	383,	200,	43,0,0,0,	/* label5 */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	331,	202,	42,0,0,0,	/* label4 */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	280,	202,	41,0,0,0,	/* label3 */},
+  	{CWWidth | CWHeight | CWX | CWY,	222,	280,	268,	31,0,0,0,	/* optionMenu1 */},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	3,	10,	25,0,0,0,	/* OptionLabel */},
+  	{CWWidth | CWHeight | CWX | CWY,	16,	3,	103,	25,0,0,0,	/* OptionButton */},
+  	{CWWidth | CWHeight | CWX | CWY,	222,	230,	268,	36,0,0,0,	/* dbNameTf */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	230,	202,	40,0,0,0,	/* label2 */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	50,	481,	100,0,0,0,	/* scrolledWindow1 */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	481,	100,0,0,0,	/* dbList */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	10,	101,	30,0,0,0,	/* label1 */},
+  	{CWWidth | CWHeight | CWX | CWY,	230,	456,	115,	31,0,0,0,	/* cancelButton */},
+  	{CWWidth | CWHeight | CWX | CWY,	20,	456,	115,	31,0,0,0,	/* applyButton */},
 };
 
   PrintDetails(toplevel, Expected);
