@@ -6,6 +6,8 @@
 #include <Xm/FormP.h>
 #include <Xm/Label.h>
 
+#define IGNORE_TEMPVALUE
+
 static char *FallBack[] =
 {
     "*.borderWidth: 1",
@@ -16,7 +18,14 @@ extern int GlobalErrors;
 
 /* Fake Form sub-class */
 /* Fake FormP.h */
-typedef enum {FormConstraint, ConstraintInitialize, ConstraintSetValues, GeometryManager, ChangeManaged, QueryGeometry} ExpectedType;
+typedef enum {FormConstraint, 
+	      ConstraintInitialize, 
+	      ConstraintSetValues, 
+	      GeometryManager, 
+	      ChangeManaged, 
+	      QueryGeometry,
+	      Geometry
+} ExpectedType;
 
 typedef struct {
     ExpectedType type;
@@ -60,6 +69,10 @@ typedef struct {
 
     Dimension form_width;
     Dimension form_height;
+
+    unsigned long request_mode;
+    Position geox, geoy;
+    Dimension geowidth, geoheight, geoborder_width;
 } ExpectedResults;
 
 typedef struct {
@@ -269,12 +282,84 @@ Type2String(ExpectedType type)
     case QueryGeometry:
     	return("QueryGeometry");
     	break;
+    case Geometry:
+    	return("Geometry");
+    	break;
     default:
     	return("UNKNOWN");
     	break;
     }
 }
 
+static void
+PrintGeometry(Widget w, XtWidgetGeometry *geo)
+{
+FakeFormWidget Form = (FakeFormWidget)(w);
+
+    if (Form->fake_form.expected_index < Form->fake_form.expected_count)
+    {
+	printf("%s(%s) ", Type2String(Geometry), Type2String(Form->fake_form.expected[Form->fake_form.expected_index].type));
+	if (Form->fake_form.expected[Form->fake_form.expected_index].type != Geometry)
+	{
+	    printf("Bad\n");
+	    GlobalErrors++;
+	}
+	else
+	{
+	XtWidgetGeometry tmp;
+
+	    printf("%s(", XdbWidgetGeometry2String(geo));
+    tmp.request_mode = Form->fake_form.expected[Form->fake_form.expected_index].request_mode;
+    tmp.x = Form->fake_form.expected[Form->fake_form.expected_index].geox;
+    tmp.y = Form->fake_form.expected[Form->fake_form.expected_index].geoy;
+    tmp.width = Form->fake_form.expected[Form->fake_form.expected_index].geowidth;
+    tmp.height = Form->fake_form.expected[Form->fake_form.expected_index].geoheight;
+	    printf("%s", XdbWidgetGeometry2String(&tmp));
+	    printf(") ");
+	    if (geo->request_mode == Form->fake_form.expected[Form->fake_form.expected_index].request_mode &&
+	        (!(geo->request_mode & CWX) || (geo->request_mode & CWX && geo->x == Form->fake_form.expected[Form->fake_form.expected_index].geox)) &&
+	        (!(geo->request_mode & CWY) || (geo->request_mode & CWY && geo->y == Form->fake_form.expected[Form->fake_form.expected_index].geoy)) &&
+	        (!(geo->request_mode & CWWidth) || (geo->request_mode & CWWidth && geo->width == Form->fake_form.expected[Form->fake_form.expected_index].geowidth)) &&
+	        (!(geo->request_mode & CWHeight) || (geo->request_mode & CWHeight && geo->height == Form->fake_form.expected[Form->fake_form.expected_index].geoheight)) &&
+	        (!(geo->request_mode & CWBorderWidth) || (geo->request_mode & CWBorderWidth && geo->border_width == Form->fake_form.expected[Form->fake_form.expected_index].geoborder_width))
+	        )
+	    {
+		printf("Okay\n");
+	    }
+	    else
+	    {
+		printf("Bad\n");
+		GlobalErrors++;
+	    }
+	}
+	Form->fake_form.expected_index++;
+    }
+    else
+    {
+	printf("{Geometry, \"%s\", %i, %i, %i, %i, ", XtName(w), XtX(w), XtY(w), XtWidth(w), XtHeight(w));
+	printf("0, \"\", 0,0,0,0,");
+	printf("0, \"\", 0,0,0,0,");
+	printf("0, \"\", 0,0,0,0,");
+	printf("0, \"\", 0,0,0,0,");
+
+	printf("\"\", False, False, 0, 0, %d, %d, ", XtWidth(w), XtHeight(w));
+	printf("0 | ");
+	printf("%s", geo->request_mode & CWX ? "CWX | " : "");
+	printf("%s", geo->request_mode & CWY ? "CWY | " : "");
+	printf("%s", geo->request_mode & CWWidth ? "CWWidth | " : "");
+	printf("%s", geo->request_mode & CWHeight ? "CWHeight | " : "");
+	printf("%s", geo->request_mode & CWBorderWidth ? "CWBorderWidth | " : "");
+	printf("%s", geo->request_mode & CWSibling ? "CWSibling | " : "");
+	printf("%s", geo->request_mode & CWStackMode ? "CWStackMode | " : "");
+	printf("0,");
+	printf(" %d, %d,", geo->request_mode & CWX ? geo->x : 0, geo->request_mode & CWY ? geo->y : 0);
+	printf(" %d,", geo->request_mode & CWWidth ? geo->width : 0);
+	printf(" %d,", geo->request_mode & CWHeight ? geo->height : 0);
+	printf(" %d", geo->request_mode & CWBorderWidth ? geo->border_width : 0);
+	printf("},\n");
+    }
+}
+
 static void
 PrintConstraints(Widget w)
 {
@@ -329,8 +414,11 @@ FakeFormWidget Form = (FakeFormWidget)XtParent(w);
 	    	strcmp(constraints->att[0].w ?  XtName(constraints->att[0].w) : "" , Form->fake_form.expected[Form->fake_form.expected_index].left_widget) != 0 ||
 	    	constraints->att[0].percent != Form->fake_form.expected[Form->fake_form.expected_index].left_percent ||
 	    	constraints->att[0].offset != Form->fake_form.expected[Form->fake_form.expected_index].left_offset ||
-	    	constraints->att[0].value != Form->fake_form.expected[Form->fake_form.expected_index].left_value /*||
-	    	constraints->att[0].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].left_tempValue*/)
+	    	constraints->att[0].value != Form->fake_form.expected[Form->fake_form.expected_index].left_value
+#ifndef IGNORE_TEMPVALUE
+	    	|| constraints->att[0].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].left_tempValue
+#endif
+	    	)
 	    {
 		printf("Bad\n");
 		GlobalErrors++;
@@ -362,7 +450,10 @@ FakeFormWidget Form = (FakeFormWidget)XtParent(w);
 #else
 	    	constraints->att[1].value != Form->fake_form.expected[Form->fake_form.expected_index].right_value
 #endif
-	    	/*constraints->att[1].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].right_tempValue*/)
+#ifndef IGNORE_TEMPVALUE
+	    	|| constraints->att[1].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].right_tempValue
+#endif
+	    	)
 	    {
 		printf("Bad\n");
 		GlobalErrors++;
@@ -385,8 +476,11 @@ FakeFormWidget Form = (FakeFormWidget)XtParent(w);
 	    	strcmp(constraints->att[2].w ?  XtName(constraints->att[2].w) : "" , Form->fake_form.expected[Form->fake_form.expected_index].top_widget) != 0 ||
 	    	constraints->att[2].percent != Form->fake_form.expected[Form->fake_form.expected_index].top_percent ||
 	    	constraints->att[2].offset != Form->fake_form.expected[Form->fake_form.expected_index].top_offset ||
-	    	constraints->att[2].value != Form->fake_form.expected[Form->fake_form.expected_index].top_value /*||
-	    	constraints->att[2].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].top_tempValue*/)
+	    	constraints->att[2].value != Form->fake_form.expected[Form->fake_form.expected_index].top_value
+#ifndef IGNORE_TEMPVALUE
+	    	|| constraints->att[2].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].top_tempValue
+#endif
+	    	)
 	    {
 		printf("Bad\n");
 		GlobalErrors++;
@@ -417,7 +511,10 @@ FakeFormWidget Form = (FakeFormWidget)XtParent(w);
 #else
 	    	constraints->att[3].value != Form->fake_form.expected[Form->fake_form.expected_index].bottom_value
 #endif
-	    	/*constraints->att[3].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].bottom_tempValue*/)
+#ifndef IGNORE_TEMPVALUE
+	    	|| constraints->att[3].tempValue != Form->fake_form.expected[Form->fake_form.expected_index].bottom_tempValue
+#endif
+	    	)
 	    {
 		printf("Bad\n");
 		GlobalErrors++;
@@ -636,6 +733,7 @@ static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
 {
 XtGeometryResult result;
+int i;
 FakeFormWidget Form = (FakeFormWidget)(w);
 
     printf("/* query_geometry - begin %s */\n", XtName(w));
@@ -656,7 +754,21 @@ FakeFormWidget Form = (FakeFormWidget)(w);
     {
 	printf("{QueryGeometry},\n");
     }
+    printf("/* proposed (%s) desired (%s) */\n", XdbWidgetGeometry2String(proposed), XdbWidgetGeometry2String(desired));
+    PrintGeometry(w, proposed);
+    PrintGeometry(w, desired);
+    for (i = 0; i < ((CompositeWidget)(w))->composite.num_children; i++)
+    {
+	PrintConstraints(((CompositeWidget)(w))->composite.children[i]);
+    }
     result = (((CompositeWidgetClass)XtClass(w)->core_class.superclass)->core_class.query_geometry)(w, proposed, desired);
+    for (i = 0; i < ((CompositeWidget)(w))->composite.num_children; i++)
+    {
+	PrintConstraints(((CompositeWidget)(w))->composite.children[i]);
+    }
+    PrintGeometry(w, proposed);
+    PrintGeometry(w, desired);
+    printf("/* proposed (%s) desired (%s) result (%s) */\n", XdbWidgetGeometry2String(proposed), XdbWidgetGeometry2String(desired), XdbGeometryResult2String(result));
     printf("/* query_geometry - end   %s */\n", XtName(w));
     return(result);
 }
@@ -983,6 +1095,20 @@ main(int argc, char **argv)
 /* request (x 1) reply (GEOMETRY_NO_FIELDS) answer No */
 /* geometry_manager - end   MyForm TopLabelTopLabel */
 /* 0 errors */
+/* query_geometry - begin MyForm */
+{QueryGeometry},
+/* proposed (GEOMETRY_NO_FIELDS) desired (GEOMETRY_NO_FIELDS) */
+{Geometry, "MyForm", 0, 0, 204, 61, 0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,"", False, False, 0, 0, 204, 61, 0 | 0, 0, 0, 0, 0, 0},
+{Geometry, "MyForm", 0, 0, 204, 61, 0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,"", False, False, 0, 0, 204, 61, 0 | 0, 0, 0, 0, 0, 0},
+{FormConstraint, "TopLabelTopLabel", 0, 0, 202, 17, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_FORM, "", 0, 65535, 204, 102, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_NONE, "", 0, 65535, 19, 61, "BottomLabel", True, True, 100, 17, 204, 61},
+{FormConstraint, "BottomLabel", 0, 19, 100, 40, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_FORM, "", 0, 65535, 102, 102, XmATTACH_WIDGET, "TopLabelTopLabel", 0, 65535, 19, 19, XmATTACH_FORM, "", 0, 65535, 61, 61, "", True, True, 70, 40, 204, 61},
+{FormConstraint, "TopLabelTopLabel", 0, 0, 202, 17, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_FORM, "", 0, 65535, 204, 102, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_NONE, "", 0, 65535, 19, 19, "BottomLabel", True, True, 100, 17, 204, 61},
+{FormConstraint, "BottomLabel", 0, 19, 100, 40, XmATTACH_FORM, "", 0, 65535, 0, 0, XmATTACH_FORM, "", 0, 65535, 102, 102, XmATTACH_WIDGET, "TopLabelTopLabel", 0, 65535, 19, 19, XmATTACH_FORM, "", 0, 65535, 61, 61, "", True, True, 70, 40, 204, 61},
+{Geometry, "MyForm", 0, 0, 204, 61, 0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,"", False, False, 0, 0, 204, 61, 0 | 0, 0, 0, 0, 0, 0},
+{Geometry, "MyForm", 0, 0, 204, 61, 0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,0, "", 0,0,0,0,"", False, False, 0, 0, 204, 61, 0 | CWWidth | CWHeight | 0, 0, 0, 102, 19, 0},
+/* proposed (GEOMETRY_NO_FIELDS) desired (w 102 h 19) result (Almost) */
+/* query_geometry - end   MyForm */
+/* 0 errors */
 };
 
     XtSetLanguageProc(NULL, NULL, NULL);
@@ -1024,6 +1150,7 @@ main(int argc, char **argv)
     XtManageChild(Form);
     XtRealizeWidget(Shell);
   LessTifTestWaitForIt(Shell);
+#if 1
   XtVaSetValues(BottomLabel,
   	XmNtopAttachment, XmATTACH_NONE,
   	NULL);
@@ -1067,6 +1194,22 @@ main(int argc, char **argv)
   XtVaSetValues(TopLabel,
 		  XmNbottomAttachment, XmATTACH_NONE,
 		  NULL);
+#endif
+#if 1
+  LessTifTestWaitForIt(Shell);
+	{
+	Dimension width;
+	XtWidgetGeometry geo;
+
+	    XtVaGetValues(Shell,
+	    	XmNwidth, &width,
+	    	NULL);
+	    XtVaSetValues(Shell,
+	    	XmNwidth, 2 * width,
+	    	NULL);
+	    XtQueryGeometry(Form, NULL, &geo);
+	}
+#endif
 #endif
   printf("/* %i errors */\n", GlobalErrors);
     LessTifTestMainLoop(Shell);
