@@ -3,7 +3,9 @@
 #include <Xm/PushB.h>
 #include <Xm/Form.h>
 
-#include "DumpLayout.h"
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 
 int
 main(int argc, char **argv)
@@ -40,16 +42,16 @@ main(int argc, char **argv)
   XtRealizeWidget(top);
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	90,	75,	0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	30,	0,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	60,	0,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	25,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	30,	25,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	60,	25,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	50,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	30,	50,	30,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	60,	50,	30,	25,	0,0,0,	/* two */
+  	{CWWidth | CWHeight,		0,	0,	90,	75,	0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	30,	0,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	0,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	25,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	30,	25,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	25,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	50,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	30,	50,	30,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	50,	30,	25,	0,0,0,	/* two */},
 };
 
   PrintDetails(top, Expected);
