@@ -7,7 +7,9 @@
 #include <Xm/TextF.h>
 #include <Xm/SeparatoG.h>
 
-#include "DumpLayout.h"
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 
 void Push(Widget w, XtPointer client, XtPointer call)
 {
@@ -141,33 +143,34 @@ void Push(Widget w, XtPointer client, XtPointer call)
 	XtManageChild(fd);
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	406,	72,	0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	406,	72,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	2,	2,	402,	68,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	10,	14,	82,	17,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	92,	0,	310,	31,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	41,	402,	2,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	43,	402,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	8,	0,	89,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	105,	0,	92,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	205,	0,	93,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	306,	0,	88,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	406,	72,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	2,	2,	402,	68,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	10,	14,	82,	17,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	92,	0,	310,	31,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	41,	402,	2,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	43,	402,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	8,	0,	89,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	105,	0,	92,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	205,	0,	93,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	306,	0,	88,	25,	0,0,0,	/* two */
+  	{CWWidth | CWHeight,		0,	0,	406,	72,	0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	406,	72,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	2,	2,	402,	68,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	14,	82,	17,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	92,	0,	310,	31,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	41,	402,	2,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	43,	402,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	8,	0,	89,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	105,	0,	92,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	205,	0,	93,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	306,	0,	88,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	406,	72,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	2,	2,	402,	68,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	10,	14,	82,	17,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	92,	0,	310,	31,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	41,	402,	2,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	43,	402,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	8,	0,	89,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	105,	0,	92,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	205,	0,	93,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	306,	0,	88,	25,	0,0,0,	/* two */},
 };
 
   PrintDetails(fd, Expected);
   }
 }
 
+/*
 static void
 StructureNotifyHandler(Widget w, Boolean *mapped, XEvent *event, Boolean *cont)
 {
@@ -183,6 +186,7 @@ StructureNotifyHandler(Widget w, Boolean *mapped, XEvent *event, Boolean *cont)
 		break;
 	}
 }
+*/
 
 /*
 void LessTifTestPushButton(Widget w)
