@@ -21,6 +21,9 @@
 #include <Xm/RCUtilsP.h>
 #include <Xm/PushB.h>
 
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 void
 resize(Widget w, XtPointer a, XtPointer b)
 {
@@ -105,12 +108,12 @@ main(int argc, char **argv)
 
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	60,	143,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	3,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	31,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	59,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	87,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	115,	54,	25,	0,0,0,
+  	{CWWidth | CWHeight,		0,	0,	60,	143,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	3,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	31,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	59,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	87,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	115,	54,	25,	0,0,0,},
 };
 
   PrintDetails(toplevel, Expected);
