@@ -56,7 +56,24 @@ main(int argc, char **argv)
   XtAddCallback(b, XmNactivateCallback, Doit, NULL);
 
   XtRealizeWidget(toplevel);
-  XtAppMainLoop(app);
 
+  
+
+/* Note: the following values are the result of
+ * querying the current geometry.
+ */
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,  317,  334,  179,  141, 0,0,0, /* rc */
+   CWWidth | CWHeight | CWX | CWY,   10,   10,  138,   31, 0,0,0, /* tf */
+   CWWidth | CWHeight | CWX | CWY,  150,   10,   18,   25, 0,0,0, /* b */
+   CWWidth | CWHeight | CWX | CWY,   10,   50,  100,   80, 0,0,0, /* textSW */
+   CWWidth | CWHeight | CWX | CWY,    0,   65,  100,   15, 0,0,0, /* HorScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,  100,   61, 0,0,0, /* text */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+LessTifTestMainLoop(toplevel);
   exit(0);
 }
