@@ -1,9 +1,8 @@
-/* $Id: test15.c,v 1.5 2000/08/25 13:38:55 amai Exp $ */
-/**---------------------------------------------------------------
-***-------------------------------------------------------------------*/
-
+/* $Id: test15.c,v 1.6 2000/09/02 13:40:43 amai Exp $ */
+/** --------------------------------------------------------------- **/
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <ctype.h>
 
 #include <Xm/TextP.h>
@@ -2419,6 +2418,3 @@ int	main	(
 #endif
 	return 0;
 	}
-
-
-
