@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Test.c,v 1.27 2000/02/13 12:43:31 rwscott Exp $
+ * $Id: Test.c,v 1.31 2000/11/09 15:24:02 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -24,6 +25,8 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
+
 #include <X11/X.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
@@ -34,9 +37,14 @@
 
 int GlobalErrors = 0;
 
-static Time SynthTime = 0;
-
+/* local prototypes */
+static void Initialize(Widget w);
 static void Delay(Widget w);
+static void Exit(Widget w);
+static void Popup(Widget w, Boolean *mapped, XEvent *event);
+static void TimeOut(Boolean *mapped);
+static void LessTifTestPrintEvent(Widget w, XEvent *event);
+static void LessTifTestProcessEvent(Widget w);
 
 typedef struct
 {
@@ -45,9 +53,7 @@ typedef struct
     int geometrySlop;
     Boolean printEvents;
     String dumpOnFailureFile;
-}
-AppResources_t, *AppResourcesPtr;
-
+} AppResources_t, *AppResourcesPtr;
 static AppResources_t AppResources;
 
 static XtResource resources[] =
@@ -61,7 +67,7 @@ static XtResource resources[] =
 
 /* ************** */
 
-char *
+const char *
 XdbGeometryResult2String(XtGeometryResult r)
 {
     switch (r)
@@ -85,7 +91,7 @@ XdbGeometryResult2String(XtGeometryResult r)
 
 /* ************** */
 
-char *
+extern const char *
 XdbWidgetGeometry2String(XtWidgetGeometry *g)
 {
     static char o1[128], o2[128], b[20], *out = NULL;
@@ -171,7 +177,7 @@ Initialize(Widget w)
 
 /* ************** */
 
-int
+extern int
 LessTifTestGetSlop(Widget w)
 {
     Initialize(w);
@@ -180,7 +186,7 @@ LessTifTestGetSlop(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestSetSlop(Widget w, int slop)
 {
     Initialize(w);
@@ -192,9 +198,9 @@ LessTifTestSetSlop(Widget w, int slop)
 static void
 Exit(Widget w)
 {
-    Display *display = 
+/*    Display *display = 
       XtIsSubclass(w,coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
-    XtAppContext app_context=XtWidgetToApplicationContext(w);
+    XtAppContext app_context=XtWidgetToApplicationContext(w); */
 
     /* destroy application and reclaim memory */ 
 
@@ -408,7 +414,7 @@ TimeOut(Boolean *mapped)
 
 /* ************** */
 
-void
+extern void
 LessTifTestDelay(Widget w, unsigned long interval)
 {
     Boolean mapped = False;
@@ -432,7 +438,7 @@ Delay(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestFlushEvents(Widget w)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -448,7 +454,8 @@ LessTifTestFlushEvents(Widget w)
 
 /* ************** */
 
-void LessTifTestPrintEvents(Widget w, Boolean flag)
+extern void
+LessTifTestPrintEvents(Widget w, Boolean flag)
 {
 	LessTifTestFlushEvents(w);
 	AppResources.printEvents = flag;
@@ -456,7 +463,7 @@ void LessTifTestPrintEvents(Widget w, Boolean flag)
 
 /* ************** */
 
-int
+extern int
 LessTifTestResizeWidget(Widget w, Dimension wt, Dimension ht)
 {
     Dimension bw;
@@ -472,7 +479,7 @@ LessTifTestResizeWidget(Widget w, Dimension wt, Dimension ht)
 
 /* ************** */
 
-int
+extern int
 LessTifTestWaitForIt(Widget w)
 {
     XWindowAttributes window_attributes;
@@ -500,7 +507,7 @@ LessTifTestWaitForIt(Widget w)
 
 /* ************** */
 
-int
+extern int
 LessTifTestMainLoop(Widget w)
 {
     Initialize(w);
@@ -529,7 +536,7 @@ LessTifTestMainLoop(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestWarpPointerAbove(Widget w)
 {
     Dimension width, height;
@@ -554,7 +561,7 @@ LessTifTestWarpPointerAbove(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestWarpPointer(Widget w)
 {
     Dimension width, height;
@@ -579,7 +586,7 @@ LessTifTestWarpPointer(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestKeyRelease(Widget w, KeySym keysym, unsigned int state)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -616,21 +623,16 @@ LessTifTestKeyRelease(Widget w, KeySym keysym, unsigned int state)
 		  &keys_buttons);
     event = (XEvent*)&key_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = SynthTime;
-    SynthTime += 200;
-    XSendEvent(display, key_event.window /*PointerWindow*/, True, KeyReleaseMask, event);
-    /*
-    key_event.type = KeyRelease;
-    key_event.window = XtWindow(XtParent(w));
+    event->xbutton.time = XtLastTimestampProcessed(display);
+    LessTifTestDelay(w, 200);
     XSendEvent(display, key_event.window, True, KeyReleaseMask, event);
-    */
     LessTifTestFlushEvents(w);
     Delay(w);
 }
 
 /* ************** */
 
-void
+extern void
 LessTifTestKeyPress(Widget w, KeySym keysym, unsigned int state)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -667,21 +669,16 @@ LessTifTestKeyPress(Widget w, KeySym keysym, unsigned int state)
 		  &keys_buttons);
     event = (XEvent*)&key_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = SynthTime;
-    SynthTime += 200;
-    XSendEvent(display, InputFocus /*PointerWindow*/, True, KeyPressMask, event);
-    /*
-    key_event.type = KeyRelease;
-    key_event.window = XtWindow(XtParent(w));
-    XSendEvent(display, key_event.window, True, KeyReleaseMask, event);
-    */
+    event->xbutton.time = XtLastTimestampProcessed(display);
+    LessTifTestDelay(w, 200);
+    XSendEvent(display, InputFocus, True, KeyPressMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
 }
 
 /* ************** */
 
-void
+extern void
 LessTifTestKeysym(Widget w, KeySym keysym)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -717,19 +714,19 @@ LessTifTestKeysym(Widget w, KeySym keysym)
 		  &keys_buttons);
     event = (XEvent*)&key_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = SynthTime;
-    SynthTime += 200;
-    XSendEvent(display, InputFocus /*PointerWindow*/, True, KeyPressMask, event);
+    event->xbutton.time = XtLastTimestampProcessed(display);
+    LessTifTestDelay(w, 200);
+    XSendEvent(display, InputFocus, True, KeyPressMask, event);
     key_event.type = KeyRelease;
     key_event.window = XtWindow(XtParent(w));
-    XSendEvent(display, key_event.window /*PointerWindow*/, True, KeyReleaseMask, event);
+    XSendEvent(display, key_event.window, True, KeyReleaseMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
 }
 
 /* ************** */
 
-void
+extern void
 LessTifTestEsc(Widget w)
 {
     LessTifTestKeysym(w, XK_Escape);
@@ -737,7 +734,7 @@ LessTifTestEsc(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtnDown(Widget w, int button)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -773,8 +770,8 @@ LessTifTestBtnDown(Widget w, int button)
 		  &keys_buttons);
     event = (XEvent*)&button_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = SynthTime;
-    SynthTime += 200;
+    event->xbutton.time = XtLastTimestampProcessed(display);
+    LessTifTestDelay(w, 200);
     XSendEvent(display, PointerWindow, True, ButtonPressMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
@@ -782,7 +779,7 @@ LessTifTestBtnDown(Widget w, int button)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtnUp(Widget w, int button)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -833,8 +830,8 @@ LessTifTestBtnUp(Widget w, int button)
 		  &keys_buttons);
     event = (XEvent*)&button_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = SynthTime;
-    SynthTime += 200;
+    event->xbutton.time = XtLastTimestampProcessed(display);
+    LessTifTestDelay(w, 200);
     XSendEvent(display, PointerWindow, True, ButtonReleaseMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
@@ -842,7 +839,7 @@ LessTifTestBtnUp(Widget w, int button)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn1Down(Widget w)
 {
     LessTifTestBtnDown(w, 1);
@@ -850,7 +847,7 @@ LessTifTestBtn1Down(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn1Up(Widget w)
 {
     LessTifTestBtnUp(w, 1);
@@ -858,7 +855,7 @@ LessTifTestBtn1Up(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn2Down(Widget w)
 {
     LessTifTestBtnDown(w, 2);
@@ -866,7 +863,7 @@ LessTifTestBtn2Down(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn2Up(Widget w)
 {
     LessTifTestBtnUp(w, 2);
@@ -874,7 +871,7 @@ LessTifTestBtn2Up(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn3Down(Widget w)
 {
     LessTifTestBtnDown(w, 3);
@@ -882,7 +879,7 @@ LessTifTestBtn3Down(Widget w)
 
 /* ************** */
 
-void
+extern void
 LessTifTestBtn3Up(Widget w)
 {
     LessTifTestBtnUp(w, 3);
@@ -890,7 +887,7 @@ LessTifTestBtn3Up(Widget w)
 
 /* ************** */
 
-int
+extern int
 LessTifTestPushButton(Widget w)
 {
     Initialize(w);
